/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

/* using ShadowStackFrameworkGCTransformer */
#define MALLOC_ZERO_FILLED 0
#define _CFFI_INTERNAL
#define _GNU_SOURCE 1
#include <stdlib.h>
#include <src/signals.h>
#include <sys/time.h>
#include <src/thread.h>
#include <sys/mman.h>
#include <time.h>
#include <errno.h>
#include <sys/select.h>
#include <sys/types.h>
#include <unistd.h>
#include <sys/resource.h>
#include <sys/timeb.h>
#include <src/stacklet/stacklet.h>
#include <stdio.h>
#include <sys/wait.h>
#include <utime.h>
#include <sys/times.h>
#include <grp.h>
#include <dirent.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <signal.h>
#include <sys/utsname.h>
#include <pty.h>
#include <src/dtoa.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/poll.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>
#include <net/if.h>
#include <zlib.h>
#include <bzlib.h>
#include <src/cjkcodecs/multibytecodec.h>
#include <openssl/ssl.h>
#include <openssl/err.h>
#include <openssl/rand.h>
#include <openssl/evp.h>
#include <openssl/ossl_typ.h>
#include <openssl/x509v3.h>
#include <openssl/comp.h>
#include <dlfcn.h>
#include <expat.h>
#include <limits.h>
#include <semaphore.h>
#include <locale.h>
#include <ctype.h>
#include <wchar.h>
#include <langinfo.h>
#include <libintl.h>
#include <Python.h>
#include <sys/epoll.h>
#include <parse_c_type.h>
#include <sys/statvfs.h>
#include <stdarg.h>
#include <structmember.h>
#include <ffi.h>
#include <curses.h>
#include <term.h>
#include <string.h>
#include <assert.h>
#include <sys/prctl.h>
#include </builddir/build/BUILD/pypy-5.0.1-src/pypy/module/operator/tscmp.h>
#include <sys/file.h>
#include <termios.h>
#include <pwd.h>
#define RPY_WITH_GIL
RPY_EXTERN int get_errno ();
RPY_EXTERN void set_errno (int v);

static void pypy__decay_jit_counters(char *data, double f1, long size) {
    struct rpy_jitcnt { float times[5]; unsigned short subhashes[5]; };
    struct rpy_jitcnt *p = (struct rpy_jitcnt *)data;
    float f = (float)f1;
    long i;
    for (i=0; i<size; i++) {
        p->times[0] *= f;
        p->times[1] *= f;
        p->times[2] *= f;
        p->times[3] *= f;
        p->times[4] *= f;
        ++p;
    }
}

#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/poll.h>
#include <sys/select.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <errno.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>
#include <net/if.h>

#ifdef AF_NETLINK
#include <linux/netlink.h>
#endif

#define pypy_GENERAL_NAME_dirn(name) (name->d.dirn)
#define pypy_GENERAL_NAME_uri(name) (name->d.uniformResourceIdentifier)
#define pypy_GENERAL_NAME_pop_free(names) (sk_GENERAL_NAME_pop_free(names, GENERAL_NAME_free))
#define pypy_X509_OBJECT_data_x509(obj) (obj->data.x509)
#define pypy_DIST_POINT_fullname(obj) (obj->distpoint->name.fullname)
#define PYPY_NO_OP()
#define rpython_flush_icache()  asm("isync":::"memory")


#define pypy__is_nonnull_longdouble(x)  ((x) != 0.0)


static void *pypy__cffi_fetch_var(void *fetch_addr) {
    return ((void*(*)(void))fetch_addr)();
}


static unsigned long pypy__rotateLeft(unsigned long x, long n) {
    unsigned int x1 = x;    /* arithmetic directly on int */
    int n1 = n;
    return (x1 << n1) | (x1 >> (32-n1));
}

RPY_EXTERN PyObject *pypy_static_pyobjs[];
RPY_EXPORTED PyTypeObject PyArray_Type;
RPY_EXPORTED PyTypeObject PyBaseObject_Type;
RPY_EXPORTED PyTypeObject PyBaseString_Type;
RPY_EXPORTED PyTypeObject PyBool_Type;
RPY_EXPORTED PyTypeObject PyByteArray_Type;
RPY_EXPORTED PyTypeObject PyCFunction_Type;
RPY_EXPORTED PyTypeObject PyCell_Type;
RPY_EXPORTED PyTypeObject PyClass_Type;
RPY_EXPORTED PyTypeObject PyComplex_Type;
RPY_EXPORTED PyTypeObject PyDict_Type;
RPY_EXPORTED PyTypeObject _PyExc_ArithmeticError;
RPY_EXPORTED PyTypeObject _PyExc_AssertionError;
RPY_EXPORTED PyTypeObject _PyExc_AttributeError;
RPY_EXPORTED PyTypeObject _PyExc_BaseException;
RPY_EXPORTED PyTypeObject _PyExc_BufferError;
RPY_EXPORTED PyTypeObject _PyExc_BytesWarning;
RPY_EXPORTED PyTypeObject _PyExc_DeprecationWarning;
RPY_EXPORTED PyTypeObject _PyExc_EOFError;
RPY_EXPORTED PyTypeObject _PyExc_EnvironmentError;
RPY_EXPORTED PyTypeObject _PyExc_Exception;
RPY_EXPORTED PyTypeObject _PyExc_FloatingPointError;
RPY_EXPORTED PyTypeObject _PyExc_FutureWarning;
RPY_EXPORTED PyTypeObject _PyExc_GeneratorExit;
RPY_EXPORTED PyTypeObject _PyExc_IOError;
RPY_EXPORTED PyTypeObject _PyExc_ImportError;
RPY_EXPORTED PyTypeObject _PyExc_ImportWarning;
RPY_EXPORTED PyTypeObject _PyExc_IndentationError;
RPY_EXPORTED PyTypeObject _PyExc_IndexError;
RPY_EXPORTED PyTypeObject _PyExc_KeyError;
RPY_EXPORTED PyTypeObject _PyExc_KeyboardInterrupt;
RPY_EXPORTED PyTypeObject _PyExc_LookupError;
RPY_EXPORTED PyTypeObject _PyExc_MemoryError;
RPY_EXPORTED PyTypeObject _PyExc_NameError;
RPY_EXPORTED PyTypeObject _PyExc_NotImplementedError;
RPY_EXPORTED PyTypeObject _PyExc_OSError;
RPY_EXPORTED PyTypeObject _PyExc_OverflowError;
RPY_EXPORTED PyTypeObject _PyExc_PendingDeprecationWarning;
RPY_EXPORTED PyTypeObject _PyExc_ReferenceError;
RPY_EXPORTED PyTypeObject _PyExc_RuntimeError;
RPY_EXPORTED PyTypeObject _PyExc_RuntimeWarning;
RPY_EXPORTED PyTypeObject _PyExc_StandardError;
RPY_EXPORTED PyTypeObject _PyExc_StopIteration;
RPY_EXPORTED PyTypeObject _PyExc_SyntaxError;
RPY_EXPORTED PyTypeObject _PyExc_SyntaxWarning;
RPY_EXPORTED PyTypeObject _PyExc_SystemError;
RPY_EXPORTED PyTypeObject _PyExc_SystemExit;
RPY_EXPORTED PyTypeObject _PyExc_TabError;
RPY_EXPORTED PyTypeObject _PyExc_TypeError;
RPY_EXPORTED PyTypeObject _PyExc_UnboundLocalError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeDecodeError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeEncodeError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeTranslateError;
RPY_EXPORTED PyTypeObject _PyExc_UnicodeWarning;
RPY_EXPORTED PyTypeObject _PyExc_UserWarning;
RPY_EXPORTED PyTypeObject _PyExc_ValueError;
RPY_EXPORTED PyTypeObject _PyExc_Warning;
RPY_EXPORTED PyTypeObject _PyExc_ZeroDivisionError;
RPY_EXPORTED PyTypeObject PyFloat_Type;
RPY_EXPORTED PyTypeObject PyFrozenSet_Type;
RPY_EXPORTED PyTypeObject PyInt_Type;
RPY_EXPORTED PyTypeObject PyList_Type;
RPY_EXPORTED PyTypeObject PyLong_Type;
RPY_EXPORTED PyTypeObject PyMemoryView_Type;
RPY_EXPORTED PyTypeObject PyModule_Type;
RPY_EXPORTED PyTypeObject PyNone_Type;
RPY_EXPORTED PyTypeObject PyNotImplemented_Type;
RPY_EXPORTED PyTypeObject PyProperty_Type;
RPY_EXPORTED PyTypeObject PySet_Type;
RPY_EXPORTED PyTypeObject PySlice_Type;
RPY_EXPORTED PyTypeObject PyStaticMethod_Type;
RPY_EXPORTED PyTypeObject PyString_Type;
RPY_EXPORTED PyTypeObject PyTuple_Type;
RPY_EXPORTED PyTypeObject PyType_Type;
RPY_EXPORTED PyTypeObject PyUnicode_Type;
RPY_EXPORTED PyTypeObject PyWrapperDescr_Type;
RPY_EXPORTED PyObject _Py_EllipsisObject;
RPY_EXPORTED PyObject _Py_NoneStruct;
RPY_EXPORTED PyObject _Py_NotImplementedStruct;
RPY_EXPORTED PyIntObject _Py_TrueStruct;
RPY_EXPORTED PyIntObject _Py_ZeroStruct;

RPY_EXTERN PyObject ** get_pypy_static_pyobjs ();

static float pypy__uint2singlefloat(unsigned int x) {
    float ff;
    assert(sizeof(float) == 4 && sizeof(unsigned int) == 4);
    memcpy(&ff, &x, 4);
    return ff;
}
static unsigned int pypy__singlefloat2uint(float x) {
    unsigned int ii;
    assert(sizeof(float) == 4 && sizeof(unsigned int) == 4);
    memcpy(&ii, &x, 4);
    return ii;
}

RPY_EXTERN int _PyPy_SSL_SetupThreads(void);

/* If we have an old Linux kernel (or compile with old system headers),
   the following two macros are not defined.  But we would still like
   a pypy translated on such a system to run on a more modern system. */
#ifndef PR_SET_PTRACER
#  define PR_SET_PTRACER 0x59616d61
#endif
#ifndef PR_SET_PTRACER_ANY
#  define PR_SET_PTRACER_ANY ((unsigned long)-1)
#endif
static void pypy__allow_attach(void) {
    prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY);
}

RPY_EXTERN char ** get_environ ();
RPY_EXTERN void set_environ (char ** v);
extern char ** environ;
char ** get_environ () { return environ; }
void set_environ (char ** v) { environ = v; }
