/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/poll.h>
#include <sys/select.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <errno.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>
#include <net/if.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/poll.h>
#include <sys/select.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netinet/tcp.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <netdb.h>
#include <arpa/inet.h>
#include <stdint.h>
#include <errno.h>
#include <netpacket/packet.h>
#include <sys/ioctl.h>
#include <net/if.h>

#ifdef AF_NETLINK
#include <linux/netlink.h>
#endif


#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_AD_DECnet(void) {
#ifdef AD_DECnet
	dump("defined", 1);
	if ((AD_DECnet) <= 0) {
	    long long x = (long long)(AD_DECnet);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AD_DECnet);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_AAL5(void) {
#ifdef AF_AAL5
	dump("defined", 1);
	if ((AF_AAL5) <= 0) {
	    long long x = (long long)(AF_AAL5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_AAL5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_APPLETALK(void) {
#ifdef AF_APPLETALK
	dump("defined", 1);
	if ((AF_APPLETALK) <= 0) {
	    long long x = (long long)(AF_APPLETALK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_APPLETALK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_ASH(void) {
#ifdef AF_ASH
	dump("defined", 1);
	if ((AF_ASH) <= 0) {
	    long long x = (long long)(AF_ASH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ASH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_ATMPVC(void) {
#ifdef AF_ATMPVC
	dump("defined", 1);
	if ((AF_ATMPVC) <= 0) {
	    long long x = (long long)(AF_ATMPVC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ATMPVC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_ATMSVC(void) {
#ifdef AF_ATMSVC
	dump("defined", 1);
	if ((AF_ATMSVC) <= 0) {
	    long long x = (long long)(AF_ATMSVC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ATMSVC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_AX25(void) {
#ifdef AF_AX25
	dump("defined", 1);
	if ((AF_AX25) <= 0) {
	    long long x = (long long)(AF_AX25);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_AX25);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_BLUETOOTH(void) {
#ifdef AF_BLUETOOTH
	dump("defined", 1);
	if ((AF_BLUETOOTH) <= 0) {
	    long long x = (long long)(AF_BLUETOOTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_BLUETOOTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_BRIDGE(void) {
#ifdef AF_BRIDGE
	dump("defined", 1);
	if ((AF_BRIDGE) <= 0) {
	    long long x = (long long)(AF_BRIDGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_BRIDGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_ECONET(void) {
#ifdef AF_ECONET
	dump("defined", 1);
	if ((AF_ECONET) <= 0) {
	    long long x = (long long)(AF_ECONET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ECONET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_INET(void) {
#ifdef AF_INET
	dump("defined", 1);
	if ((AF_INET) <= 0) {
	    long long x = (long long)(AF_INET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_INET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_INET6(void) {
#ifdef AF_INET6
	dump("defined", 1);
	if ((AF_INET6) <= 0) {
	    long long x = (long long)(AF_INET6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_INET6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_IPX(void) {
#ifdef AF_IPX
	dump("defined", 1);
	if ((AF_IPX) <= 0) {
	    long long x = (long long)(AF_IPX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_IPX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_IRDA(void) {
#ifdef AF_IRDA
	dump("defined", 1);
	if ((AF_IRDA) <= 0) {
	    long long x = (long long)(AF_IRDA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_IRDA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_KEY(void) {
#ifdef AF_KEY
	dump("defined", 1);
	if ((AF_KEY) <= 0) {
	    long long x = (long long)(AF_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_LLC(void) {
#ifdef AF_LLC
	dump("defined", 1);
	if ((AF_LLC) <= 0) {
	    long long x = (long long)(AF_LLC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_LLC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_NETBEUI(void) {
#ifdef AF_NETBEUI
	dump("defined", 1);
	if ((AF_NETBEUI) <= 0) {
	    long long x = (long long)(AF_NETBEUI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_NETBEUI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_NETLINK(void) {
#ifdef AF_NETLINK
	dump("defined", 1);
	if ((AF_NETLINK) <= 0) {
	    long long x = (long long)(AF_NETLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_NETLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_NETROM(void) {
#ifdef AF_NETROM
	dump("defined", 1);
	if ((AF_NETROM) <= 0) {
	    long long x = (long long)(AF_NETROM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_NETROM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_PACKET(void) {
#ifdef AF_PACKET
	dump("defined", 1);
	if ((AF_PACKET) <= 0) {
	    long long x = (long long)(AF_PACKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_PACKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_PPPOX(void) {
#ifdef AF_PPPOX
	dump("defined", 1);
	if ((AF_PPPOX) <= 0) {
	    long long x = (long long)(AF_PPPOX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_PPPOX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_ROSE(void) {
#ifdef AF_ROSE
	dump("defined", 1);
	if ((AF_ROSE) <= 0) {
	    long long x = (long long)(AF_ROSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ROSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_ROUTE(void) {
#ifdef AF_ROUTE
	dump("defined", 1);
	if ((AF_ROUTE) <= 0) {
	    long long x = (long long)(AF_ROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_ROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_SECURITY(void) {
#ifdef AF_SECURITY
	dump("defined", 1);
	if ((AF_SECURITY) <= 0) {
	    long long x = (long long)(AF_SECURITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_SECURITY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_SNA(void) {
#ifdef AF_SNA
	dump("defined", 1);
	if ((AF_SNA) <= 0) {
	    long long x = (long long)(AF_SNA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_SNA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_UNIX(void) {
#ifdef AF_UNIX
	dump("defined", 1);
	if ((AF_UNIX) <= 0) {
	    long long x = (long long)(AF_UNIX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_UNIX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_UNSPEC(void) {
#ifdef AF_UNSPEC
	dump("defined", 1);
	if ((AF_UNSPEC) <= 0) {
	    long long x = (long long)(AF_UNSPEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_UNSPEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_WANPIPE(void) {
#ifdef AF_WANPIPE
	dump("defined", 1);
	if ((AF_WANPIPE) <= 0) {
	    long long x = (long long)(AF_WANPIPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_WANPIPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AF_X25(void) {
#ifdef AF_X25
	dump("defined", 1);
	if ((AF_X25) <= 0) {
	    long long x = (long long)(AF_X25);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AF_X25);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_ADDRCONFIG(void) {
#ifdef AI_ADDRCONFIG
	dump("defined", 1);
	if ((AI_ADDRCONFIG) <= 0) {
	    long long x = (long long)(AI_ADDRCONFIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_ADDRCONFIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_ALL(void) {
#ifdef AI_ALL
	dump("defined", 1);
	if ((AI_ALL) <= 0) {
	    long long x = (long long)(AI_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_ALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_CANONNAME(void) {
#ifdef AI_CANONNAME
	dump("defined", 1);
	if ((AI_CANONNAME) <= 0) {
	    long long x = (long long)(AI_CANONNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_CANONNAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_DEFAULT(void) {
#ifdef AI_DEFAULT
	dump("defined", 1);
	if ((AI_DEFAULT) <= 0) {
	    long long x = (long long)(AI_DEFAULT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_DEFAULT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_MASK(void) {
#ifdef AI_MASK
	dump("defined", 1);
	if ((AI_MASK) <= 0) {
	    long long x = (long long)(AI_MASK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_MASK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_NUMERICHOST(void) {
#ifdef AI_NUMERICHOST
	dump("defined", 1);
	if ((AI_NUMERICHOST) <= 0) {
	    long long x = (long long)(AI_NUMERICHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_NUMERICHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_NUMERICSERV(void) {
#ifdef AI_NUMERICSERV
	dump("defined", 1);
	if ((AI_NUMERICSERV) <= 0) {
	    long long x = (long long)(AI_NUMERICSERV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_NUMERICSERV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_PASSIVE(void) {
#ifdef AI_PASSIVE
	dump("defined", 1);
	if ((AI_PASSIVE) <= 0) {
	    long long x = (long long)(AI_PASSIVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_PASSIVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_V4MAPPED(void) {
#ifdef AI_V4MAPPED
	dump("defined", 1);
	if ((AI_V4MAPPED) <= 0) {
	    long long x = (long long)(AI_V4MAPPED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_V4MAPPED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AI_V4MAPPED_CFG(void) {
#ifdef AI_V4MAPPED_CFG
	dump("defined", 1);
	if ((AI_V4MAPPED_CFG) <= 0) {
	    long long x = (long long)(AI_V4MAPPED_CFG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AI_V4MAPPED_CFG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BTPROTO_L2CAP(void) {
#ifdef BTPROTO_L2CAP
	dump("defined", 1);
	if ((BTPROTO_L2CAP) <= 0) {
	    long long x = (long long)(BTPROTO_L2CAP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BTPROTO_L2CAP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BTPROTO_RFCOMM(void) {
#ifdef BTPROTO_RFCOMM
	dump("defined", 1);
	if ((BTPROTO_RFCOMM) <= 0) {
	    long long x = (long long)(BTPROTO_RFCOMM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BTPROTO_RFCOMM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BTPROTO_SCO(void) {
#ifdef BTPROTO_SCO
	dump("defined", 1);
	if ((BTPROTO_SCO) <= 0) {
	    long long x = (long long)(BTPROTO_SCO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BTPROTO_SCO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAFNOSUPPORT(void) {
#ifdef EAFNOSUPPORT
	dump("defined", 1);
	if ((EAFNOSUPPORT) <= 0) {
	    long long x = (long long)(EAFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_ADDRFAMILY(void) {
#ifdef EAI_ADDRFAMILY
	dump("defined", 1);
	if ((EAI_ADDRFAMILY) <= 0) {
	    long long x = (long long)(EAI_ADDRFAMILY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_ADDRFAMILY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_AGAIN(void) {
#ifdef EAI_AGAIN
	dump("defined", 1);
	if ((EAI_AGAIN) <= 0) {
	    long long x = (long long)(EAI_AGAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_AGAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_BADFLAGS(void) {
#ifdef EAI_BADFLAGS
	dump("defined", 1);
	if ((EAI_BADFLAGS) <= 0) {
	    long long x = (long long)(EAI_BADFLAGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_BADFLAGS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_BADHINTS(void) {
#ifdef EAI_BADHINTS
	dump("defined", 1);
	if ((EAI_BADHINTS) <= 0) {
	    long long x = (long long)(EAI_BADHINTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_BADHINTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_FAIL(void) {
#ifdef EAI_FAIL
	dump("defined", 1);
	if ((EAI_FAIL) <= 0) {
	    long long x = (long long)(EAI_FAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_FAIL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_FAMILY(void) {
#ifdef EAI_FAMILY
	dump("defined", 1);
	if ((EAI_FAMILY) <= 0) {
	    long long x = (long long)(EAI_FAMILY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_FAMILY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_MAX(void) {
#ifdef EAI_MAX
	dump("defined", 1);
	if ((EAI_MAX) <= 0) {
	    long long x = (long long)(EAI_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_MEMORY(void) {
#ifdef EAI_MEMORY
	dump("defined", 1);
	if ((EAI_MEMORY) <= 0) {
	    long long x = (long long)(EAI_MEMORY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_MEMORY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_NODATA(void) {
#ifdef EAI_NODATA
	dump("defined", 1);
	if ((EAI_NODATA) <= 0) {
	    long long x = (long long)(EAI_NODATA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_NODATA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_NONAME(void) {
#ifdef EAI_NONAME
	dump("defined", 1);
	if ((EAI_NONAME) <= 0) {
	    long long x = (long long)(EAI_NONAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_NONAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_OVERFLOW(void) {
#ifdef EAI_OVERFLOW
	dump("defined", 1);
	if ((EAI_OVERFLOW) <= 0) {
	    long long x = (long long)(EAI_OVERFLOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_OVERFLOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_PROTOCOL(void) {
#ifdef EAI_PROTOCOL
	dump("defined", 1);
	if ((EAI_PROTOCOL) <= 0) {
	    long long x = (long long)(EAI_PROTOCOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_PROTOCOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_SERVICE(void) {
#ifdef EAI_SERVICE
	dump("defined", 1);
	if ((EAI_SERVICE) <= 0) {
	    long long x = (long long)(EAI_SERVICE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_SERVICE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_SOCKTYPE(void) {
#ifdef EAI_SOCKTYPE
	dump("defined", 1);
	if ((EAI_SOCKTYPE) <= 0) {
	    long long x = (long long)(EAI_SOCKTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_SOCKTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EAI_SYSTEM(void) {
#ifdef EAI_SYSTEM
	dump("defined", 1);
	if ((EAI_SYSTEM) <= 0) {
	    long long x = (long long)(EAI_SYSTEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EAI_SYSTEM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EINPROGRESS(void) {
#ifdef EINPROGRESS
	dump("defined", 1);
	if ((EINPROGRESS) <= 0) {
	    long long x = (long long)(EINPROGRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EINPROGRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EINTR(void) {
#ifdef EINTR
	dump("defined", 1);
	if ((EINTR) <= 0) {
	    long long x = (long long)(EINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EISCONN(void) {
#ifdef EISCONN
	dump("defined", 1);
	if ((EISCONN) <= 0) {
	    long long x = (long long)(EISCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EISCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EWOULDBLOCK(void) {
#ifdef EWOULDBLOCK
	dump("defined", 1);
	if ((EWOULDBLOCK) <= 0) {
	    long long x = (long long)(EWOULDBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EWOULDBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_ACCEPT(void) {
#ifdef FD_ACCEPT
	dump("defined", 1);
	if ((FD_ACCEPT) <= 0) {
	    long long x = (long long)(FD_ACCEPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_ACCEPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_CLOSE(void) {
#ifdef FD_CLOSE
	dump("defined", 1);
	if ((FD_CLOSE) <= 0) {
	    long long x = (long long)(FD_CLOSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CLOSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_CLOSE_BIT(void) {
#ifdef FD_CLOSE_BIT
	dump("defined", 1);
	if ((FD_CLOSE_BIT) <= 0) {
	    long long x = (long long)(FD_CLOSE_BIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CLOSE_BIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_CONNECT(void) {
#ifdef FD_CONNECT
	dump("defined", 1);
	if ((FD_CONNECT) <= 0) {
	    long long x = (long long)(FD_CONNECT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CONNECT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_CONNECT_BIT(void) {
#ifdef FD_CONNECT_BIT
	dump("defined", 1);
	if ((FD_CONNECT_BIT) <= 0) {
	    long long x = (long long)(FD_CONNECT_BIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CONNECT_BIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_READ(void) {
#ifdef FD_READ
	dump("defined", 1);
	if ((FD_READ) <= 0) {
	    long long x = (long long)(FD_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_READ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_SETSIZE(void) {
#ifdef FD_SETSIZE
	dump("defined", 1);
	if ((FD_SETSIZE) <= 0) {
	    long long x = (long long)(FD_SETSIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_SETSIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_WRITE(void) {
#ifdef FD_WRITE
	dump("defined", 1);
	if ((FD_WRITE) <= 0) {
	    long long x = (long long)(FD_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_WRITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FIONBIO(void) {
#ifdef FIONBIO
	dump("defined", 1);
	if ((FIONBIO) <= 0) {
	    long long x = (long long)(FIONBIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONBIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETFL(void) {
#ifdef F_GETFL
	dump("defined", 1);
	if ((F_GETFL) <= 0) {
	    long long x = (long long)(F_GETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETFL(void) {
#ifdef F_SETFL
	dump("defined", 1);
	if ((F_SETFL) <= 0) {
	    long long x = (long long)(F_SETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INADDR_ALLHOSTS_GROUP(void) {
#ifdef INADDR_ALLHOSTS_GROUP
	dump("defined", 1);
	if ((INADDR_ALLHOSTS_GROUP) <= 0) {
	    long long x = (long long)(INADDR_ALLHOSTS_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_ALLHOSTS_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INADDR_ANY(void) {
#ifdef INADDR_ANY
	dump("defined", 1);
	if ((INADDR_ANY) <= 0) {
	    long long x = (long long)(INADDR_ANY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_ANY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INADDR_BROADCAST(void) {
#ifdef INADDR_BROADCAST
	dump("defined", 1);
	if ((INADDR_BROADCAST) <= 0) {
	    long long x = (long long)(INADDR_BROADCAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_BROADCAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INADDR_LOOPBACK(void) {
#ifdef INADDR_LOOPBACK
	dump("defined", 1);
	if ((INADDR_LOOPBACK) <= 0) {
	    long long x = (long long)(INADDR_LOOPBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_LOOPBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INADDR_MAX_LOCAL_GROUP(void) {
#ifdef INADDR_MAX_LOCAL_GROUP
	dump("defined", 1);
	if ((INADDR_MAX_LOCAL_GROUP) <= 0) {
	    long long x = (long long)(INADDR_MAX_LOCAL_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_MAX_LOCAL_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INADDR_NONE(void) {
#ifdef INADDR_NONE
	dump("defined", 1);
	if ((INADDR_NONE) <= 0) {
	    long long x = (long long)(INADDR_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_NONE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INADDR_UNSPEC_GROUP(void) {
#ifdef INADDR_UNSPEC_GROUP
	dump("defined", 1);
	if ((INADDR_UNSPEC_GROUP) <= 0) {
	    long long x = (long long)(INADDR_UNSPEC_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INADDR_UNSPEC_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INET6_ADDRSTRLEN(void) {
#ifdef INET6_ADDRSTRLEN
	dump("defined", 1);
	if ((INET6_ADDRSTRLEN) <= 0) {
	    long long x = (long long)(INET6_ADDRSTRLEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INET6_ADDRSTRLEN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INET_ADDRSTRLEN(void) {
#ifdef INET_ADDRSTRLEN
	dump("defined", 1);
	if ((INET_ADDRSTRLEN) <= 0) {
	    long long x = (long long)(INET_ADDRSTRLEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INET_ADDRSTRLEN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INFINITE(void) {
#ifdef INFINITE
	dump("defined", 1);
	if ((INFINITE) <= 0) {
	    long long x = (long long)(INFINITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INFINITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_SOCKET(void) {
#ifdef INVALID_SOCKET
	dump("defined", 1);
	if ((INVALID_SOCKET) <= 0) {
	    long long x = (long long)(INVALID_SOCKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INVALID_SOCKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPORT_RESERVED(void) {
#ifdef IPPORT_RESERVED
	dump("defined", 1);
	if ((IPPORT_RESERVED) <= 0) {
	    long long x = (long long)(IPPORT_RESERVED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPORT_RESERVED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPORT_USERRESERVED(void) {
#ifdef IPPORT_USERRESERVED
	dump("defined", 1);
	if ((IPPORT_USERRESERVED) <= 0) {
	    long long x = (long long)(IPPORT_USERRESERVED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPORT_USERRESERVED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_AH(void) {
#ifdef IPPROTO_AH
	dump("defined", 1);
	if ((IPPROTO_AH) <= 0) {
	    long long x = (long long)(IPPROTO_AH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_AH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_BIP(void) {
#ifdef IPPROTO_BIP
	dump("defined", 1);
	if ((IPPROTO_BIP) <= 0) {
	    long long x = (long long)(IPPROTO_BIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_BIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_DSTOPTS(void) {
#ifdef IPPROTO_DSTOPTS
	dump("defined", 1);
	if ((IPPROTO_DSTOPTS) <= 0) {
	    long long x = (long long)(IPPROTO_DSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_DSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_EGP(void) {
#ifdef IPPROTO_EGP
	dump("defined", 1);
	if ((IPPROTO_EGP) <= 0) {
	    long long x = (long long)(IPPROTO_EGP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_EGP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_EON(void) {
#ifdef IPPROTO_EON
	dump("defined", 1);
	if ((IPPROTO_EON) <= 0) {
	    long long x = (long long)(IPPROTO_EON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_EON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_ESP(void) {
#ifdef IPPROTO_ESP
	dump("defined", 1);
	if ((IPPROTO_ESP) <= 0) {
	    long long x = (long long)(IPPROTO_ESP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ESP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_FRAGMENT(void) {
#ifdef IPPROTO_FRAGMENT
	dump("defined", 1);
	if ((IPPROTO_FRAGMENT) <= 0) {
	    long long x = (long long)(IPPROTO_FRAGMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_FRAGMENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_GGP(void) {
#ifdef IPPROTO_GGP
	dump("defined", 1);
	if ((IPPROTO_GGP) <= 0) {
	    long long x = (long long)(IPPROTO_GGP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_GGP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_GRE(void) {
#ifdef IPPROTO_GRE
	dump("defined", 1);
	if ((IPPROTO_GRE) <= 0) {
	    long long x = (long long)(IPPROTO_GRE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_GRE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_HELLO(void) {
#ifdef IPPROTO_HELLO
	dump("defined", 1);
	if ((IPPROTO_HELLO) <= 0) {
	    long long x = (long long)(IPPROTO_HELLO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_HELLO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_HOPOPTS(void) {
#ifdef IPPROTO_HOPOPTS
	dump("defined", 1);
	if ((IPPROTO_HOPOPTS) <= 0) {
	    long long x = (long long)(IPPROTO_HOPOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_HOPOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_ICMP(void) {
#ifdef IPPROTO_ICMP
	dump("defined", 1);
	if ((IPPROTO_ICMP) <= 0) {
	    long long x = (long long)(IPPROTO_ICMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ICMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_ICMPV6(void) {
#ifdef IPPROTO_ICMPV6
	dump("defined", 1);
	if ((IPPROTO_ICMPV6) <= 0) {
	    long long x = (long long)(IPPROTO_ICMPV6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ICMPV6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_IDP(void) {
#ifdef IPPROTO_IDP
	dump("defined", 1);
	if ((IPPROTO_IDP) <= 0) {
	    long long x = (long long)(IPPROTO_IDP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IDP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_IGMP(void) {
#ifdef IPPROTO_IGMP
	dump("defined", 1);
	if ((IPPROTO_IGMP) <= 0) {
	    long long x = (long long)(IPPROTO_IGMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IGMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_IP(void) {
#ifdef IPPROTO_IP
	dump("defined", 1);
	if ((IPPROTO_IP) <= 0) {
	    long long x = (long long)(IPPROTO_IP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_IPCOMP(void) {
#ifdef IPPROTO_IPCOMP
	dump("defined", 1);
	if ((IPPROTO_IPCOMP) <= 0) {
	    long long x = (long long)(IPPROTO_IPCOMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPCOMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_IPIP(void) {
#ifdef IPPROTO_IPIP
	dump("defined", 1);
	if ((IPPROTO_IPIP) <= 0) {
	    long long x = (long long)(IPPROTO_IPIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_IPV4(void) {
#ifdef IPPROTO_IPV4
	dump("defined", 1);
	if ((IPPROTO_IPV4) <= 0) {
	    long long x = (long long)(IPPROTO_IPV4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPV4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_IPV6(void) {
#ifdef IPPROTO_IPV6
	dump("defined", 1);
	if ((IPPROTO_IPV6) <= 0) {
	    long long x = (long long)(IPPROTO_IPV6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_IPV6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_MAX(void) {
#ifdef IPPROTO_MAX
	dump("defined", 1);
	if ((IPPROTO_MAX) <= 0) {
	    long long x = (long long)(IPPROTO_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_MOBILE(void) {
#ifdef IPPROTO_MOBILE
	dump("defined", 1);
	if ((IPPROTO_MOBILE) <= 0) {
	    long long x = (long long)(IPPROTO_MOBILE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_MOBILE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_ND(void) {
#ifdef IPPROTO_ND
	dump("defined", 1);
	if ((IPPROTO_ND) <= 0) {
	    long long x = (long long)(IPPROTO_ND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_NONE(void) {
#ifdef IPPROTO_NONE
	dump("defined", 1);
	if ((IPPROTO_NONE) <= 0) {
	    long long x = (long long)(IPPROTO_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_NONE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_PIM(void) {
#ifdef IPPROTO_PIM
	dump("defined", 1);
	if ((IPPROTO_PIM) <= 0) {
	    long long x = (long long)(IPPROTO_PIM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_PIM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_PUP(void) {
#ifdef IPPROTO_PUP
	dump("defined", 1);
	if ((IPPROTO_PUP) <= 0) {
	    long long x = (long long)(IPPROTO_PUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_PUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_RAW(void) {
#ifdef IPPROTO_RAW
	dump("defined", 1);
	if ((IPPROTO_RAW) <= 0) {
	    long long x = (long long)(IPPROTO_RAW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_RAW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_ROUTING(void) {
#ifdef IPPROTO_ROUTING
	dump("defined", 1);
	if ((IPPROTO_ROUTING) <= 0) {
	    long long x = (long long)(IPPROTO_ROUTING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_ROUTING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_RSVP(void) {
#ifdef IPPROTO_RSVP
	dump("defined", 1);
	if ((IPPROTO_RSVP) <= 0) {
	    long long x = (long long)(IPPROTO_RSVP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_RSVP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_TCP(void) {
#ifdef IPPROTO_TCP
	dump("defined", 1);
	if ((IPPROTO_TCP) <= 0) {
	    long long x = (long long)(IPPROTO_TCP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_TCP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_TP(void) {
#ifdef IPPROTO_TP
	dump("defined", 1);
	if ((IPPROTO_TP) <= 0) {
	    long long x = (long long)(IPPROTO_TP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_TP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_UDP(void) {
#ifdef IPPROTO_UDP
	dump("defined", 1);
	if ((IPPROTO_UDP) <= 0) {
	    long long x = (long long)(IPPROTO_UDP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_UDP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_VRRP(void) {
#ifdef IPPROTO_VRRP
	dump("defined", 1);
	if ((IPPROTO_VRRP) <= 0) {
	    long long x = (long long)(IPPROTO_VRRP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_VRRP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPPROTO_XTP(void) {
#ifdef IPPROTO_XTP
	dump("defined", 1);
	if ((IPPROTO_XTP) <= 0) {
	    long long x = (long long)(IPPROTO_XTP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPPROTO_XTP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_CHECKSUM(void) {
#ifdef IPV6_CHECKSUM
	dump("defined", 1);
	if ((IPV6_CHECKSUM) <= 0) {
	    long long x = (long long)(IPV6_CHECKSUM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_CHECKSUM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_DONTFRAG(void) {
#ifdef IPV6_DONTFRAG
	dump("defined", 1);
	if ((IPV6_DONTFRAG) <= 0) {
	    long long x = (long long)(IPV6_DONTFRAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_DONTFRAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_DSTOPTS(void) {
#ifdef IPV6_DSTOPTS
	dump("defined", 1);
	if ((IPV6_DSTOPTS) <= 0) {
	    long long x = (long long)(IPV6_DSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_DSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_HOPLIMIT(void) {
#ifdef IPV6_HOPLIMIT
	dump("defined", 1);
	if ((IPV6_HOPLIMIT) <= 0) {
	    long long x = (long long)(IPV6_HOPLIMIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_HOPLIMIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_HOPOPTS(void) {
#ifdef IPV6_HOPOPTS
	dump("defined", 1);
	if ((IPV6_HOPOPTS) <= 0) {
	    long long x = (long long)(IPV6_HOPOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_HOPOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_JOIN_GROUP(void) {
#ifdef IPV6_JOIN_GROUP
	dump("defined", 1);
	if ((IPV6_JOIN_GROUP) <= 0) {
	    long long x = (long long)(IPV6_JOIN_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_JOIN_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_LEAVE_GROUP(void) {
#ifdef IPV6_LEAVE_GROUP
	dump("defined", 1);
	if ((IPV6_LEAVE_GROUP) <= 0) {
	    long long x = (long long)(IPV6_LEAVE_GROUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_LEAVE_GROUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_MULTICAST_HOPS(void) {
#ifdef IPV6_MULTICAST_HOPS
	dump("defined", 1);
	if ((IPV6_MULTICAST_HOPS) <= 0) {
	    long long x = (long long)(IPV6_MULTICAST_HOPS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_MULTICAST_HOPS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_MULTICAST_IF(void) {
#ifdef IPV6_MULTICAST_IF
	dump("defined", 1);
	if ((IPV6_MULTICAST_IF) <= 0) {
	    long long x = (long long)(IPV6_MULTICAST_IF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_MULTICAST_IF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_MULTICAST_LOOP(void) {
#ifdef IPV6_MULTICAST_LOOP
	dump("defined", 1);
	if ((IPV6_MULTICAST_LOOP) <= 0) {
	    long long x = (long long)(IPV6_MULTICAST_LOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_MULTICAST_LOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_NEXTHOP(void) {
#ifdef IPV6_NEXTHOP
	dump("defined", 1);
	if ((IPV6_NEXTHOP) <= 0) {
	    long long x = (long long)(IPV6_NEXTHOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_NEXTHOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_PATHMTU(void) {
#ifdef IPV6_PATHMTU
	dump("defined", 1);
	if ((IPV6_PATHMTU) <= 0) {
	    long long x = (long long)(IPV6_PATHMTU);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_PATHMTU);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_PKTINFO(void) {
#ifdef IPV6_PKTINFO
	dump("defined", 1);
	if ((IPV6_PKTINFO) <= 0) {
	    long long x = (long long)(IPV6_PKTINFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_PKTINFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RECVDSTOPTS(void) {
#ifdef IPV6_RECVDSTOPTS
	dump("defined", 1);
	if ((IPV6_RECVDSTOPTS) <= 0) {
	    long long x = (long long)(IPV6_RECVDSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVDSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RECVHOPLIMIT(void) {
#ifdef IPV6_RECVHOPLIMIT
	dump("defined", 1);
	if ((IPV6_RECVHOPLIMIT) <= 0) {
	    long long x = (long long)(IPV6_RECVHOPLIMIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVHOPLIMIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RECVHOPOPTS(void) {
#ifdef IPV6_RECVHOPOPTS
	dump("defined", 1);
	if ((IPV6_RECVHOPOPTS) <= 0) {
	    long long x = (long long)(IPV6_RECVHOPOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVHOPOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RECVPATHMTU(void) {
#ifdef IPV6_RECVPATHMTU
	dump("defined", 1);
	if ((IPV6_RECVPATHMTU) <= 0) {
	    long long x = (long long)(IPV6_RECVPATHMTU);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVPATHMTU);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RECVPKTINFO(void) {
#ifdef IPV6_RECVPKTINFO
	dump("defined", 1);
	if ((IPV6_RECVPKTINFO) <= 0) {
	    long long x = (long long)(IPV6_RECVPKTINFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVPKTINFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RECVRTHDR(void) {
#ifdef IPV6_RECVRTHDR
	dump("defined", 1);
	if ((IPV6_RECVRTHDR) <= 0) {
	    long long x = (long long)(IPV6_RECVRTHDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVRTHDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RECVTCLASS(void) {
#ifdef IPV6_RECVTCLASS
	dump("defined", 1);
	if ((IPV6_RECVTCLASS) <= 0) {
	    long long x = (long long)(IPV6_RECVTCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RECVTCLASS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RTHDR(void) {
#ifdef IPV6_RTHDR
	dump("defined", 1);
	if ((IPV6_RTHDR) <= 0) {
	    long long x = (long long)(IPV6_RTHDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RTHDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RTHDRDSTOPTS(void) {
#ifdef IPV6_RTHDRDSTOPTS
	dump("defined", 1);
	if ((IPV6_RTHDRDSTOPTS) <= 0) {
	    long long x = (long long)(IPV6_RTHDRDSTOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RTHDRDSTOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_RTHDR_TYPE_0(void) {
#ifdef IPV6_RTHDR_TYPE_0
	dump("defined", 1);
	if ((IPV6_RTHDR_TYPE_0) <= 0) {
	    long long x = (long long)(IPV6_RTHDR_TYPE_0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_RTHDR_TYPE_0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_TCLASS(void) {
#ifdef IPV6_TCLASS
	dump("defined", 1);
	if ((IPV6_TCLASS) <= 0) {
	    long long x = (long long)(IPV6_TCLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_TCLASS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_UNICAST_HOPS(void) {
#ifdef IPV6_UNICAST_HOPS
	dump("defined", 1);
	if ((IPV6_UNICAST_HOPS) <= 0) {
	    long long x = (long long)(IPV6_UNICAST_HOPS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_UNICAST_HOPS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_USE_MIN_MTU(void) {
#ifdef IPV6_USE_MIN_MTU
	dump("defined", 1);
	if ((IPV6_USE_MIN_MTU) <= 0) {
	    long long x = (long long)(IPV6_USE_MIN_MTU);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_USE_MIN_MTU);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPV6_V6ONLY(void) {
#ifdef IPV6_V6ONLY
	dump("defined", 1);
	if ((IPV6_V6ONLY) <= 0) {
	    long long x = (long long)(IPV6_V6ONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPV6_V6ONLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IPX_TYPE(void) {
#ifdef IPX_TYPE
	dump("defined", 1);
	if ((IPX_TYPE) <= 0) {
	    long long x = (long long)(IPX_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IPX_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_ADD_MEMBERSHIP(void) {
#ifdef IP_ADD_MEMBERSHIP
	dump("defined", 1);
	if ((IP_ADD_MEMBERSHIP) <= 0) {
	    long long x = (long long)(IP_ADD_MEMBERSHIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_ADD_MEMBERSHIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_DEFAULT_MULTICAST_LOOP(void) {
#ifdef IP_DEFAULT_MULTICAST_LOOP
	dump("defined", 1);
	if ((IP_DEFAULT_MULTICAST_LOOP) <= 0) {
	    long long x = (long long)(IP_DEFAULT_MULTICAST_LOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_DEFAULT_MULTICAST_LOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_DEFAULT_MULTICAST_TTL(void) {
#ifdef IP_DEFAULT_MULTICAST_TTL
	dump("defined", 1);
	if ((IP_DEFAULT_MULTICAST_TTL) <= 0) {
	    long long x = (long long)(IP_DEFAULT_MULTICAST_TTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_DEFAULT_MULTICAST_TTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_DROP_MEMBERSHIP(void) {
#ifdef IP_DROP_MEMBERSHIP
	dump("defined", 1);
	if ((IP_DROP_MEMBERSHIP) <= 0) {
	    long long x = (long long)(IP_DROP_MEMBERSHIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_DROP_MEMBERSHIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_HDRINCL(void) {
#ifdef IP_HDRINCL
	dump("defined", 1);
	if ((IP_HDRINCL) <= 0) {
	    long long x = (long long)(IP_HDRINCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_HDRINCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_MAX_MEMBERSHIPS(void) {
#ifdef IP_MAX_MEMBERSHIPS
	dump("defined", 1);
	if ((IP_MAX_MEMBERSHIPS) <= 0) {
	    long long x = (long long)(IP_MAX_MEMBERSHIPS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MAX_MEMBERSHIPS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_MULTICAST_IF(void) {
#ifdef IP_MULTICAST_IF
	dump("defined", 1);
	if ((IP_MULTICAST_IF) <= 0) {
	    long long x = (long long)(IP_MULTICAST_IF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MULTICAST_IF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_MULTICAST_LOOP(void) {
#ifdef IP_MULTICAST_LOOP
	dump("defined", 1);
	if ((IP_MULTICAST_LOOP) <= 0) {
	    long long x = (long long)(IP_MULTICAST_LOOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MULTICAST_LOOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_MULTICAST_TTL(void) {
#ifdef IP_MULTICAST_TTL
	dump("defined", 1);
	if ((IP_MULTICAST_TTL) <= 0) {
	    long long x = (long long)(IP_MULTICAST_TTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_MULTICAST_TTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_OPTIONS(void) {
#ifdef IP_OPTIONS
	dump("defined", 1);
	if ((IP_OPTIONS) <= 0) {
	    long long x = (long long)(IP_OPTIONS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_OPTIONS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_RECVDSTADDR(void) {
#ifdef IP_RECVDSTADDR
	dump("defined", 1);
	if ((IP_RECVDSTADDR) <= 0) {
	    long long x = (long long)(IP_RECVDSTADDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RECVDSTADDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_RECVOPTS(void) {
#ifdef IP_RECVOPTS
	dump("defined", 1);
	if ((IP_RECVOPTS) <= 0) {
	    long long x = (long long)(IP_RECVOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RECVOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_RECVRETOPTS(void) {
#ifdef IP_RECVRETOPTS
	dump("defined", 1);
	if ((IP_RECVRETOPTS) <= 0) {
	    long long x = (long long)(IP_RECVRETOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RECVRETOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_RETOPTS(void) {
#ifdef IP_RETOPTS
	dump("defined", 1);
	if ((IP_RETOPTS) <= 0) {
	    long long x = (long long)(IP_RETOPTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_RETOPTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_TOS(void) {
#ifdef IP_TOS
	dump("defined", 1);
	if ((IP_TOS) <= 0) {
	    long long x = (long long)(IP_TOS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_TOS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IP_TTL(void) {
#ifdef IP_TTL
	dump("defined", 1);
	if ((IP_TTL) <= 0) {
	    long long x = (long long)(IP_TTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IP_TTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_BTAG(void) {
#ifdef MSG_BTAG
	dump("defined", 1);
	if ((MSG_BTAG) <= 0) {
	    long long x = (long long)(MSG_BTAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_BTAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_CTRUNC(void) {
#ifdef MSG_CTRUNC
	dump("defined", 1);
	if ((MSG_CTRUNC) <= 0) {
	    long long x = (long long)(MSG_CTRUNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_CTRUNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_DONTROUTE(void) {
#ifdef MSG_DONTROUTE
	dump("defined", 1);
	if ((MSG_DONTROUTE) <= 0) {
	    long long x = (long long)(MSG_DONTROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_DONTROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_DONTWAIT(void) {
#ifdef MSG_DONTWAIT
	dump("defined", 1);
	if ((MSG_DONTWAIT) <= 0) {
	    long long x = (long long)(MSG_DONTWAIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_DONTWAIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_EOR(void) {
#ifdef MSG_EOR
	dump("defined", 1);
	if ((MSG_EOR) <= 0) {
	    long long x = (long long)(MSG_EOR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_EOR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_ETAG(void) {
#ifdef MSG_ETAG
	dump("defined", 1);
	if ((MSG_ETAG) <= 0) {
	    long long x = (long long)(MSG_ETAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_ETAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_OOB(void) {
#ifdef MSG_OOB
	dump("defined", 1);
	if ((MSG_OOB) <= 0) {
	    long long x = (long long)(MSG_OOB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_OOB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_PEEK(void) {
#ifdef MSG_PEEK
	dump("defined", 1);
	if ((MSG_PEEK) <= 0) {
	    long long x = (long long)(MSG_PEEK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_PEEK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_TRUNC(void) {
#ifdef MSG_TRUNC
	dump("defined", 1);
	if ((MSG_TRUNC) <= 0) {
	    long long x = (long long)(MSG_TRUNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_TRUNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MSG_WAITALL(void) {
#ifdef MSG_WAITALL
	dump("defined", 1);
	if ((MSG_WAITALL) <= 0) {
	    long long x = (long long)(MSG_WAITALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MSG_WAITALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_ARPD(void) {
#ifdef NETLINK_ARPD
	dump("defined", 1);
	if ((NETLINK_ARPD) <= 0) {
	    long long x = (long long)(NETLINK_ARPD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_ARPD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_DNRTMSG(void) {
#ifdef NETLINK_DNRTMSG
	dump("defined", 1);
	if ((NETLINK_DNRTMSG) <= 0) {
	    long long x = (long long)(NETLINK_DNRTMSG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_DNRTMSG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_FIREWALL(void) {
#ifdef NETLINK_FIREWALL
	dump("defined", 1);
	if ((NETLINK_FIREWALL) <= 0) {
	    long long x = (long long)(NETLINK_FIREWALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_FIREWALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_IP6_FW(void) {
#ifdef NETLINK_IP6_FW
	dump("defined", 1);
	if ((NETLINK_IP6_FW) <= 0) {
	    long long x = (long long)(NETLINK_IP6_FW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_IP6_FW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_NFLOG(void) {
#ifdef NETLINK_NFLOG
	dump("defined", 1);
	if ((NETLINK_NFLOG) <= 0) {
	    long long x = (long long)(NETLINK_NFLOG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_NFLOG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_ROUTE(void) {
#ifdef NETLINK_ROUTE
	dump("defined", 1);
	if ((NETLINK_ROUTE) <= 0) {
	    long long x = (long long)(NETLINK_ROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_ROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_ROUTE6(void) {
#ifdef NETLINK_ROUTE6
	dump("defined", 1);
	if ((NETLINK_ROUTE6) <= 0) {
	    long long x = (long long)(NETLINK_ROUTE6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_ROUTE6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_SKIP(void) {
#ifdef NETLINK_SKIP
	dump("defined", 1);
	if ((NETLINK_SKIP) <= 0) {
	    long long x = (long long)(NETLINK_SKIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_SKIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_TAPBASE(void) {
#ifdef NETLINK_TAPBASE
	dump("defined", 1);
	if ((NETLINK_TAPBASE) <= 0) {
	    long long x = (long long)(NETLINK_TAPBASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_TAPBASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_TCPDIAG(void) {
#ifdef NETLINK_TCPDIAG
	dump("defined", 1);
	if ((NETLINK_TCPDIAG) <= 0) {
	    long long x = (long long)(NETLINK_TCPDIAG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_TCPDIAG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_USERSOCK(void) {
#ifdef NETLINK_USERSOCK
	dump("defined", 1);
	if ((NETLINK_USERSOCK) <= 0) {
	    long long x = (long long)(NETLINK_USERSOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_USERSOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_W1(void) {
#ifdef NETLINK_W1
	dump("defined", 1);
	if ((NETLINK_W1) <= 0) {
	    long long x = (long long)(NETLINK_W1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_W1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NETLINK_XFRM(void) {
#ifdef NETLINK_XFRM
	dump("defined", 1);
	if ((NETLINK_XFRM) <= 0) {
	    long long x = (long long)(NETLINK_XFRM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NETLINK_XFRM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NI_DGRAM(void) {
#ifdef NI_DGRAM
	dump("defined", 1);
	if ((NI_DGRAM) <= 0) {
	    long long x = (long long)(NI_DGRAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_DGRAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NI_MAXHOST(void) {
#ifdef NI_MAXHOST
	dump("defined", 1);
	if ((NI_MAXHOST) <= 0) {
	    long long x = (long long)(NI_MAXHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_MAXHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NI_MAXSERV(void) {
#ifdef NI_MAXSERV
	dump("defined", 1);
	if ((NI_MAXSERV) <= 0) {
	    long long x = (long long)(NI_MAXSERV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_MAXSERV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NI_NAMEREQD(void) {
#ifdef NI_NAMEREQD
	dump("defined", 1);
	if ((NI_NAMEREQD) <= 0) {
	    long long x = (long long)(NI_NAMEREQD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NAMEREQD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NI_NOFQDN(void) {
#ifdef NI_NOFQDN
	dump("defined", 1);
	if ((NI_NOFQDN) <= 0) {
	    long long x = (long long)(NI_NOFQDN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NOFQDN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NI_NUMERICHOST(void) {
#ifdef NI_NUMERICHOST
	dump("defined", 1);
	if ((NI_NUMERICHOST) <= 0) {
	    long long x = (long long)(NI_NUMERICHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NUMERICHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NI_NUMERICSERV(void) {
#ifdef NI_NUMERICSERV
	dump("defined", 1);
	if ((NI_NUMERICSERV) <= 0) {
	    long long x = (long long)(NI_NUMERICSERV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NI_NUMERICSERV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_O_NONBLOCK(void) {
#ifdef O_NONBLOCK
	dump("defined", 1);
	if ((O_NONBLOCK) <= 0) {
	    long long x = (long long)(O_NONBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_NONBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_O_RDONLY(void) {
#ifdef O_RDONLY
	dump("defined", 1);
	if ((O_RDONLY) <= 0) {
	    long long x = (long long)(O_RDONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_RDONLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_O_RDWR(void) {
#ifdef O_RDWR
	dump("defined", 1);
	if ((O_RDWR) <= 0) {
	    long long x = (long long)(O_RDWR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_RDWR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_O_WRONLY(void) {
#ifdef O_WRONLY
	dump("defined", 1);
	if ((O_WRONLY) <= 0) {
	    long long x = (long long)(O_WRONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(O_WRONLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_BROADCAST(void) {
#ifdef PACKET_BROADCAST
	dump("defined", 1);
	if ((PACKET_BROADCAST) <= 0) {
	    long long x = (long long)(PACKET_BROADCAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_BROADCAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_FASTROUTE(void) {
#ifdef PACKET_FASTROUTE
	dump("defined", 1);
	if ((PACKET_FASTROUTE) <= 0) {
	    long long x = (long long)(PACKET_FASTROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_FASTROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_HOST(void) {
#ifdef PACKET_HOST
	dump("defined", 1);
	if ((PACKET_HOST) <= 0) {
	    long long x = (long long)(PACKET_HOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_HOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_LOOPBACK(void) {
#ifdef PACKET_LOOPBACK
	dump("defined", 1);
	if ((PACKET_LOOPBACK) <= 0) {
	    long long x = (long long)(PACKET_LOOPBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_LOOPBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_MULTICAST(void) {
#ifdef PACKET_MULTICAST
	dump("defined", 1);
	if ((PACKET_MULTICAST) <= 0) {
	    long long x = (long long)(PACKET_MULTICAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_MULTICAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_OTHERHOST(void) {
#ifdef PACKET_OTHERHOST
	dump("defined", 1);
	if ((PACKET_OTHERHOST) <= 0) {
	    long long x = (long long)(PACKET_OTHERHOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_OTHERHOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_OUTGOING(void) {
#ifdef PACKET_OUTGOING
	dump("defined", 1);
	if ((PACKET_OUTGOING) <= 0) {
	    long long x = (long long)(PACKET_OUTGOING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PACKET_OUTGOING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLERR(void) {
#ifdef POLLERR
	dump("defined", 1);
	if ((POLLERR) <= 0) {
	    long long x = (long long)(POLLERR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLERR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLHUP(void) {
#ifdef POLLHUP
	dump("defined", 1);
	if ((POLLHUP) <= 0) {
	    long long x = (long long)(POLLHUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLHUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLIN(void) {
#ifdef POLLIN
	dump("defined", 1);
	if ((POLLIN) <= 0) {
	    long long x = (long long)(POLLIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLMSG(void) {
#ifdef POLLMSG
	dump("defined", 1);
	if ((POLLMSG) <= 0) {
	    long long x = (long long)(POLLMSG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLMSG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLNVAL(void) {
#ifdef POLLNVAL
	dump("defined", 1);
	if ((POLLNVAL) <= 0) {
	    long long x = (long long)(POLLNVAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLNVAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLOUT(void) {
#ifdef POLLOUT
	dump("defined", 1);
	if ((POLLOUT) <= 0) {
	    long long x = (long long)(POLLOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLPRI(void) {
#ifdef POLLPRI
	dump("defined", 1);
	if ((POLLPRI) <= 0) {
	    long long x = (long long)(POLLPRI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLPRI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLRDBAND(void) {
#ifdef POLLRDBAND
	dump("defined", 1);
	if ((POLLRDBAND) <= 0) {
	    long long x = (long long)(POLLRDBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLRDBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLRDNORM(void) {
#ifdef POLLRDNORM
	dump("defined", 1);
	if ((POLLRDNORM) <= 0) {
	    long long x = (long long)(POLLRDNORM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLRDNORM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLWEBAND(void) {
#ifdef POLLWEBAND
	dump("defined", 1);
	if ((POLLWEBAND) <= 0) {
	    long long x = (long long)(POLLWEBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLWEBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_POLLWRNORM(void) {
#ifdef POLLWRNORM
	dump("defined", 1);
	if ((POLLWRNORM) <= 0) {
	    long long x = (long long)(POLLWRNORM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(POLLWRNORM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SHUT_RD(void) {
#ifdef SHUT_RD
	dump("defined", 1);
	if ((SHUT_RD) <= 0) {
	    long long x = (long long)(SHUT_RD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SHUT_RD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SHUT_RDWR(void) {
#ifdef SHUT_RDWR
	dump("defined", 1);
	if ((SHUT_RDWR) <= 0) {
	    long long x = (long long)(SHUT_RDWR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SHUT_RDWR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SHUT_WR(void) {
#ifdef SHUT_WR
	dump("defined", 1);
	if ((SHUT_WR) <= 0) {
	    long long x = (long long)(SHUT_WR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SHUT_WR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SIOCGIFINDEX(void) {
#ifdef SIOCGIFINDEX
	dump("defined", 1);
	if ((SIOCGIFINDEX) <= 0) {
	    long long x = (long long)(SIOCGIFINDEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIOCGIFINDEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SIOCGIFNAME(void) {
#ifdef SIOCGIFNAME
	dump("defined", 1);
	if ((SIOCGIFNAME) <= 0) {
	    long long x = (long long)(SIOCGIFNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIOCGIFNAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SIO_KEEPALIVE_VALS(void) {
#ifdef SIO_KEEPALIVE_VALS
	dump("defined", 1);
	if ((SIO_KEEPALIVE_VALS) <= 0) {
	    long long x = (long long)(SIO_KEEPALIVE_VALS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIO_KEEPALIVE_VALS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SIO_RCVALL(void) {
#ifdef SIO_RCVALL
	dump("defined", 1);
	if ((SIO_RCVALL) <= 0) {
	    long long x = (long long)(SIO_RCVALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SIO_RCVALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOCK_DGRAM(void) {
#ifdef SOCK_DGRAM
	dump("defined", 1);
	if ((SOCK_DGRAM) <= 0) {
	    long long x = (long long)(SOCK_DGRAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_DGRAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOCK_RAW(void) {
#ifdef SOCK_RAW
	dump("defined", 1);
	if ((SOCK_RAW) <= 0) {
	    long long x = (long long)(SOCK_RAW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_RAW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOCK_RDM(void) {
#ifdef SOCK_RDM
	dump("defined", 1);
	if ((SOCK_RDM) <= 0) {
	    long long x = (long long)(SOCK_RDM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_RDM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOCK_SEQPACKET(void) {
#ifdef SOCK_SEQPACKET
	dump("defined", 1);
	if ((SOCK_SEQPACKET) <= 0) {
	    long long x = (long long)(SOCK_SEQPACKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_SEQPACKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOCK_STREAM(void) {
#ifdef SOCK_STREAM
	dump("defined", 1);
	if ((SOCK_STREAM) <= 0) {
	    long long x = (long long)(SOCK_STREAM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOCK_STREAM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_ATALK(void) {
#ifdef SOL_ATALK
	dump("defined", 1);
	if ((SOL_ATALK) <= 0) {
	    long long x = (long long)(SOL_ATALK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_ATALK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_AX25(void) {
#ifdef SOL_AX25
	dump("defined", 1);
	if ((SOL_AX25) <= 0) {
	    long long x = (long long)(SOL_AX25);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_AX25);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_IP(void) {
#ifdef SOL_IP
	dump("defined", 1);
	if ((SOL_IP) <= 0) {
	    long long x = (long long)(SOL_IP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_IP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_IPX(void) {
#ifdef SOL_IPX
	dump("defined", 1);
	if ((SOL_IPX) <= 0) {
	    long long x = (long long)(SOL_IPX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_IPX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_NETROM(void) {
#ifdef SOL_NETROM
	dump("defined", 1);
	if ((SOL_NETROM) <= 0) {
	    long long x = (long long)(SOL_NETROM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_NETROM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_ROSE(void) {
#ifdef SOL_ROSE
	dump("defined", 1);
	if ((SOL_ROSE) <= 0) {
	    long long x = (long long)(SOL_ROSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_ROSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_SOCKET(void) {
#ifdef SOL_SOCKET
	dump("defined", 1);
	if ((SOL_SOCKET) <= 0) {
	    long long x = (long long)(SOL_SOCKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_SOCKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_TCP(void) {
#ifdef SOL_TCP
	dump("defined", 1);
	if ((SOL_TCP) <= 0) {
	    long long x = (long long)(SOL_TCP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_TCP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOL_UDP(void) {
#ifdef SOL_UDP
	dump("defined", 1);
	if ((SOL_UDP) <= 0) {
	    long long x = (long long)(SOL_UDP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOL_UDP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SOMAXCONN(void) {
#ifdef SOMAXCONN
	dump("defined", 1);
	if ((SOMAXCONN) <= 0) {
	    long long x = (long long)(SOMAXCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SOMAXCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_ACCEPTCONN(void) {
#ifdef SO_ACCEPTCONN
	dump("defined", 1);
	if ((SO_ACCEPTCONN) <= 0) {
	    long long x = (long long)(SO_ACCEPTCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_ACCEPTCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_BROADCAST(void) {
#ifdef SO_BROADCAST
	dump("defined", 1);
	if ((SO_BROADCAST) <= 0) {
	    long long x = (long long)(SO_BROADCAST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_BROADCAST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_DEBUG(void) {
#ifdef SO_DEBUG
	dump("defined", 1);
	if ((SO_DEBUG) <= 0) {
	    long long x = (long long)(SO_DEBUG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_DEBUG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_DONTROUTE(void) {
#ifdef SO_DONTROUTE
	dump("defined", 1);
	if ((SO_DONTROUTE) <= 0) {
	    long long x = (long long)(SO_DONTROUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_DONTROUTE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_ERROR(void) {
#ifdef SO_ERROR
	dump("defined", 1);
	if ((SO_ERROR) <= 0) {
	    long long x = (long long)(SO_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_EXCLUSIVEADDRUSE(void) {
#ifdef SO_EXCLUSIVEADDRUSE
	dump("defined", 1);
	if ((SO_EXCLUSIVEADDRUSE) <= 0) {
	    long long x = (long long)(SO_EXCLUSIVEADDRUSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_EXCLUSIVEADDRUSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_KEEPALIVE(void) {
#ifdef SO_KEEPALIVE
	dump("defined", 1);
	if ((SO_KEEPALIVE) <= 0) {
	    long long x = (long long)(SO_KEEPALIVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_KEEPALIVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_LINGER(void) {
#ifdef SO_LINGER
	dump("defined", 1);
	if ((SO_LINGER) <= 0) {
	    long long x = (long long)(SO_LINGER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_LINGER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_OOBINLINE(void) {
#ifdef SO_OOBINLINE
	dump("defined", 1);
	if ((SO_OOBINLINE) <= 0) {
	    long long x = (long long)(SO_OOBINLINE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_OOBINLINE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_RCVBUF(void) {
#ifdef SO_RCVBUF
	dump("defined", 1);
	if ((SO_RCVBUF) <= 0) {
	    long long x = (long long)(SO_RCVBUF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_RCVBUF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_RCVLOWAT(void) {
#ifdef SO_RCVLOWAT
	dump("defined", 1);
	if ((SO_RCVLOWAT) <= 0) {
	    long long x = (long long)(SO_RCVLOWAT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_RCVLOWAT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_RCVTIMEO(void) {
#ifdef SO_RCVTIMEO
	dump("defined", 1);
	if ((SO_RCVTIMEO) <= 0) {
	    long long x = (long long)(SO_RCVTIMEO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_RCVTIMEO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_REUSEADDR(void) {
#ifdef SO_REUSEADDR
	dump("defined", 1);
	if ((SO_REUSEADDR) <= 0) {
	    long long x = (long long)(SO_REUSEADDR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_REUSEADDR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_REUSEPORT(void) {
#ifdef SO_REUSEPORT
	dump("defined", 1);
	if ((SO_REUSEPORT) <= 0) {
	    long long x = (long long)(SO_REUSEPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_REUSEPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_SNDBUF(void) {
#ifdef SO_SNDBUF
	dump("defined", 1);
	if ((SO_SNDBUF) <= 0) {
	    long long x = (long long)(SO_SNDBUF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_SNDBUF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_SNDLOWAT(void) {
#ifdef SO_SNDLOWAT
	dump("defined", 1);
	if ((SO_SNDLOWAT) <= 0) {
	    long long x = (long long)(SO_SNDLOWAT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_SNDLOWAT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_SNDTIMEO(void) {
#ifdef SO_SNDTIMEO
	dump("defined", 1);
	if ((SO_SNDTIMEO) <= 0) {
	    long long x = (long long)(SO_SNDTIMEO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_SNDTIMEO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_TYPE(void) {
#ifdef SO_TYPE
	dump("defined", 1);
	if ((SO_TYPE) <= 0) {
	    long long x = (long long)(SO_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SO_USELOOPBACK(void) {
#ifdef SO_USELOOPBACK
	dump("defined", 1);
	if ((SO_USELOOPBACK) <= 0) {
	    long long x = (long long)(SO_USELOOPBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SO_USELOOPBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_CORK(void) {
#ifdef TCP_CORK
	dump("defined", 1);
	if ((TCP_CORK) <= 0) {
	    long long x = (long long)(TCP_CORK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_CORK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_DEFER_ACCEPT(void) {
#ifdef TCP_DEFER_ACCEPT
	dump("defined", 1);
	if ((TCP_DEFER_ACCEPT) <= 0) {
	    long long x = (long long)(TCP_DEFER_ACCEPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_DEFER_ACCEPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_INFO(void) {
#ifdef TCP_INFO
	dump("defined", 1);
	if ((TCP_INFO) <= 0) {
	    long long x = (long long)(TCP_INFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_INFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_KEEPCNT(void) {
#ifdef TCP_KEEPCNT
	dump("defined", 1);
	if ((TCP_KEEPCNT) <= 0) {
	    long long x = (long long)(TCP_KEEPCNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_KEEPCNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_KEEPIDLE(void) {
#ifdef TCP_KEEPIDLE
	dump("defined", 1);
	if ((TCP_KEEPIDLE) <= 0) {
	    long long x = (long long)(TCP_KEEPIDLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_KEEPIDLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_KEEPINTVL(void) {
#ifdef TCP_KEEPINTVL
	dump("defined", 1);
	if ((TCP_KEEPINTVL) <= 0) {
	    long long x = (long long)(TCP_KEEPINTVL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_KEEPINTVL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_LINGER2(void) {
#ifdef TCP_LINGER2
	dump("defined", 1);
	if ((TCP_LINGER2) <= 0) {
	    long long x = (long long)(TCP_LINGER2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_LINGER2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_MAXSEG(void) {
#ifdef TCP_MAXSEG
	dump("defined", 1);
	if ((TCP_MAXSEG) <= 0) {
	    long long x = (long long)(TCP_MAXSEG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_MAXSEG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_NODELAY(void) {
#ifdef TCP_NODELAY
	dump("defined", 1);
	if ((TCP_NODELAY) <= 0) {
	    long long x = (long long)(TCP_NODELAY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_NODELAY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_QUICKACK(void) {
#ifdef TCP_QUICKACK
	dump("defined", 1);
	if ((TCP_QUICKACK) <= 0) {
	    long long x = (long long)(TCP_QUICKACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_QUICKACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_SYNCNT(void) {
#ifdef TCP_SYNCNT
	dump("defined", 1);
	if ((TCP_SYNCNT) <= 0) {
	    long long x = (long long)(TCP_SYNCNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_SYNCNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCP_WINDOW_CLAMP(void) {
#ifdef TCP_WINDOW_CLAMP
	dump("defined", 1);
	if ((TCP_WINDOW_CLAMP) <= 0) {
	    long long x = (long long)(TCP_WINDOW_CLAMP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCP_WINDOW_CLAMP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WIN32(void) {
#ifdef _WIN32
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_WSAEAFNOSUPPORT(void) {
#ifdef WSAEAFNOSUPPORT
	dump("defined", 1);
	if ((WSAEAFNOSUPPORT) <= 0) {
	    long long x = (long long)(WSAEAFNOSUPPORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEAFNOSUPPORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSAEINPROGRESS(void) {
#ifdef WSAEINPROGRESS
	dump("defined", 1);
	if ((WSAEINPROGRESS) <= 0) {
	    long long x = (long long)(WSAEINPROGRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEINPROGRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSAEINTR(void) {
#ifdef WSAEINTR
	dump("defined", 1);
	if ((WSAEINTR) <= 0) {
	    long long x = (long long)(WSAEINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSAEISCONN(void) {
#ifdef WSAEISCONN
	dump("defined", 1);
	if ((WSAEISCONN) <= 0) {
	    long long x = (long long)(WSAEISCONN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEISCONN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSAEWOULDBLOCK(void) {
#ifdef WSAEWOULDBLOCK
	dump("defined", 1);
	if ((WSAEWOULDBLOCK) <= 0) {
	    long long x = (long long)(WSAEWOULDBLOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSAEWOULDBLOCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_INVALID_HANDLE(void) {
#ifdef WSA_INVALID_HANDLE
	dump("defined", 1);
	if ((WSA_INVALID_HANDLE) <= 0) {
	    long long x = (long long)(WSA_INVALID_HANDLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_INVALID_HANDLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_INVALID_PARAMETER(void) {
#ifdef WSA_INVALID_PARAMETER
	dump("defined", 1);
	if ((WSA_INVALID_PARAMETER) <= 0) {
	    long long x = (long long)(WSA_INVALID_PARAMETER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_INVALID_PARAMETER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_IO_INCOMPLETE(void) {
#ifdef WSA_IO_INCOMPLETE
	dump("defined", 1);
	if ((WSA_IO_INCOMPLETE) <= 0) {
	    long long x = (long long)(WSA_IO_INCOMPLETE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_IO_INCOMPLETE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_IO_PENDING(void) {
#ifdef WSA_IO_PENDING
	dump("defined", 1);
	if ((WSA_IO_PENDING) <= 0) {
	    long long x = (long long)(WSA_IO_PENDING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_IO_PENDING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_NOT_ENOUGH_MEMORY(void) {
#ifdef WSA_NOT_ENOUGH_MEMORY
	dump("defined", 1);
	if ((WSA_NOT_ENOUGH_MEMORY) <= 0) {
	    long long x = (long long)(WSA_NOT_ENOUGH_MEMORY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_NOT_ENOUGH_MEMORY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_OPERATION_ABORTED(void) {
#ifdef WSA_OPERATION_ABORTED
	dump("defined", 1);
	if ((WSA_OPERATION_ABORTED) <= 0) {
	    long long x = (long long)(WSA_OPERATION_ABORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_OPERATION_ABORTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_WAIT_FAILED(void) {
#ifdef WSA_WAIT_FAILED
	dump("defined", 1);
	if ((WSA_WAIT_FAILED) <= 0) {
	    long long x = (long long)(WSA_WAIT_FAILED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_WAIT_FAILED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WSA_WAIT_TIMEOUT(void) {
#ifdef WSA_WAIT_TIMEOUT
	dump("defined", 1);
	if ((WSA_WAIT_TIMEOUT) <= 0) {
	    long long x = (long long)(WSA_WAIT_TIMEOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(WSA_WAIT_TIMEOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_addrinfo(void) {
	typedef struct addrinfo platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ai_flags", offsetof(platcheck_t, ai_flags));
	dump("fldsize ai_flags",   sizeof(s.ai_flags));
	s.ai_flags = 0; s.ai_flags = ~s.ai_flags;
	dump("fldunsigned ai_flags", s.ai_flags > 0);
	dump("fldofs ai_family", offsetof(platcheck_t, ai_family));
	dump("fldsize ai_family",   sizeof(s.ai_family));
	s.ai_family = 0; s.ai_family = ~s.ai_family;
	dump("fldunsigned ai_family", s.ai_family > 0);
	dump("fldofs ai_socktype", offsetof(platcheck_t, ai_socktype));
	dump("fldsize ai_socktype",   sizeof(s.ai_socktype));
	s.ai_socktype = 0; s.ai_socktype = ~s.ai_socktype;
	dump("fldunsigned ai_socktype", s.ai_socktype > 0);
	dump("fldofs ai_protocol", offsetof(platcheck_t, ai_protocol));
	dump("fldsize ai_protocol",   sizeof(s.ai_protocol));
	s.ai_protocol = 0; s.ai_protocol = ~s.ai_protocol;
	dump("fldunsigned ai_protocol", s.ai_protocol > 0);
	dump("fldofs ai_addrlen", offsetof(platcheck_t, ai_addrlen));
	dump("fldsize ai_addrlen",   sizeof(s.ai_addrlen));
	s.ai_addrlen = 0; s.ai_addrlen = ~s.ai_addrlen;
	dump("fldunsigned ai_addrlen", s.ai_addrlen > 0);
	dump("fldofs ai_addr", offsetof(platcheck_t, ai_addr));
	dump("fldsize ai_addr",   sizeof(s.ai_addr));
	dump("fldofs ai_canonname", offsetof(platcheck_t, ai_canonname));
	dump("fldsize ai_canonname",   sizeof(s.ai_canonname));
	dump("fldofs ai_next", offsetof(platcheck_t, ai_next));
	dump("fldsize ai_next",   sizeof(s.ai_next));
}

void dump_section_hostent(void) {
	typedef struct hostent platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs h_name", offsetof(platcheck_t, h_name));
	dump("fldsize h_name",   sizeof(s.h_name));
	dump("fldofs h_aliases", offsetof(platcheck_t, h_aliases));
	dump("fldsize h_aliases",   sizeof(s.h_aliases));
	dump("fldofs h_addrtype", offsetof(platcheck_t, h_addrtype));
	dump("fldsize h_addrtype",   sizeof(s.h_addrtype));
	s.h_addrtype = 0; s.h_addrtype = ~s.h_addrtype;
	dump("fldunsigned h_addrtype", s.h_addrtype > 0);
	dump("fldofs h_length", offsetof(platcheck_t, h_length));
	dump("fldsize h_length",   sizeof(s.h_length));
	s.h_length = 0; s.h_length = ~s.h_length;
	dump("fldunsigned h_length", s.h_length > 0);
	dump("fldofs h_addr_list", offsetof(platcheck_t, h_addr_list));
	dump("fldsize h_addr_list",   sizeof(s.h_addr_list));
}

void dump_section_ifreq(void) {
	typedef struct ifreq platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ifr_ifindex", offsetof(platcheck_t, ifr_ifindex));
	dump("fldsize ifr_ifindex",   sizeof(s.ifr_ifindex));
	s.ifr_ifindex = 0; s.ifr_ifindex = ~s.ifr_ifindex;
	dump("fldunsigned ifr_ifindex", s.ifr_ifindex > 0);
	dump("fldofs ifr_name", offsetof(platcheck_t, ifr_name));
	dump("fldsize ifr_name",   sizeof(s.ifr_name));
}

void dump_section_in6_addr(void) {
	typedef struct in6_addr platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs s6_addr", offsetof(platcheck_t, s6_addr));
	dump("fldsize s6_addr",   sizeof(s.s6_addr));
}

void dump_section_in_addr(void) {
	typedef struct in_addr platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs s_addr", offsetof(platcheck_t, s_addr));
	dump("fldsize s_addr",   sizeof(s.s_addr));
	s.s_addr = 0; s.s_addr = ~s.s_addr;
	dump("fldunsigned s_addr", s.s_addr > 0);
}

void dump_section_linux(void) {
#ifdef linux
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_nfds_t(void) {
	typedef nfds_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_pollfd(void) {
	typedef struct pollfd platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs fd", offsetof(platcheck_t, fd));
	dump("fldsize fd",   sizeof(s.fd));
	s.fd = 0; s.fd = ~s.fd;
	dump("fldunsigned fd", s.fd > 0);
	dump("fldofs events", offsetof(platcheck_t, events));
	dump("fldsize events",   sizeof(s.events));
	s.events = 0; s.events = ~s.events;
	dump("fldunsigned events", s.events > 0);
	dump("fldofs revents", offsetof(platcheck_t, revents));
	dump("fldsize revents",   sizeof(s.revents));
	s.revents = 0; s.revents = ~s.revents;
	dump("fldunsigned revents", s.revents > 0);
}

void dump_section_protoent(void) {
	typedef struct protoent platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs p_proto", offsetof(platcheck_t, p_proto));
	dump("fldsize p_proto",   sizeof(s.p_proto));
	s.p_proto = 0; s.p_proto = ~s.p_proto;
	dump("fldunsigned p_proto", s.p_proto > 0);
}

void dump_section_servent(void) {
	typedef struct servent platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs s_name", offsetof(platcheck_t, s_name));
	dump("fldsize s_name",   sizeof(s.s_name));
	dump("fldofs s_port", offsetof(platcheck_t, s_port));
	dump("fldsize s_port",   sizeof(s.s_port));
	s.s_port = 0; s.s_port = ~s.s_port;
	dump("fldunsigned s_port", s.s_port > 0);
	dump("fldofs s_proto", offsetof(platcheck_t, s_proto));
	dump("fldsize s_proto",   sizeof(s.s_proto));
}

void dump_section_size_t(void) {
	typedef size_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_sockaddr(void) {
	typedef struct sockaddr platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sa_family", offsetof(platcheck_t, sa_family));
	dump("fldsize sa_family",   sizeof(s.sa_family));
	s.sa_family = 0; s.sa_family = ~s.sa_family;
	dump("fldunsigned sa_family", s.sa_family > 0);
	dump("fldofs sa_data", offsetof(platcheck_t, sa_data));
	dump("fldsize sa_data",   sizeof(s.sa_data));
}

void dump_section_sockaddr_in(void) {
	typedef struct sockaddr_in platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sin_family", offsetof(platcheck_t, sin_family));
	dump("fldsize sin_family",   sizeof(s.sin_family));
	s.sin_family = 0; s.sin_family = ~s.sin_family;
	dump("fldunsigned sin_family", s.sin_family > 0);
	dump("fldofs sin_port", offsetof(platcheck_t, sin_port));
	dump("fldsize sin_port",   sizeof(s.sin_port));
	s.sin_port = 0; s.sin_port = ~s.sin_port;
	dump("fldunsigned sin_port", s.sin_port > 0);
	dump("fldofs sin_addr", offsetof(platcheck_t, sin_addr));
	dump("fldsize sin_addr",   sizeof(s.sin_addr));
}

void dump_section_sockaddr_in6(void) {
	typedef struct sockaddr_in6 platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sin6_family", offsetof(platcheck_t, sin6_family));
	dump("fldsize sin6_family",   sizeof(s.sin6_family));
	s.sin6_family = 0; s.sin6_family = ~s.sin6_family;
	dump("fldunsigned sin6_family", s.sin6_family > 0);
	dump("fldofs sin6_port", offsetof(platcheck_t, sin6_port));
	dump("fldsize sin6_port",   sizeof(s.sin6_port));
	s.sin6_port = 0; s.sin6_port = ~s.sin6_port;
	dump("fldunsigned sin6_port", s.sin6_port > 0);
	dump("fldofs sin6_flowinfo", offsetof(platcheck_t, sin6_flowinfo));
	dump("fldsize sin6_flowinfo",   sizeof(s.sin6_flowinfo));
	s.sin6_flowinfo = 0; s.sin6_flowinfo = ~s.sin6_flowinfo;
	dump("fldunsigned sin6_flowinfo", s.sin6_flowinfo > 0);
	dump("fldofs sin6_addr", offsetof(platcheck_t, sin6_addr));
	dump("fldsize sin6_addr",   sizeof(s.sin6_addr));
	dump("fldofs sin6_scope_id", offsetof(platcheck_t, sin6_scope_id));
	dump("fldsize sin6_scope_id",   sizeof(s.sin6_scope_id));
	s.sin6_scope_id = 0; s.sin6_scope_id = ~s.sin6_scope_id;
	dump("fldunsigned sin6_scope_id", s.sin6_scope_id > 0);
}

void dump_section_sockaddr_ll(void) {
	typedef struct sockaddr_ll platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sll_family", offsetof(platcheck_t, sll_family));
	dump("fldsize sll_family",   sizeof(s.sll_family));
	s.sll_family = 0; s.sll_family = ~s.sll_family;
	dump("fldunsigned sll_family", s.sll_family > 0);
	dump("fldofs sll_ifindex", offsetof(platcheck_t, sll_ifindex));
	dump("fldsize sll_ifindex",   sizeof(s.sll_ifindex));
	s.sll_ifindex = 0; s.sll_ifindex = ~s.sll_ifindex;
	dump("fldunsigned sll_ifindex", s.sll_ifindex > 0);
	dump("fldofs sll_protocol", offsetof(platcheck_t, sll_protocol));
	dump("fldsize sll_protocol",   sizeof(s.sll_protocol));
	s.sll_protocol = 0; s.sll_protocol = ~s.sll_protocol;
	dump("fldunsigned sll_protocol", s.sll_protocol > 0);
	dump("fldofs sll_pkttype", offsetof(platcheck_t, sll_pkttype));
	dump("fldsize sll_pkttype",   sizeof(s.sll_pkttype));
	s.sll_pkttype = 0; s.sll_pkttype = ~s.sll_pkttype;
	dump("fldunsigned sll_pkttype", s.sll_pkttype > 0);
	dump("fldofs sll_hatype", offsetof(platcheck_t, sll_hatype));
	dump("fldsize sll_hatype",   sizeof(s.sll_hatype));
	s.sll_hatype = 0; s.sll_hatype = ~s.sll_hatype;
	dump("fldunsigned sll_hatype", s.sll_hatype > 0);
	dump("fldofs sll_addr", offsetof(platcheck_t, sll_addr));
	dump("fldsize sll_addr",   sizeof(s.sll_addr));
	dump("fldofs sll_halen", offsetof(platcheck_t, sll_halen));
	dump("fldsize sll_halen",   sizeof(s.sll_halen));
	s.sll_halen = 0; s.sll_halen = ~s.sll_halen;
	dump("fldunsigned sll_halen", s.sll_halen > 0);
}

void dump_section_sockaddr_nl(void) {
#ifdef AF_NETLINK
	typedef struct sockaddr_nl platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("defined", 1);
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs nl_family", offsetof(platcheck_t, nl_family));
	dump("fldsize nl_family",   sizeof(s.nl_family));
	s.nl_family = 0; s.nl_family = ~s.nl_family;
	dump("fldunsigned nl_family", s.nl_family > 0);
	dump("fldofs nl_pid", offsetof(platcheck_t, nl_pid));
	dump("fldsize nl_pid",   sizeof(s.nl_pid));
	s.nl_pid = 0; s.nl_pid = ~s.nl_pid;
	dump("fldunsigned nl_pid", s.nl_pid > 0);
	dump("fldofs nl_groups", offsetof(platcheck_t, nl_groups));
	dump("fldsize nl_groups",   sizeof(s.nl_groups));
	s.nl_groups = 0; s.nl_groups = ~s.nl_groups;
	dump("fldunsigned nl_groups", s.nl_groups > 0);
#else
	dump("defined", 0);
#endif
}

void dump_section_sockaddr_un(void) {
#ifdef AF_UNIX
	typedef struct sockaddr_un platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("defined", 1);
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sun_family", offsetof(platcheck_t, sun_family));
	dump("fldsize sun_family",   sizeof(s.sun_family));
	s.sun_family = 0; s.sun_family = ~s.sun_family;
	dump("fldunsigned sun_family", s.sun_family > 0);
	dump("fldofs sun_path", offsetof(platcheck_t, sun_path));
	dump("fldsize sun_path",   sizeof(s.sun_path));
#else
	dump("defined", 0);
#endif
}

void dump_section_socklen_t(void) {
	typedef socklen_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_ssize_t(void) {
	typedef ssize_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_timeval(void) {
	typedef struct timeval platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs tv_sec", offsetof(platcheck_t, tv_sec));
	dump("fldsize tv_sec",   sizeof(s.tv_sec));
	s.tv_sec = 0; s.tv_sec = ~s.tv_sec;
	dump("fldunsigned tv_sec", s.tv_sec > 0);
	dump("fldofs tv_usec", offsetof(platcheck_t, tv_usec));
	dump("fldsize tv_usec",   sizeof(s.tv_usec));
	s.tv_usec = 0; s.tv_usec = ~s.tv_usec;
	dump("fldunsigned tv_usec", s.tv_usec > 0);
}

void dump_section_uint16_t(void) {
	typedef uint16_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_uint32_t(void) {
	typedef uint32_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- AD_DECnet\n");
	dump_section_AD_DECnet();
	printf("---\n");
	printf("-+- AF_AAL5\n");
	dump_section_AF_AAL5();
	printf("---\n");
	printf("-+- AF_APPLETALK\n");
	dump_section_AF_APPLETALK();
	printf("---\n");
	printf("-+- AF_ASH\n");
	dump_section_AF_ASH();
	printf("---\n");
	printf("-+- AF_ATMPVC\n");
	dump_section_AF_ATMPVC();
	printf("---\n");
	printf("-+- AF_ATMSVC\n");
	dump_section_AF_ATMSVC();
	printf("---\n");
	printf("-+- AF_AX25\n");
	dump_section_AF_AX25();
	printf("---\n");
	printf("-+- AF_BLUETOOTH\n");
	dump_section_AF_BLUETOOTH();
	printf("---\n");
	printf("-+- AF_BRIDGE\n");
	dump_section_AF_BRIDGE();
	printf("---\n");
	printf("-+- AF_ECONET\n");
	dump_section_AF_ECONET();
	printf("---\n");
	printf("-+- AF_INET\n");
	dump_section_AF_INET();
	printf("---\n");
	printf("-+- AF_INET6\n");
	dump_section_AF_INET6();
	printf("---\n");
	printf("-+- AF_IPX\n");
	dump_section_AF_IPX();
	printf("---\n");
	printf("-+- AF_IRDA\n");
	dump_section_AF_IRDA();
	printf("---\n");
	printf("-+- AF_KEY\n");
	dump_section_AF_KEY();
	printf("---\n");
	printf("-+- AF_LLC\n");
	dump_section_AF_LLC();
	printf("---\n");
	printf("-+- AF_NETBEUI\n");
	dump_section_AF_NETBEUI();
	printf("---\n");
	printf("-+- AF_NETLINK\n");
	dump_section_AF_NETLINK();
	printf("---\n");
	printf("-+- AF_NETROM\n");
	dump_section_AF_NETROM();
	printf("---\n");
	printf("-+- AF_PACKET\n");
	dump_section_AF_PACKET();
	printf("---\n");
	printf("-+- AF_PPPOX\n");
	dump_section_AF_PPPOX();
	printf("---\n");
	printf("-+- AF_ROSE\n");
	dump_section_AF_ROSE();
	printf("---\n");
	printf("-+- AF_ROUTE\n");
	dump_section_AF_ROUTE();
	printf("---\n");
	printf("-+- AF_SECURITY\n");
	dump_section_AF_SECURITY();
	printf("---\n");
	printf("-+- AF_SNA\n");
	dump_section_AF_SNA();
	printf("---\n");
	printf("-+- AF_UNIX\n");
	dump_section_AF_UNIX();
	printf("---\n");
	printf("-+- AF_UNSPEC\n");
	dump_section_AF_UNSPEC();
	printf("---\n");
	printf("-+- AF_WANPIPE\n");
	dump_section_AF_WANPIPE();
	printf("---\n");
	printf("-+- AF_X25\n");
	dump_section_AF_X25();
	printf("---\n");
	printf("-+- AI_ADDRCONFIG\n");
	dump_section_AI_ADDRCONFIG();
	printf("---\n");
	printf("-+- AI_ALL\n");
	dump_section_AI_ALL();
	printf("---\n");
	printf("-+- AI_CANONNAME\n");
	dump_section_AI_CANONNAME();
	printf("---\n");
	printf("-+- AI_DEFAULT\n");
	dump_section_AI_DEFAULT();
	printf("---\n");
	printf("-+- AI_MASK\n");
	dump_section_AI_MASK();
	printf("---\n");
	printf("-+- AI_NUMERICHOST\n");
	dump_section_AI_NUMERICHOST();
	printf("---\n");
	printf("-+- AI_NUMERICSERV\n");
	dump_section_AI_NUMERICSERV();
	printf("---\n");
	printf("-+- AI_PASSIVE\n");
	dump_section_AI_PASSIVE();
	printf("---\n");
	printf("-+- AI_V4MAPPED\n");
	dump_section_AI_V4MAPPED();
	printf("---\n");
	printf("-+- AI_V4MAPPED_CFG\n");
	dump_section_AI_V4MAPPED_CFG();
	printf("---\n");
	printf("-+- BTPROTO_L2CAP\n");
	dump_section_BTPROTO_L2CAP();
	printf("---\n");
	printf("-+- BTPROTO_RFCOMM\n");
	dump_section_BTPROTO_RFCOMM();
	printf("---\n");
	printf("-+- BTPROTO_SCO\n");
	dump_section_BTPROTO_SCO();
	printf("---\n");
	printf("-+- EAFNOSUPPORT\n");
	dump_section_EAFNOSUPPORT();
	printf("---\n");
	printf("-+- EAI_ADDRFAMILY\n");
	dump_section_EAI_ADDRFAMILY();
	printf("---\n");
	printf("-+- EAI_AGAIN\n");
	dump_section_EAI_AGAIN();
	printf("---\n");
	printf("-+- EAI_BADFLAGS\n");
	dump_section_EAI_BADFLAGS();
	printf("---\n");
	printf("-+- EAI_BADHINTS\n");
	dump_section_EAI_BADHINTS();
	printf("---\n");
	printf("-+- EAI_FAIL\n");
	dump_section_EAI_FAIL();
	printf("---\n");
	printf("-+- EAI_FAMILY\n");
	dump_section_EAI_FAMILY();
	printf("---\n");
	printf("-+- EAI_MAX\n");
	dump_section_EAI_MAX();
	printf("---\n");
	printf("-+- EAI_MEMORY\n");
	dump_section_EAI_MEMORY();
	printf("---\n");
	printf("-+- EAI_NODATA\n");
	dump_section_EAI_NODATA();
	printf("---\n");
	printf("-+- EAI_NONAME\n");
	dump_section_EAI_NONAME();
	printf("---\n");
	printf("-+- EAI_OVERFLOW\n");
	dump_section_EAI_OVERFLOW();
	printf("---\n");
	printf("-+- EAI_PROTOCOL\n");
	dump_section_EAI_PROTOCOL();
	printf("---\n");
	printf("-+- EAI_SERVICE\n");
	dump_section_EAI_SERVICE();
	printf("---\n");
	printf("-+- EAI_SOCKTYPE\n");
	dump_section_EAI_SOCKTYPE();
	printf("---\n");
	printf("-+- EAI_SYSTEM\n");
	dump_section_EAI_SYSTEM();
	printf("---\n");
	printf("-+- EINPROGRESS\n");
	dump_section_EINPROGRESS();
	printf("---\n");
	printf("-+- EINTR\n");
	dump_section_EINTR();
	printf("---\n");
	printf("-+- EISCONN\n");
	dump_section_EISCONN();
	printf("---\n");
	printf("-+- EWOULDBLOCK\n");
	dump_section_EWOULDBLOCK();
	printf("---\n");
	printf("-+- FD_ACCEPT\n");
	dump_section_FD_ACCEPT();
	printf("---\n");
	printf("-+- FD_CLOSE\n");
	dump_section_FD_CLOSE();
	printf("---\n");
	printf("-+- FD_CLOSE_BIT\n");
	dump_section_FD_CLOSE_BIT();
	printf("---\n");
	printf("-+- FD_CONNECT\n");
	dump_section_FD_CONNECT();
	printf("---\n");
	printf("-+- FD_CONNECT_BIT\n");
	dump_section_FD_CONNECT_BIT();
	printf("---\n");
	printf("-+- FD_READ\n");
	dump_section_FD_READ();
	printf("---\n");
	printf("-+- FD_SETSIZE\n");
	dump_section_FD_SETSIZE();
	printf("---\n");
	printf("-+- FD_WRITE\n");
	dump_section_FD_WRITE();
	printf("---\n");
	printf("-+- FIONBIO\n");
	dump_section_FIONBIO();
	printf("---\n");
	printf("-+- F_GETFL\n");
	dump_section_F_GETFL();
	printf("---\n");
	printf("-+- F_SETFL\n");
	dump_section_F_SETFL();
	printf("---\n");
	printf("-+- INADDR_ALLHOSTS_GROUP\n");
	dump_section_INADDR_ALLHOSTS_GROUP();
	printf("---\n");
	printf("-+- INADDR_ANY\n");
	dump_section_INADDR_ANY();
	printf("---\n");
	printf("-+- INADDR_BROADCAST\n");
	dump_section_INADDR_BROADCAST();
	printf("---\n");
	printf("-+- INADDR_LOOPBACK\n");
	dump_section_INADDR_LOOPBACK();
	printf("---\n");
	printf("-+- INADDR_MAX_LOCAL_GROUP\n");
	dump_section_INADDR_MAX_LOCAL_GROUP();
	printf("---\n");
	printf("-+- INADDR_NONE\n");
	dump_section_INADDR_NONE();
	printf("---\n");
	printf("-+- INADDR_UNSPEC_GROUP\n");
	dump_section_INADDR_UNSPEC_GROUP();
	printf("---\n");
	printf("-+- INET6_ADDRSTRLEN\n");
	dump_section_INET6_ADDRSTRLEN();
	printf("---\n");
	printf("-+- INET_ADDRSTRLEN\n");
	dump_section_INET_ADDRSTRLEN();
	printf("---\n");
	printf("-+- INFINITE\n");
	dump_section_INFINITE();
	printf("---\n");
	printf("-+- INVALID_SOCKET\n");
	dump_section_INVALID_SOCKET();
	printf("---\n");
	printf("-+- IPPORT_RESERVED\n");
	dump_section_IPPORT_RESERVED();
	printf("---\n");
	printf("-+- IPPORT_USERRESERVED\n");
	dump_section_IPPORT_USERRESERVED();
	printf("---\n");
	printf("-+- IPPROTO_AH\n");
	dump_section_IPPROTO_AH();
	printf("---\n");
	printf("-+- IPPROTO_BIP\n");
	dump_section_IPPROTO_BIP();
	printf("---\n");
	printf("-+- IPPROTO_DSTOPTS\n");
	dump_section_IPPROTO_DSTOPTS();
	printf("---\n");
	printf("-+- IPPROTO_EGP\n");
	dump_section_IPPROTO_EGP();
	printf("---\n");
	printf("-+- IPPROTO_EON\n");
	dump_section_IPPROTO_EON();
	printf("---\n");
	printf("-+- IPPROTO_ESP\n");
	dump_section_IPPROTO_ESP();
	printf("---\n");
	printf("-+- IPPROTO_FRAGMENT\n");
	dump_section_IPPROTO_FRAGMENT();
	printf("---\n");
	printf("-+- IPPROTO_GGP\n");
	dump_section_IPPROTO_GGP();
	printf("---\n");
	printf("-+- IPPROTO_GRE\n");
	dump_section_IPPROTO_GRE();
	printf("---\n");
	printf("-+- IPPROTO_HELLO\n");
	dump_section_IPPROTO_HELLO();
	printf("---\n");
	printf("-+- IPPROTO_HOPOPTS\n");
	dump_section_IPPROTO_HOPOPTS();
	printf("---\n");
	printf("-+- IPPROTO_ICMP\n");
	dump_section_IPPROTO_ICMP();
	printf("---\n");
	printf("-+- IPPROTO_ICMPV6\n");
	dump_section_IPPROTO_ICMPV6();
	printf("---\n");
	printf("-+- IPPROTO_IDP\n");
	dump_section_IPPROTO_IDP();
	printf("---\n");
	printf("-+- IPPROTO_IGMP\n");
	dump_section_IPPROTO_IGMP();
	printf("---\n");
	printf("-+- IPPROTO_IP\n");
	dump_section_IPPROTO_IP();
	printf("---\n");
	printf("-+- IPPROTO_IPCOMP\n");
	dump_section_IPPROTO_IPCOMP();
	printf("---\n");
	printf("-+- IPPROTO_IPIP\n");
	dump_section_IPPROTO_IPIP();
	printf("---\n");
	printf("-+- IPPROTO_IPV4\n");
	dump_section_IPPROTO_IPV4();
	printf("---\n");
	printf("-+- IPPROTO_IPV6\n");
	dump_section_IPPROTO_IPV6();
	printf("---\n");
	printf("-+- IPPROTO_MAX\n");
	dump_section_IPPROTO_MAX();
	printf("---\n");
	printf("-+- IPPROTO_MOBILE\n");
	dump_section_IPPROTO_MOBILE();
	printf("---\n");
	printf("-+- IPPROTO_ND\n");
	dump_section_IPPROTO_ND();
	printf("---\n");
	printf("-+- IPPROTO_NONE\n");
	dump_section_IPPROTO_NONE();
	printf("---\n");
	printf("-+- IPPROTO_PIM\n");
	dump_section_IPPROTO_PIM();
	printf("---\n");
	printf("-+- IPPROTO_PUP\n");
	dump_section_IPPROTO_PUP();
	printf("---\n");
	printf("-+- IPPROTO_RAW\n");
	dump_section_IPPROTO_RAW();
	printf("---\n");
	printf("-+- IPPROTO_ROUTING\n");
	dump_section_IPPROTO_ROUTING();
	printf("---\n");
	printf("-+- IPPROTO_RSVP\n");
	dump_section_IPPROTO_RSVP();
	printf("---\n");
	printf("-+- IPPROTO_TCP\n");
	dump_section_IPPROTO_TCP();
	printf("---\n");
	printf("-+- IPPROTO_TP\n");
	dump_section_IPPROTO_TP();
	printf("---\n");
	printf("-+- IPPROTO_UDP\n");
	dump_section_IPPROTO_UDP();
	printf("---\n");
	printf("-+- IPPROTO_VRRP\n");
	dump_section_IPPROTO_VRRP();
	printf("---\n");
	printf("-+- IPPROTO_XTP\n");
	dump_section_IPPROTO_XTP();
	printf("---\n");
	printf("-+- IPV6_CHECKSUM\n");
	dump_section_IPV6_CHECKSUM();
	printf("---\n");
	printf("-+- IPV6_DONTFRAG\n");
	dump_section_IPV6_DONTFRAG();
	printf("---\n");
	printf("-+- IPV6_DSTOPTS\n");
	dump_section_IPV6_DSTOPTS();
	printf("---\n");
	printf("-+- IPV6_HOPLIMIT\n");
	dump_section_IPV6_HOPLIMIT();
	printf("---\n");
	printf("-+- IPV6_HOPOPTS\n");
	dump_section_IPV6_HOPOPTS();
	printf("---\n");
	printf("-+- IPV6_JOIN_GROUP\n");
	dump_section_IPV6_JOIN_GROUP();
	printf("---\n");
	printf("-+- IPV6_LEAVE_GROUP\n");
	dump_section_IPV6_LEAVE_GROUP();
	printf("---\n");
	printf("-+- IPV6_MULTICAST_HOPS\n");
	dump_section_IPV6_MULTICAST_HOPS();
	printf("---\n");
	printf("-+- IPV6_MULTICAST_IF\n");
	dump_section_IPV6_MULTICAST_IF();
	printf("---\n");
	printf("-+- IPV6_MULTICAST_LOOP\n");
	dump_section_IPV6_MULTICAST_LOOP();
	printf("---\n");
	printf("-+- IPV6_NEXTHOP\n");
	dump_section_IPV6_NEXTHOP();
	printf("---\n");
	printf("-+- IPV6_PATHMTU\n");
	dump_section_IPV6_PATHMTU();
	printf("---\n");
	printf("-+- IPV6_PKTINFO\n");
	dump_section_IPV6_PKTINFO();
	printf("---\n");
	printf("-+- IPV6_RECVDSTOPTS\n");
	dump_section_IPV6_RECVDSTOPTS();
	printf("---\n");
	printf("-+- IPV6_RECVHOPLIMIT\n");
	dump_section_IPV6_RECVHOPLIMIT();
	printf("---\n");
	printf("-+- IPV6_RECVHOPOPTS\n");
	dump_section_IPV6_RECVHOPOPTS();
	printf("---\n");
	printf("-+- IPV6_RECVPATHMTU\n");
	dump_section_IPV6_RECVPATHMTU();
	printf("---\n");
	printf("-+- IPV6_RECVPKTINFO\n");
	dump_section_IPV6_RECVPKTINFO();
	printf("---\n");
	printf("-+- IPV6_RECVRTHDR\n");
	dump_section_IPV6_RECVRTHDR();
	printf("---\n");
	printf("-+- IPV6_RECVTCLASS\n");
	dump_section_IPV6_RECVTCLASS();
	printf("---\n");
	printf("-+- IPV6_RTHDR\n");
	dump_section_IPV6_RTHDR();
	printf("---\n");
	printf("-+- IPV6_RTHDRDSTOPTS\n");
	dump_section_IPV6_RTHDRDSTOPTS();
	printf("---\n");
	printf("-+- IPV6_RTHDR_TYPE_0\n");
	dump_section_IPV6_RTHDR_TYPE_0();
	printf("---\n");
	printf("-+- IPV6_TCLASS\n");
	dump_section_IPV6_TCLASS();
	printf("---\n");
	printf("-+- IPV6_UNICAST_HOPS\n");
	dump_section_IPV6_UNICAST_HOPS();
	printf("---\n");
	printf("-+- IPV6_USE_MIN_MTU\n");
	dump_section_IPV6_USE_MIN_MTU();
	printf("---\n");
	printf("-+- IPV6_V6ONLY\n");
	dump_section_IPV6_V6ONLY();
	printf("---\n");
	printf("-+- IPX_TYPE\n");
	dump_section_IPX_TYPE();
	printf("---\n");
	printf("-+- IP_ADD_MEMBERSHIP\n");
	dump_section_IP_ADD_MEMBERSHIP();
	printf("---\n");
	printf("-+- IP_DEFAULT_MULTICAST_LOOP\n");
	dump_section_IP_DEFAULT_MULTICAST_LOOP();
	printf("---\n");
	printf("-+- IP_DEFAULT_MULTICAST_TTL\n");
	dump_section_IP_DEFAULT_MULTICAST_TTL();
	printf("---\n");
	printf("-+- IP_DROP_MEMBERSHIP\n");
	dump_section_IP_DROP_MEMBERSHIP();
	printf("---\n");
	printf("-+- IP_HDRINCL\n");
	dump_section_IP_HDRINCL();
	printf("---\n");
	printf("-+- IP_MAX_MEMBERSHIPS\n");
	dump_section_IP_MAX_MEMBERSHIPS();
	printf("---\n");
	printf("-+- IP_MULTICAST_IF\n");
	dump_section_IP_MULTICAST_IF();
	printf("---\n");
	printf("-+- IP_MULTICAST_LOOP\n");
	dump_section_IP_MULTICAST_LOOP();
	printf("---\n");
	printf("-+- IP_MULTICAST_TTL\n");
	dump_section_IP_MULTICAST_TTL();
	printf("---\n");
	printf("-+- IP_OPTIONS\n");
	dump_section_IP_OPTIONS();
	printf("---\n");
	printf("-+- IP_RECVDSTADDR\n");
	dump_section_IP_RECVDSTADDR();
	printf("---\n");
	printf("-+- IP_RECVOPTS\n");
	dump_section_IP_RECVOPTS();
	printf("---\n");
	printf("-+- IP_RECVRETOPTS\n");
	dump_section_IP_RECVRETOPTS();
	printf("---\n");
	printf("-+- IP_RETOPTS\n");
	dump_section_IP_RETOPTS();
	printf("---\n");
	printf("-+- IP_TOS\n");
	dump_section_IP_TOS();
	printf("---\n");
	printf("-+- IP_TTL\n");
	dump_section_IP_TTL();
	printf("---\n");
	printf("-+- MSG_BTAG\n");
	dump_section_MSG_BTAG();
	printf("---\n");
	printf("-+- MSG_CTRUNC\n");
	dump_section_MSG_CTRUNC();
	printf("---\n");
	printf("-+- MSG_DONTROUTE\n");
	dump_section_MSG_DONTROUTE();
	printf("---\n");
	printf("-+- MSG_DONTWAIT\n");
	dump_section_MSG_DONTWAIT();
	printf("---\n");
	printf("-+- MSG_EOR\n");
	dump_section_MSG_EOR();
	printf("---\n");
	printf("-+- MSG_ETAG\n");
	dump_section_MSG_ETAG();
	printf("---\n");
	printf("-+- MSG_OOB\n");
	dump_section_MSG_OOB();
	printf("---\n");
	printf("-+- MSG_PEEK\n");
	dump_section_MSG_PEEK();
	printf("---\n");
	printf("-+- MSG_TRUNC\n");
	dump_section_MSG_TRUNC();
	printf("---\n");
	printf("-+- MSG_WAITALL\n");
	dump_section_MSG_WAITALL();
	printf("---\n");
	printf("-+- NETLINK_ARPD\n");
	dump_section_NETLINK_ARPD();
	printf("---\n");
	printf("-+- NETLINK_DNRTMSG\n");
	dump_section_NETLINK_DNRTMSG();
	printf("---\n");
	printf("-+- NETLINK_FIREWALL\n");
	dump_section_NETLINK_FIREWALL();
	printf("---\n");
	printf("-+- NETLINK_IP6_FW\n");
	dump_section_NETLINK_IP6_FW();
	printf("---\n");
	printf("-+- NETLINK_NFLOG\n");
	dump_section_NETLINK_NFLOG();
	printf("---\n");
	printf("-+- NETLINK_ROUTE\n");
	dump_section_NETLINK_ROUTE();
	printf("---\n");
	printf("-+- NETLINK_ROUTE6\n");
	dump_section_NETLINK_ROUTE6();
	printf("---\n");
	printf("-+- NETLINK_SKIP\n");
	dump_section_NETLINK_SKIP();
	printf("---\n");
	printf("-+- NETLINK_TAPBASE\n");
	dump_section_NETLINK_TAPBASE();
	printf("---\n");
	printf("-+- NETLINK_TCPDIAG\n");
	dump_section_NETLINK_TCPDIAG();
	printf("---\n");
	printf("-+- NETLINK_USERSOCK\n");
	dump_section_NETLINK_USERSOCK();
	printf("---\n");
	printf("-+- NETLINK_W1\n");
	dump_section_NETLINK_W1();
	printf("---\n");
	printf("-+- NETLINK_XFRM\n");
	dump_section_NETLINK_XFRM();
	printf("---\n");
	printf("-+- NI_DGRAM\n");
	dump_section_NI_DGRAM();
	printf("---\n");
	printf("-+- NI_MAXHOST\n");
	dump_section_NI_MAXHOST();
	printf("---\n");
	printf("-+- NI_MAXSERV\n");
	dump_section_NI_MAXSERV();
	printf("---\n");
	printf("-+- NI_NAMEREQD\n");
	dump_section_NI_NAMEREQD();
	printf("---\n");
	printf("-+- NI_NOFQDN\n");
	dump_section_NI_NOFQDN();
	printf("---\n");
	printf("-+- NI_NUMERICHOST\n");
	dump_section_NI_NUMERICHOST();
	printf("---\n");
	printf("-+- NI_NUMERICSERV\n");
	dump_section_NI_NUMERICSERV();
	printf("---\n");
	printf("-+- O_NONBLOCK\n");
	dump_section_O_NONBLOCK();
	printf("---\n");
	printf("-+- O_RDONLY\n");
	dump_section_O_RDONLY();
	printf("---\n");
	printf("-+- O_RDWR\n");
	dump_section_O_RDWR();
	printf("---\n");
	printf("-+- O_WRONLY\n");
	dump_section_O_WRONLY();
	printf("---\n");
	printf("-+- PACKET_BROADCAST\n");
	dump_section_PACKET_BROADCAST();
	printf("---\n");
	printf("-+- PACKET_FASTROUTE\n");
	dump_section_PACKET_FASTROUTE();
	printf("---\n");
	printf("-+- PACKET_HOST\n");
	dump_section_PACKET_HOST();
	printf("---\n");
	printf("-+- PACKET_LOOPBACK\n");
	dump_section_PACKET_LOOPBACK();
	printf("---\n");
	printf("-+- PACKET_MULTICAST\n");
	dump_section_PACKET_MULTICAST();
	printf("---\n");
	printf("-+- PACKET_OTHERHOST\n");
	dump_section_PACKET_OTHERHOST();
	printf("---\n");
	printf("-+- PACKET_OUTGOING\n");
	dump_section_PACKET_OUTGOING();
	printf("---\n");
	printf("-+- POLLERR\n");
	dump_section_POLLERR();
	printf("---\n");
	printf("-+- POLLHUP\n");
	dump_section_POLLHUP();
	printf("---\n");
	printf("-+- POLLIN\n");
	dump_section_POLLIN();
	printf("---\n");
	printf("-+- POLLMSG\n");
	dump_section_POLLMSG();
	printf("---\n");
	printf("-+- POLLNVAL\n");
	dump_section_POLLNVAL();
	printf("---\n");
	printf("-+- POLLOUT\n");
	dump_section_POLLOUT();
	printf("---\n");
	printf("-+- POLLPRI\n");
	dump_section_POLLPRI();
	printf("---\n");
	printf("-+- POLLRDBAND\n");
	dump_section_POLLRDBAND();
	printf("---\n");
	printf("-+- POLLRDNORM\n");
	dump_section_POLLRDNORM();
	printf("---\n");
	printf("-+- POLLWEBAND\n");
	dump_section_POLLWEBAND();
	printf("---\n");
	printf("-+- POLLWRNORM\n");
	dump_section_POLLWRNORM();
	printf("---\n");
	printf("-+- SHUT_RD\n");
	dump_section_SHUT_RD();
	printf("---\n");
	printf("-+- SHUT_RDWR\n");
	dump_section_SHUT_RDWR();
	printf("---\n");
	printf("-+- SHUT_WR\n");
	dump_section_SHUT_WR();
	printf("---\n");
	printf("-+- SIOCGIFINDEX\n");
	dump_section_SIOCGIFINDEX();
	printf("---\n");
	printf("-+- SIOCGIFNAME\n");
	dump_section_SIOCGIFNAME();
	printf("---\n");
	printf("-+- SIO_KEEPALIVE_VALS\n");
	dump_section_SIO_KEEPALIVE_VALS();
	printf("---\n");
	printf("-+- SIO_RCVALL\n");
	dump_section_SIO_RCVALL();
	printf("---\n");
	printf("-+- SOCK_DGRAM\n");
	dump_section_SOCK_DGRAM();
	printf("---\n");
	printf("-+- SOCK_RAW\n");
	dump_section_SOCK_RAW();
	printf("---\n");
	printf("-+- SOCK_RDM\n");
	dump_section_SOCK_RDM();
	printf("---\n");
	printf("-+- SOCK_SEQPACKET\n");
	dump_section_SOCK_SEQPACKET();
	printf("---\n");
	printf("-+- SOCK_STREAM\n");
	dump_section_SOCK_STREAM();
	printf("---\n");
	printf("-+- SOL_ATALK\n");
	dump_section_SOL_ATALK();
	printf("---\n");
	printf("-+- SOL_AX25\n");
	dump_section_SOL_AX25();
	printf("---\n");
	printf("-+- SOL_IP\n");
	dump_section_SOL_IP();
	printf("---\n");
	printf("-+- SOL_IPX\n");
	dump_section_SOL_IPX();
	printf("---\n");
	printf("-+- SOL_NETROM\n");
	dump_section_SOL_NETROM();
	printf("---\n");
	printf("-+- SOL_ROSE\n");
	dump_section_SOL_ROSE();
	printf("---\n");
	printf("-+- SOL_SOCKET\n");
	dump_section_SOL_SOCKET();
	printf("---\n");
	printf("-+- SOL_TCP\n");
	dump_section_SOL_TCP();
	printf("---\n");
	printf("-+- SOL_UDP\n");
	dump_section_SOL_UDP();
	printf("---\n");
	printf("-+- SOMAXCONN\n");
	dump_section_SOMAXCONN();
	printf("---\n");
	printf("-+- SO_ACCEPTCONN\n");
	dump_section_SO_ACCEPTCONN();
	printf("---\n");
	printf("-+- SO_BROADCAST\n");
	dump_section_SO_BROADCAST();
	printf("---\n");
	printf("-+- SO_DEBUG\n");
	dump_section_SO_DEBUG();
	printf("---\n");
	printf("-+- SO_DONTROUTE\n");
	dump_section_SO_DONTROUTE();
	printf("---\n");
	printf("-+- SO_ERROR\n");
	dump_section_SO_ERROR();
	printf("---\n");
	printf("-+- SO_EXCLUSIVEADDRUSE\n");
	dump_section_SO_EXCLUSIVEADDRUSE();
	printf("---\n");
	printf("-+- SO_KEEPALIVE\n");
	dump_section_SO_KEEPALIVE();
	printf("---\n");
	printf("-+- SO_LINGER\n");
	dump_section_SO_LINGER();
	printf("---\n");
	printf("-+- SO_OOBINLINE\n");
	dump_section_SO_OOBINLINE();
	printf("---\n");
	printf("-+- SO_RCVBUF\n");
	dump_section_SO_RCVBUF();
	printf("---\n");
	printf("-+- SO_RCVLOWAT\n");
	dump_section_SO_RCVLOWAT();
	printf("---\n");
	printf("-+- SO_RCVTIMEO\n");
	dump_section_SO_RCVTIMEO();
	printf("---\n");
	printf("-+- SO_REUSEADDR\n");
	dump_section_SO_REUSEADDR();
	printf("---\n");
	printf("-+- SO_REUSEPORT\n");
	dump_section_SO_REUSEPORT();
	printf("---\n");
	printf("-+- SO_SNDBUF\n");
	dump_section_SO_SNDBUF();
	printf("---\n");
	printf("-+- SO_SNDLOWAT\n");
	dump_section_SO_SNDLOWAT();
	printf("---\n");
	printf("-+- SO_SNDTIMEO\n");
	dump_section_SO_SNDTIMEO();
	printf("---\n");
	printf("-+- SO_TYPE\n");
	dump_section_SO_TYPE();
	printf("---\n");
	printf("-+- SO_USELOOPBACK\n");
	dump_section_SO_USELOOPBACK();
	printf("---\n");
	printf("-+- TCP_CORK\n");
	dump_section_TCP_CORK();
	printf("---\n");
	printf("-+- TCP_DEFER_ACCEPT\n");
	dump_section_TCP_DEFER_ACCEPT();
	printf("---\n");
	printf("-+- TCP_INFO\n");
	dump_section_TCP_INFO();
	printf("---\n");
	printf("-+- TCP_KEEPCNT\n");
	dump_section_TCP_KEEPCNT();
	printf("---\n");
	printf("-+- TCP_KEEPIDLE\n");
	dump_section_TCP_KEEPIDLE();
	printf("---\n");
	printf("-+- TCP_KEEPINTVL\n");
	dump_section_TCP_KEEPINTVL();
	printf("---\n");
	printf("-+- TCP_LINGER2\n");
	dump_section_TCP_LINGER2();
	printf("---\n");
	printf("-+- TCP_MAXSEG\n");
	dump_section_TCP_MAXSEG();
	printf("---\n");
	printf("-+- TCP_NODELAY\n");
	dump_section_TCP_NODELAY();
	printf("---\n");
	printf("-+- TCP_QUICKACK\n");
	dump_section_TCP_QUICKACK();
	printf("---\n");
	printf("-+- TCP_SYNCNT\n");
	dump_section_TCP_SYNCNT();
	printf("---\n");
	printf("-+- TCP_WINDOW_CLAMP\n");
	dump_section_TCP_WINDOW_CLAMP();
	printf("---\n");
	printf("-+- WIN32\n");
	dump_section_WIN32();
	printf("---\n");
	printf("-+- WSAEAFNOSUPPORT\n");
	dump_section_WSAEAFNOSUPPORT();
	printf("---\n");
	printf("-+- WSAEINPROGRESS\n");
	dump_section_WSAEINPROGRESS();
	printf("---\n");
	printf("-+- WSAEINTR\n");
	dump_section_WSAEINTR();
	printf("---\n");
	printf("-+- WSAEISCONN\n");
	dump_section_WSAEISCONN();
	printf("---\n");
	printf("-+- WSAEWOULDBLOCK\n");
	dump_section_WSAEWOULDBLOCK();
	printf("---\n");
	printf("-+- WSA_INVALID_HANDLE\n");
	dump_section_WSA_INVALID_HANDLE();
	printf("---\n");
	printf("-+- WSA_INVALID_PARAMETER\n");
	dump_section_WSA_INVALID_PARAMETER();
	printf("---\n");
	printf("-+- WSA_IO_INCOMPLETE\n");
	dump_section_WSA_IO_INCOMPLETE();
	printf("---\n");
	printf("-+- WSA_IO_PENDING\n");
	dump_section_WSA_IO_PENDING();
	printf("---\n");
	printf("-+- WSA_NOT_ENOUGH_MEMORY\n");
	dump_section_WSA_NOT_ENOUGH_MEMORY();
	printf("---\n");
	printf("-+- WSA_OPERATION_ABORTED\n");
	dump_section_WSA_OPERATION_ABORTED();
	printf("---\n");
	printf("-+- WSA_WAIT_FAILED\n");
	dump_section_WSA_WAIT_FAILED();
	printf("---\n");
	printf("-+- WSA_WAIT_TIMEOUT\n");
	dump_section_WSA_WAIT_TIMEOUT();
	printf("---\n");
	printf("-+- addrinfo\n");
	dump_section_addrinfo();
	printf("---\n");
	printf("-+- hostent\n");
	dump_section_hostent();
	printf("---\n");
	printf("-+- ifreq\n");
	dump_section_ifreq();
	printf("---\n");
	printf("-+- in6_addr\n");
	dump_section_in6_addr();
	printf("---\n");
	printf("-+- in_addr\n");
	dump_section_in_addr();
	printf("---\n");
	printf("-+- linux\n");
	dump_section_linux();
	printf("---\n");
	printf("-+- nfds_t\n");
	dump_section_nfds_t();
	printf("---\n");
	printf("-+- pollfd\n");
	dump_section_pollfd();
	printf("---\n");
	printf("-+- protoent\n");
	dump_section_protoent();
	printf("---\n");
	printf("-+- servent\n");
	dump_section_servent();
	printf("---\n");
	printf("-+- size_t\n");
	dump_section_size_t();
	printf("---\n");
	printf("-+- sockaddr\n");
	dump_section_sockaddr();
	printf("---\n");
	printf("-+- sockaddr_in\n");
	dump_section_sockaddr_in();
	printf("---\n");
	printf("-+- sockaddr_in6\n");
	dump_section_sockaddr_in6();
	printf("---\n");
	printf("-+- sockaddr_ll\n");
	dump_section_sockaddr_ll();
	printf("---\n");
	printf("-+- sockaddr_nl\n");
	dump_section_sockaddr_nl();
	printf("---\n");
	printf("-+- sockaddr_un\n");
	dump_section_sockaddr_un();
	printf("---\n");
	printf("-+- socklen_t\n");
	dump_section_socklen_t();
	printf("---\n");
	printf("-+- ssize_t\n");
	dump_section_ssize_t();
	printf("---\n");
	printf("-+- timeval\n");
	dump_section_timeval();
	printf("---\n");
	printf("-+- uint16_t\n");
	dump_section_uint16_t();
	printf("---\n");
	printf("-+- uint32_t\n");
	dump_section_uint32_t();
	printf("---\n");
	return 0;
}
