/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <zlib.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_Bytef(void) {
	typedef Bytef platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_MAX_MEM_LEVEL(void) {
	if ((MAX_MEM_LEVEL) <= 0) {
	    long long x = (long long)(MAX_MEM_LEVEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAX_MEM_LEVEL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_MAX_WBITS(void) {
	if ((MAX_WBITS) <= 0) {
	    long long x = (long long)(MAX_WBITS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAX_WBITS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_ZLIB_VERSION(void) {
#ifdef ZLIB_VERSION
	int i;
	const char *p = ZLIB_VERSION;
	dump("defined", 1);
	for (i = 0; p[i] != 0; i++ ) {
	  printf("value_%d: %d\n", i, (int)(unsigned char)p[i]);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_Z_BEST_COMPRESSION(void) {
	if ((Z_BEST_COMPRESSION) <= 0) {
	    long long x = (long long)(Z_BEST_COMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_BEST_COMPRESSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_BEST_SPEED(void) {
	if ((Z_BEST_SPEED) <= 0) {
	    long long x = (long long)(Z_BEST_SPEED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_BEST_SPEED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_BUF_ERROR(void) {
	if ((Z_BUF_ERROR) <= 0) {
	    long long x = (long long)(Z_BUF_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_BUF_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_DATA_ERROR(void) {
	if ((Z_DATA_ERROR) <= 0) {
	    long long x = (long long)(Z_DATA_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DATA_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_DEFAULT_COMPRESSION(void) {
	if ((Z_DEFAULT_COMPRESSION) <= 0) {
	    long long x = (long long)(Z_DEFAULT_COMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DEFAULT_COMPRESSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_DEFAULT_STRATEGY(void) {
	if ((Z_DEFAULT_STRATEGY) <= 0) {
	    long long x = (long long)(Z_DEFAULT_STRATEGY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DEFAULT_STRATEGY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_DEFLATED(void) {
	if ((Z_DEFLATED) <= 0) {
	    long long x = (long long)(Z_DEFLATED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_DEFLATED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_FILTERED(void) {
	if ((Z_FILTERED) <= 0) {
	    long long x = (long long)(Z_FILTERED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_FILTERED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_FINISH(void) {
	if ((Z_FINISH) <= 0) {
	    long long x = (long long)(Z_FINISH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_FINISH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_FULL_FLUSH(void) {
	if ((Z_FULL_FLUSH) <= 0) {
	    long long x = (long long)(Z_FULL_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_FULL_FLUSH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_HUFFMAN_ONLY(void) {
	if ((Z_HUFFMAN_ONLY) <= 0) {
	    long long x = (long long)(Z_HUFFMAN_ONLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_HUFFMAN_ONLY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_MEM_ERROR(void) {
	if ((Z_MEM_ERROR) <= 0) {
	    long long x = (long long)(Z_MEM_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_MEM_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_NEED_DICT(void) {
	if ((Z_NEED_DICT) <= 0) {
	    long long x = (long long)(Z_NEED_DICT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_NEED_DICT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_NO_FLUSH(void) {
	if ((Z_NO_FLUSH) <= 0) {
	    long long x = (long long)(Z_NO_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_NO_FLUSH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_OK(void) {
	if ((Z_OK) <= 0) {
	    long long x = (long long)(Z_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_OK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_STREAM_END(void) {
	if ((Z_STREAM_END) <= 0) {
	    long long x = (long long)(Z_STREAM_END);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_STREAM_END);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_STREAM_ERROR(void) {
	if ((Z_STREAM_ERROR) <= 0) {
	    long long x = (long long)(Z_STREAM_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_STREAM_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Z_SYNC_FLUSH(void) {
	if ((Z_SYNC_FLUSH) <= 0) {
	    long long x = (long long)(Z_SYNC_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Z_SYNC_FLUSH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_uInt(void) {
	typedef uInt platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_uLong(void) {
	typedef uLong platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_voidpf(void) {
	typedef voidpf platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
}

int main(int argc, char *argv[]) {
	printf("-+- Bytef\n");
	dump_section_Bytef();
	printf("---\n");
	printf("-+- MAX_MEM_LEVEL\n");
	dump_section_MAX_MEM_LEVEL();
	printf("---\n");
	printf("-+- MAX_WBITS\n");
	dump_section_MAX_WBITS();
	printf("---\n");
	printf("-+- ZLIB_VERSION\n");
	dump_section_ZLIB_VERSION();
	printf("---\n");
	printf("-+- Z_BEST_COMPRESSION\n");
	dump_section_Z_BEST_COMPRESSION();
	printf("---\n");
	printf("-+- Z_BEST_SPEED\n");
	dump_section_Z_BEST_SPEED();
	printf("---\n");
	printf("-+- Z_BUF_ERROR\n");
	dump_section_Z_BUF_ERROR();
	printf("---\n");
	printf("-+- Z_DATA_ERROR\n");
	dump_section_Z_DATA_ERROR();
	printf("---\n");
	printf("-+- Z_DEFAULT_COMPRESSION\n");
	dump_section_Z_DEFAULT_COMPRESSION();
	printf("---\n");
	printf("-+- Z_DEFAULT_STRATEGY\n");
	dump_section_Z_DEFAULT_STRATEGY();
	printf("---\n");
	printf("-+- Z_DEFLATED\n");
	dump_section_Z_DEFLATED();
	printf("---\n");
	printf("-+- Z_FILTERED\n");
	dump_section_Z_FILTERED();
	printf("---\n");
	printf("-+- Z_FINISH\n");
	dump_section_Z_FINISH();
	printf("---\n");
	printf("-+- Z_FULL_FLUSH\n");
	dump_section_Z_FULL_FLUSH();
	printf("---\n");
	printf("-+- Z_HUFFMAN_ONLY\n");
	dump_section_Z_HUFFMAN_ONLY();
	printf("---\n");
	printf("-+- Z_MEM_ERROR\n");
	dump_section_Z_MEM_ERROR();
	printf("---\n");
	printf("-+- Z_NEED_DICT\n");
	dump_section_Z_NEED_DICT();
	printf("---\n");
	printf("-+- Z_NO_FLUSH\n");
	dump_section_Z_NO_FLUSH();
	printf("---\n");
	printf("-+- Z_OK\n");
	dump_section_Z_OK();
	printf("---\n");
	printf("-+- Z_STREAM_END\n");
	dump_section_Z_STREAM_END();
	printf("---\n");
	printf("-+- Z_STREAM_ERROR\n");
	dump_section_Z_STREAM_ERROR();
	printf("---\n");
	printf("-+- Z_SYNC_FLUSH\n");
	dump_section_Z_SYNC_FLUSH();
	printf("---\n");
	printf("-+- uInt\n");
	dump_section_uInt();
	printf("---\n");
	printf("-+- uLong\n");
	dump_section_uLong();
	printf("---\n");
	printf("-+- voidpf\n");
	dump_section_voidpf();
	printf("---\n");
	return 0;
}
