/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <openssl/ssl.h>
#include <openssl/err.h>
#include <openssl/rand.h>
#include <openssl/evp.h>
#include <openssl/ossl_typ.h>
#include <openssl/x509v3.h>
#include <openssl/comp.h>
#define pypy_GENERAL_NAME_dirn(name) (name->d.dirn)
#define pypy_GENERAL_NAME_uri(name) (name->d.uniformResourceIdentifier)
#define pypy_GENERAL_NAME_pop_free(names) (sk_GENERAL_NAME_pop_free(names, GENERAL_NAME_free))
#define pypy_X509_OBJECT_data_x509(obj) (obj->data.x509)
#define pypy_DIST_POINT_fullname(obj) (obj->distpoint->name.fullname)

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_ACCESS_DESCRIPTION_st(void) {
	typedef struct ACCESS_DESCRIPTION_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs method", offsetof(platcheck_t, method));
	dump("fldsize method",   sizeof(s.method));
	dump("fldofs location", offsetof(platcheck_t, location));
	dump("fldsize location",   sizeof(s.location));
}

void dump_section_ASN1_R_HEADER_TOO_LONG(void) {
	if ((ASN1_R_HEADER_TOO_LONG) <= 0) {
	    long long x = (long long)(ASN1_R_HEADER_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ASN1_R_HEADER_TOO_LONG);
	    printf("value: %llu\n", x);
	}
}

void dump_section_COMP_METHOD_st(void) {
	typedef struct comp_method_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	s.type = 0; s.type = ~s.type;
	dump("fldunsigned type", s.type > 0);
}

void dump_section_CRYPTO_LOCK(void) {
	if ((CRYPTO_LOCK) <= 0) {
	    long long x = (long long)(CRYPTO_LOCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRYPTO_LOCK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_ERR_LIB_ASN1(void) {
	if ((ERR_LIB_ASN1) <= 0) {
	    long long x = (long long)(ERR_LIB_ASN1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_ASN1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_ERR_LIB_PEM(void) {
	if ((ERR_LIB_PEM) <= 0) {
	    long long x = (long long)(ERR_LIB_PEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_PEM);
	    printf("value: %llu\n", x);
	}
}

void dump_section_ERR_LIB_X509(void) {
	if ((ERR_LIB_X509) <= 0) {
	    long long x = (long long)(ERR_LIB_X509);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_X509);
	    printf("value: %llu\n", x);
	}
}

void dump_section_EVP_MD_CTX_SIZE(void) {
	dump("size",  sizeof(EVP_MD_CTX));
}

void dump_section_EVP_MD_SIZE(void) {
	dump("size",  sizeof(EVP_MD));
}

void dump_section_EVP_MD_st(void) {
	typedef EVP_MD platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs md_size", offsetof(platcheck_t, md_size));
	dump("fldsize md_size",   sizeof(s.md_size));
	s.md_size = 0; s.md_size = ~s.md_size;
	dump("fldunsigned md_size", s.md_size > 0);
	dump("fldofs block_size", offsetof(platcheck_t, block_size));
	dump("fldsize block_size",   sizeof(s.block_size));
	s.block_size = 0; s.block_size = ~s.block_size;
	dump("fldunsigned block_size", s.block_size > 0);
}

void dump_section_GENERAL_NAME_st(void) {
	typedef struct GENERAL_NAME_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	s.type = 0; s.type = ~s.type;
	dump("fldunsigned type", s.type > 0);
}

void dump_section_GEN_DIRNAME(void) {
	if ((GEN_DIRNAME) <= 0) {
	    long long x = (long long)(GEN_DIRNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_DIRNAME);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_DNS(void) {
	if ((GEN_DNS) <= 0) {
	    long long x = (long long)(GEN_DNS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_DNS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_EDIPARTY(void) {
	if ((GEN_EDIPARTY) <= 0) {
	    long long x = (long long)(GEN_EDIPARTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_EDIPARTY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_EMAIL(void) {
	if ((GEN_EMAIL) <= 0) {
	    long long x = (long long)(GEN_EMAIL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_EMAIL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_IPADD(void) {
	if ((GEN_IPADD) <= 0) {
	    long long x = (long long)(GEN_IPADD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_IPADD);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_OTHERNAME(void) {
	if ((GEN_OTHERNAME) <= 0) {
	    long long x = (long long)(GEN_OTHERNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_OTHERNAME);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_RID(void) {
	if ((GEN_RID) <= 0) {
	    long long x = (long long)(GEN_RID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_RID);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_URI(void) {
	if ((GEN_URI) <= 0) {
	    long long x = (long long)(GEN_URI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_URI);
	    printf("value: %llu\n", x);
	}
}

void dump_section_GEN_X400(void) {
	if ((GEN_X400) <= 0) {
	    long long x = (long long)(GEN_X400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(GEN_X400);
	    printf("value: %llu\n", x);
	}
}

void dump_section_HAS_NPN(void) {
#ifdef OPENSSL_NPN_NEGOTIATED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_HAS_SNI(void) {
#ifdef SSL_CTRL_SET_TLSEXT_HOSTNAME
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_NID_X9_62_prime256v1(void) {
	if ((NID_X9_62_prime256v1) <= 0) {
	    long long x = (long long)(NID_X9_62_prime256v1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_X9_62_prime256v1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_NID_ad_OCSP(void) {
	if ((NID_ad_OCSP) <= 0) {
	    long long x = (long long)(NID_ad_OCSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_ad_OCSP);
	    printf("value: %llu\n", x);
	}
}

void dump_section_NID_ad_ca_issuers(void) {
	if ((NID_ad_ca_issuers) <= 0) {
	    long long x = (long long)(NID_ad_ca_issuers);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_ad_ca_issuers);
	    printf("value: %llu\n", x);
	}
}

void dump_section_NID_crl_distribution_points(void) {
	if ((NID_crl_distribution_points) <= 0) {
	    long long x = (long long)(NID_crl_distribution_points);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_crl_distribution_points);
	    printf("value: %llu\n", x);
	}
}

void dump_section_NID_info_access(void) {
	if ((NID_info_access) <= 0) {
	    long long x = (long long)(NID_info_access);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_info_access);
	    printf("value: %llu\n", x);
	}
}

void dump_section_NID_subject_alt_name(void) {
	if ((NID_subject_alt_name) <= 0) {
	    long long x = (long long)(NID_subject_alt_name);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_subject_alt_name);
	    printf("value: %llu\n", x);
	}
}

void dump_section_NID_undef(void) {
	if ((NID_undef) <= 0) {
	    long long x = (long long)(NID_undef);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NID_undef);
	    printf("value: %llu\n", x);
	}
}

void dump_section_OBJ_NAME_TYPE_MD_METH(void) {
	if ((OBJ_NAME_TYPE_MD_METH) <= 0) {
	    long long x = (long long)(OBJ_NAME_TYPE_MD_METH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OBJ_NAME_TYPE_MD_METH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_OBJ_NAME_st(void) {
	typedef OBJ_NAME platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs alias", offsetof(platcheck_t, alias));
	dump("fldsize alias",   sizeof(s.alias));
	s.alias = 0; s.alias = ~s.alias;
	dump("fldunsigned alias", s.alias > 0);
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
}

void dump_section_OPENSSL_NO_ECDH(void) {
#ifdef OPENSSL_NO_ECDH
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_OPENSSL_NO_SSL2(void) {
#ifdef OPENSSL_NO_SSL2
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_OPENSSL_NO_SSL3(void) {
#ifdef OPENSSL_NO_SSL3
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_OPENSSL_NO_TLSEXT(void) {
#ifdef OPENSSL_NO_TLSEXT
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_OPENSSL_NPN_NEGOTIATED(void) {
#ifdef OPENSSL_NPN_NEGOTIATED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section_PEM_R_NO_START_LINE(void) {
	if ((PEM_R_NO_START_LINE) <= 0) {
	    long long x = (long long)(PEM_R_NO_START_LINE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_NO_START_LINE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSLEAY_VERSION(void) {
#ifdef SSLEAY_VERSION
	int i;
	const char *p = SSLeay_version(SSLEAY_VERSION);
	dump("defined", 1);
	for (i = 0; p[i] != 0; i++ ) {
	  printf("value_%d: %d\n", i, (int)(unsigned char)p[i]);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_AD_HANDSHAKE_FAILURE(void) {
	if ((SSL_AD_HANDSHAKE_FAILURE) <= 0) {
	    long long x = (long long)(SSL_AD_HANDSHAKE_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_HANDSHAKE_FAILURE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_AD_INTERNAL_ERROR(void) {
	if ((SSL_AD_INTERNAL_ERROR) <= 0) {
	    long long x = (long long)(SSL_AD_INTERNAL_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_INTERNAL_ERROR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_ERROR_SSL(void) {
	if ((SSL_ERROR_SSL) <= 0) {
	    long long x = (long long)(SSL_ERROR_SSL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_SSL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_ERROR_SYSCALL(void) {
	if ((SSL_ERROR_SYSCALL) <= 0) {
	    long long x = (long long)(SSL_ERROR_SYSCALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_SYSCALL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_ERROR_WANT_CONNECT(void) {
	if ((SSL_ERROR_WANT_CONNECT) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_CONNECT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_CONNECT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_ERROR_WANT_READ(void) {
	if ((SSL_ERROR_WANT_READ) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_READ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_ERROR_WANT_WRITE(void) {
	if ((SSL_ERROR_WANT_WRITE) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_WRITE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_ERROR_WANT_X509_LOOKUP(void) {
	if ((SSL_ERROR_WANT_X509_LOOKUP) <= 0) {
	    long long x = (long long)(SSL_ERROR_WANT_X509_LOOKUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_WANT_X509_LOOKUP);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_ERROR_ZERO_RETURN(void) {
	if ((SSL_ERROR_ZERO_RETURN) <= 0) {
	    long long x = (long long)(SSL_ERROR_ZERO_RETURN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_ERROR_ZERO_RETURN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_FILETYPE_ASN1(void) {
	if ((SSL_FILETYPE_ASN1) <= 0) {
	    long long x = (long long)(SSL_FILETYPE_ASN1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_FILETYPE_ASN1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_FILETYPE_PEM(void) {
	if ((SSL_FILETYPE_PEM) <= 0) {
	    long long x = (long long)(SSL_FILETYPE_PEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_FILETYPE_PEM);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER(void) {
	if ((SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER) <= 0) {
	    long long x = (long long)(SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_MODE_AUTO_RETRY(void) {
	if ((SSL_MODE_AUTO_RETRY) <= 0) {
	    long long x = (long long)(SSL_MODE_AUTO_RETRY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_MODE_AUTO_RETRY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_ALL(void) {
	if ((SSL_OP_ALL) <= 0) {
	    long long x = (long long)(SSL_OP_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_ALL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_CIPHER_SERVER_PREFERENCE(void) {
	if ((SSL_OP_CIPHER_SERVER_PREFERENCE) <= 0) {
	    long long x = (long long)(SSL_OP_CIPHER_SERVER_PREFERENCE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_CIPHER_SERVER_PREFERENCE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS(void) {
	if ((SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS) <= 0) {
	    long long x = (long long)(SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_NO_COMPRESSION(void) {
#ifdef SSL_OP_NO_COMPRESSION
	dump("defined", 1);
	if ((SSL_OP_NO_COMPRESSION) <= 0) {
	    long long x = (long long)(SSL_OP_NO_COMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_COMPRESSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_OP_NO_SSLv2(void) {
	if ((SSL_OP_NO_SSLv2) <= 0) {
	    long long x = (long long)(SSL_OP_NO_SSLv2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_SSLv2);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_NO_SSLv3(void) {
	if ((SSL_OP_NO_SSLv3) <= 0) {
	    long long x = (long long)(SSL_OP_NO_SSLv3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_SSLv3);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_NO_TLSv1(void) {
	if ((SSL_OP_NO_TLSv1) <= 0) {
	    long long x = (long long)(SSL_OP_NO_TLSv1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_TLSv1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_NO_TLSv1_1(void) {
	if ((SSL_OP_NO_TLSv1_1) <= 0) {
	    long long x = (long long)(SSL_OP_NO_TLSv1_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_TLSv1_1);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_NO_TLSv1_2(void) {
	if ((SSL_OP_NO_TLSv1_2) <= 0) {
	    long long x = (long long)(SSL_OP_NO_TLSv1_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_NO_TLSv1_2);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_SINGLE_DH_USE(void) {
	if ((SSL_OP_SINGLE_DH_USE) <= 0) {
	    long long x = (long long)(SSL_OP_SINGLE_DH_USE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_SINGLE_DH_USE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_OP_SINGLE_ECDH_USE(void) {
	if ((SSL_OP_SINGLE_ECDH_USE) <= 0) {
	    long long x = (long long)(SSL_OP_SINGLE_ECDH_USE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_OP_SINGLE_ECDH_USE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_RECEIVED_SHUTDOWN(void) {
	if ((SSL_RECEIVED_SHUTDOWN) <= 0) {
	    long long x = (long long)(SSL_RECEIVED_SHUTDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_RECEIVED_SHUTDOWN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_TLSEXT_ERR_ALERT_FATAL(void) {
	if ((SSL_TLSEXT_ERR_ALERT_FATAL) <= 0) {
	    long long x = (long long)(SSL_TLSEXT_ERR_ALERT_FATAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_TLSEXT_ERR_ALERT_FATAL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_TLSEXT_ERR_NOACK(void) {
	if ((SSL_TLSEXT_ERR_NOACK) <= 0) {
	    long long x = (long long)(SSL_TLSEXT_ERR_NOACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_TLSEXT_ERR_NOACK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_TLSEXT_ERR_OK(void) {
	if ((SSL_TLSEXT_ERR_OK) <= 0) {
	    long long x = (long long)(SSL_TLSEXT_ERR_OK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_TLSEXT_ERR_OK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_VERIFY_FAIL_IF_NO_PEER_CERT(void) {
	if ((SSL_VERIFY_FAIL_IF_NO_PEER_CERT) <= 0) {
	    long long x = (long long)(SSL_VERIFY_FAIL_IF_NO_PEER_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_VERIFY_FAIL_IF_NO_PEER_CERT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_VERIFY_NONE(void) {
	if ((SSL_VERIFY_NONE) <= 0) {
	    long long x = (long long)(SSL_VERIFY_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_VERIFY_NONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL_VERIFY_PEER(void) {
	if ((SSL_VERIFY_PEER) <= 0) {
	    long long x = (long long)(SSL_VERIFY_PEER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_VERIFY_PEER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_TLSEXT_NAMETYPE_host_name(void) {
	if ((TLSEXT_NAMETYPE_host_name) <= 0) {
	    long long x = (long long)(TLSEXT_NAMETYPE_host_name);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TLSEXT_NAMETYPE_host_name);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_LU_CRL(void) {
	if ((X509_LU_CRL) <= 0) {
	    long long x = (long long)(X509_LU_CRL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_LU_CRL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_LU_X509(void) {
	if ((X509_LU_X509) <= 0) {
	    long long x = (long long)(X509_LU_X509);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_LU_X509);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_R_CERT_ALREADY_IN_HASH_TABLE(void) {
	if ((X509_R_CERT_ALREADY_IN_HASH_TABLE) <= 0) {
	    long long x = (long long)(X509_R_CERT_ALREADY_IN_HASH_TABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_CERT_ALREADY_IN_HASH_TABLE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_V_FLAG_CRL_CHECK(void) {
	if ((X509_V_FLAG_CRL_CHECK) <= 0) {
	    long long x = (long long)(X509_V_FLAG_CRL_CHECK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_V_FLAG_CRL_CHECK);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_V_FLAG_CRL_CHECK_ALL(void) {
	if ((X509_V_FLAG_CRL_CHECK_ALL) <= 0) {
	    long long x = (long long)(X509_V_FLAG_CRL_CHECK_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_V_FLAG_CRL_CHECK_ALL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_V_FLAG_X509_STRICT(void) {
	if ((X509_V_FLAG_X509_STRICT) <= 0) {
	    long long x = (long long)(X509_V_FLAG_X509_STRICT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_V_FLAG_X509_STRICT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_extension_st(void) {
	typedef struct X509_extension_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs value", offsetof(platcheck_t, value));
	dump("fldsize value",   sizeof(s.value));
}

void dump_section_X509_name_entry_st(void) {
	typedef struct X509_name_entry_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs set", offsetof(platcheck_t, set));
	dump("fldsize set",   sizeof(s.set));
	s.set = 0; s.set = ~s.set;
	dump("fldunsigned set", s.set > 0);
}

void dump_section_X509_st(void) {
	typedef struct x509_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs crldp", offsetof(platcheck_t, crldp));
	dump("fldsize crldp",   sizeof(s.crldp));
}

void dump_section_asn1_string_st(void) {
	typedef struct asn1_string_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs length", offsetof(platcheck_t, length));
	dump("fldsize length",   sizeof(s.length));
	s.length = 0; s.length = ~s.length;
	dump("fldunsigned length", s.length > 0);
	dump("fldofs data", offsetof(platcheck_t, data));
	dump("fldsize data",   sizeof(s.data));
}

void dump_section_v3_ext_method(void) {
	typedef struct v3_ext_method platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs it", offsetof(platcheck_t, it));
	dump("fldsize it",   sizeof(s.it));
	dump("fldofs d2i", offsetof(platcheck_t, d2i));
	dump("fldsize d2i",   sizeof(s.d2i));
}

void dump_section_x509_object_st(void) {
	typedef struct x509_object_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	s.type = 0; s.type = ~s.type;
	dump("fldunsigned type", s.type > 0);
}

void dump_section_x509_store_st(void) {
	typedef struct x509_store_st platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs objs", offsetof(platcheck_t, objs));
	dump("fldsize objs",   sizeof(s.objs));
	dump("fldofs param", offsetof(platcheck_t, param));
	dump("fldsize param",   sizeof(s.param));
}

int main(int argc, char *argv[]) {
	printf("-+- ACCESS_DESCRIPTION_st\n");
	dump_section_ACCESS_DESCRIPTION_st();
	printf("---\n");
	printf("-+- ASN1_R_HEADER_TOO_LONG\n");
	dump_section_ASN1_R_HEADER_TOO_LONG();
	printf("---\n");
	printf("-+- COMP_METHOD_st\n");
	dump_section_COMP_METHOD_st();
	printf("---\n");
	printf("-+- CRYPTO_LOCK\n");
	dump_section_CRYPTO_LOCK();
	printf("---\n");
	printf("-+- ERR_LIB_ASN1\n");
	dump_section_ERR_LIB_ASN1();
	printf("---\n");
	printf("-+- ERR_LIB_PEM\n");
	dump_section_ERR_LIB_PEM();
	printf("---\n");
	printf("-+- ERR_LIB_X509\n");
	dump_section_ERR_LIB_X509();
	printf("---\n");
	printf("-+- EVP_MD_CTX_SIZE\n");
	dump_section_EVP_MD_CTX_SIZE();
	printf("---\n");
	printf("-+- EVP_MD_SIZE\n");
	dump_section_EVP_MD_SIZE();
	printf("---\n");
	printf("-+- EVP_MD_st\n");
	dump_section_EVP_MD_st();
	printf("---\n");
	printf("-+- GENERAL_NAME_st\n");
	dump_section_GENERAL_NAME_st();
	printf("---\n");
	printf("-+- GEN_DIRNAME\n");
	dump_section_GEN_DIRNAME();
	printf("---\n");
	printf("-+- GEN_DNS\n");
	dump_section_GEN_DNS();
	printf("---\n");
	printf("-+- GEN_EDIPARTY\n");
	dump_section_GEN_EDIPARTY();
	printf("---\n");
	printf("-+- GEN_EMAIL\n");
	dump_section_GEN_EMAIL();
	printf("---\n");
	printf("-+- GEN_IPADD\n");
	dump_section_GEN_IPADD();
	printf("---\n");
	printf("-+- GEN_OTHERNAME\n");
	dump_section_GEN_OTHERNAME();
	printf("---\n");
	printf("-+- GEN_RID\n");
	dump_section_GEN_RID();
	printf("---\n");
	printf("-+- GEN_URI\n");
	dump_section_GEN_URI();
	printf("---\n");
	printf("-+- GEN_X400\n");
	dump_section_GEN_X400();
	printf("---\n");
	printf("-+- HAS_NPN\n");
	dump_section_HAS_NPN();
	printf("---\n");
	printf("-+- HAS_SNI\n");
	dump_section_HAS_SNI();
	printf("---\n");
	printf("-+- NID_X9_62_prime256v1\n");
	dump_section_NID_X9_62_prime256v1();
	printf("---\n");
	printf("-+- NID_ad_OCSP\n");
	dump_section_NID_ad_OCSP();
	printf("---\n");
	printf("-+- NID_ad_ca_issuers\n");
	dump_section_NID_ad_ca_issuers();
	printf("---\n");
	printf("-+- NID_crl_distribution_points\n");
	dump_section_NID_crl_distribution_points();
	printf("---\n");
	printf("-+- NID_info_access\n");
	dump_section_NID_info_access();
	printf("---\n");
	printf("-+- NID_subject_alt_name\n");
	dump_section_NID_subject_alt_name();
	printf("---\n");
	printf("-+- NID_undef\n");
	dump_section_NID_undef();
	printf("---\n");
	printf("-+- OBJ_NAME_TYPE_MD_METH\n");
	dump_section_OBJ_NAME_TYPE_MD_METH();
	printf("---\n");
	printf("-+- OBJ_NAME_st\n");
	dump_section_OBJ_NAME_st();
	printf("---\n");
	printf("-+- OPENSSL_NO_ECDH\n");
	dump_section_OPENSSL_NO_ECDH();
	printf("---\n");
	printf("-+- OPENSSL_NO_SSL2\n");
	dump_section_OPENSSL_NO_SSL2();
	printf("---\n");
	printf("-+- OPENSSL_NO_SSL3\n");
	dump_section_OPENSSL_NO_SSL3();
	printf("---\n");
	printf("-+- OPENSSL_NO_TLSEXT\n");
	dump_section_OPENSSL_NO_TLSEXT();
	printf("---\n");
	printf("-+- OPENSSL_NPN_NEGOTIATED\n");
	dump_section_OPENSSL_NPN_NEGOTIATED();
	printf("---\n");
	printf("-+- PEM_R_NO_START_LINE\n");
	dump_section_PEM_R_NO_START_LINE();
	printf("---\n");
	printf("-+- SSLEAY_VERSION\n");
	dump_section_SSLEAY_VERSION();
	printf("---\n");
	printf("-+- SSL_AD_HANDSHAKE_FAILURE\n");
	dump_section_SSL_AD_HANDSHAKE_FAILURE();
	printf("---\n");
	printf("-+- SSL_AD_INTERNAL_ERROR\n");
	dump_section_SSL_AD_INTERNAL_ERROR();
	printf("---\n");
	printf("-+- SSL_ERROR_SSL\n");
	dump_section_SSL_ERROR_SSL();
	printf("---\n");
	printf("-+- SSL_ERROR_SYSCALL\n");
	dump_section_SSL_ERROR_SYSCALL();
	printf("---\n");
	printf("-+- SSL_ERROR_WANT_CONNECT\n");
	dump_section_SSL_ERROR_WANT_CONNECT();
	printf("---\n");
	printf("-+- SSL_ERROR_WANT_READ\n");
	dump_section_SSL_ERROR_WANT_READ();
	printf("---\n");
	printf("-+- SSL_ERROR_WANT_WRITE\n");
	dump_section_SSL_ERROR_WANT_WRITE();
	printf("---\n");
	printf("-+- SSL_ERROR_WANT_X509_LOOKUP\n");
	dump_section_SSL_ERROR_WANT_X509_LOOKUP();
	printf("---\n");
	printf("-+- SSL_ERROR_ZERO_RETURN\n");
	dump_section_SSL_ERROR_ZERO_RETURN();
	printf("---\n");
	printf("-+- SSL_FILETYPE_ASN1\n");
	dump_section_SSL_FILETYPE_ASN1();
	printf("---\n");
	printf("-+- SSL_FILETYPE_PEM\n");
	dump_section_SSL_FILETYPE_PEM();
	printf("---\n");
	printf("-+- SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER\n");
	dump_section_SSL_MODE_ACCEPT_MOVING_WRITE_BUFFER();
	printf("---\n");
	printf("-+- SSL_MODE_AUTO_RETRY\n");
	dump_section_SSL_MODE_AUTO_RETRY();
	printf("---\n");
	printf("-+- SSL_OP_ALL\n");
	dump_section_SSL_OP_ALL();
	printf("---\n");
	printf("-+- SSL_OP_CIPHER_SERVER_PREFERENCE\n");
	dump_section_SSL_OP_CIPHER_SERVER_PREFERENCE();
	printf("---\n");
	printf("-+- SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS\n");
	dump_section_SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS();
	printf("---\n");
	printf("-+- SSL_OP_NO_COMPRESSION\n");
	dump_section_SSL_OP_NO_COMPRESSION();
	printf("---\n");
	printf("-+- SSL_OP_NO_SSLv2\n");
	dump_section_SSL_OP_NO_SSLv2();
	printf("---\n");
	printf("-+- SSL_OP_NO_SSLv3\n");
	dump_section_SSL_OP_NO_SSLv3();
	printf("---\n");
	printf("-+- SSL_OP_NO_TLSv1\n");
	dump_section_SSL_OP_NO_TLSv1();
	printf("---\n");
	printf("-+- SSL_OP_NO_TLSv1_1\n");
	dump_section_SSL_OP_NO_TLSv1_1();
	printf("---\n");
	printf("-+- SSL_OP_NO_TLSv1_2\n");
	dump_section_SSL_OP_NO_TLSv1_2();
	printf("---\n");
	printf("-+- SSL_OP_SINGLE_DH_USE\n");
	dump_section_SSL_OP_SINGLE_DH_USE();
	printf("---\n");
	printf("-+- SSL_OP_SINGLE_ECDH_USE\n");
	dump_section_SSL_OP_SINGLE_ECDH_USE();
	printf("---\n");
	printf("-+- SSL_RECEIVED_SHUTDOWN\n");
	dump_section_SSL_RECEIVED_SHUTDOWN();
	printf("---\n");
	printf("-+- SSL_TLSEXT_ERR_ALERT_FATAL\n");
	dump_section_SSL_TLSEXT_ERR_ALERT_FATAL();
	printf("---\n");
	printf("-+- SSL_TLSEXT_ERR_NOACK\n");
	dump_section_SSL_TLSEXT_ERR_NOACK();
	printf("---\n");
	printf("-+- SSL_TLSEXT_ERR_OK\n");
	dump_section_SSL_TLSEXT_ERR_OK();
	printf("---\n");
	printf("-+- SSL_VERIFY_FAIL_IF_NO_PEER_CERT\n");
	dump_section_SSL_VERIFY_FAIL_IF_NO_PEER_CERT();
	printf("---\n");
	printf("-+- SSL_VERIFY_NONE\n");
	dump_section_SSL_VERIFY_NONE();
	printf("---\n");
	printf("-+- SSL_VERIFY_PEER\n");
	dump_section_SSL_VERIFY_PEER();
	printf("---\n");
	printf("-+- TLSEXT_NAMETYPE_host_name\n");
	dump_section_TLSEXT_NAMETYPE_host_name();
	printf("---\n");
	printf("-+- X509_LU_CRL\n");
	dump_section_X509_LU_CRL();
	printf("---\n");
	printf("-+- X509_LU_X509\n");
	dump_section_X509_LU_X509();
	printf("---\n");
	printf("-+- X509_R_CERT_ALREADY_IN_HASH_TABLE\n");
	dump_section_X509_R_CERT_ALREADY_IN_HASH_TABLE();
	printf("---\n");
	printf("-+- X509_V_FLAG_CRL_CHECK\n");
	dump_section_X509_V_FLAG_CRL_CHECK();
	printf("---\n");
	printf("-+- X509_V_FLAG_CRL_CHECK_ALL\n");
	dump_section_X509_V_FLAG_CRL_CHECK_ALL();
	printf("---\n");
	printf("-+- X509_V_FLAG_X509_STRICT\n");
	dump_section_X509_V_FLAG_X509_STRICT();
	printf("---\n");
	printf("-+- X509_extension_st\n");
	dump_section_X509_extension_st();
	printf("---\n");
	printf("-+- X509_name_entry_st\n");
	dump_section_X509_name_entry_st();
	printf("---\n");
	printf("-+- X509_st\n");
	dump_section_X509_st();
	printf("---\n");
	printf("-+- asn1_string_st\n");
	dump_section_asn1_string_st();
	printf("---\n");
	printf("-+- v3_ext_method\n");
	dump_section_v3_ext_method();
	printf("---\n");
	printf("-+- x509_object_st\n");
	dump_section_x509_object_st();
	printf("---\n");
	printf("-+- x509_store_st\n");
	dump_section_x509_store_st();
	printf("---\n");
	return 0;
}
