/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/types.h>
#include <unistd.h>
#include <sys/mman.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_MAP_ANON(void) {
#ifdef MAP_ANON
	dump("defined", 1);
	if ((MAP_ANON) <= 0) {
	    long long x = (long long)(MAP_ANON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_ANON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MAP_ANONYMOUS(void) {
#ifdef MAP_ANONYMOUS
	dump("defined", 1);
	if ((MAP_ANONYMOUS) <= 0) {
	    long long x = (long long)(MAP_ANONYMOUS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_ANONYMOUS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MAP_DENYWRITE(void) {
#ifdef MAP_DENYWRITE
	dump("defined", 1);
	if ((MAP_DENYWRITE) <= 0) {
	    long long x = (long long)(MAP_DENYWRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_DENYWRITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MAP_EXECUTABLE(void) {
#ifdef MAP_EXECUTABLE
	dump("defined", 1);
	if ((MAP_EXECUTABLE) <= 0) {
	    long long x = (long long)(MAP_EXECUTABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_EXECUTABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MAP_FIXED(void) {
	if ((MAP_FIXED) <= 0) {
	    long long x = (long long)(MAP_FIXED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_FIXED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_MAP_NORESERVE(void) {
#ifdef MAP_NORESERVE
	dump("defined", 1);
	if ((MAP_NORESERVE) <= 0) {
	    long long x = (long long)(MAP_NORESERVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_NORESERVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MAP_PRIVATE(void) {
	if ((MAP_PRIVATE) <= 0) {
	    long long x = (long long)(MAP_PRIVATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_PRIVATE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_MAP_SHARED(void) {
	if ((MAP_SHARED) <= 0) {
	    long long x = (long long)(MAP_SHARED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MAP_SHARED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_MREMAP_MAYMOVE(void) {
#ifdef MREMAP_MAYMOVE
	dump("defined", 1);
	if ((MREMAP_MAYMOVE) <= 0) {
	    long long x = (long long)(MREMAP_MAYMOVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MREMAP_MAYMOVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MS_SYNC(void) {
	if ((MS_SYNC) <= 0) {
	    long long x = (long long)(MS_SYNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MS_SYNC);
	    printf("value: %llu\n", x);
	}
}

void dump_section_PROT_EXEC(void) {
#ifdef PROT_EXEC
	dump("defined", 1);
	if ((PROT_EXEC) <= 0) {
	    long long x = (long long)(PROT_EXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PROT_EXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PROT_READ(void) {
	if ((PROT_READ) <= 0) {
	    long long x = (long long)(PROT_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PROT_READ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_PROT_WRITE(void) {
	if ((PROT_WRITE) <= 0) {
	    long long x = (long long)(PROT_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PROT_WRITE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_off_t(void) {
	typedef off_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_size_t(void) {
	typedef size_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- MAP_ANON\n");
	dump_section_MAP_ANON();
	printf("---\n");
	printf("-+- MAP_ANONYMOUS\n");
	dump_section_MAP_ANONYMOUS();
	printf("---\n");
	printf("-+- MAP_DENYWRITE\n");
	dump_section_MAP_DENYWRITE();
	printf("---\n");
	printf("-+- MAP_EXECUTABLE\n");
	dump_section_MAP_EXECUTABLE();
	printf("---\n");
	printf("-+- MAP_FIXED\n");
	dump_section_MAP_FIXED();
	printf("---\n");
	printf("-+- MAP_NORESERVE\n");
	dump_section_MAP_NORESERVE();
	printf("---\n");
	printf("-+- MAP_PRIVATE\n");
	dump_section_MAP_PRIVATE();
	printf("---\n");
	printf("-+- MAP_SHARED\n");
	dump_section_MAP_SHARED();
	printf("---\n");
	printf("-+- MREMAP_MAYMOVE\n");
	dump_section_MREMAP_MAYMOVE();
	printf("---\n");
	printf("-+- MS_SYNC\n");
	dump_section_MS_SYNC();
	printf("---\n");
	printf("-+- PROT_EXEC\n");
	dump_section_PROT_EXEC();
	printf("---\n");
	printf("-+- PROT_READ\n");
	dump_section_PROT_READ();
	printf("---\n");
	printf("-+- PROT_WRITE\n");
	dump_section_PROT_WRITE();
	printf("---\n");
	printf("-+- off_t\n");
	dump_section_off_t();
	printf("---\n");
	printf("-+- size_t\n");
	dump_section_size_t();
	printf("---\n");
	return 0;
}
