/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <dlfcn.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_RTLD_DEEPBIND(void) {
#ifdef RTLD_DEEPBIND
	dump("defined", 1);
	if ((RTLD_DEEPBIND) <= 0) {
	    long long x = (long long)(RTLD_DEEPBIND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RTLD_DEEPBIND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RTLD_GLOBAL(void) {
#ifdef RTLD_GLOBAL
	dump("defined", 1);
	if ((RTLD_GLOBAL) <= 0) {
	    long long x = (long long)(RTLD_GLOBAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RTLD_GLOBAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RTLD_LAZY(void) {
#ifdef RTLD_LAZY
	dump("defined", 1);
	if ((RTLD_LAZY) <= 0) {
	    long long x = (long long)(RTLD_LAZY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RTLD_LAZY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RTLD_LOCAL(void) {
#ifdef RTLD_LOCAL
	dump("defined", 1);
	if ((RTLD_LOCAL) <= 0) {
	    long long x = (long long)(RTLD_LOCAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RTLD_LOCAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RTLD_NODELETE(void) {
#ifdef RTLD_NODELETE
	dump("defined", 1);
	if ((RTLD_NODELETE) <= 0) {
	    long long x = (long long)(RTLD_NODELETE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RTLD_NODELETE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RTLD_NOLOAD(void) {
#ifdef RTLD_NOLOAD
	dump("defined", 1);
	if ((RTLD_NOLOAD) <= 0) {
	    long long x = (long long)(RTLD_NOLOAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RTLD_NOLOAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RTLD_NOW(void) {
#ifdef RTLD_NOW
	dump("defined", 1);
	if ((RTLD_NOW) <= 0) {
	    long long x = (long long)(RTLD_NOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RTLD_NOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- RTLD_DEEPBIND\n");
	dump_section_RTLD_DEEPBIND();
	printf("---\n");
	printf("-+- RTLD_GLOBAL\n");
	dump_section_RTLD_GLOBAL();
	printf("---\n");
	printf("-+- RTLD_LAZY\n");
	dump_section_RTLD_LAZY();
	printf("---\n");
	printf("-+- RTLD_LOCAL\n");
	dump_section_RTLD_LOCAL();
	printf("---\n");
	printf("-+- RTLD_NODELETE\n");
	dump_section_RTLD_NODELETE();
	printf("---\n");
	printf("-+- RTLD_NOLOAD\n");
	dump_section_RTLD_NOLOAD();
	printf("---\n");
	printf("-+- RTLD_NOW\n");
	dump_section_RTLD_NOW();
	printf("---\n");
	return 0;
}
