/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <Python.h>
#include <stdarg.h>
#include <structmember.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_METH_CLASS(void) {
	if ((METH_CLASS) <= 0) {
	    long long x = (long long)(METH_CLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_CLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_METH_COEXIST(void) {
	if ((METH_COEXIST) <= 0) {
	    long long x = (long long)(METH_COEXIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_COEXIST);
	    printf("value: %llu\n", x);
	}
}

void dump_section_METH_KEYWORDS(void) {
	if ((METH_KEYWORDS) <= 0) {
	    long long x = (long long)(METH_KEYWORDS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_KEYWORDS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_METH_NOARGS(void) {
	if ((METH_NOARGS) <= 0) {
	    long long x = (long long)(METH_NOARGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_NOARGS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_METH_O(void) {
	if ((METH_O) <= 0) {
	    long long x = (long long)(METH_O);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_O);
	    printf("value: %llu\n", x);
	}
}

void dump_section_METH_STATIC(void) {
	if ((METH_STATIC) <= 0) {
	    long long x = (long long)(METH_STATIC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_STATIC);
	    printf("value: %llu\n", x);
	}
}

void dump_section_METH_VARARGS(void) {
	if ((METH_VARARGS) <= 0) {
	    long long x = (long long)(METH_VARARGS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(METH_VARARGS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_EQ(void) {
	if ((Py_EQ) <= 0) {
	    long long x = (long long)(Py_EQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_EQ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_GE(void) {
	if ((Py_GE) <= 0) {
	    long long x = (long long)(Py_GE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_GE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_GT(void) {
	if ((Py_GT) <= 0) {
	    long long x = (long long)(Py_GT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_GT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_LE(void) {
	if ((Py_LE) <= 0) {
	    long long x = (long long)(Py_LE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_LE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_LT(void) {
	if ((Py_LT) <= 0) {
	    long long x = (long long)(Py_LT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_LT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_NE(void) {
	if ((Py_NE) <= 0) {
	    long long x = (long long)(Py_NE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_NE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_TPFLAGS_CHECKTYPES(void) {
	if ((Py_TPFLAGS_CHECKTYPES) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_CHECKTYPES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_CHECKTYPES);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_TPFLAGS_HAVE_CLASS(void) {
	if ((Py_TPFLAGS_HAVE_CLASS) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HAVE_CLASS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HAVE_CLASS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_TPFLAGS_HAVE_GETCHARBUFFER(void) {
	if ((Py_TPFLAGS_HAVE_GETCHARBUFFER) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HAVE_GETCHARBUFFER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HAVE_GETCHARBUFFER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_TPFLAGS_HEAPTYPE(void) {
	if ((Py_TPFLAGS_HEAPTYPE) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_HEAPTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_HEAPTYPE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_TPFLAGS_READY(void) {
	if ((Py_TPFLAGS_READY) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_READY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_READY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_Py_TPFLAGS_READYING(void) {
	if ((Py_TPFLAGS_READYING) <= 0) {
	    long long x = (long long)(Py_TPFLAGS_READYING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(Py_TPFLAGS_READYING);
	    printf("value: %llu\n", x);
	}
}

int main(int argc, char *argv[]) {
	printf("-+- METH_CLASS\n");
	dump_section_METH_CLASS();
	printf("---\n");
	printf("-+- METH_COEXIST\n");
	dump_section_METH_COEXIST();
	printf("---\n");
	printf("-+- METH_KEYWORDS\n");
	dump_section_METH_KEYWORDS();
	printf("---\n");
	printf("-+- METH_NOARGS\n");
	dump_section_METH_NOARGS();
	printf("---\n");
	printf("-+- METH_O\n");
	dump_section_METH_O();
	printf("---\n");
	printf("-+- METH_STATIC\n");
	dump_section_METH_STATIC();
	printf("---\n");
	printf("-+- METH_VARARGS\n");
	dump_section_METH_VARARGS();
	printf("---\n");
	printf("-+- Py_EQ\n");
	dump_section_Py_EQ();
	printf("---\n");
	printf("-+- Py_GE\n");
	dump_section_Py_GE();
	printf("---\n");
	printf("-+- Py_GT\n");
	dump_section_Py_GT();
	printf("---\n");
	printf("-+- Py_LE\n");
	dump_section_Py_LE();
	printf("---\n");
	printf("-+- Py_LT\n");
	dump_section_Py_LT();
	printf("---\n");
	printf("-+- Py_NE\n");
	dump_section_Py_NE();
	printf("---\n");
	printf("-+- Py_TPFLAGS_CHECKTYPES\n");
	dump_section_Py_TPFLAGS_CHECKTYPES();
	printf("---\n");
	printf("-+- Py_TPFLAGS_HAVE_CLASS\n");
	dump_section_Py_TPFLAGS_HAVE_CLASS();
	printf("---\n");
	printf("-+- Py_TPFLAGS_HAVE_GETCHARBUFFER\n");
	dump_section_Py_TPFLAGS_HAVE_GETCHARBUFFER();
	printf("---\n");
	printf("-+- Py_TPFLAGS_HEAPTYPE\n");
	dump_section_Py_TPFLAGS_HEAPTYPE();
	printf("---\n");
	printf("-+- Py_TPFLAGS_READY\n");
	dump_section_Py_TPFLAGS_READY();
	printf("---\n");
	printf("-+- Py_TPFLAGS_READYING\n");
	dump_section_Py_TPFLAGS_READYING();
	printf("---\n");
	return 0;
}
