/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <Python.h>
#include <stdarg.h>
#include <structmember.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_PyBufferObject(void) {
	typedef PyBufferObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs b_base", offsetof(platcheck_t, b_base));
	dump("fldsize b_base",   sizeof(s.b_base));
	dump("fldofs b_ptr", offsetof(platcheck_t, b_ptr));
	dump("fldsize b_ptr",   sizeof(s.b_ptr));
	dump("fldofs b_size", offsetof(platcheck_t, b_size));
	dump("fldsize b_size",   sizeof(s.b_size));
	s.b_size = 0; s.b_size = ~s.b_size;
	dump("fldunsigned b_size", s.b_size > 0);
	dump("fldofs b_offset", offsetof(platcheck_t, b_offset));
	dump("fldsize b_offset",   sizeof(s.b_offset));
	s.b_offset = 0; s.b_offset = ~s.b_offset;
	dump("fldunsigned b_offset", s.b_offset > 0);
	dump("fldofs b_readonly", offsetof(platcheck_t, b_readonly));
	dump("fldsize b_readonly",   sizeof(s.b_readonly));
	s.b_readonly = 0; s.b_readonly = ~s.b_readonly;
	dump("fldunsigned b_readonly", s.b_readonly > 0);
	dump("fldofs b_hash", offsetof(platcheck_t, b_hash));
	dump("fldsize b_hash",   sizeof(s.b_hash));
	s.b_hash = 0; s.b_hash = ~s.b_hash;
	dump("fldunsigned b_hash", s.b_hash > 0);
}

void dump_section_PyBufferProcs(void) {
	typedef PyBufferProcs platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs bf_getreadbuffer", offsetof(platcheck_t, bf_getreadbuffer));
	dump("fldsize bf_getreadbuffer",   sizeof(s.bf_getreadbuffer));
	dump("fldofs bf_getwritebuffer", offsetof(platcheck_t, bf_getwritebuffer));
	dump("fldsize bf_getwritebuffer",   sizeof(s.bf_getwritebuffer));
	dump("fldofs bf_getsegcount", offsetof(platcheck_t, bf_getsegcount));
	dump("fldsize bf_getsegcount",   sizeof(s.bf_getsegcount));
	dump("fldofs bf_getcharbuffer", offsetof(platcheck_t, bf_getcharbuffer));
	dump("fldsize bf_getcharbuffer",   sizeof(s.bf_getcharbuffer));
	dump("fldofs bf_getbuffer", offsetof(platcheck_t, bf_getbuffer));
	dump("fldsize bf_getbuffer",   sizeof(s.bf_getbuffer));
	dump("fldofs bf_releasebuffer", offsetof(platcheck_t, bf_releasebuffer));
	dump("fldsize bf_releasebuffer",   sizeof(s.bf_releasebuffer));
}

void dump_section_PyCFunctionObject(void) {
	typedef PyCFunctionObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs m_ml", offsetof(platcheck_t, m_ml));
	dump("fldsize m_ml",   sizeof(s.m_ml));
	dump("fldofs m_self", offsetof(platcheck_t, m_self));
	dump("fldsize m_self",   sizeof(s.m_self));
	dump("fldofs m_module", offsetof(platcheck_t, m_module));
	dump("fldsize m_module",   sizeof(s.m_module));
}

void dump_section_PyCodeObject(void) {
	typedef PyCodeObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs co_name", offsetof(platcheck_t, co_name));
	dump("fldsize co_name",   sizeof(s.co_name));
	dump("fldofs co_filename", offsetof(platcheck_t, co_filename));
	dump("fldsize co_filename",   sizeof(s.co_filename));
	dump("fldofs co_flags", offsetof(platcheck_t, co_flags));
	dump("fldsize co_flags",   sizeof(s.co_flags));
	s.co_flags = 0; s.co_flags = ~s.co_flags;
	dump("fldunsigned co_flags", s.co_flags > 0);
	dump("fldofs co_argcount", offsetof(platcheck_t, co_argcount));
	dump("fldsize co_argcount",   sizeof(s.co_argcount));
	s.co_argcount = 0; s.co_argcount = ~s.co_argcount;
	dump("fldunsigned co_argcount", s.co_argcount > 0);
}

void dump_section_PyCompilerFlags(void) {
	typedef PyCompilerFlags platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs cf_flags", offsetof(platcheck_t, cf_flags));
	dump("fldsize cf_flags",   sizeof(s.cf_flags));
	s.cf_flags = 0; s.cf_flags = ~s.cf_flags;
	dump("fldunsigned cf_flags", s.cf_flags > 0);
}

void dump_section_PyDateTime_CAPI(void) {
	typedef PyDateTime_CAPI platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs DateType", offsetof(platcheck_t, DateType));
	dump("fldsize DateType",   sizeof(s.DateType));
	dump("fldofs DateTimeType", offsetof(platcheck_t, DateTimeType));
	dump("fldsize DateTimeType",   sizeof(s.DateTimeType));
	dump("fldofs TimeType", offsetof(platcheck_t, TimeType));
	dump("fldsize TimeType",   sizeof(s.TimeType));
	dump("fldofs DeltaType", offsetof(platcheck_t, DeltaType));
	dump("fldsize DeltaType",   sizeof(s.DeltaType));
}

void dump_section_PyDateTime_Delta(void) {
	typedef PyDateTime_Delta platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
}

void dump_section_PyFrameObject(void) {
	typedef PyFrameObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs f_code", offsetof(platcheck_t, f_code));
	dump("fldsize f_code",   sizeof(s.f_code));
	dump("fldofs f_globals", offsetof(platcheck_t, f_globals));
	dump("fldsize f_globals",   sizeof(s.f_globals));
	dump("fldofs f_locals", offsetof(platcheck_t, f_locals));
	dump("fldsize f_locals",   sizeof(s.f_locals));
	dump("fldofs f_lineno", offsetof(platcheck_t, f_lineno));
	dump("fldsize f_lineno",   sizeof(s.f_lineno));
	s.f_lineno = 0; s.f_lineno = ~s.f_lineno;
	dump("fldunsigned f_lineno", s.f_lineno > 0);
}

void dump_section_PyFunctionObject(void) {
	typedef PyFunctionObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs func_name", offsetof(platcheck_t, func_name));
	dump("fldsize func_name",   sizeof(s.func_name));
}

void dump_section_PyGetSetDef(void) {
	typedef PyGetSetDef platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs get", offsetof(platcheck_t, get));
	dump("fldsize get",   sizeof(s.get));
	dump("fldofs set", offsetof(platcheck_t, set));
	dump("fldsize set",   sizeof(s.set));
	dump("fldofs doc", offsetof(platcheck_t, doc));
	dump("fldsize doc",   sizeof(s.doc));
	dump("fldofs closure", offsetof(platcheck_t, closure));
	dump("fldsize closure",   sizeof(s.closure));
}

void dump_section_PyIntObject(void) {
	typedef PyIntObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_ival", offsetof(platcheck_t, ob_ival));
	dump("fldsize ob_ival",   sizeof(s.ob_ival));
	s.ob_ival = 0; s.ob_ival = ~s.ob_ival;
	dump("fldunsigned ob_ival", s.ob_ival > 0);
}

void dump_section_PyInterpreterState(void) {
	typedef PyInterpreterState platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs next", offsetof(platcheck_t, next));
	dump("fldsize next",   sizeof(s.next));
}

void dump_section_PyMappingMethods(void) {
	typedef PyMappingMethods platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs mp_length", offsetof(platcheck_t, mp_length));
	dump("fldsize mp_length",   sizeof(s.mp_length));
	dump("fldofs mp_subscript", offsetof(platcheck_t, mp_subscript));
	dump("fldsize mp_subscript",   sizeof(s.mp_subscript));
	dump("fldofs mp_ass_subscript", offsetof(platcheck_t, mp_ass_subscript));
	dump("fldsize mp_ass_subscript",   sizeof(s.mp_ass_subscript));
}

void dump_section_PyMemberDef(void) {
	typedef PyMemberDef platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	dump("fldofs offset", offsetof(platcheck_t, offset));
	dump("fldsize offset",   sizeof(s.offset));
	s.offset = 0; s.offset = ~s.offset;
	dump("fldunsigned offset", s.offset > 0);
	dump("fldofs flags", offsetof(platcheck_t, flags));
	dump("fldsize flags",   sizeof(s.flags));
	dump("fldofs doc", offsetof(platcheck_t, doc));
	dump("fldsize doc",   sizeof(s.doc));
}

void dump_section_PyMethodDef(void) {
	typedef PyMethodDef platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ml_name", offsetof(platcheck_t, ml_name));
	dump("fldsize ml_name",   sizeof(s.ml_name));
	dump("fldofs ml_meth", offsetof(platcheck_t, ml_meth));
	dump("fldsize ml_meth",   sizeof(s.ml_meth));
	dump("fldofs ml_flags", offsetof(platcheck_t, ml_flags));
	dump("fldsize ml_flags",   sizeof(s.ml_flags));
	dump("fldofs ml_doc", offsetof(platcheck_t, ml_doc));
	dump("fldsize ml_doc",   sizeof(s.ml_doc));
}

void dump_section_PyNumberMethods(void) {
	typedef PyNumberMethods platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs nb_add", offsetof(platcheck_t, nb_add));
	dump("fldsize nb_add",   sizeof(s.nb_add));
	dump("fldofs nb_subtract", offsetof(platcheck_t, nb_subtract));
	dump("fldsize nb_subtract",   sizeof(s.nb_subtract));
	dump("fldofs nb_multiply", offsetof(platcheck_t, nb_multiply));
	dump("fldsize nb_multiply",   sizeof(s.nb_multiply));
	dump("fldofs nb_divide", offsetof(platcheck_t, nb_divide));
	dump("fldsize nb_divide",   sizeof(s.nb_divide));
	dump("fldofs nb_remainder", offsetof(platcheck_t, nb_remainder));
	dump("fldsize nb_remainder",   sizeof(s.nb_remainder));
	dump("fldofs nb_divmod", offsetof(platcheck_t, nb_divmod));
	dump("fldsize nb_divmod",   sizeof(s.nb_divmod));
	dump("fldofs nb_power", offsetof(platcheck_t, nb_power));
	dump("fldsize nb_power",   sizeof(s.nb_power));
	dump("fldofs nb_negative", offsetof(platcheck_t, nb_negative));
	dump("fldsize nb_negative",   sizeof(s.nb_negative));
	dump("fldofs nb_positive", offsetof(platcheck_t, nb_positive));
	dump("fldsize nb_positive",   sizeof(s.nb_positive));
	dump("fldofs nb_absolute", offsetof(platcheck_t, nb_absolute));
	dump("fldsize nb_absolute",   sizeof(s.nb_absolute));
	dump("fldofs nb_nonzero", offsetof(platcheck_t, nb_nonzero));
	dump("fldsize nb_nonzero",   sizeof(s.nb_nonzero));
	dump("fldofs nb_invert", offsetof(platcheck_t, nb_invert));
	dump("fldsize nb_invert",   sizeof(s.nb_invert));
	dump("fldofs nb_lshift", offsetof(platcheck_t, nb_lshift));
	dump("fldsize nb_lshift",   sizeof(s.nb_lshift));
	dump("fldofs nb_rshift", offsetof(platcheck_t, nb_rshift));
	dump("fldsize nb_rshift",   sizeof(s.nb_rshift));
	dump("fldofs nb_and", offsetof(platcheck_t, nb_and));
	dump("fldsize nb_and",   sizeof(s.nb_and));
	dump("fldofs nb_xor", offsetof(platcheck_t, nb_xor));
	dump("fldsize nb_xor",   sizeof(s.nb_xor));
	dump("fldofs nb_or", offsetof(platcheck_t, nb_or));
	dump("fldsize nb_or",   sizeof(s.nb_or));
	dump("fldofs nb_coerce", offsetof(platcheck_t, nb_coerce));
	dump("fldsize nb_coerce",   sizeof(s.nb_coerce));
	dump("fldofs nb_int", offsetof(platcheck_t, nb_int));
	dump("fldsize nb_int",   sizeof(s.nb_int));
	dump("fldofs nb_long", offsetof(platcheck_t, nb_long));
	dump("fldsize nb_long",   sizeof(s.nb_long));
	dump("fldofs nb_float", offsetof(platcheck_t, nb_float));
	dump("fldsize nb_float",   sizeof(s.nb_float));
	dump("fldofs nb_oct", offsetof(platcheck_t, nb_oct));
	dump("fldsize nb_oct",   sizeof(s.nb_oct));
	dump("fldofs nb_hex", offsetof(platcheck_t, nb_hex));
	dump("fldsize nb_hex",   sizeof(s.nb_hex));
	dump("fldofs nb_inplace_add", offsetof(platcheck_t, nb_inplace_add));
	dump("fldsize nb_inplace_add",   sizeof(s.nb_inplace_add));
	dump("fldofs nb_inplace_subtract", offsetof(platcheck_t, nb_inplace_subtract));
	dump("fldsize nb_inplace_subtract",   sizeof(s.nb_inplace_subtract));
	dump("fldofs nb_inplace_multiply", offsetof(platcheck_t, nb_inplace_multiply));
	dump("fldsize nb_inplace_multiply",   sizeof(s.nb_inplace_multiply));
	dump("fldofs nb_inplace_divide", offsetof(platcheck_t, nb_inplace_divide));
	dump("fldsize nb_inplace_divide",   sizeof(s.nb_inplace_divide));
	dump("fldofs nb_inplace_remainder", offsetof(platcheck_t, nb_inplace_remainder));
	dump("fldsize nb_inplace_remainder",   sizeof(s.nb_inplace_remainder));
	dump("fldofs nb_inplace_power", offsetof(platcheck_t, nb_inplace_power));
	dump("fldsize nb_inplace_power",   sizeof(s.nb_inplace_power));
	dump("fldofs nb_inplace_lshift", offsetof(platcheck_t, nb_inplace_lshift));
	dump("fldsize nb_inplace_lshift",   sizeof(s.nb_inplace_lshift));
	dump("fldofs nb_inplace_rshift", offsetof(platcheck_t, nb_inplace_rshift));
	dump("fldsize nb_inplace_rshift",   sizeof(s.nb_inplace_rshift));
	dump("fldofs nb_inplace_and", offsetof(platcheck_t, nb_inplace_and));
	dump("fldsize nb_inplace_and",   sizeof(s.nb_inplace_and));
	dump("fldofs nb_inplace_xor", offsetof(platcheck_t, nb_inplace_xor));
	dump("fldsize nb_inplace_xor",   sizeof(s.nb_inplace_xor));
	dump("fldofs nb_inplace_or", offsetof(platcheck_t, nb_inplace_or));
	dump("fldsize nb_inplace_or",   sizeof(s.nb_inplace_or));
	dump("fldofs nb_floor_divide", offsetof(platcheck_t, nb_floor_divide));
	dump("fldsize nb_floor_divide",   sizeof(s.nb_floor_divide));
	dump("fldofs nb_true_divide", offsetof(platcheck_t, nb_true_divide));
	dump("fldsize nb_true_divide",   sizeof(s.nb_true_divide));
	dump("fldofs nb_inplace_floor_divide", offsetof(platcheck_t, nb_inplace_floor_divide));
	dump("fldsize nb_inplace_floor_divide",   sizeof(s.nb_inplace_floor_divide));
	dump("fldofs nb_inplace_true_divide", offsetof(platcheck_t, nb_inplace_true_divide));
	dump("fldsize nb_inplace_true_divide",   sizeof(s.nb_inplace_true_divide));
	dump("fldofs nb_index", offsetof(platcheck_t, nb_index));
	dump("fldsize nb_index",   sizeof(s.nb_index));
}

void dump_section_PyObject(void) {
	typedef PyObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
}

void dump_section_PySequenceMethods(void) {
	typedef PySequenceMethods platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs sq_length", offsetof(platcheck_t, sq_length));
	dump("fldsize sq_length",   sizeof(s.sq_length));
	dump("fldofs sq_concat", offsetof(platcheck_t, sq_concat));
	dump("fldsize sq_concat",   sizeof(s.sq_concat));
	dump("fldofs sq_repeat", offsetof(platcheck_t, sq_repeat));
	dump("fldsize sq_repeat",   sizeof(s.sq_repeat));
	dump("fldofs sq_item", offsetof(platcheck_t, sq_item));
	dump("fldsize sq_item",   sizeof(s.sq_item));
	dump("fldofs sq_slice", offsetof(platcheck_t, sq_slice));
	dump("fldsize sq_slice",   sizeof(s.sq_slice));
	dump("fldofs sq_ass_item", offsetof(platcheck_t, sq_ass_item));
	dump("fldsize sq_ass_item",   sizeof(s.sq_ass_item));
	dump("fldofs sq_ass_slice", offsetof(platcheck_t, sq_ass_slice));
	dump("fldsize sq_ass_slice",   sizeof(s.sq_ass_slice));
	dump("fldofs sq_contains", offsetof(platcheck_t, sq_contains));
	dump("fldsize sq_contains",   sizeof(s.sq_contains));
	dump("fldofs sq_inplace_concat", offsetof(platcheck_t, sq_inplace_concat));
	dump("fldsize sq_inplace_concat",   sizeof(s.sq_inplace_concat));
	dump("fldofs sq_inplace_repeat", offsetof(platcheck_t, sq_inplace_repeat));
	dump("fldsize sq_inplace_repeat",   sizeof(s.sq_inplace_repeat));
}

void dump_section_PySliceObject(void) {
	typedef PySliceObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs start", offsetof(platcheck_t, start));
	dump("fldsize start",   sizeof(s.start));
	dump("fldofs step", offsetof(platcheck_t, step));
	dump("fldsize step",   sizeof(s.step));
	dump("fldofs stop", offsetof(platcheck_t, stop));
	dump("fldsize stop",   sizeof(s.stop));
}

void dump_section_PyStringObject(void) {
	typedef PyStringObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs buffer", offsetof(platcheck_t, buffer));
	dump("fldsize buffer",   sizeof(s.buffer));
	dump("fldofs size", offsetof(platcheck_t, size));
	dump("fldsize size",   sizeof(s.size));
	s.size = 0; s.size = ~s.size;
	dump("fldunsigned size", s.size > 0);
}

void dump_section_PyThreadState(void) {
	typedef PyThreadState platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs interp", offsetof(platcheck_t, interp));
	dump("fldsize interp",   sizeof(s.interp));
	dump("fldofs dict", offsetof(platcheck_t, dict));
	dump("fldsize dict",   sizeof(s.dict));
}

void dump_section_PyTracebackObject(void) {
	typedef PyTracebackObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs tb_next", offsetof(platcheck_t, tb_next));
	dump("fldsize tb_next",   sizeof(s.tb_next));
	dump("fldofs tb_frame", offsetof(platcheck_t, tb_frame));
	dump("fldsize tb_frame",   sizeof(s.tb_frame));
	dump("fldofs tb_lasti", offsetof(platcheck_t, tb_lasti));
	dump("fldsize tb_lasti",   sizeof(s.tb_lasti));
	s.tb_lasti = 0; s.tb_lasti = ~s.tb_lasti;
	dump("fldunsigned tb_lasti", s.tb_lasti > 0);
	dump("fldofs tb_lineno", offsetof(platcheck_t, tb_lineno));
	dump("fldsize tb_lineno",   sizeof(s.tb_lineno));
	s.tb_lineno = 0; s.tb_lineno = ~s.tb_lineno;
	dump("fldunsigned tb_lineno", s.tb_lineno > 0);
}

void dump_section_PyTupleObject(void) {
	typedef PyTupleObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
	dump("fldofs ob_item", offsetof(platcheck_t, ob_item));
	dump("fldsize ob_item",   sizeof(s.ob_item));
}

void dump_section_PyTypeObject(void) {
	typedef PyTypeObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
	dump("fldofs tp_name", offsetof(platcheck_t, tp_name));
	dump("fldsize tp_name",   sizeof(s.tp_name));
	dump("fldofs tp_basicsize", offsetof(platcheck_t, tp_basicsize));
	dump("fldsize tp_basicsize",   sizeof(s.tp_basicsize));
	s.tp_basicsize = 0; s.tp_basicsize = ~s.tp_basicsize;
	dump("fldunsigned tp_basicsize", s.tp_basicsize > 0);
	dump("fldofs tp_itemsize", offsetof(platcheck_t, tp_itemsize));
	dump("fldsize tp_itemsize",   sizeof(s.tp_itemsize));
	s.tp_itemsize = 0; s.tp_itemsize = ~s.tp_itemsize;
	dump("fldunsigned tp_itemsize", s.tp_itemsize > 0);
	dump("fldofs tp_dealloc", offsetof(platcheck_t, tp_dealloc));
	dump("fldsize tp_dealloc",   sizeof(s.tp_dealloc));
	dump("fldofs tp_print", offsetof(platcheck_t, tp_print));
	dump("fldsize tp_print",   sizeof(s.tp_print));
	dump("fldofs tp_getattr", offsetof(platcheck_t, tp_getattr));
	dump("fldsize tp_getattr",   sizeof(s.tp_getattr));
	dump("fldofs tp_setattr", offsetof(platcheck_t, tp_setattr));
	dump("fldsize tp_setattr",   sizeof(s.tp_setattr));
	dump("fldofs tp_compare", offsetof(platcheck_t, tp_compare));
	dump("fldsize tp_compare",   sizeof(s.tp_compare));
	dump("fldofs tp_repr", offsetof(platcheck_t, tp_repr));
	dump("fldsize tp_repr",   sizeof(s.tp_repr));
	dump("fldofs tp_as_number", offsetof(platcheck_t, tp_as_number));
	dump("fldsize tp_as_number",   sizeof(s.tp_as_number));
	dump("fldofs tp_as_sequence", offsetof(platcheck_t, tp_as_sequence));
	dump("fldsize tp_as_sequence",   sizeof(s.tp_as_sequence));
	dump("fldofs tp_as_mapping", offsetof(platcheck_t, tp_as_mapping));
	dump("fldsize tp_as_mapping",   sizeof(s.tp_as_mapping));
	dump("fldofs tp_hash", offsetof(platcheck_t, tp_hash));
	dump("fldsize tp_hash",   sizeof(s.tp_hash));
	dump("fldofs tp_call", offsetof(platcheck_t, tp_call));
	dump("fldsize tp_call",   sizeof(s.tp_call));
	dump("fldofs tp_str", offsetof(platcheck_t, tp_str));
	dump("fldsize tp_str",   sizeof(s.tp_str));
	dump("fldofs tp_getattro", offsetof(platcheck_t, tp_getattro));
	dump("fldsize tp_getattro",   sizeof(s.tp_getattro));
	dump("fldofs tp_setattro", offsetof(platcheck_t, tp_setattro));
	dump("fldsize tp_setattro",   sizeof(s.tp_setattro));
	dump("fldofs tp_as_buffer", offsetof(platcheck_t, tp_as_buffer));
	dump("fldsize tp_as_buffer",   sizeof(s.tp_as_buffer));
	dump("fldofs tp_flags", offsetof(platcheck_t, tp_flags));
	dump("fldsize tp_flags",   sizeof(s.tp_flags));
	s.tp_flags = 0; s.tp_flags = ~s.tp_flags;
	dump("fldunsigned tp_flags", s.tp_flags > 0);
	dump("fldofs tp_doc", offsetof(platcheck_t, tp_doc));
	dump("fldsize tp_doc",   sizeof(s.tp_doc));
	dump("fldofs tp_traverse", offsetof(platcheck_t, tp_traverse));
	dump("fldsize tp_traverse",   sizeof(s.tp_traverse));
	dump("fldofs tp_clear", offsetof(platcheck_t, tp_clear));
	dump("fldsize tp_clear",   sizeof(s.tp_clear));
	dump("fldofs tp_richcompare", offsetof(platcheck_t, tp_richcompare));
	dump("fldsize tp_richcompare",   sizeof(s.tp_richcompare));
	dump("fldofs tp_weaklistoffset", offsetof(platcheck_t, tp_weaklistoffset));
	dump("fldsize tp_weaklistoffset",   sizeof(s.tp_weaklistoffset));
	s.tp_weaklistoffset = 0; s.tp_weaklistoffset = ~s.tp_weaklistoffset;
	dump("fldunsigned tp_weaklistoffset", s.tp_weaklistoffset > 0);
	dump("fldofs tp_iter", offsetof(platcheck_t, tp_iter));
	dump("fldsize tp_iter",   sizeof(s.tp_iter));
	dump("fldofs tp_iternext", offsetof(platcheck_t, tp_iternext));
	dump("fldsize tp_iternext",   sizeof(s.tp_iternext));
	dump("fldofs tp_methods", offsetof(platcheck_t, tp_methods));
	dump("fldsize tp_methods",   sizeof(s.tp_methods));
	dump("fldofs tp_members", offsetof(platcheck_t, tp_members));
	dump("fldsize tp_members",   sizeof(s.tp_members));
	dump("fldofs tp_getset", offsetof(platcheck_t, tp_getset));
	dump("fldsize tp_getset",   sizeof(s.tp_getset));
	dump("fldofs tp_base", offsetof(platcheck_t, tp_base));
	dump("fldsize tp_base",   sizeof(s.tp_base));
	dump("fldofs tp_dict", offsetof(platcheck_t, tp_dict));
	dump("fldsize tp_dict",   sizeof(s.tp_dict));
	dump("fldofs tp_descr_get", offsetof(platcheck_t, tp_descr_get));
	dump("fldsize tp_descr_get",   sizeof(s.tp_descr_get));
	dump("fldofs tp_descr_set", offsetof(platcheck_t, tp_descr_set));
	dump("fldsize tp_descr_set",   sizeof(s.tp_descr_set));
	dump("fldofs tp_dictoffset", offsetof(platcheck_t, tp_dictoffset));
	dump("fldsize tp_dictoffset",   sizeof(s.tp_dictoffset));
	s.tp_dictoffset = 0; s.tp_dictoffset = ~s.tp_dictoffset;
	dump("fldunsigned tp_dictoffset", s.tp_dictoffset > 0);
	dump("fldofs tp_init", offsetof(platcheck_t, tp_init));
	dump("fldsize tp_init",   sizeof(s.tp_init));
	dump("fldofs tp_alloc", offsetof(platcheck_t, tp_alloc));
	dump("fldsize tp_alloc",   sizeof(s.tp_alloc));
	dump("fldofs tp_new", offsetof(platcheck_t, tp_new));
	dump("fldsize tp_new",   sizeof(s.tp_new));
	dump("fldofs tp_free", offsetof(platcheck_t, tp_free));
	dump("fldsize tp_free",   sizeof(s.tp_free));
	dump("fldofs tp_is_gc", offsetof(platcheck_t, tp_is_gc));
	dump("fldsize tp_is_gc",   sizeof(s.tp_is_gc));
	dump("fldofs tp_bases", offsetof(platcheck_t, tp_bases));
	dump("fldsize tp_bases",   sizeof(s.tp_bases));
	dump("fldofs tp_mro", offsetof(platcheck_t, tp_mro));
	dump("fldsize tp_mro",   sizeof(s.tp_mro));
	dump("fldofs tp_cache", offsetof(platcheck_t, tp_cache));
	dump("fldsize tp_cache",   sizeof(s.tp_cache));
	dump("fldofs tp_subclasses", offsetof(platcheck_t, tp_subclasses));
	dump("fldsize tp_subclasses",   sizeof(s.tp_subclasses));
	dump("fldofs tp_weaklist", offsetof(platcheck_t, tp_weaklist));
	dump("fldsize tp_weaklist",   sizeof(s.tp_weaklist));
	dump("fldofs tp_del", offsetof(platcheck_t, tp_del));
	dump("fldsize tp_del",   sizeof(s.tp_del));
}

void dump_section_PyUnicodeObject(void) {
	typedef PyUnicodeObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs buffer", offsetof(platcheck_t, buffer));
	dump("fldsize buffer",   sizeof(s.buffer));
	dump("fldofs size", offsetof(platcheck_t, size));
	dump("fldsize size",   sizeof(s.size));
	s.size = 0; s.size = ~s.size;
	dump("fldunsigned size", s.size > 0);
}

void dump_section_PyVarObject(void) {
	typedef PyVarObject platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs ob_refcnt", offsetof(platcheck_t, ob_refcnt));
	dump("fldsize ob_refcnt",   sizeof(s.ob_refcnt));
	s.ob_refcnt = 0; s.ob_refcnt = ~s.ob_refcnt;
	dump("fldunsigned ob_refcnt", s.ob_refcnt > 0);
	dump("fldofs ob_pypy_link", offsetof(platcheck_t, ob_pypy_link));
	dump("fldsize ob_pypy_link",   sizeof(s.ob_pypy_link));
	s.ob_pypy_link = 0; s.ob_pypy_link = ~s.ob_pypy_link;
	dump("fldunsigned ob_pypy_link", s.ob_pypy_link > 0);
	dump("fldofs ob_type", offsetof(platcheck_t, ob_type));
	dump("fldsize ob_type",   sizeof(s.ob_type));
	dump("fldofs ob_size", offsetof(platcheck_t, ob_size));
	dump("fldsize ob_size",   sizeof(s.ob_size));
	s.ob_size = 0; s.ob_size = ~s.ob_size;
	dump("fldunsigned ob_size", s.ob_size > 0);
}

void dump_section_Py_buffer(void) {
	typedef Py_buffer platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs buf", offsetof(platcheck_t, buf));
	dump("fldsize buf",   sizeof(s.buf));
	dump("fldofs obj", offsetof(platcheck_t, obj));
	dump("fldsize obj",   sizeof(s.obj));
	dump("fldofs len", offsetof(platcheck_t, len));
	dump("fldsize len",   sizeof(s.len));
	s.len = 0; s.len = ~s.len;
	dump("fldunsigned len", s.len > 0);
	dump("fldofs itemsize", offsetof(platcheck_t, itemsize));
	dump("fldsize itemsize",   sizeof(s.itemsize));
	s.itemsize = 0; s.itemsize = ~s.itemsize;
	dump("fldunsigned itemsize", s.itemsize > 0);
	dump("fldofs readonly", offsetof(platcheck_t, readonly));
	dump("fldsize readonly",   sizeof(s.readonly));
	s.readonly = 0; s.readonly = ~s.readonly;
	dump("fldunsigned readonly", s.readonly > 0);
	dump("fldofs ndim", offsetof(platcheck_t, ndim));
	dump("fldsize ndim",   sizeof(s.ndim));
	s.ndim = 0; s.ndim = ~s.ndim;
	dump("fldunsigned ndim", s.ndim > 0);
	dump("fldofs format", offsetof(platcheck_t, format));
	dump("fldsize format",   sizeof(s.format));
	dump("fldofs shape", offsetof(platcheck_t, shape));
	dump("fldsize shape",   sizeof(s.shape));
	dump("fldofs strides", offsetof(platcheck_t, strides));
	dump("fldsize strides",   sizeof(s.strides));
	dump("fldofs suboffsets", offsetof(platcheck_t, suboffsets));
	dump("fldsize suboffsets",   sizeof(s.suboffsets));
	dump("fldofs internal", offsetof(platcheck_t, internal));
	dump("fldsize internal",   sizeof(s.internal));
}

void dump_section_Py_complex(void) {
	typedef Py_complex platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs real", offsetof(platcheck_t, real));
	dump("fldsize real",   sizeof(s.real));
	dump("fldofs imag", offsetof(platcheck_t, imag));
	dump("fldsize imag",   sizeof(s.imag));
}

int main(int argc, char *argv[]) {
	printf("-+- PyBufferObject\n");
	dump_section_PyBufferObject();
	printf("---\n");
	printf("-+- PyBufferProcs\n");
	dump_section_PyBufferProcs();
	printf("---\n");
	printf("-+- PyCFunctionObject\n");
	dump_section_PyCFunctionObject();
	printf("---\n");
	printf("-+- PyCodeObject\n");
	dump_section_PyCodeObject();
	printf("---\n");
	printf("-+- PyCompilerFlags\n");
	dump_section_PyCompilerFlags();
	printf("---\n");
	printf("-+- PyDateTime_CAPI\n");
	dump_section_PyDateTime_CAPI();
	printf("---\n");
	printf("-+- PyDateTime_Delta\n");
	dump_section_PyDateTime_Delta();
	printf("---\n");
	printf("-+- PyFrameObject\n");
	dump_section_PyFrameObject();
	printf("---\n");
	printf("-+- PyFunctionObject\n");
	dump_section_PyFunctionObject();
	printf("---\n");
	printf("-+- PyGetSetDef\n");
	dump_section_PyGetSetDef();
	printf("---\n");
	printf("-+- PyIntObject\n");
	dump_section_PyIntObject();
	printf("---\n");
	printf("-+- PyInterpreterState\n");
	dump_section_PyInterpreterState();
	printf("---\n");
	printf("-+- PyMappingMethods\n");
	dump_section_PyMappingMethods();
	printf("---\n");
	printf("-+- PyMemberDef\n");
	dump_section_PyMemberDef();
	printf("---\n");
	printf("-+- PyMethodDef\n");
	dump_section_PyMethodDef();
	printf("---\n");
	printf("-+- PyNumberMethods\n");
	dump_section_PyNumberMethods();
	printf("---\n");
	printf("-+- PyObject\n");
	dump_section_PyObject();
	printf("---\n");
	printf("-+- PySequenceMethods\n");
	dump_section_PySequenceMethods();
	printf("---\n");
	printf("-+- PySliceObject\n");
	dump_section_PySliceObject();
	printf("---\n");
	printf("-+- PyStringObject\n");
	dump_section_PyStringObject();
	printf("---\n");
	printf("-+- PyThreadState\n");
	dump_section_PyThreadState();
	printf("---\n");
	printf("-+- PyTracebackObject\n");
	dump_section_PyTracebackObject();
	printf("---\n");
	printf("-+- PyTupleObject\n");
	dump_section_PyTupleObject();
	printf("---\n");
	printf("-+- PyTypeObject\n");
	dump_section_PyTypeObject();
	printf("---\n");
	printf("-+- PyUnicodeObject\n");
	dump_section_PyUnicodeObject();
	printf("---\n");
	printf("-+- PyVarObject\n");
	dump_section_PyVarObject();
	printf("---\n");
	printf("-+- Py_buffer\n");
	dump_section_Py_buffer();
	printf("---\n");
	printf("-+- Py_complex\n");
	dump_section_Py_complex();
	printf("---\n");
	return 0;
}
