/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <locale.h>
#include <limits.h>
#include <ctype.h>
#include <wchar.h>
#include <langinfo.h>
#include <libintl.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_ABDAY_1(void) {
#ifdef ABDAY_1
	dump("defined", 1);
	if ((ABDAY_1) <= 0) {
	    long long x = (long long)(ABDAY_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABDAY_2(void) {
#ifdef ABDAY_2
	dump("defined", 1);
	if ((ABDAY_2) <= 0) {
	    long long x = (long long)(ABDAY_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABDAY_3(void) {
#ifdef ABDAY_3
	dump("defined", 1);
	if ((ABDAY_3) <= 0) {
	    long long x = (long long)(ABDAY_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABDAY_4(void) {
#ifdef ABDAY_4
	dump("defined", 1);
	if ((ABDAY_4) <= 0) {
	    long long x = (long long)(ABDAY_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABDAY_5(void) {
#ifdef ABDAY_5
	dump("defined", 1);
	if ((ABDAY_5) <= 0) {
	    long long x = (long long)(ABDAY_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABDAY_6(void) {
#ifdef ABDAY_6
	dump("defined", 1);
	if ((ABDAY_6) <= 0) {
	    long long x = (long long)(ABDAY_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABDAY_7(void) {
#ifdef ABDAY_7
	dump("defined", 1);
	if ((ABDAY_7) <= 0) {
	    long long x = (long long)(ABDAY_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABDAY_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_1(void) {
#ifdef ABMON_1
	dump("defined", 1);
	if ((ABMON_1) <= 0) {
	    long long x = (long long)(ABMON_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_10(void) {
#ifdef ABMON_10
	dump("defined", 1);
	if ((ABMON_10) <= 0) {
	    long long x = (long long)(ABMON_10);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_10);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_11(void) {
#ifdef ABMON_11
	dump("defined", 1);
	if ((ABMON_11) <= 0) {
	    long long x = (long long)(ABMON_11);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_11);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_12(void) {
#ifdef ABMON_12
	dump("defined", 1);
	if ((ABMON_12) <= 0) {
	    long long x = (long long)(ABMON_12);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_12);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_2(void) {
#ifdef ABMON_2
	dump("defined", 1);
	if ((ABMON_2) <= 0) {
	    long long x = (long long)(ABMON_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_3(void) {
#ifdef ABMON_3
	dump("defined", 1);
	if ((ABMON_3) <= 0) {
	    long long x = (long long)(ABMON_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_4(void) {
#ifdef ABMON_4
	dump("defined", 1);
	if ((ABMON_4) <= 0) {
	    long long x = (long long)(ABMON_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_5(void) {
#ifdef ABMON_5
	dump("defined", 1);
	if ((ABMON_5) <= 0) {
	    long long x = (long long)(ABMON_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_6(void) {
#ifdef ABMON_6
	dump("defined", 1);
	if ((ABMON_6) <= 0) {
	    long long x = (long long)(ABMON_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_7(void) {
#ifdef ABMON_7
	dump("defined", 1);
	if ((ABMON_7) <= 0) {
	    long long x = (long long)(ABMON_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_8(void) {
#ifdef ABMON_8
	dump("defined", 1);
	if ((ABMON_8) <= 0) {
	    long long x = (long long)(ABMON_8);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_8);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ABMON_9(void) {
#ifdef ABMON_9
	dump("defined", 1);
	if ((ABMON_9) <= 0) {
	    long long x = (long long)(ABMON_9);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ABMON_9);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ALT_DIGITS(void) {
#ifdef ALT_DIGITS
	dump("defined", 1);
	if ((ALT_DIGITS) <= 0) {
	    long long x = (long long)(ALT_DIGITS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ALT_DIGITS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_AM_STR(void) {
#ifdef AM_STR
	dump("defined", 1);
	if ((AM_STR) <= 0) {
	    long long x = (long long)(AM_STR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(AM_STR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CHAR_MAX(void) {
#ifdef CHAR_MAX
	dump("defined", 1);
	if ((CHAR_MAX) <= 0) {
	    long long x = (long long)(CHAR_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CHAR_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CODESET(void) {
#ifdef CODESET
	dump("defined", 1);
	if ((CODESET) <= 0) {
	    long long x = (long long)(CODESET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CODESET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CRNCYSTR(void) {
#ifdef CRNCYSTR
	dump("defined", 1);
	if ((CRNCYSTR) <= 0) {
	    long long x = (long long)(CRNCYSTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRNCYSTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DAY_1(void) {
#ifdef DAY_1
	dump("defined", 1);
	if ((DAY_1) <= 0) {
	    long long x = (long long)(DAY_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DAY_2(void) {
#ifdef DAY_2
	dump("defined", 1);
	if ((DAY_2) <= 0) {
	    long long x = (long long)(DAY_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DAY_3(void) {
#ifdef DAY_3
	dump("defined", 1);
	if ((DAY_3) <= 0) {
	    long long x = (long long)(DAY_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DAY_4(void) {
#ifdef DAY_4
	dump("defined", 1);
	if ((DAY_4) <= 0) {
	    long long x = (long long)(DAY_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DAY_5(void) {
#ifdef DAY_5
	dump("defined", 1);
	if ((DAY_5) <= 0) {
	    long long x = (long long)(DAY_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DAY_6(void) {
#ifdef DAY_6
	dump("defined", 1);
	if ((DAY_6) <= 0) {
	    long long x = (long long)(DAY_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DAY_7(void) {
#ifdef DAY_7
	dump("defined", 1);
	if ((DAY_7) <= 0) {
	    long long x = (long long)(DAY_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DAY_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_D_FMT(void) {
#ifdef D_FMT
	dump("defined", 1);
	if ((D_FMT) <= 0) {
	    long long x = (long long)(D_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(D_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_D_T_FMT(void) {
#ifdef D_T_FMT
	dump("defined", 1);
	if ((D_T_FMT) <= 0) {
	    long long x = (long long)(D_T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(D_T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERA(void) {
#ifdef ERA
	dump("defined", 1);
	if ((ERA) <= 0) {
	    long long x = (long long)(ERA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERA_D_FMT(void) {
#ifdef ERA_D_FMT
	dump("defined", 1);
	if ((ERA_D_FMT) <= 0) {
	    long long x = (long long)(ERA_D_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA_D_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERA_D_T_FMT(void) {
#ifdef ERA_D_T_FMT
	dump("defined", 1);
	if ((ERA_D_T_FMT) <= 0) {
	    long long x = (long long)(ERA_D_T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA_D_T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERA_T_FMT(void) {
#ifdef ERA_T_FMT
	dump("defined", 1);
	if ((ERA_T_FMT) <= 0) {
	    long long x = (long long)(ERA_T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERA_T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_ADDRESS(void) {
#ifdef LC_ADDRESS
	dump("defined", 1);
	if ((LC_ADDRESS) <= 0) {
	    long long x = (long long)(LC_ADDRESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_ADDRESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_ALL(void) {
#ifdef LC_ALL
	dump("defined", 1);
	if ((LC_ALL) <= 0) {
	    long long x = (long long)(LC_ALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_ALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_COLLATE(void) {
#ifdef LC_COLLATE
	dump("defined", 1);
	if ((LC_COLLATE) <= 0) {
	    long long x = (long long)(LC_COLLATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_COLLATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_CTYPE(void) {
#ifdef LC_CTYPE
	dump("defined", 1);
	if ((LC_CTYPE) <= 0) {
	    long long x = (long long)(LC_CTYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_CTYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_IDENTIFICATION(void) {
#ifdef LC_IDENTIFICATION
	dump("defined", 1);
	if ((LC_IDENTIFICATION) <= 0) {
	    long long x = (long long)(LC_IDENTIFICATION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_IDENTIFICATION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_MAX(void) {
#ifdef LC_MAX
	dump("defined", 1);
	if ((LC_MAX) <= 0) {
	    long long x = (long long)(LC_MAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MAX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_MEASUREMENT(void) {
#ifdef LC_MEASUREMENT
	dump("defined", 1);
	if ((LC_MEASUREMENT) <= 0) {
	    long long x = (long long)(LC_MEASUREMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MEASUREMENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_MESSAGES(void) {
#ifdef LC_MESSAGES
	dump("defined", 1);
	if ((LC_MESSAGES) <= 0) {
	    long long x = (long long)(LC_MESSAGES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MESSAGES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_MIN(void) {
#ifdef LC_MIN
	dump("defined", 1);
	if ((LC_MIN) <= 0) {
	    long long x = (long long)(LC_MIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_MONETARY(void) {
#ifdef LC_MONETARY
	dump("defined", 1);
	if ((LC_MONETARY) <= 0) {
	    long long x = (long long)(LC_MONETARY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_MONETARY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_NAME(void) {
#ifdef LC_NAME
	dump("defined", 1);
	if ((LC_NAME) <= 0) {
	    long long x = (long long)(LC_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_NUMERIC(void) {
#ifdef LC_NUMERIC
	dump("defined", 1);
	if ((LC_NUMERIC) <= 0) {
	    long long x = (long long)(LC_NUMERIC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_NUMERIC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_PAPER(void) {
#ifdef LC_PAPER
	dump("defined", 1);
	if ((LC_PAPER) <= 0) {
	    long long x = (long long)(LC_PAPER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_PAPER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_TELEPHONE(void) {
#ifdef LC_TELEPHONE
	dump("defined", 1);
	if ((LC_TELEPHONE) <= 0) {
	    long long x = (long long)(LC_TELEPHONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_TELEPHONE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LC_TIME(void) {
#ifdef LC_TIME
	dump("defined", 1);
	if ((LC_TIME) <= 0) {
	    long long x = (long long)(LC_TIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LC_TIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_1(void) {
#ifdef MON_1
	dump("defined", 1);
	if ((MON_1) <= 0) {
	    long long x = (long long)(MON_1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_10(void) {
#ifdef MON_10
	dump("defined", 1);
	if ((MON_10) <= 0) {
	    long long x = (long long)(MON_10);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_10);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_11(void) {
#ifdef MON_11
	dump("defined", 1);
	if ((MON_11) <= 0) {
	    long long x = (long long)(MON_11);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_11);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_12(void) {
#ifdef MON_12
	dump("defined", 1);
	if ((MON_12) <= 0) {
	    long long x = (long long)(MON_12);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_12);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_2(void) {
#ifdef MON_2
	dump("defined", 1);
	if ((MON_2) <= 0) {
	    long long x = (long long)(MON_2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_3(void) {
#ifdef MON_3
	dump("defined", 1);
	if ((MON_3) <= 0) {
	    long long x = (long long)(MON_3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_4(void) {
#ifdef MON_4
	dump("defined", 1);
	if ((MON_4) <= 0) {
	    long long x = (long long)(MON_4);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_4);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_5(void) {
#ifdef MON_5
	dump("defined", 1);
	if ((MON_5) <= 0) {
	    long long x = (long long)(MON_5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_6(void) {
#ifdef MON_6
	dump("defined", 1);
	if ((MON_6) <= 0) {
	    long long x = (long long)(MON_6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_7(void) {
#ifdef MON_7
	dump("defined", 1);
	if ((MON_7) <= 0) {
	    long long x = (long long)(MON_7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_8(void) {
#ifdef MON_8
	dump("defined", 1);
	if ((MON_8) <= 0) {
	    long long x = (long long)(MON_8);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_8);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MON_9(void) {
#ifdef MON_9
	dump("defined", 1);
	if ((MON_9) <= 0) {
	    long long x = (long long)(MON_9);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(MON_9);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NOEXPR(void) {
#ifdef NOEXPR
	dump("defined", 1);
	if ((NOEXPR) <= 0) {
	    long long x = (long long)(NOEXPR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NOEXPR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PM_STR(void) {
#ifdef PM_STR
	dump("defined", 1);
	if ((PM_STR) <= 0) {
	    long long x = (long long)(PM_STR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PM_STR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RADIXCHAR(void) {
#ifdef RADIXCHAR
	dump("defined", 1);
	if ((RADIXCHAR) <= 0) {
	    long long x = (long long)(RADIXCHAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(RADIXCHAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_THOUSEP(void) {
#ifdef THOUSEP
	dump("defined", 1);
	if ((THOUSEP) <= 0) {
	    long long x = (long long)(THOUSEP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(THOUSEP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_T_FMT(void) {
#ifdef T_FMT
	dump("defined", 1);
	if ((T_FMT) <= 0) {
	    long long x = (long long)(T_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(T_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_T_FMT_AMPM(void) {
#ifdef T_FMT_AMPM
	dump("defined", 1);
	if ((T_FMT_AMPM) <= 0) {
	    long long x = (long long)(T_FMT_AMPM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(T_FMT_AMPM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_YESEXPR(void) {
#ifdef YESEXPR
	dump("defined", 1);
	if ((YESEXPR) <= 0) {
	    long long x = (long long)(YESEXPR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(YESEXPR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section__DATE_FMT(void) {
#ifdef _DATE_FMT
	dump("defined", 1);
	if ((_DATE_FMT) <= 0) {
	    long long x = (long long)(_DATE_FMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(_DATE_FMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_lconv(void) {
	typedef struct lconv platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs decimal_point", offsetof(platcheck_t, decimal_point));
	dump("fldsize decimal_point",   sizeof(s.decimal_point));
	dump("fldofs thousands_sep", offsetof(platcheck_t, thousands_sep));
	dump("fldsize thousands_sep",   sizeof(s.thousands_sep));
	dump("fldofs grouping", offsetof(platcheck_t, grouping));
	dump("fldsize grouping",   sizeof(s.grouping));
	dump("fldofs int_curr_symbol", offsetof(platcheck_t, int_curr_symbol));
	dump("fldsize int_curr_symbol",   sizeof(s.int_curr_symbol));
	dump("fldofs currency_symbol", offsetof(platcheck_t, currency_symbol));
	dump("fldsize currency_symbol",   sizeof(s.currency_symbol));
	dump("fldofs mon_decimal_point", offsetof(platcheck_t, mon_decimal_point));
	dump("fldsize mon_decimal_point",   sizeof(s.mon_decimal_point));
	dump("fldofs mon_thousands_sep", offsetof(platcheck_t, mon_thousands_sep));
	dump("fldsize mon_thousands_sep",   sizeof(s.mon_thousands_sep));
	dump("fldofs mon_grouping", offsetof(platcheck_t, mon_grouping));
	dump("fldsize mon_grouping",   sizeof(s.mon_grouping));
	dump("fldofs positive_sign", offsetof(platcheck_t, positive_sign));
	dump("fldsize positive_sign",   sizeof(s.positive_sign));
	dump("fldofs negative_sign", offsetof(platcheck_t, negative_sign));
	dump("fldsize negative_sign",   sizeof(s.negative_sign));
	dump("fldofs int_frac_digits", offsetof(platcheck_t, int_frac_digits));
	dump("fldsize int_frac_digits",   sizeof(s.int_frac_digits));
	s.int_frac_digits = 0; s.int_frac_digits = ~s.int_frac_digits;
	dump("fldunsigned int_frac_digits", s.int_frac_digits > 0);
	dump("fldofs frac_digits", offsetof(platcheck_t, frac_digits));
	dump("fldsize frac_digits",   sizeof(s.frac_digits));
	s.frac_digits = 0; s.frac_digits = ~s.frac_digits;
	dump("fldunsigned frac_digits", s.frac_digits > 0);
	dump("fldofs p_cs_precedes", offsetof(platcheck_t, p_cs_precedes));
	dump("fldsize p_cs_precedes",   sizeof(s.p_cs_precedes));
	s.p_cs_precedes = 0; s.p_cs_precedes = ~s.p_cs_precedes;
	dump("fldunsigned p_cs_precedes", s.p_cs_precedes > 0);
	dump("fldofs p_sep_by_space", offsetof(platcheck_t, p_sep_by_space));
	dump("fldsize p_sep_by_space",   sizeof(s.p_sep_by_space));
	s.p_sep_by_space = 0; s.p_sep_by_space = ~s.p_sep_by_space;
	dump("fldunsigned p_sep_by_space", s.p_sep_by_space > 0);
	dump("fldofs n_cs_precedes", offsetof(platcheck_t, n_cs_precedes));
	dump("fldsize n_cs_precedes",   sizeof(s.n_cs_precedes));
	s.n_cs_precedes = 0; s.n_cs_precedes = ~s.n_cs_precedes;
	dump("fldunsigned n_cs_precedes", s.n_cs_precedes > 0);
	dump("fldofs n_sep_by_space", offsetof(platcheck_t, n_sep_by_space));
	dump("fldsize n_sep_by_space",   sizeof(s.n_sep_by_space));
	s.n_sep_by_space = 0; s.n_sep_by_space = ~s.n_sep_by_space;
	dump("fldunsigned n_sep_by_space", s.n_sep_by_space > 0);
	dump("fldofs p_sign_posn", offsetof(platcheck_t, p_sign_posn));
	dump("fldsize p_sign_posn",   sizeof(s.p_sign_posn));
	s.p_sign_posn = 0; s.p_sign_posn = ~s.p_sign_posn;
	dump("fldunsigned p_sign_posn", s.p_sign_posn > 0);
	dump("fldofs n_sign_posn", offsetof(platcheck_t, n_sign_posn));
	dump("fldsize n_sign_posn",   sizeof(s.n_sign_posn));
	s.n_sign_posn = 0; s.n_sign_posn = ~s.n_sign_posn;
	dump("fldunsigned n_sign_posn", s.n_sign_posn > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- ABDAY_1\n");
	dump_section_ABDAY_1();
	printf("---\n");
	printf("-+- ABDAY_2\n");
	dump_section_ABDAY_2();
	printf("---\n");
	printf("-+- ABDAY_3\n");
	dump_section_ABDAY_3();
	printf("---\n");
	printf("-+- ABDAY_4\n");
	dump_section_ABDAY_4();
	printf("---\n");
	printf("-+- ABDAY_5\n");
	dump_section_ABDAY_5();
	printf("---\n");
	printf("-+- ABDAY_6\n");
	dump_section_ABDAY_6();
	printf("---\n");
	printf("-+- ABDAY_7\n");
	dump_section_ABDAY_7();
	printf("---\n");
	printf("-+- ABMON_1\n");
	dump_section_ABMON_1();
	printf("---\n");
	printf("-+- ABMON_10\n");
	dump_section_ABMON_10();
	printf("---\n");
	printf("-+- ABMON_11\n");
	dump_section_ABMON_11();
	printf("---\n");
	printf("-+- ABMON_12\n");
	dump_section_ABMON_12();
	printf("---\n");
	printf("-+- ABMON_2\n");
	dump_section_ABMON_2();
	printf("---\n");
	printf("-+- ABMON_3\n");
	dump_section_ABMON_3();
	printf("---\n");
	printf("-+- ABMON_4\n");
	dump_section_ABMON_4();
	printf("---\n");
	printf("-+- ABMON_5\n");
	dump_section_ABMON_5();
	printf("---\n");
	printf("-+- ABMON_6\n");
	dump_section_ABMON_6();
	printf("---\n");
	printf("-+- ABMON_7\n");
	dump_section_ABMON_7();
	printf("---\n");
	printf("-+- ABMON_8\n");
	dump_section_ABMON_8();
	printf("---\n");
	printf("-+- ABMON_9\n");
	dump_section_ABMON_9();
	printf("---\n");
	printf("-+- ALT_DIGITS\n");
	dump_section_ALT_DIGITS();
	printf("---\n");
	printf("-+- AM_STR\n");
	dump_section_AM_STR();
	printf("---\n");
	printf("-+- CHAR_MAX\n");
	dump_section_CHAR_MAX();
	printf("---\n");
	printf("-+- CODESET\n");
	dump_section_CODESET();
	printf("---\n");
	printf("-+- CRNCYSTR\n");
	dump_section_CRNCYSTR();
	printf("---\n");
	printf("-+- DAY_1\n");
	dump_section_DAY_1();
	printf("---\n");
	printf("-+- DAY_2\n");
	dump_section_DAY_2();
	printf("---\n");
	printf("-+- DAY_3\n");
	dump_section_DAY_3();
	printf("---\n");
	printf("-+- DAY_4\n");
	dump_section_DAY_4();
	printf("---\n");
	printf("-+- DAY_5\n");
	dump_section_DAY_5();
	printf("---\n");
	printf("-+- DAY_6\n");
	dump_section_DAY_6();
	printf("---\n");
	printf("-+- DAY_7\n");
	dump_section_DAY_7();
	printf("---\n");
	printf("-+- D_FMT\n");
	dump_section_D_FMT();
	printf("---\n");
	printf("-+- D_T_FMT\n");
	dump_section_D_T_FMT();
	printf("---\n");
	printf("-+- ERA\n");
	dump_section_ERA();
	printf("---\n");
	printf("-+- ERA_D_FMT\n");
	dump_section_ERA_D_FMT();
	printf("---\n");
	printf("-+- ERA_D_T_FMT\n");
	dump_section_ERA_D_T_FMT();
	printf("---\n");
	printf("-+- ERA_T_FMT\n");
	dump_section_ERA_T_FMT();
	printf("---\n");
	printf("-+- LC_ADDRESS\n");
	dump_section_LC_ADDRESS();
	printf("---\n");
	printf("-+- LC_ALL\n");
	dump_section_LC_ALL();
	printf("---\n");
	printf("-+- LC_COLLATE\n");
	dump_section_LC_COLLATE();
	printf("---\n");
	printf("-+- LC_CTYPE\n");
	dump_section_LC_CTYPE();
	printf("---\n");
	printf("-+- LC_IDENTIFICATION\n");
	dump_section_LC_IDENTIFICATION();
	printf("---\n");
	printf("-+- LC_MAX\n");
	dump_section_LC_MAX();
	printf("---\n");
	printf("-+- LC_MEASUREMENT\n");
	dump_section_LC_MEASUREMENT();
	printf("---\n");
	printf("-+- LC_MESSAGES\n");
	dump_section_LC_MESSAGES();
	printf("---\n");
	printf("-+- LC_MIN\n");
	dump_section_LC_MIN();
	printf("---\n");
	printf("-+- LC_MONETARY\n");
	dump_section_LC_MONETARY();
	printf("---\n");
	printf("-+- LC_NAME\n");
	dump_section_LC_NAME();
	printf("---\n");
	printf("-+- LC_NUMERIC\n");
	dump_section_LC_NUMERIC();
	printf("---\n");
	printf("-+- LC_PAPER\n");
	dump_section_LC_PAPER();
	printf("---\n");
	printf("-+- LC_TELEPHONE\n");
	dump_section_LC_TELEPHONE();
	printf("---\n");
	printf("-+- LC_TIME\n");
	dump_section_LC_TIME();
	printf("---\n");
	printf("-+- MON_1\n");
	dump_section_MON_1();
	printf("---\n");
	printf("-+- MON_10\n");
	dump_section_MON_10();
	printf("---\n");
	printf("-+- MON_11\n");
	dump_section_MON_11();
	printf("---\n");
	printf("-+- MON_12\n");
	dump_section_MON_12();
	printf("---\n");
	printf("-+- MON_2\n");
	dump_section_MON_2();
	printf("---\n");
	printf("-+- MON_3\n");
	dump_section_MON_3();
	printf("---\n");
	printf("-+- MON_4\n");
	dump_section_MON_4();
	printf("---\n");
	printf("-+- MON_5\n");
	dump_section_MON_5();
	printf("---\n");
	printf("-+- MON_6\n");
	dump_section_MON_6();
	printf("---\n");
	printf("-+- MON_7\n");
	dump_section_MON_7();
	printf("---\n");
	printf("-+- MON_8\n");
	dump_section_MON_8();
	printf("---\n");
	printf("-+- MON_9\n");
	dump_section_MON_9();
	printf("---\n");
	printf("-+- NOEXPR\n");
	dump_section_NOEXPR();
	printf("---\n");
	printf("-+- PM_STR\n");
	dump_section_PM_STR();
	printf("---\n");
	printf("-+- RADIXCHAR\n");
	dump_section_RADIXCHAR();
	printf("---\n");
	printf("-+- THOUSEP\n");
	dump_section_THOUSEP();
	printf("---\n");
	printf("-+- T_FMT\n");
	dump_section_T_FMT();
	printf("---\n");
	printf("-+- T_FMT_AMPM\n");
	dump_section_T_FMT_AMPM();
	printf("---\n");
	printf("-+- YESEXPR\n");
	dump_section_YESEXPR();
	printf("---\n");
	printf("-+- _DATE_FMT\n");
	dump_section__DATE_FMT();
	printf("---\n");
	printf("-+- lconv\n");
	dump_section_lconv();
	printf("---\n");
	return 0;
}
