/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <termios.h>
#include <unistd.h>
#include <sys/ioctl.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_B0(void) {
#ifdef B0
	dump("defined", 1);
	if ((B0) <= 0) {
	    long long x = (long long)(B0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B110(void) {
#ifdef B110
	dump("defined", 1);
	if ((B110) <= 0) {
	    long long x = (long long)(B110);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B110);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B115200(void) {
#ifdef B115200
	dump("defined", 1);
	if ((B115200) <= 0) {
	    long long x = (long long)(B115200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B115200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B1200(void) {
#ifdef B1200
	dump("defined", 1);
	if ((B1200) <= 0) {
	    long long x = (long long)(B1200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B1200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B134(void) {
#ifdef B134
	dump("defined", 1);
	if ((B134) <= 0) {
	    long long x = (long long)(B134);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B134);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B150(void) {
#ifdef B150
	dump("defined", 1);
	if ((B150) <= 0) {
	    long long x = (long long)(B150);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B150);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B1800(void) {
#ifdef B1800
	dump("defined", 1);
	if ((B1800) <= 0) {
	    long long x = (long long)(B1800);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B1800);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B19200(void) {
#ifdef B19200
	dump("defined", 1);
	if ((B19200) <= 0) {
	    long long x = (long long)(B19200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B19200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B200(void) {
#ifdef B200
	dump("defined", 1);
	if ((B200) <= 0) {
	    long long x = (long long)(B200);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B200);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B230400(void) {
#ifdef B230400
	dump("defined", 1);
	if ((B230400) <= 0) {
	    long long x = (long long)(B230400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B230400);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B2400(void) {
#ifdef B2400
	dump("defined", 1);
	if ((B2400) <= 0) {
	    long long x = (long long)(B2400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B2400);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B300(void) {
#ifdef B300
	dump("defined", 1);
	if ((B300) <= 0) {
	    long long x = (long long)(B300);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B300);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B38400(void) {
#ifdef B38400
	dump("defined", 1);
	if ((B38400) <= 0) {
	    long long x = (long long)(B38400);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B38400);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B460800(void) {
#ifdef B460800
	dump("defined", 1);
	if ((B460800) <= 0) {
	    long long x = (long long)(B460800);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B460800);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B4800(void) {
#ifdef B4800
	dump("defined", 1);
	if ((B4800) <= 0) {
	    long long x = (long long)(B4800);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B4800);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B50(void) {
#ifdef B50
	dump("defined", 1);
	if ((B50) <= 0) {
	    long long x = (long long)(B50);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B50);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B57600(void) {
#ifdef B57600
	dump("defined", 1);
	if ((B57600) <= 0) {
	    long long x = (long long)(B57600);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B57600);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B600(void) {
#ifdef B600
	dump("defined", 1);
	if ((B600) <= 0) {
	    long long x = (long long)(B600);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B600);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B75(void) {
#ifdef B75
	dump("defined", 1);
	if ((B75) <= 0) {
	    long long x = (long long)(B75);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B75);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_B9600(void) {
#ifdef B9600
	dump("defined", 1);
	if ((B9600) <= 0) {
	    long long x = (long long)(B9600);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(B9600);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BRKINT(void) {
#ifdef BRKINT
	dump("defined", 1);
	if ((BRKINT) <= 0) {
	    long long x = (long long)(BRKINT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BRKINT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BS0(void) {
#ifdef BS0
	dump("defined", 1);
	if ((BS0) <= 0) {
	    long long x = (long long)(BS0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BS0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BS1(void) {
#ifdef BS1
	dump("defined", 1);
	if ((BS1) <= 0) {
	    long long x = (long long)(BS1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BS1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BSDLY(void) {
#ifdef BSDLY
	dump("defined", 1);
	if ((BSDLY) <= 0) {
	    long long x = (long long)(BSDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(BSDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CBAUD(void) {
#ifdef CBAUD
	dump("defined", 1);
	if ((CBAUD) <= 0) {
	    long long x = (long long)(CBAUD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CBAUD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CBAUDEX(void) {
#ifdef CBAUDEX
	dump("defined", 1);
	if ((CBAUDEX) <= 0) {
	    long long x = (long long)(CBAUDEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CBAUDEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CDEL(void) {
#ifdef CDEL
	dump("defined", 1);
	if ((CDEL) <= 0) {
	    long long x = (long long)(CDEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CDEL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CDSUSP(void) {
#ifdef CDSUSP
	dump("defined", 1);
	if ((CDSUSP) <= 0) {
	    long long x = (long long)(CDSUSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CDSUSP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CEOF(void) {
#ifdef CEOF
	dump("defined", 1);
	if ((CEOF) <= 0) {
	    long long x = (long long)(CEOF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CEOL(void) {
#ifdef CEOL
	dump("defined", 1);
	if ((CEOL) <= 0) {
	    long long x = (long long)(CEOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CEOL2(void) {
#ifdef CEOL2
	dump("defined", 1);
	if ((CEOL2) <= 0) {
	    long long x = (long long)(CEOL2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOL2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CEOT(void) {
#ifdef CEOT
	dump("defined", 1);
	if ((CEOT) <= 0) {
	    long long x = (long long)(CEOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CEOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERASE(void) {
#ifdef CERASE
	dump("defined", 1);
	if ((CERASE) <= 0) {
	    long long x = (long long)(CERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CESC(void) {
#ifdef CESC
	dump("defined", 1);
	if ((CESC) <= 0) {
	    long long x = (long long)(CESC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CESC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CFLUSH(void) {
#ifdef CFLUSH
	dump("defined", 1);
	if ((CFLUSH) <= 0) {
	    long long x = (long long)(CFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CIBAUD(void) {
#ifdef CIBAUD
	dump("defined", 1);
	if ((CIBAUD) <= 0) {
	    long long x = (long long)(CIBAUD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CIBAUD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CINTR(void) {
#ifdef CINTR
	dump("defined", 1);
	if ((CINTR) <= 0) {
	    long long x = (long long)(CINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CKILL(void) {
#ifdef CKILL
	dump("defined", 1);
	if ((CKILL) <= 0) {
	    long long x = (long long)(CKILL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CKILL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CLNEXT(void) {
#ifdef CLNEXT
	dump("defined", 1);
	if ((CLNEXT) <= 0) {
	    long long x = (long long)(CLNEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CLNEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CLOCAL(void) {
#ifdef CLOCAL
	dump("defined", 1);
	if ((CLOCAL) <= 0) {
	    long long x = (long long)(CLOCAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CLOCAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CNUL(void) {
#ifdef CNUL
	dump("defined", 1);
	if ((CNUL) <= 0) {
	    long long x = (long long)(CNUL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CNUL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_COMMON(void) {
#ifdef COMMON
	dump("defined", 1);
	if ((COMMON) <= 0) {
	    long long x = (long long)(COMMON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(COMMON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CQUIT(void) {
#ifdef CQUIT
	dump("defined", 1);
	if ((CQUIT) <= 0) {
	    long long x = (long long)(CQUIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CQUIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CR0(void) {
#ifdef CR0
	dump("defined", 1);
	if ((CR0) <= 0) {
	    long long x = (long long)(CR0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CR1(void) {
#ifdef CR1
	dump("defined", 1);
	if ((CR1) <= 0) {
	    long long x = (long long)(CR1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CR2(void) {
#ifdef CR2
	dump("defined", 1);
	if ((CR2) <= 0) {
	    long long x = (long long)(CR2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CR3(void) {
#ifdef CR3
	dump("defined", 1);
	if ((CR3) <= 0) {
	    long long x = (long long)(CR3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CR3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CRDLY(void) {
#ifdef CRDLY
	dump("defined", 1);
	if ((CRDLY) <= 0) {
	    long long x = (long long)(CRDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CREAD(void) {
#ifdef CREAD
	dump("defined", 1);
	if ((CREAD) <= 0) {
	    long long x = (long long)(CREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CRPRNT(void) {
#ifdef CRPRNT
	dump("defined", 1);
	if ((CRPRNT) <= 0) {
	    long long x = (long long)(CRPRNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRPRNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CRTSCTS(void) {
#ifdef CRTSCTS
	dump("defined", 1);
	if ((CRTSCTS) <= 0) {
	    long long x = (long long)(CRTSCTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CRTSCTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CS5(void) {
#ifdef CS5
	dump("defined", 1);
	if ((CS5) <= 0) {
	    long long x = (long long)(CS5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CS6(void) {
#ifdef CS6
	dump("defined", 1);
	if ((CS6) <= 0) {
	    long long x = (long long)(CS6);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS6);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CS7(void) {
#ifdef CS7
	dump("defined", 1);
	if ((CS7) <= 0) {
	    long long x = (long long)(CS7);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS7);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CS8(void) {
#ifdef CS8
	dump("defined", 1);
	if ((CS8) <= 0) {
	    long long x = (long long)(CS8);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CS8);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CSIZE(void) {
#ifdef CSIZE
	dump("defined", 1);
	if ((CSIZE) <= 0) {
	    long long x = (long long)(CSIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CSTART(void) {
#ifdef CSTART
	dump("defined", 1);
	if ((CSTART) <= 0) {
	    long long x = (long long)(CSTART);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSTART);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CSTOP(void) {
#ifdef CSTOP
	dump("defined", 1);
	if ((CSTOP) <= 0) {
	    long long x = (long long)(CSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CSTOPB(void) {
#ifdef CSTOPB
	dump("defined", 1);
	if ((CSTOPB) <= 0) {
	    long long x = (long long)(CSTOPB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSTOPB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CSUSP(void) {
#ifdef CSUSP
	dump("defined", 1);
	if ((CSUSP) <= 0) {
	    long long x = (long long)(CSUSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSUSP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CSWTCH(void) {
#ifdef CSWTCH
	dump("defined", 1);
	if ((CSWTCH) <= 0) {
	    long long x = (long long)(CSWTCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CSWTCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CWERASE(void) {
#ifdef CWERASE
	dump("defined", 1);
	if ((CWERASE) <= 0) {
	    long long x = (long long)(CWERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(CWERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECHO(void) {
#ifdef ECHO
	dump("defined", 1);
	if ((ECHO) <= 0) {
	    long long x = (long long)(ECHO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECHOCTL(void) {
#ifdef ECHOCTL
	dump("defined", 1);
	if ((ECHOCTL) <= 0) {
	    long long x = (long long)(ECHOCTL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOCTL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECHOE(void) {
#ifdef ECHOE
	dump("defined", 1);
	if ((ECHOE) <= 0) {
	    long long x = (long long)(ECHOE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECHOK(void) {
#ifdef ECHOK
	dump("defined", 1);
	if ((ECHOK) <= 0) {
	    long long x = (long long)(ECHOK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECHOKE(void) {
#ifdef ECHOKE
	dump("defined", 1);
	if ((ECHOKE) <= 0) {
	    long long x = (long long)(ECHOKE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOKE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECHONL(void) {
#ifdef ECHONL
	dump("defined", 1);
	if ((ECHONL) <= 0) {
	    long long x = (long long)(ECHONL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHONL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECHOPRT(void) {
#ifdef ECHOPRT
	dump("defined", 1);
	if ((ECHOPRT) <= 0) {
	    long long x = (long long)(ECHOPRT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ECHOPRT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EXTA(void) {
#ifdef EXTA
	dump("defined", 1);
	if ((EXTA) <= 0) {
	    long long x = (long long)(EXTA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EXTA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EXTB(void) {
#ifdef EXTB
	dump("defined", 1);
	if ((EXTB) <= 0) {
	    long long x = (long long)(EXTB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EXTB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FF0(void) {
#ifdef FF0
	dump("defined", 1);
	if ((FF0) <= 0) {
	    long long x = (long long)(FF0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FF0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FF1(void) {
#ifdef FF1
	dump("defined", 1);
	if ((FF1) <= 0) {
	    long long x = (long long)(FF1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FF1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FFDLY(void) {
#ifdef FFDLY
	dump("defined", 1);
	if ((FFDLY) <= 0) {
	    long long x = (long long)(FFDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FFDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FIOASYNC(void) {
#ifdef FIOASYNC
	dump("defined", 1);
	if ((FIOASYNC) <= 0) {
	    long long x = (long long)(FIOASYNC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIOASYNC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FIOCLEX(void) {
#ifdef FIOCLEX
	dump("defined", 1);
	if ((FIOCLEX) <= 0) {
	    long long x = (long long)(FIOCLEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIOCLEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FIONBIO(void) {
#ifdef FIONBIO
	dump("defined", 1);
	if ((FIONBIO) <= 0) {
	    long long x = (long long)(FIONBIO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONBIO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FIONCLEX(void) {
#ifdef FIONCLEX
	dump("defined", 1);
	if ((FIONCLEX) <= 0) {
	    long long x = (long long)(FIONCLEX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONCLEX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FIONREAD(void) {
#ifdef FIONREAD
	dump("defined", 1);
	if ((FIONREAD) <= 0) {
	    long long x = (long long)(FIONREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FIONREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FLUSHO(void) {
#ifdef FLUSHO
	dump("defined", 1);
	if ((FLUSHO) <= 0) {
	    long long x = (long long)(FLUSHO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FLUSHO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_HUPCL(void) {
#ifdef HUPCL
	dump("defined", 1);
	if ((HUPCL) <= 0) {
	    long long x = (long long)(HUPCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(HUPCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IBSHIFT(void) {
#ifdef IBSHIFT
	dump("defined", 1);
	if ((IBSHIFT) <= 0) {
	    long long x = (long long)(IBSHIFT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IBSHIFT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ICANON(void) {
#ifdef ICANON
	dump("defined", 1);
	if ((ICANON) <= 0) {
	    long long x = (long long)(ICANON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ICANON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ICRNL(void) {
#ifdef ICRNL
	dump("defined", 1);
	if ((ICRNL) <= 0) {
	    long long x = (long long)(ICRNL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ICRNL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IEXTEN(void) {
#ifdef IEXTEN
	dump("defined", 1);
	if ((IEXTEN) <= 0) {
	    long long x = (long long)(IEXTEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IEXTEN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IGNBRK(void) {
#ifdef IGNBRK
	dump("defined", 1);
	if ((IGNBRK) <= 0) {
	    long long x = (long long)(IGNBRK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IGNBRK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IGNCR(void) {
#ifdef IGNCR
	dump("defined", 1);
	if ((IGNCR) <= 0) {
	    long long x = (long long)(IGNCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IGNCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IGNPAR(void) {
#ifdef IGNPAR
	dump("defined", 1);
	if ((IGNPAR) <= 0) {
	    long long x = (long long)(IGNPAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IGNPAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IMAXBEL(void) {
#ifdef IMAXBEL
	dump("defined", 1);
	if ((IMAXBEL) <= 0) {
	    long long x = (long long)(IMAXBEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IMAXBEL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INIT_C_CC(void) {
#ifdef INIT_C_CC
	dump("defined", 1);
	if ((INIT_C_CC) <= 0) {
	    long long x = (long long)(INIT_C_CC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INIT_C_CC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INLCR(void) {
#ifdef INLCR
	dump("defined", 1);
	if ((INLCR) <= 0) {
	    long long x = (long long)(INLCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INLCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INPCK(void) {
#ifdef INPCK
	dump("defined", 1);
	if ((INPCK) <= 0) {
	    long long x = (long long)(INPCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(INPCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IOCSIZE_MASK(void) {
#ifdef IOCSIZE_MASK
	dump("defined", 1);
	if ((IOCSIZE_MASK) <= 0) {
	    long long x = (long long)(IOCSIZE_MASK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IOCSIZE_MASK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IOCSIZE_SHIFT(void) {
#ifdef IOCSIZE_SHIFT
	dump("defined", 1);
	if ((IOCSIZE_SHIFT) <= 0) {
	    long long x = (long long)(IOCSIZE_SHIFT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IOCSIZE_SHIFT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ISIG(void) {
#ifdef ISIG
	dump("defined", 1);
	if ((ISIG) <= 0) {
	    long long x = (long long)(ISIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ISIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ISTRIP(void) {
#ifdef ISTRIP
	dump("defined", 1);
	if ((ISTRIP) <= 0) {
	    long long x = (long long)(ISTRIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ISTRIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IUCLC(void) {
#ifdef IUCLC
	dump("defined", 1);
	if ((IUCLC) <= 0) {
	    long long x = (long long)(IUCLC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IUCLC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IXANY(void) {
#ifdef IXANY
	dump("defined", 1);
	if ((IXANY) <= 0) {
	    long long x = (long long)(IXANY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IXANY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IXOFF(void) {
#ifdef IXOFF
	dump("defined", 1);
	if ((IXOFF) <= 0) {
	    long long x = (long long)(IXOFF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IXOFF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_IXON(void) {
#ifdef IXON
	dump("defined", 1);
	if ((IXON) <= 0) {
	    long long x = (long long)(IXON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(IXON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NCC(void) {
#ifdef NCC
	dump("defined", 1);
	if ((NCC) <= 0) {
	    long long x = (long long)(NCC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NCC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NCCS(void) {
#ifdef NCCS
	dump("defined", 1);
	if ((NCCS) <= 0) {
	    long long x = (long long)(NCCS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NCCS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NL0(void) {
#ifdef NL0
	dump("defined", 1);
	if ((NL0) <= 0) {
	    long long x = (long long)(NL0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NL0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NL1(void) {
#ifdef NL1
	dump("defined", 1);
	if ((NL1) <= 0) {
	    long long x = (long long)(NL1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NL1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NLDLY(void) {
#ifdef NLDLY
	dump("defined", 1);
	if ((NLDLY) <= 0) {
	    long long x = (long long)(NLDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NLDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NOFLSH(void) {
#ifdef NOFLSH
	dump("defined", 1);
	if ((NOFLSH) <= 0) {
	    long long x = (long long)(NOFLSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NOFLSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NSWTCH(void) {
#ifdef NSWTCH
	dump("defined", 1);
	if ((NSWTCH) <= 0) {
	    long long x = (long long)(NSWTCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(NSWTCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_N_MOUSE(void) {
#ifdef N_MOUSE
	dump("defined", 1);
	if ((N_MOUSE) <= 0) {
	    long long x = (long long)(N_MOUSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_MOUSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_N_PPP(void) {
#ifdef N_PPP
	dump("defined", 1);
	if ((N_PPP) <= 0) {
	    long long x = (long long)(N_PPP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_PPP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_N_SLIP(void) {
#ifdef N_SLIP
	dump("defined", 1);
	if ((N_SLIP) <= 0) {
	    long long x = (long long)(N_SLIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_SLIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_N_STRIP(void) {
#ifdef N_STRIP
	dump("defined", 1);
	if ((N_STRIP) <= 0) {
	    long long x = (long long)(N_STRIP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_STRIP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_N_TTY(void) {
#ifdef N_TTY
	dump("defined", 1);
	if ((N_TTY) <= 0) {
	    long long x = (long long)(N_TTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(N_TTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OCRNL(void) {
#ifdef OCRNL
	dump("defined", 1);
	if ((OCRNL) <= 0) {
	    long long x = (long long)(OCRNL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OCRNL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OFDEL(void) {
#ifdef OFDEL
	dump("defined", 1);
	if ((OFDEL) <= 0) {
	    long long x = (long long)(OFDEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OFDEL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OFILL(void) {
#ifdef OFILL
	dump("defined", 1);
	if ((OFILL) <= 0) {
	    long long x = (long long)(OFILL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OFILL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OLCUC(void) {
#ifdef OLCUC
	dump("defined", 1);
	if ((OLCUC) <= 0) {
	    long long x = (long long)(OLCUC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OLCUC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ONLCR(void) {
#ifdef ONLCR
	dump("defined", 1);
	if ((ONLCR) <= 0) {
	    long long x = (long long)(ONLCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ONLCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ONLRET(void) {
#ifdef ONLRET
	dump("defined", 1);
	if ((ONLRET) <= 0) {
	    long long x = (long long)(ONLRET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ONLRET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ONOCR(void) {
#ifdef ONOCR
	dump("defined", 1);
	if ((ONOCR) <= 0) {
	    long long x = (long long)(ONOCR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ONOCR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OPOST(void) {
#ifdef OPOST
	dump("defined", 1);
	if ((OPOST) <= 0) {
	    long long x = (long long)(OPOST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(OPOST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PARENB(void) {
#ifdef PARENB
	dump("defined", 1);
	if ((PARENB) <= 0) {
	    long long x = (long long)(PARENB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PARENB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PARMRK(void) {
#ifdef PARMRK
	dump("defined", 1);
	if ((PARMRK) <= 0) {
	    long long x = (long long)(PARMRK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PARMRK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PARODD(void) {
#ifdef PARODD
	dump("defined", 1);
	if ((PARODD) <= 0) {
	    long long x = (long long)(PARODD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PARODD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PENDIN(void) {
#ifdef PENDIN
	dump("defined", 1);
	if ((PENDIN) <= 0) {
	    long long x = (long long)(PENDIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PENDIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TAB0(void) {
#ifdef TAB0
	dump("defined", 1);
	if ((TAB0) <= 0) {
	    long long x = (long long)(TAB0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TAB1(void) {
#ifdef TAB1
	dump("defined", 1);
	if ((TAB1) <= 0) {
	    long long x = (long long)(TAB1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TAB2(void) {
#ifdef TAB2
	dump("defined", 1);
	if ((TAB2) <= 0) {
	    long long x = (long long)(TAB2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TAB3(void) {
#ifdef TAB3
	dump("defined", 1);
	if ((TAB3) <= 0) {
	    long long x = (long long)(TAB3);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TAB3);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TABDLY(void) {
#ifdef TABDLY
	dump("defined", 1);
	if ((TABDLY) <= 0) {
	    long long x = (long long)(TABDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TABDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCFLSH(void) {
#ifdef TCFLSH
	dump("defined", 1);
	if ((TCFLSH) <= 0) {
	    long long x = (long long)(TCFLSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCFLSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCGETA(void) {
#ifdef TCGETA
	dump("defined", 1);
	if ((TCGETA) <= 0) {
	    long long x = (long long)(TCGETA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCGETA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCGETS(void) {
#ifdef TCGETS
	dump("defined", 1);
	if ((TCGETS) <= 0) {
	    long long x = (long long)(TCGETS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCGETS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCIFLUSH(void) {
#ifdef TCIFLUSH
	dump("defined", 1);
	if ((TCIFLUSH) <= 0) {
	    long long x = (long long)(TCIFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCIFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCIOFF(void) {
#ifdef TCIOFF
	dump("defined", 1);
	if ((TCIOFF) <= 0) {
	    long long x = (long long)(TCIOFF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCIOFF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCIOFLUSH(void) {
#ifdef TCIOFLUSH
	dump("defined", 1);
	if ((TCIOFLUSH) <= 0) {
	    long long x = (long long)(TCIOFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCIOFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCION(void) {
#ifdef TCION
	dump("defined", 1);
	if ((TCION) <= 0) {
	    long long x = (long long)(TCION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCOFLUSH(void) {
#ifdef TCOFLUSH
	dump("defined", 1);
	if ((TCOFLUSH) <= 0) {
	    long long x = (long long)(TCOFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCOFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCOOFF(void) {
#ifdef TCOOFF
	dump("defined", 1);
	if ((TCOOFF) <= 0) {
	    long long x = (long long)(TCOOFF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCOOFF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCOON(void) {
#ifdef TCOON
	dump("defined", 1);
	if ((TCOON) <= 0) {
	    long long x = (long long)(TCOON);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCOON);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSADRAIN(void) {
#ifdef TCSADRAIN
	dump("defined", 1);
	if ((TCSADRAIN) <= 0) {
	    long long x = (long long)(TCSADRAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSADRAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSAFLUSH(void) {
#ifdef TCSAFLUSH
	dump("defined", 1);
	if ((TCSAFLUSH) <= 0) {
	    long long x = (long long)(TCSAFLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSAFLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSANOW(void) {
#ifdef TCSANOW
	dump("defined", 1);
	if ((TCSANOW) <= 0) {
	    long long x = (long long)(TCSANOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSANOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSASOFT(void) {
#ifdef TCSASOFT
	dump("defined", 1);
	if ((TCSASOFT) <= 0) {
	    long long x = (long long)(TCSASOFT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSASOFT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSBRK(void) {
#ifdef TCSBRK
	dump("defined", 1);
	if ((TCSBRK) <= 0) {
	    long long x = (long long)(TCSBRK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSBRK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSBRKP(void) {
#ifdef TCSBRKP
	dump("defined", 1);
	if ((TCSBRKP) <= 0) {
	    long long x = (long long)(TCSBRKP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSBRKP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSETA(void) {
#ifdef TCSETA
	dump("defined", 1);
	if ((TCSETA) <= 0) {
	    long long x = (long long)(TCSETA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSETAF(void) {
#ifdef TCSETAF
	dump("defined", 1);
	if ((TCSETAF) <= 0) {
	    long long x = (long long)(TCSETAF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETAF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSETAW(void) {
#ifdef TCSETAW
	dump("defined", 1);
	if ((TCSETAW) <= 0) {
	    long long x = (long long)(TCSETAW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETAW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSETS(void) {
#ifdef TCSETS
	dump("defined", 1);
	if ((TCSETS) <= 0) {
	    long long x = (long long)(TCSETS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSETSF(void) {
#ifdef TCSETSF
	dump("defined", 1);
	if ((TCSETSF) <= 0) {
	    long long x = (long long)(TCSETSF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETSF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCSETSW(void) {
#ifdef TCSETSW
	dump("defined", 1);
	if ((TCSETSW) <= 0) {
	    long long x = (long long)(TCSETSW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCSETSW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TCXONC(void) {
#ifdef TCXONC
	dump("defined", 1);
	if ((TCXONC) <= 0) {
	    long long x = (long long)(TCXONC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TCXONC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCCONS(void) {
#ifdef TIOCCONS
	dump("defined", 1);
	if ((TIOCCONS) <= 0) {
	    long long x = (long long)(TIOCCONS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCCONS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCEXCL(void) {
#ifdef TIOCEXCL
	dump("defined", 1);
	if ((TIOCEXCL) <= 0) {
	    long long x = (long long)(TIOCEXCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCEXCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCGETD(void) {
#ifdef TIOCGETD
	dump("defined", 1);
	if ((TIOCGETD) <= 0) {
	    long long x = (long long)(TIOCGETD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGETD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCGICOUNT(void) {
#ifdef TIOCGICOUNT
	dump("defined", 1);
	if ((TIOCGICOUNT) <= 0) {
	    long long x = (long long)(TIOCGICOUNT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGICOUNT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCGLCKTRMIOS(void) {
#ifdef TIOCGLCKTRMIOS
	dump("defined", 1);
	if ((TIOCGLCKTRMIOS) <= 0) {
	    long long x = (long long)(TIOCGLCKTRMIOS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGLCKTRMIOS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCGPGRP(void) {
#ifdef TIOCGPGRP
	dump("defined", 1);
	if ((TIOCGPGRP) <= 0) {
	    long long x = (long long)(TIOCGPGRP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGPGRP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCGSERIAL(void) {
#ifdef TIOCGSERIAL
	dump("defined", 1);
	if ((TIOCGSERIAL) <= 0) {
	    long long x = (long long)(TIOCGSERIAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGSERIAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCGSOFTCAR(void) {
#ifdef TIOCGSOFTCAR
	dump("defined", 1);
	if ((TIOCGSOFTCAR) <= 0) {
	    long long x = (long long)(TIOCGSOFTCAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGSOFTCAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCGWINSZ(void) {
#ifdef TIOCGWINSZ
	dump("defined", 1);
	if ((TIOCGWINSZ) <= 0) {
	    long long x = (long long)(TIOCGWINSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCGWINSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCINQ(void) {
#ifdef TIOCINQ
	dump("defined", 1);
	if ((TIOCINQ) <= 0) {
	    long long x = (long long)(TIOCINQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCINQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCLINUX(void) {
#ifdef TIOCLINUX
	dump("defined", 1);
	if ((TIOCLINUX) <= 0) {
	    long long x = (long long)(TIOCLINUX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCLINUX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCMBIC(void) {
#ifdef TIOCMBIC
	dump("defined", 1);
	if ((TIOCMBIC) <= 0) {
	    long long x = (long long)(TIOCMBIC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMBIC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCMBIS(void) {
#ifdef TIOCMBIS
	dump("defined", 1);
	if ((TIOCMBIS) <= 0) {
	    long long x = (long long)(TIOCMBIS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMBIS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCMGET(void) {
#ifdef TIOCMGET
	dump("defined", 1);
	if ((TIOCMGET) <= 0) {
	    long long x = (long long)(TIOCMGET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMGET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCMIWAIT(void) {
#ifdef TIOCMIWAIT
	dump("defined", 1);
	if ((TIOCMIWAIT) <= 0) {
	    long long x = (long long)(TIOCMIWAIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMIWAIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCMSET(void) {
#ifdef TIOCMSET
	dump("defined", 1);
	if ((TIOCMSET) <= 0) {
	    long long x = (long long)(TIOCMSET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCMSET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_CAR(void) {
#ifdef TIOCM_CAR
	dump("defined", 1);
	if ((TIOCM_CAR) <= 0) {
	    long long x = (long long)(TIOCM_CAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_CAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_CD(void) {
#ifdef TIOCM_CD
	dump("defined", 1);
	if ((TIOCM_CD) <= 0) {
	    long long x = (long long)(TIOCM_CD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_CD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_CTS(void) {
#ifdef TIOCM_CTS
	dump("defined", 1);
	if ((TIOCM_CTS) <= 0) {
	    long long x = (long long)(TIOCM_CTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_CTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_DSR(void) {
#ifdef TIOCM_DSR
	dump("defined", 1);
	if ((TIOCM_DSR) <= 0) {
	    long long x = (long long)(TIOCM_DSR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_DSR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_DTR(void) {
#ifdef TIOCM_DTR
	dump("defined", 1);
	if ((TIOCM_DTR) <= 0) {
	    long long x = (long long)(TIOCM_DTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_DTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_LE(void) {
#ifdef TIOCM_LE
	dump("defined", 1);
	if ((TIOCM_LE) <= 0) {
	    long long x = (long long)(TIOCM_LE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_LE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_RI(void) {
#ifdef TIOCM_RI
	dump("defined", 1);
	if ((TIOCM_RI) <= 0) {
	    long long x = (long long)(TIOCM_RI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_RI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_RNG(void) {
#ifdef TIOCM_RNG
	dump("defined", 1);
	if ((TIOCM_RNG) <= 0) {
	    long long x = (long long)(TIOCM_RNG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_RNG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_RTS(void) {
#ifdef TIOCM_RTS
	dump("defined", 1);
	if ((TIOCM_RTS) <= 0) {
	    long long x = (long long)(TIOCM_RTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_RTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_SR(void) {
#ifdef TIOCM_SR
	dump("defined", 1);
	if ((TIOCM_SR) <= 0) {
	    long long x = (long long)(TIOCM_SR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_SR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCM_ST(void) {
#ifdef TIOCM_ST
	dump("defined", 1);
	if ((TIOCM_ST) <= 0) {
	    long long x = (long long)(TIOCM_ST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCM_ST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCNOTTY(void) {
#ifdef TIOCNOTTY
	dump("defined", 1);
	if ((TIOCNOTTY) <= 0) {
	    long long x = (long long)(TIOCNOTTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCNOTTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCNXCL(void) {
#ifdef TIOCNXCL
	dump("defined", 1);
	if ((TIOCNXCL) <= 0) {
	    long long x = (long long)(TIOCNXCL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCNXCL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCOUTQ(void) {
#ifdef TIOCOUTQ
	dump("defined", 1);
	if ((TIOCOUTQ) <= 0) {
	    long long x = (long long)(TIOCOUTQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCOUTQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT(void) {
#ifdef TIOCPKT
	dump("defined", 1);
	if ((TIOCPKT) <= 0) {
	    long long x = (long long)(TIOCPKT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT_DATA(void) {
#ifdef TIOCPKT_DATA
	dump("defined", 1);
	if ((TIOCPKT_DATA) <= 0) {
	    long long x = (long long)(TIOCPKT_DATA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_DATA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT_DOSTOP(void) {
#ifdef TIOCPKT_DOSTOP
	dump("defined", 1);
	if ((TIOCPKT_DOSTOP) <= 0) {
	    long long x = (long long)(TIOCPKT_DOSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_DOSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT_FLUSHREAD(void) {
#ifdef TIOCPKT_FLUSHREAD
	dump("defined", 1);
	if ((TIOCPKT_FLUSHREAD) <= 0) {
	    long long x = (long long)(TIOCPKT_FLUSHREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_FLUSHREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT_FLUSHWRITE(void) {
#ifdef TIOCPKT_FLUSHWRITE
	dump("defined", 1);
	if ((TIOCPKT_FLUSHWRITE) <= 0) {
	    long long x = (long long)(TIOCPKT_FLUSHWRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_FLUSHWRITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT_NOSTOP(void) {
#ifdef TIOCPKT_NOSTOP
	dump("defined", 1);
	if ((TIOCPKT_NOSTOP) <= 0) {
	    long long x = (long long)(TIOCPKT_NOSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_NOSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT_START(void) {
#ifdef TIOCPKT_START
	dump("defined", 1);
	if ((TIOCPKT_START) <= 0) {
	    long long x = (long long)(TIOCPKT_START);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_START);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCPKT_STOP(void) {
#ifdef TIOCPKT_STOP
	dump("defined", 1);
	if ((TIOCPKT_STOP) <= 0) {
	    long long x = (long long)(TIOCPKT_STOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCPKT_STOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSCTTY(void) {
#ifdef TIOCSCTTY
	dump("defined", 1);
	if ((TIOCSCTTY) <= 0) {
	    long long x = (long long)(TIOCSCTTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSCTTY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSERCONFIG(void) {
#ifdef TIOCSERCONFIG
	dump("defined", 1);
	if ((TIOCSERCONFIG) <= 0) {
	    long long x = (long long)(TIOCSERCONFIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERCONFIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSERGETLSR(void) {
#ifdef TIOCSERGETLSR
	dump("defined", 1);
	if ((TIOCSERGETLSR) <= 0) {
	    long long x = (long long)(TIOCSERGETLSR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGETLSR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSERGETMULTI(void) {
#ifdef TIOCSERGETMULTI
	dump("defined", 1);
	if ((TIOCSERGETMULTI) <= 0) {
	    long long x = (long long)(TIOCSERGETMULTI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGETMULTI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSERGSTRUCT(void) {
#ifdef TIOCSERGSTRUCT
	dump("defined", 1);
	if ((TIOCSERGSTRUCT) <= 0) {
	    long long x = (long long)(TIOCSERGSTRUCT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGSTRUCT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSERGWILD(void) {
#ifdef TIOCSERGWILD
	dump("defined", 1);
	if ((TIOCSERGWILD) <= 0) {
	    long long x = (long long)(TIOCSERGWILD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERGWILD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSERSETMULTI(void) {
#ifdef TIOCSERSETMULTI
	dump("defined", 1);
	if ((TIOCSERSETMULTI) <= 0) {
	    long long x = (long long)(TIOCSERSETMULTI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERSETMULTI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSERSWILD(void) {
#ifdef TIOCSERSWILD
	dump("defined", 1);
	if ((TIOCSERSWILD) <= 0) {
	    long long x = (long long)(TIOCSERSWILD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSERSWILD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSER_TEMT(void) {
#ifdef TIOCSER_TEMT
	dump("defined", 1);
	if ((TIOCSER_TEMT) <= 0) {
	    long long x = (long long)(TIOCSER_TEMT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSER_TEMT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSETD(void) {
#ifdef TIOCSETD
	dump("defined", 1);
	if ((TIOCSETD) <= 0) {
	    long long x = (long long)(TIOCSETD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSETD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSLCKTRMIOS(void) {
#ifdef TIOCSLCKTRMIOS
	dump("defined", 1);
	if ((TIOCSLCKTRMIOS) <= 0) {
	    long long x = (long long)(TIOCSLCKTRMIOS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSLCKTRMIOS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSPGRP(void) {
#ifdef TIOCSPGRP
	dump("defined", 1);
	if ((TIOCSPGRP) <= 0) {
	    long long x = (long long)(TIOCSPGRP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSPGRP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSSERIAL(void) {
#ifdef TIOCSSERIAL
	dump("defined", 1);
	if ((TIOCSSERIAL) <= 0) {
	    long long x = (long long)(TIOCSSERIAL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSSERIAL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSSOFTCAR(void) {
#ifdef TIOCSSOFTCAR
	dump("defined", 1);
	if ((TIOCSSOFTCAR) <= 0) {
	    long long x = (long long)(TIOCSSOFTCAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSSOFTCAR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSTI(void) {
#ifdef TIOCSTI
	dump("defined", 1);
	if ((TIOCSTI) <= 0) {
	    long long x = (long long)(TIOCSTI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSTI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCSWINSZ(void) {
#ifdef TIOCSWINSZ
	dump("defined", 1);
	if ((TIOCSWINSZ) <= 0) {
	    long long x = (long long)(TIOCSWINSZ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCSWINSZ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TIOCTTYGSTRUCT(void) {
#ifdef TIOCTTYGSTRUCT
	dump("defined", 1);
	if ((TIOCTTYGSTRUCT) <= 0) {
	    long long x = (long long)(TIOCTTYGSTRUCT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TIOCTTYGSTRUCT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TOSTOP(void) {
#ifdef TOSTOP
	dump("defined", 1);
	if ((TOSTOP) <= 0) {
	    long long x = (long long)(TOSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(TOSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VDISCARD(void) {
#ifdef VDISCARD
	dump("defined", 1);
	if ((VDISCARD) <= 0) {
	    long long x = (long long)(VDISCARD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VDISCARD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VEOF(void) {
#ifdef VEOF
	dump("defined", 1);
	if ((VEOF) <= 0) {
	    long long x = (long long)(VEOF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VEOF);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VEOL(void) {
#ifdef VEOL
	dump("defined", 1);
	if ((VEOL) <= 0) {
	    long long x = (long long)(VEOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VEOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VEOL2(void) {
#ifdef VEOL2
	dump("defined", 1);
	if ((VEOL2) <= 0) {
	    long long x = (long long)(VEOL2);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VEOL2);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VERASE(void) {
#ifdef VERASE
	dump("defined", 1);
	if ((VERASE) <= 0) {
	    long long x = (long long)(VERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VINTR(void) {
#ifdef VINTR
	dump("defined", 1);
	if ((VINTR) <= 0) {
	    long long x = (long long)(VINTR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VINTR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VKILL(void) {
#ifdef VKILL
	dump("defined", 1);
	if ((VKILL) <= 0) {
	    long long x = (long long)(VKILL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VKILL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VLNEXT(void) {
#ifdef VLNEXT
	dump("defined", 1);
	if ((VLNEXT) <= 0) {
	    long long x = (long long)(VLNEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VLNEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VMIN(void) {
#ifdef VMIN
	dump("defined", 1);
	if ((VMIN) <= 0) {
	    long long x = (long long)(VMIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VMIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VQUIT(void) {
#ifdef VQUIT
	dump("defined", 1);
	if ((VQUIT) <= 0) {
	    long long x = (long long)(VQUIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VQUIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VREPRINT(void) {
#ifdef VREPRINT
	dump("defined", 1);
	if ((VREPRINT) <= 0) {
	    long long x = (long long)(VREPRINT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VREPRINT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VSTART(void) {
#ifdef VSTART
	dump("defined", 1);
	if ((VSTART) <= 0) {
	    long long x = (long long)(VSTART);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSTART);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VSTOP(void) {
#ifdef VSTOP
	dump("defined", 1);
	if ((VSTOP) <= 0) {
	    long long x = (long long)(VSTOP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSTOP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VSUSP(void) {
#ifdef VSUSP
	dump("defined", 1);
	if ((VSUSP) <= 0) {
	    long long x = (long long)(VSUSP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSUSP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VSWTC(void) {
#ifdef VSWTC
	dump("defined", 1);
	if ((VSWTC) <= 0) {
	    long long x = (long long)(VSWTC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSWTC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VSWTCH(void) {
#ifdef VSWTCH
	dump("defined", 1);
	if ((VSWTCH) <= 0) {
	    long long x = (long long)(VSWTCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VSWTCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VT0(void) {
#ifdef VT0
	dump("defined", 1);
	if ((VT0) <= 0) {
	    long long x = (long long)(VT0);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VT0);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VT1(void) {
#ifdef VT1
	dump("defined", 1);
	if ((VT1) <= 0) {
	    long long x = (long long)(VT1);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VT1);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VTDLY(void) {
#ifdef VTDLY
	dump("defined", 1);
	if ((VTDLY) <= 0) {
	    long long x = (long long)(VTDLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VTDLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VTIME(void) {
#ifdef VTIME
	dump("defined", 1);
	if ((VTIME) <= 0) {
	    long long x = (long long)(VTIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VTIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_VWERASE(void) {
#ifdef VWERASE
	dump("defined", 1);
	if ((VWERASE) <= 0) {
	    long long x = (long long)(VWERASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(VWERASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_XCASE(void) {
#ifdef XCASE
	dump("defined", 1);
	if ((XCASE) <= 0) {
	    long long x = (long long)(XCASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XCASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_XTABS(void) {
#ifdef XTABS
	dump("defined", 1);
	if ((XTABS) <= 0) {
	    long long x = (long long)(XTABS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XTABS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section__HAVE_STRUCT_TERMIOS_C_ISPEED(void) {
#ifdef _HAVE_STRUCT_TERMIOS_C_ISPEED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

void dump_section__HAVE_STRUCT_TERMIOS_C_OSPEED(void) {
#ifdef _HAVE_STRUCT_TERMIOS_C_OSPEED
	dump("defined", 1);
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- B0\n");
	dump_section_B0();
	printf("---\n");
	printf("-+- B110\n");
	dump_section_B110();
	printf("---\n");
	printf("-+- B115200\n");
	dump_section_B115200();
	printf("---\n");
	printf("-+- B1200\n");
	dump_section_B1200();
	printf("---\n");
	printf("-+- B134\n");
	dump_section_B134();
	printf("---\n");
	printf("-+- B150\n");
	dump_section_B150();
	printf("---\n");
	printf("-+- B1800\n");
	dump_section_B1800();
	printf("---\n");
	printf("-+- B19200\n");
	dump_section_B19200();
	printf("---\n");
	printf("-+- B200\n");
	dump_section_B200();
	printf("---\n");
	printf("-+- B230400\n");
	dump_section_B230400();
	printf("---\n");
	printf("-+- B2400\n");
	dump_section_B2400();
	printf("---\n");
	printf("-+- B300\n");
	dump_section_B300();
	printf("---\n");
	printf("-+- B38400\n");
	dump_section_B38400();
	printf("---\n");
	printf("-+- B460800\n");
	dump_section_B460800();
	printf("---\n");
	printf("-+- B4800\n");
	dump_section_B4800();
	printf("---\n");
	printf("-+- B50\n");
	dump_section_B50();
	printf("---\n");
	printf("-+- B57600\n");
	dump_section_B57600();
	printf("---\n");
	printf("-+- B600\n");
	dump_section_B600();
	printf("---\n");
	printf("-+- B75\n");
	dump_section_B75();
	printf("---\n");
	printf("-+- B9600\n");
	dump_section_B9600();
	printf("---\n");
	printf("-+- BRKINT\n");
	dump_section_BRKINT();
	printf("---\n");
	printf("-+- BS0\n");
	dump_section_BS0();
	printf("---\n");
	printf("-+- BS1\n");
	dump_section_BS1();
	printf("---\n");
	printf("-+- BSDLY\n");
	dump_section_BSDLY();
	printf("---\n");
	printf("-+- CBAUD\n");
	dump_section_CBAUD();
	printf("---\n");
	printf("-+- CBAUDEX\n");
	dump_section_CBAUDEX();
	printf("---\n");
	printf("-+- CDEL\n");
	dump_section_CDEL();
	printf("---\n");
	printf("-+- CDSUSP\n");
	dump_section_CDSUSP();
	printf("---\n");
	printf("-+- CEOF\n");
	dump_section_CEOF();
	printf("---\n");
	printf("-+- CEOL\n");
	dump_section_CEOL();
	printf("---\n");
	printf("-+- CEOL2\n");
	dump_section_CEOL2();
	printf("---\n");
	printf("-+- CEOT\n");
	dump_section_CEOT();
	printf("---\n");
	printf("-+- CERASE\n");
	dump_section_CERASE();
	printf("---\n");
	printf("-+- CESC\n");
	dump_section_CESC();
	printf("---\n");
	printf("-+- CFLUSH\n");
	dump_section_CFLUSH();
	printf("---\n");
	printf("-+- CIBAUD\n");
	dump_section_CIBAUD();
	printf("---\n");
	printf("-+- CINTR\n");
	dump_section_CINTR();
	printf("---\n");
	printf("-+- CKILL\n");
	dump_section_CKILL();
	printf("---\n");
	printf("-+- CLNEXT\n");
	dump_section_CLNEXT();
	printf("---\n");
	printf("-+- CLOCAL\n");
	dump_section_CLOCAL();
	printf("---\n");
	printf("-+- CNUL\n");
	dump_section_CNUL();
	printf("---\n");
	printf("-+- COMMON\n");
	dump_section_COMMON();
	printf("---\n");
	printf("-+- CQUIT\n");
	dump_section_CQUIT();
	printf("---\n");
	printf("-+- CR0\n");
	dump_section_CR0();
	printf("---\n");
	printf("-+- CR1\n");
	dump_section_CR1();
	printf("---\n");
	printf("-+- CR2\n");
	dump_section_CR2();
	printf("---\n");
	printf("-+- CR3\n");
	dump_section_CR3();
	printf("---\n");
	printf("-+- CRDLY\n");
	dump_section_CRDLY();
	printf("---\n");
	printf("-+- CREAD\n");
	dump_section_CREAD();
	printf("---\n");
	printf("-+- CRPRNT\n");
	dump_section_CRPRNT();
	printf("---\n");
	printf("-+- CRTSCTS\n");
	dump_section_CRTSCTS();
	printf("---\n");
	printf("-+- CS5\n");
	dump_section_CS5();
	printf("---\n");
	printf("-+- CS6\n");
	dump_section_CS6();
	printf("---\n");
	printf("-+- CS7\n");
	dump_section_CS7();
	printf("---\n");
	printf("-+- CS8\n");
	dump_section_CS8();
	printf("---\n");
	printf("-+- CSIZE\n");
	dump_section_CSIZE();
	printf("---\n");
	printf("-+- CSTART\n");
	dump_section_CSTART();
	printf("---\n");
	printf("-+- CSTOP\n");
	dump_section_CSTOP();
	printf("---\n");
	printf("-+- CSTOPB\n");
	dump_section_CSTOPB();
	printf("---\n");
	printf("-+- CSUSP\n");
	dump_section_CSUSP();
	printf("---\n");
	printf("-+- CSWTCH\n");
	dump_section_CSWTCH();
	printf("---\n");
	printf("-+- CWERASE\n");
	dump_section_CWERASE();
	printf("---\n");
	printf("-+- ECHO\n");
	dump_section_ECHO();
	printf("---\n");
	printf("-+- ECHOCTL\n");
	dump_section_ECHOCTL();
	printf("---\n");
	printf("-+- ECHOE\n");
	dump_section_ECHOE();
	printf("---\n");
	printf("-+- ECHOK\n");
	dump_section_ECHOK();
	printf("---\n");
	printf("-+- ECHOKE\n");
	dump_section_ECHOKE();
	printf("---\n");
	printf("-+- ECHONL\n");
	dump_section_ECHONL();
	printf("---\n");
	printf("-+- ECHOPRT\n");
	dump_section_ECHOPRT();
	printf("---\n");
	printf("-+- EXTA\n");
	dump_section_EXTA();
	printf("---\n");
	printf("-+- EXTB\n");
	dump_section_EXTB();
	printf("---\n");
	printf("-+- FF0\n");
	dump_section_FF0();
	printf("---\n");
	printf("-+- FF1\n");
	dump_section_FF1();
	printf("---\n");
	printf("-+- FFDLY\n");
	dump_section_FFDLY();
	printf("---\n");
	printf("-+- FIOASYNC\n");
	dump_section_FIOASYNC();
	printf("---\n");
	printf("-+- FIOCLEX\n");
	dump_section_FIOCLEX();
	printf("---\n");
	printf("-+- FIONBIO\n");
	dump_section_FIONBIO();
	printf("---\n");
	printf("-+- FIONCLEX\n");
	dump_section_FIONCLEX();
	printf("---\n");
	printf("-+- FIONREAD\n");
	dump_section_FIONREAD();
	printf("---\n");
	printf("-+- FLUSHO\n");
	dump_section_FLUSHO();
	printf("---\n");
	printf("-+- HUPCL\n");
	dump_section_HUPCL();
	printf("---\n");
	printf("-+- IBSHIFT\n");
	dump_section_IBSHIFT();
	printf("---\n");
	printf("-+- ICANON\n");
	dump_section_ICANON();
	printf("---\n");
	printf("-+- ICRNL\n");
	dump_section_ICRNL();
	printf("---\n");
	printf("-+- IEXTEN\n");
	dump_section_IEXTEN();
	printf("---\n");
	printf("-+- IGNBRK\n");
	dump_section_IGNBRK();
	printf("---\n");
	printf("-+- IGNCR\n");
	dump_section_IGNCR();
	printf("---\n");
	printf("-+- IGNPAR\n");
	dump_section_IGNPAR();
	printf("---\n");
	printf("-+- IMAXBEL\n");
	dump_section_IMAXBEL();
	printf("---\n");
	printf("-+- INIT_C_CC\n");
	dump_section_INIT_C_CC();
	printf("---\n");
	printf("-+- INLCR\n");
	dump_section_INLCR();
	printf("---\n");
	printf("-+- INPCK\n");
	dump_section_INPCK();
	printf("---\n");
	printf("-+- IOCSIZE_MASK\n");
	dump_section_IOCSIZE_MASK();
	printf("---\n");
	printf("-+- IOCSIZE_SHIFT\n");
	dump_section_IOCSIZE_SHIFT();
	printf("---\n");
	printf("-+- ISIG\n");
	dump_section_ISIG();
	printf("---\n");
	printf("-+- ISTRIP\n");
	dump_section_ISTRIP();
	printf("---\n");
	printf("-+- IUCLC\n");
	dump_section_IUCLC();
	printf("---\n");
	printf("-+- IXANY\n");
	dump_section_IXANY();
	printf("---\n");
	printf("-+- IXOFF\n");
	dump_section_IXOFF();
	printf("---\n");
	printf("-+- IXON\n");
	dump_section_IXON();
	printf("---\n");
	printf("-+- NCC\n");
	dump_section_NCC();
	printf("---\n");
	printf("-+- NCCS\n");
	dump_section_NCCS();
	printf("---\n");
	printf("-+- NL0\n");
	dump_section_NL0();
	printf("---\n");
	printf("-+- NL1\n");
	dump_section_NL1();
	printf("---\n");
	printf("-+- NLDLY\n");
	dump_section_NLDLY();
	printf("---\n");
	printf("-+- NOFLSH\n");
	dump_section_NOFLSH();
	printf("---\n");
	printf("-+- NSWTCH\n");
	dump_section_NSWTCH();
	printf("---\n");
	printf("-+- N_MOUSE\n");
	dump_section_N_MOUSE();
	printf("---\n");
	printf("-+- N_PPP\n");
	dump_section_N_PPP();
	printf("---\n");
	printf("-+- N_SLIP\n");
	dump_section_N_SLIP();
	printf("---\n");
	printf("-+- N_STRIP\n");
	dump_section_N_STRIP();
	printf("---\n");
	printf("-+- N_TTY\n");
	dump_section_N_TTY();
	printf("---\n");
	printf("-+- OCRNL\n");
	dump_section_OCRNL();
	printf("---\n");
	printf("-+- OFDEL\n");
	dump_section_OFDEL();
	printf("---\n");
	printf("-+- OFILL\n");
	dump_section_OFILL();
	printf("---\n");
	printf("-+- OLCUC\n");
	dump_section_OLCUC();
	printf("---\n");
	printf("-+- ONLCR\n");
	dump_section_ONLCR();
	printf("---\n");
	printf("-+- ONLRET\n");
	dump_section_ONLRET();
	printf("---\n");
	printf("-+- ONOCR\n");
	dump_section_ONOCR();
	printf("---\n");
	printf("-+- OPOST\n");
	dump_section_OPOST();
	printf("---\n");
	printf("-+- PARENB\n");
	dump_section_PARENB();
	printf("---\n");
	printf("-+- PARMRK\n");
	dump_section_PARMRK();
	printf("---\n");
	printf("-+- PARODD\n");
	dump_section_PARODD();
	printf("---\n");
	printf("-+- PENDIN\n");
	dump_section_PENDIN();
	printf("---\n");
	printf("-+- TAB0\n");
	dump_section_TAB0();
	printf("---\n");
	printf("-+- TAB1\n");
	dump_section_TAB1();
	printf("---\n");
	printf("-+- TAB2\n");
	dump_section_TAB2();
	printf("---\n");
	printf("-+- TAB3\n");
	dump_section_TAB3();
	printf("---\n");
	printf("-+- TABDLY\n");
	dump_section_TABDLY();
	printf("---\n");
	printf("-+- TCFLSH\n");
	dump_section_TCFLSH();
	printf("---\n");
	printf("-+- TCGETA\n");
	dump_section_TCGETA();
	printf("---\n");
	printf("-+- TCGETS\n");
	dump_section_TCGETS();
	printf("---\n");
	printf("-+- TCIFLUSH\n");
	dump_section_TCIFLUSH();
	printf("---\n");
	printf("-+- TCIOFF\n");
	dump_section_TCIOFF();
	printf("---\n");
	printf("-+- TCIOFLUSH\n");
	dump_section_TCIOFLUSH();
	printf("---\n");
	printf("-+- TCION\n");
	dump_section_TCION();
	printf("---\n");
	printf("-+- TCOFLUSH\n");
	dump_section_TCOFLUSH();
	printf("---\n");
	printf("-+- TCOOFF\n");
	dump_section_TCOOFF();
	printf("---\n");
	printf("-+- TCOON\n");
	dump_section_TCOON();
	printf("---\n");
	printf("-+- TCSADRAIN\n");
	dump_section_TCSADRAIN();
	printf("---\n");
	printf("-+- TCSAFLUSH\n");
	dump_section_TCSAFLUSH();
	printf("---\n");
	printf("-+- TCSANOW\n");
	dump_section_TCSANOW();
	printf("---\n");
	printf("-+- TCSASOFT\n");
	dump_section_TCSASOFT();
	printf("---\n");
	printf("-+- TCSBRK\n");
	dump_section_TCSBRK();
	printf("---\n");
	printf("-+- TCSBRKP\n");
	dump_section_TCSBRKP();
	printf("---\n");
	printf("-+- TCSETA\n");
	dump_section_TCSETA();
	printf("---\n");
	printf("-+- TCSETAF\n");
	dump_section_TCSETAF();
	printf("---\n");
	printf("-+- TCSETAW\n");
	dump_section_TCSETAW();
	printf("---\n");
	printf("-+- TCSETS\n");
	dump_section_TCSETS();
	printf("---\n");
	printf("-+- TCSETSF\n");
	dump_section_TCSETSF();
	printf("---\n");
	printf("-+- TCSETSW\n");
	dump_section_TCSETSW();
	printf("---\n");
	printf("-+- TCXONC\n");
	dump_section_TCXONC();
	printf("---\n");
	printf("-+- TIOCCONS\n");
	dump_section_TIOCCONS();
	printf("---\n");
	printf("-+- TIOCEXCL\n");
	dump_section_TIOCEXCL();
	printf("---\n");
	printf("-+- TIOCGETD\n");
	dump_section_TIOCGETD();
	printf("---\n");
	printf("-+- TIOCGICOUNT\n");
	dump_section_TIOCGICOUNT();
	printf("---\n");
	printf("-+- TIOCGLCKTRMIOS\n");
	dump_section_TIOCGLCKTRMIOS();
	printf("---\n");
	printf("-+- TIOCGPGRP\n");
	dump_section_TIOCGPGRP();
	printf("---\n");
	printf("-+- TIOCGSERIAL\n");
	dump_section_TIOCGSERIAL();
	printf("---\n");
	printf("-+- TIOCGSOFTCAR\n");
	dump_section_TIOCGSOFTCAR();
	printf("---\n");
	printf("-+- TIOCGWINSZ\n");
	dump_section_TIOCGWINSZ();
	printf("---\n");
	printf("-+- TIOCINQ\n");
	dump_section_TIOCINQ();
	printf("---\n");
	printf("-+- TIOCLINUX\n");
	dump_section_TIOCLINUX();
	printf("---\n");
	printf("-+- TIOCMBIC\n");
	dump_section_TIOCMBIC();
	printf("---\n");
	printf("-+- TIOCMBIS\n");
	dump_section_TIOCMBIS();
	printf("---\n");
	printf("-+- TIOCMGET\n");
	dump_section_TIOCMGET();
	printf("---\n");
	printf("-+- TIOCMIWAIT\n");
	dump_section_TIOCMIWAIT();
	printf("---\n");
	printf("-+- TIOCMSET\n");
	dump_section_TIOCMSET();
	printf("---\n");
	printf("-+- TIOCM_CAR\n");
	dump_section_TIOCM_CAR();
	printf("---\n");
	printf("-+- TIOCM_CD\n");
	dump_section_TIOCM_CD();
	printf("---\n");
	printf("-+- TIOCM_CTS\n");
	dump_section_TIOCM_CTS();
	printf("---\n");
	printf("-+- TIOCM_DSR\n");
	dump_section_TIOCM_DSR();
	printf("---\n");
	printf("-+- TIOCM_DTR\n");
	dump_section_TIOCM_DTR();
	printf("---\n");
	printf("-+- TIOCM_LE\n");
	dump_section_TIOCM_LE();
	printf("---\n");
	printf("-+- TIOCM_RI\n");
	dump_section_TIOCM_RI();
	printf("---\n");
	printf("-+- TIOCM_RNG\n");
	dump_section_TIOCM_RNG();
	printf("---\n");
	printf("-+- TIOCM_RTS\n");
	dump_section_TIOCM_RTS();
	printf("---\n");
	printf("-+- TIOCM_SR\n");
	dump_section_TIOCM_SR();
	printf("---\n");
	printf("-+- TIOCM_ST\n");
	dump_section_TIOCM_ST();
	printf("---\n");
	printf("-+- TIOCNOTTY\n");
	dump_section_TIOCNOTTY();
	printf("---\n");
	printf("-+- TIOCNXCL\n");
	dump_section_TIOCNXCL();
	printf("---\n");
	printf("-+- TIOCOUTQ\n");
	dump_section_TIOCOUTQ();
	printf("---\n");
	printf("-+- TIOCPKT\n");
	dump_section_TIOCPKT();
	printf("---\n");
	printf("-+- TIOCPKT_DATA\n");
	dump_section_TIOCPKT_DATA();
	printf("---\n");
	printf("-+- TIOCPKT_DOSTOP\n");
	dump_section_TIOCPKT_DOSTOP();
	printf("---\n");
	printf("-+- TIOCPKT_FLUSHREAD\n");
	dump_section_TIOCPKT_FLUSHREAD();
	printf("---\n");
	printf("-+- TIOCPKT_FLUSHWRITE\n");
	dump_section_TIOCPKT_FLUSHWRITE();
	printf("---\n");
	printf("-+- TIOCPKT_NOSTOP\n");
	dump_section_TIOCPKT_NOSTOP();
	printf("---\n");
	printf("-+- TIOCPKT_START\n");
	dump_section_TIOCPKT_START();
	printf("---\n");
	printf("-+- TIOCPKT_STOP\n");
	dump_section_TIOCPKT_STOP();
	printf("---\n");
	printf("-+- TIOCSCTTY\n");
	dump_section_TIOCSCTTY();
	printf("---\n");
	printf("-+- TIOCSERCONFIG\n");
	dump_section_TIOCSERCONFIG();
	printf("---\n");
	printf("-+- TIOCSERGETLSR\n");
	dump_section_TIOCSERGETLSR();
	printf("---\n");
	printf("-+- TIOCSERGETMULTI\n");
	dump_section_TIOCSERGETMULTI();
	printf("---\n");
	printf("-+- TIOCSERGSTRUCT\n");
	dump_section_TIOCSERGSTRUCT();
	printf("---\n");
	printf("-+- TIOCSERGWILD\n");
	dump_section_TIOCSERGWILD();
	printf("---\n");
	printf("-+- TIOCSERSETMULTI\n");
	dump_section_TIOCSERSETMULTI();
	printf("---\n");
	printf("-+- TIOCSERSWILD\n");
	dump_section_TIOCSERSWILD();
	printf("---\n");
	printf("-+- TIOCSER_TEMT\n");
	dump_section_TIOCSER_TEMT();
	printf("---\n");
	printf("-+- TIOCSETD\n");
	dump_section_TIOCSETD();
	printf("---\n");
	printf("-+- TIOCSLCKTRMIOS\n");
	dump_section_TIOCSLCKTRMIOS();
	printf("---\n");
	printf("-+- TIOCSPGRP\n");
	dump_section_TIOCSPGRP();
	printf("---\n");
	printf("-+- TIOCSSERIAL\n");
	dump_section_TIOCSSERIAL();
	printf("---\n");
	printf("-+- TIOCSSOFTCAR\n");
	dump_section_TIOCSSOFTCAR();
	printf("---\n");
	printf("-+- TIOCSTI\n");
	dump_section_TIOCSTI();
	printf("---\n");
	printf("-+- TIOCSWINSZ\n");
	dump_section_TIOCSWINSZ();
	printf("---\n");
	printf("-+- TIOCTTYGSTRUCT\n");
	dump_section_TIOCTTYGSTRUCT();
	printf("---\n");
	printf("-+- TOSTOP\n");
	dump_section_TOSTOP();
	printf("---\n");
	printf("-+- VDISCARD\n");
	dump_section_VDISCARD();
	printf("---\n");
	printf("-+- VEOF\n");
	dump_section_VEOF();
	printf("---\n");
	printf("-+- VEOL\n");
	dump_section_VEOL();
	printf("---\n");
	printf("-+- VEOL2\n");
	dump_section_VEOL2();
	printf("---\n");
	printf("-+- VERASE\n");
	dump_section_VERASE();
	printf("---\n");
	printf("-+- VINTR\n");
	dump_section_VINTR();
	printf("---\n");
	printf("-+- VKILL\n");
	dump_section_VKILL();
	printf("---\n");
	printf("-+- VLNEXT\n");
	dump_section_VLNEXT();
	printf("---\n");
	printf("-+- VMIN\n");
	dump_section_VMIN();
	printf("---\n");
	printf("-+- VQUIT\n");
	dump_section_VQUIT();
	printf("---\n");
	printf("-+- VREPRINT\n");
	dump_section_VREPRINT();
	printf("---\n");
	printf("-+- VSTART\n");
	dump_section_VSTART();
	printf("---\n");
	printf("-+- VSTOP\n");
	dump_section_VSTOP();
	printf("---\n");
	printf("-+- VSUSP\n");
	dump_section_VSUSP();
	printf("---\n");
	printf("-+- VSWTC\n");
	dump_section_VSWTC();
	printf("---\n");
	printf("-+- VSWTCH\n");
	dump_section_VSWTCH();
	printf("---\n");
	printf("-+- VT0\n");
	dump_section_VT0();
	printf("---\n");
	printf("-+- VT1\n");
	dump_section_VT1();
	printf("---\n");
	printf("-+- VTDLY\n");
	dump_section_VTDLY();
	printf("---\n");
	printf("-+- VTIME\n");
	dump_section_VTIME();
	printf("---\n");
	printf("-+- VWERASE\n");
	dump_section_VWERASE();
	printf("---\n");
	printf("-+- XCASE\n");
	dump_section_XCASE();
	printf("---\n");
	printf("-+- XTABS\n");
	dump_section_XTABS();
	printf("---\n");
	printf("-+- _HAVE_STRUCT_TERMIOS_C_ISPEED\n");
	dump_section__HAVE_STRUCT_TERMIOS_C_ISPEED();
	printf("---\n");
	printf("-+- _HAVE_STRUCT_TERMIOS_C_OSPEED\n");
	dump_section__HAVE_STRUCT_TERMIOS_C_OSPEED();
	printf("---\n");
	return 0;
}
