/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <fcntl.h>
#include <sys/file.h>
#include <sys/ioctl.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_DN_ACCESS(void) {
#ifdef DN_ACCESS
	dump("defined", 1);
	if ((DN_ACCESS) <= 0) {
	    long long x = (long long)(DN_ACCESS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_ACCESS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DN_ATTRIB(void) {
#ifdef DN_ATTRIB
	dump("defined", 1);
	if ((DN_ATTRIB) <= 0) {
	    long long x = (long long)(DN_ATTRIB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_ATTRIB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DN_CREATE(void) {
#ifdef DN_CREATE
	dump("defined", 1);
	if ((DN_CREATE) <= 0) {
	    long long x = (long long)(DN_CREATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_CREATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DN_DELETE(void) {
#ifdef DN_DELETE
	dump("defined", 1);
	if ((DN_DELETE) <= 0) {
	    long long x = (long long)(DN_DELETE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_DELETE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DN_MODIFY(void) {
#ifdef DN_MODIFY
	dump("defined", 1);
	if ((DN_MODIFY) <= 0) {
	    long long x = (long long)(DN_MODIFY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_MODIFY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DN_MULTISHOT(void) {
#ifdef DN_MULTISHOT
	dump("defined", 1);
	if ((DN_MULTISHOT) <= 0) {
	    long long x = (long long)(DN_MULTISHOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_MULTISHOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DN_RENAME(void) {
#ifdef DN_RENAME
	dump("defined", 1);
	if ((DN_RENAME) <= 0) {
	    long long x = (long long)(DN_RENAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(DN_RENAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_FD_CLOEXEC(void) {
#ifdef FD_CLOEXEC
	dump("defined", 1);
	if ((FD_CLOEXEC) <= 0) {
	    long long x = (long long)(FD_CLOEXEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(FD_CLOEXEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_DUPFD(void) {
#ifdef F_DUPFD
	dump("defined", 1);
	if ((F_DUPFD) <= 0) {
	    long long x = (long long)(F_DUPFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_DUPFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_EXLCK(void) {
#ifdef F_EXLCK
	dump("defined", 1);
	if ((F_EXLCK) <= 0) {
	    long long x = (long long)(F_EXLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_EXLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETFD(void) {
#ifdef F_GETFD
	dump("defined", 1);
	if ((F_GETFD) <= 0) {
	    long long x = (long long)(F_GETFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETFL(void) {
#ifdef F_GETFL
	dump("defined", 1);
	if ((F_GETFL) <= 0) {
	    long long x = (long long)(F_GETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETLEASE(void) {
#ifdef F_GETLEASE
	dump("defined", 1);
	if ((F_GETLEASE) <= 0) {
	    long long x = (long long)(F_GETLEASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETLEASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETLK(void) {
#ifdef F_GETLK
	dump("defined", 1);
	if ((F_GETLK) <= 0) {
	    long long x = (long long)(F_GETLK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETLK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETLK64(void) {
#ifdef F_GETLK64
	dump("defined", 1);
	if ((F_GETLK64) <= 0) {
	    long long x = (long long)(F_GETLK64);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETLK64);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETOWN(void) {
#ifdef F_GETOWN
	dump("defined", 1);
	if ((F_GETOWN) <= 0) {
	    long long x = (long long)(F_GETOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_GETSIG(void) {
#ifdef F_GETSIG
	dump("defined", 1);
	if ((F_GETSIG) <= 0) {
	    long long x = (long long)(F_GETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_GETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_NOTIFY(void) {
#ifdef F_NOTIFY
	dump("defined", 1);
	if ((F_NOTIFY) <= 0) {
	    long long x = (long long)(F_NOTIFY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_NOTIFY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_RDLCK(void) {
#ifdef F_RDLCK
	dump("defined", 1);
	if ((F_RDLCK) <= 0) {
	    long long x = (long long)(F_RDLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_RDLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETFD(void) {
#ifdef F_SETFD
	dump("defined", 1);
	if ((F_SETFD) <= 0) {
	    long long x = (long long)(F_SETFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETFL(void) {
#ifdef F_SETFL
	dump("defined", 1);
	if ((F_SETFL) <= 0) {
	    long long x = (long long)(F_SETFL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETFL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETLEASE(void) {
#ifdef F_SETLEASE
	dump("defined", 1);
	if ((F_SETLEASE) <= 0) {
	    long long x = (long long)(F_SETLEASE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLEASE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETLK(void) {
#ifdef F_SETLK
	dump("defined", 1);
	if ((F_SETLK) <= 0) {
	    long long x = (long long)(F_SETLK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETLK64(void) {
#ifdef F_SETLK64
	dump("defined", 1);
	if ((F_SETLK64) <= 0) {
	    long long x = (long long)(F_SETLK64);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLK64);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETLKW(void) {
#ifdef F_SETLKW
	dump("defined", 1);
	if ((F_SETLKW) <= 0) {
	    long long x = (long long)(F_SETLKW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLKW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETLKW64(void) {
#ifdef F_SETLKW64
	dump("defined", 1);
	if ((F_SETLKW64) <= 0) {
	    long long x = (long long)(F_SETLKW64);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETLKW64);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETOWN(void) {
#ifdef F_SETOWN
	dump("defined", 1);
	if ((F_SETOWN) <= 0) {
	    long long x = (long long)(F_SETOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SETSIG(void) {
#ifdef F_SETSIG
	dump("defined", 1);
	if ((F_SETSIG) <= 0) {
	    long long x = (long long)(F_SETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_SHLCK(void) {
#ifdef F_SHLCK
	dump("defined", 1);
	if ((F_SHLCK) <= 0) {
	    long long x = (long long)(F_SHLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_SHLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_UNLCK(void) {
#ifdef F_UNLCK
	dump("defined", 1);
	if ((F_UNLCK) <= 0) {
	    long long x = (long long)(F_UNLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_UNLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_F_WRLCK(void) {
#ifdef F_WRLCK
	dump("defined", 1);
	if ((F_WRLCK) <= 0) {
	    long long x = (long long)(F_WRLCK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(F_WRLCK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_ATMARK(void) {
#ifdef I_ATMARK
	dump("defined", 1);
	if ((I_ATMARK) <= 0) {
	    long long x = (long long)(I_ATMARK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_ATMARK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_CANPUT(void) {
#ifdef I_CANPUT
	dump("defined", 1);
	if ((I_CANPUT) <= 0) {
	    long long x = (long long)(I_CANPUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_CANPUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_CKBAND(void) {
#ifdef I_CKBAND
	dump("defined", 1);
	if ((I_CKBAND) <= 0) {
	    long long x = (long long)(I_CKBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_CKBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_FDINSERT(void) {
#ifdef I_FDINSERT
	dump("defined", 1);
	if ((I_FDINSERT) <= 0) {
	    long long x = (long long)(I_FDINSERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FDINSERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_FIND(void) {
#ifdef I_FIND
	dump("defined", 1);
	if ((I_FIND) <= 0) {
	    long long x = (long long)(I_FIND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FIND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_FLUSH(void) {
#ifdef I_FLUSH
	dump("defined", 1);
	if ((I_FLUSH) <= 0) {
	    long long x = (long long)(I_FLUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FLUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_FLUSHBAND(void) {
#ifdef I_FLUSHBAND
	dump("defined", 1);
	if ((I_FLUSHBAND) <= 0) {
	    long long x = (long long)(I_FLUSHBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_FLUSHBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_GETBAND(void) {
#ifdef I_GETBAND
	dump("defined", 1);
	if ((I_GETBAND) <= 0) {
	    long long x = (long long)(I_GETBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GETBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_GETCLTIME(void) {
#ifdef I_GETCLTIME
	dump("defined", 1);
	if ((I_GETCLTIME) <= 0) {
	    long long x = (long long)(I_GETCLTIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GETCLTIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_GETSIG(void) {
#ifdef I_GETSIG
	dump("defined", 1);
	if ((I_GETSIG) <= 0) {
	    long long x = (long long)(I_GETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_GRDOPT(void) {
#ifdef I_GRDOPT
	dump("defined", 1);
	if ((I_GRDOPT) <= 0) {
	    long long x = (long long)(I_GRDOPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_GRDOPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_LINK(void) {
#ifdef I_LINK
	dump("defined", 1);
	if ((I_LINK) <= 0) {
	    long long x = (long long)(I_LINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_LINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_LIST(void) {
#ifdef I_LIST
	dump("defined", 1);
	if ((I_LIST) <= 0) {
	    long long x = (long long)(I_LIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_LIST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_LOOK(void) {
#ifdef I_LOOK
	dump("defined", 1);
	if ((I_LOOK) <= 0) {
	    long long x = (long long)(I_LOOK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_LOOK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_NREAD(void) {
#ifdef I_NREAD
	dump("defined", 1);
	if ((I_NREAD) <= 0) {
	    long long x = (long long)(I_NREAD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_NREAD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_PEEK(void) {
#ifdef I_PEEK
	dump("defined", 1);
	if ((I_PEEK) <= 0) {
	    long long x = (long long)(I_PEEK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PEEK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_PLINK(void) {
#ifdef I_PLINK
	dump("defined", 1);
	if ((I_PLINK) <= 0) {
	    long long x = (long long)(I_PLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_POP(void) {
#ifdef I_POP
	dump("defined", 1);
	if ((I_POP) <= 0) {
	    long long x = (long long)(I_POP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_POP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_PUNLINK(void) {
#ifdef I_PUNLINK
	dump("defined", 1);
	if ((I_PUNLINK) <= 0) {
	    long long x = (long long)(I_PUNLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PUNLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_PUSH(void) {
#ifdef I_PUSH
	dump("defined", 1);
	if ((I_PUSH) <= 0) {
	    long long x = (long long)(I_PUSH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_PUSH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_RECVFD(void) {
#ifdef I_RECVFD
	dump("defined", 1);
	if ((I_RECVFD) <= 0) {
	    long long x = (long long)(I_RECVFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_RECVFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_SENDFD(void) {
#ifdef I_SENDFD
	dump("defined", 1);
	if ((I_SENDFD) <= 0) {
	    long long x = (long long)(I_SENDFD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SENDFD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_SETCLTIME(void) {
#ifdef I_SETCLTIME
	dump("defined", 1);
	if ((I_SETCLTIME) <= 0) {
	    long long x = (long long)(I_SETCLTIME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SETCLTIME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_SETSIG(void) {
#ifdef I_SETSIG
	dump("defined", 1);
	if ((I_SETSIG) <= 0) {
	    long long x = (long long)(I_SETSIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SETSIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_SRDOPT(void) {
#ifdef I_SRDOPT
	dump("defined", 1);
	if ((I_SRDOPT) <= 0) {
	    long long x = (long long)(I_SRDOPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SRDOPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_STR(void) {
#ifdef I_STR
	dump("defined", 1);
	if ((I_STR) <= 0) {
	    long long x = (long long)(I_STR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_STR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_SWROPT(void) {
#ifdef I_SWROPT
	dump("defined", 1);
	if ((I_SWROPT) <= 0) {
	    long long x = (long long)(I_SWROPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_SWROPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_I_UNLINK(void) {
#ifdef I_UNLINK
	dump("defined", 1);
	if ((I_UNLINK) <= 0) {
	    long long x = (long long)(I_UNLINK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(I_UNLINK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_EX(void) {
#ifdef LOCK_EX
	dump("defined", 1);
	if ((LOCK_EX) <= 0) {
	    long long x = (long long)(LOCK_EX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_EX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_MAND(void) {
#ifdef LOCK_MAND
	dump("defined", 1);
	if ((LOCK_MAND) <= 0) {
	    long long x = (long long)(LOCK_MAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_MAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_NB(void) {
#ifdef LOCK_NB
	dump("defined", 1);
	if ((LOCK_NB) <= 0) {
	    long long x = (long long)(LOCK_NB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_NB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_READ(void) {
#ifdef LOCK_READ
	dump("defined", 1);
	if ((LOCK_READ) <= 0) {
	    long long x = (long long)(LOCK_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_READ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_RW(void) {
#ifdef LOCK_RW
	dump("defined", 1);
	if ((LOCK_RW) <= 0) {
	    long long x = (long long)(LOCK_RW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_RW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_SH(void) {
#ifdef LOCK_SH
	dump("defined", 1);
	if ((LOCK_SH) <= 0) {
	    long long x = (long long)(LOCK_SH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_SH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_UN(void) {
#ifdef LOCK_UN
	dump("defined", 1);
	if ((LOCK_UN) <= 0) {
	    long long x = (long long)(LOCK_UN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_UN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOCK_WRITE(void) {
#ifdef LOCK_WRITE
	dump("defined", 1);
	if ((LOCK_WRITE) <= 0) {
	    long long x = (long long)(LOCK_WRITE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(LOCK_WRITE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_flock(void) {
	typedef struct flock platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs l_start", offsetof(platcheck_t, l_start));
	dump("fldsize l_start",   sizeof(s.l_start));
	s.l_start = 0; s.l_start = ~s.l_start;
	dump("fldunsigned l_start", s.l_start > 0);
	dump("fldofs l_len", offsetof(platcheck_t, l_len));
	dump("fldsize l_len",   sizeof(s.l_len));
	s.l_len = 0; s.l_len = ~s.l_len;
	dump("fldunsigned l_len", s.l_len > 0);
	dump("fldofs l_pid", offsetof(platcheck_t, l_pid));
	dump("fldsize l_pid",   sizeof(s.l_pid));
	s.l_pid = 0; s.l_pid = ~s.l_pid;
	dump("fldunsigned l_pid", s.l_pid > 0);
	dump("fldofs l_type", offsetof(platcheck_t, l_type));
	dump("fldsize l_type",   sizeof(s.l_type));
	s.l_type = 0; s.l_type = ~s.l_type;
	dump("fldunsigned l_type", s.l_type > 0);
	dump("fldofs l_whence", offsetof(platcheck_t, l_whence));
	dump("fldsize l_whence",   sizeof(s.l_whence));
	s.l_whence = 0; s.l_whence = ~s.l_whence;
	dump("fldunsigned l_whence", s.l_whence > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- DN_ACCESS\n");
	dump_section_DN_ACCESS();
	printf("---\n");
	printf("-+- DN_ATTRIB\n");
	dump_section_DN_ATTRIB();
	printf("---\n");
	printf("-+- DN_CREATE\n");
	dump_section_DN_CREATE();
	printf("---\n");
	printf("-+- DN_DELETE\n");
	dump_section_DN_DELETE();
	printf("---\n");
	printf("-+- DN_MODIFY\n");
	dump_section_DN_MODIFY();
	printf("---\n");
	printf("-+- DN_MULTISHOT\n");
	dump_section_DN_MULTISHOT();
	printf("---\n");
	printf("-+- DN_RENAME\n");
	dump_section_DN_RENAME();
	printf("---\n");
	printf("-+- FD_CLOEXEC\n");
	dump_section_FD_CLOEXEC();
	printf("---\n");
	printf("-+- F_DUPFD\n");
	dump_section_F_DUPFD();
	printf("---\n");
	printf("-+- F_EXLCK\n");
	dump_section_F_EXLCK();
	printf("---\n");
	printf("-+- F_GETFD\n");
	dump_section_F_GETFD();
	printf("---\n");
	printf("-+- F_GETFL\n");
	dump_section_F_GETFL();
	printf("---\n");
	printf("-+- F_GETLEASE\n");
	dump_section_F_GETLEASE();
	printf("---\n");
	printf("-+- F_GETLK\n");
	dump_section_F_GETLK();
	printf("---\n");
	printf("-+- F_GETLK64\n");
	dump_section_F_GETLK64();
	printf("---\n");
	printf("-+- F_GETOWN\n");
	dump_section_F_GETOWN();
	printf("---\n");
	printf("-+- F_GETSIG\n");
	dump_section_F_GETSIG();
	printf("---\n");
	printf("-+- F_NOTIFY\n");
	dump_section_F_NOTIFY();
	printf("---\n");
	printf("-+- F_RDLCK\n");
	dump_section_F_RDLCK();
	printf("---\n");
	printf("-+- F_SETFD\n");
	dump_section_F_SETFD();
	printf("---\n");
	printf("-+- F_SETFL\n");
	dump_section_F_SETFL();
	printf("---\n");
	printf("-+- F_SETLEASE\n");
	dump_section_F_SETLEASE();
	printf("---\n");
	printf("-+- F_SETLK\n");
	dump_section_F_SETLK();
	printf("---\n");
	printf("-+- F_SETLK64\n");
	dump_section_F_SETLK64();
	printf("---\n");
	printf("-+- F_SETLKW\n");
	dump_section_F_SETLKW();
	printf("---\n");
	printf("-+- F_SETLKW64\n");
	dump_section_F_SETLKW64();
	printf("---\n");
	printf("-+- F_SETOWN\n");
	dump_section_F_SETOWN();
	printf("---\n");
	printf("-+- F_SETSIG\n");
	dump_section_F_SETSIG();
	printf("---\n");
	printf("-+- F_SHLCK\n");
	dump_section_F_SHLCK();
	printf("---\n");
	printf("-+- F_UNLCK\n");
	dump_section_F_UNLCK();
	printf("---\n");
	printf("-+- F_WRLCK\n");
	dump_section_F_WRLCK();
	printf("---\n");
	printf("-+- I_ATMARK\n");
	dump_section_I_ATMARK();
	printf("---\n");
	printf("-+- I_CANPUT\n");
	dump_section_I_CANPUT();
	printf("---\n");
	printf("-+- I_CKBAND\n");
	dump_section_I_CKBAND();
	printf("---\n");
	printf("-+- I_FDINSERT\n");
	dump_section_I_FDINSERT();
	printf("---\n");
	printf("-+- I_FIND\n");
	dump_section_I_FIND();
	printf("---\n");
	printf("-+- I_FLUSH\n");
	dump_section_I_FLUSH();
	printf("---\n");
	printf("-+- I_FLUSHBAND\n");
	dump_section_I_FLUSHBAND();
	printf("---\n");
	printf("-+- I_GETBAND\n");
	dump_section_I_GETBAND();
	printf("---\n");
	printf("-+- I_GETCLTIME\n");
	dump_section_I_GETCLTIME();
	printf("---\n");
	printf("-+- I_GETSIG\n");
	dump_section_I_GETSIG();
	printf("---\n");
	printf("-+- I_GRDOPT\n");
	dump_section_I_GRDOPT();
	printf("---\n");
	printf("-+- I_LINK\n");
	dump_section_I_LINK();
	printf("---\n");
	printf("-+- I_LIST\n");
	dump_section_I_LIST();
	printf("---\n");
	printf("-+- I_LOOK\n");
	dump_section_I_LOOK();
	printf("---\n");
	printf("-+- I_NREAD\n");
	dump_section_I_NREAD();
	printf("---\n");
	printf("-+- I_PEEK\n");
	dump_section_I_PEEK();
	printf("---\n");
	printf("-+- I_PLINK\n");
	dump_section_I_PLINK();
	printf("---\n");
	printf("-+- I_POP\n");
	dump_section_I_POP();
	printf("---\n");
	printf("-+- I_PUNLINK\n");
	dump_section_I_PUNLINK();
	printf("---\n");
	printf("-+- I_PUSH\n");
	dump_section_I_PUSH();
	printf("---\n");
	printf("-+- I_RECVFD\n");
	dump_section_I_RECVFD();
	printf("---\n");
	printf("-+- I_SENDFD\n");
	dump_section_I_SENDFD();
	printf("---\n");
	printf("-+- I_SETCLTIME\n");
	dump_section_I_SETCLTIME();
	printf("---\n");
	printf("-+- I_SETSIG\n");
	dump_section_I_SETSIG();
	printf("---\n");
	printf("-+- I_SRDOPT\n");
	dump_section_I_SRDOPT();
	printf("---\n");
	printf("-+- I_STR\n");
	dump_section_I_STR();
	printf("---\n");
	printf("-+- I_SWROPT\n");
	dump_section_I_SWROPT();
	printf("---\n");
	printf("-+- I_UNLINK\n");
	dump_section_I_UNLINK();
	printf("---\n");
	printf("-+- LOCK_EX\n");
	dump_section_LOCK_EX();
	printf("---\n");
	printf("-+- LOCK_MAND\n");
	dump_section_LOCK_MAND();
	printf("---\n");
	printf("-+- LOCK_NB\n");
	dump_section_LOCK_NB();
	printf("---\n");
	printf("-+- LOCK_READ\n");
	dump_section_LOCK_READ();
	printf("---\n");
	printf("-+- LOCK_RW\n");
	dump_section_LOCK_RW();
	printf("---\n");
	printf("-+- LOCK_SH\n");
	dump_section_LOCK_SH();
	printf("---\n");
	printf("-+- LOCK_UN\n");
	dump_section_LOCK_UN();
	printf("---\n");
	printf("-+- LOCK_WRITE\n");
	dump_section_LOCK_WRITE();
	printf("---\n");
	printf("-+- flock\n");
	dump_section_flock();
	printf("---\n");
	return 0;
}
