/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <sys/epoll.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_EPOLLERR(void) {
#ifdef EPOLLERR
	dump("defined", 1);
	if ((EPOLLERR) <= 0) {
	    long long x = (long long)(EPOLLERR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLERR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLET(void) {
#ifdef EPOLLET
	dump("defined", 1);
	if ((EPOLLET) <= 0) {
	    long long x = (long long)(EPOLLET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLHUP(void) {
#ifdef EPOLLHUP
	dump("defined", 1);
	if ((EPOLLHUP) <= 0) {
	    long long x = (long long)(EPOLLHUP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLHUP);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLIN(void) {
#ifdef EPOLLIN
	dump("defined", 1);
	if ((EPOLLIN) <= 0) {
	    long long x = (long long)(EPOLLIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLMSG(void) {
#ifdef EPOLLMSG
	dump("defined", 1);
	if ((EPOLLMSG) <= 0) {
	    long long x = (long long)(EPOLLMSG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLMSG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLONESHOT(void) {
#ifdef EPOLLONESHOT
	dump("defined", 1);
	if ((EPOLLONESHOT) <= 0) {
	    long long x = (long long)(EPOLLONESHOT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLONESHOT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLOUT(void) {
#ifdef EPOLLOUT
	dump("defined", 1);
	if ((EPOLLOUT) <= 0) {
	    long long x = (long long)(EPOLLOUT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLOUT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLPRI(void) {
#ifdef EPOLLPRI
	dump("defined", 1);
	if ((EPOLLPRI) <= 0) {
	    long long x = (long long)(EPOLLPRI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLPRI);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLRDBAND(void) {
#ifdef EPOLLRDBAND
	dump("defined", 1);
	if ((EPOLLRDBAND) <= 0) {
	    long long x = (long long)(EPOLLRDBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLRDBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLRDNORM(void) {
#ifdef EPOLLRDNORM
	dump("defined", 1);
	if ((EPOLLRDNORM) <= 0) {
	    long long x = (long long)(EPOLLRDNORM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLRDNORM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLWRBAND(void) {
#ifdef EPOLLWRBAND
	dump("defined", 1);
	if ((EPOLLWRBAND) <= 0) {
	    long long x = (long long)(EPOLLWRBAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLWRBAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLLWRNORM(void) {
#ifdef EPOLLWRNORM
	dump("defined", 1);
	if ((EPOLLWRNORM) <= 0) {
	    long long x = (long long)(EPOLLWRNORM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLLWRNORM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EPOLL_CTL_ADD(void) {
	if ((EPOLL_CTL_ADD) <= 0) {
	    long long x = (long long)(EPOLL_CTL_ADD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLL_CTL_ADD);
	    printf("value: %llu\n", x);
	}
}

void dump_section_EPOLL_CTL_DEL(void) {
	if ((EPOLL_CTL_DEL) <= 0) {
	    long long x = (long long)(EPOLL_CTL_DEL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLL_CTL_DEL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_EPOLL_CTL_MOD(void) {
	if ((EPOLL_CTL_MOD) <= 0) {
	    long long x = (long long)(EPOLL_CTL_MOD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(EPOLL_CTL_MOD);
	    printf("value: %llu\n", x);
	}
}

void dump_section_epoll_data(void) {
	typedef union epoll_data platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs fd", offsetof(platcheck_t, fd));
	dump("fldsize fd",   sizeof(s.fd));
	s.fd = 0; s.fd = ~s.fd;
	dump("fldunsigned fd", s.fd > 0);
}

void dump_section_epoll_event(void) {
	typedef struct epoll_event platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs events", offsetof(platcheck_t, events));
	dump("fldsize events",   sizeof(s.events));
	s.events = 0; s.events = ~s.events;
	dump("fldunsigned events", s.events > 0);
	dump("fldofs data", offsetof(platcheck_t, data));
	dump("fldsize data",   sizeof(s.data));
}

int main(int argc, char *argv[]) {
	printf("-+- EPOLLERR\n");
	dump_section_EPOLLERR();
	printf("---\n");
	printf("-+- EPOLLET\n");
	dump_section_EPOLLET();
	printf("---\n");
	printf("-+- EPOLLHUP\n");
	dump_section_EPOLLHUP();
	printf("---\n");
	printf("-+- EPOLLIN\n");
	dump_section_EPOLLIN();
	printf("---\n");
	printf("-+- EPOLLMSG\n");
	dump_section_EPOLLMSG();
	printf("---\n");
	printf("-+- EPOLLONESHOT\n");
	dump_section_EPOLLONESHOT();
	printf("---\n");
	printf("-+- EPOLLOUT\n");
	dump_section_EPOLLOUT();
	printf("---\n");
	printf("-+- EPOLLPRI\n");
	dump_section_EPOLLPRI();
	printf("---\n");
	printf("-+- EPOLLRDBAND\n");
	dump_section_EPOLLRDBAND();
	printf("---\n");
	printf("-+- EPOLLRDNORM\n");
	dump_section_EPOLLRDNORM();
	printf("---\n");
	printf("-+- EPOLLWRBAND\n");
	dump_section_EPOLLWRBAND();
	printf("---\n");
	printf("-+- EPOLLWRNORM\n");
	dump_section_EPOLLWRNORM();
	printf("---\n");
	printf("-+- EPOLL_CTL_ADD\n");
	dump_section_EPOLL_CTL_ADD();
	printf("---\n");
	printf("-+- EPOLL_CTL_DEL\n");
	dump_section_EPOLL_CTL_DEL();
	printf("---\n");
	printf("-+- EPOLL_CTL_MOD\n");
	dump_section_EPOLL_CTL_MOD();
	printf("---\n");
	printf("-+- epoll_data\n");
	dump_section_epoll_data();
	printf("---\n");
	printf("-+- epoll_event\n");
	dump_section_epoll_event();
	printf("---\n");
	return 0;
}
