/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <expat.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_XML_CQUANT_NONE(void) {
	if ((XML_CQUANT_NONE) <= 0) {
	    long long x = (long long)(XML_CQUANT_NONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_NONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CQUANT_OPT(void) {
	if ((XML_CQUANT_OPT) <= 0) {
	    long long x = (long long)(XML_CQUANT_OPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_OPT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CQUANT_PLUS(void) {
	if ((XML_CQUANT_PLUS) <= 0) {
	    long long x = (long long)(XML_CQUANT_PLUS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_PLUS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CQUANT_REP(void) {
	if ((XML_CQUANT_REP) <= 0) {
	    long long x = (long long)(XML_CQUANT_REP);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CQUANT_REP);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CTYPE_ANY(void) {
	if ((XML_CTYPE_ANY) <= 0) {
	    long long x = (long long)(XML_CTYPE_ANY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_ANY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CTYPE_CHOICE(void) {
	if ((XML_CTYPE_CHOICE) <= 0) {
	    long long x = (long long)(XML_CTYPE_CHOICE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_CHOICE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CTYPE_EMPTY(void) {
	if ((XML_CTYPE_EMPTY) <= 0) {
	    long long x = (long long)(XML_CTYPE_EMPTY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_EMPTY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CTYPE_MIXED(void) {
	if ((XML_CTYPE_MIXED) <= 0) {
	    long long x = (long long)(XML_CTYPE_MIXED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_MIXED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CTYPE_NAME(void) {
	if ((XML_CTYPE_NAME) <= 0) {
	    long long x = (long long)(XML_CTYPE_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_NAME);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_CTYPE_SEQ(void) {
	if ((XML_CTYPE_SEQ) <= 0) {
	    long long x = (long long)(XML_CTYPE_SEQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_CTYPE_SEQ);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_Content(void) {
	typedef XML_Content platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs numchildren", offsetof(platcheck_t, numchildren));
	dump("fldsize numchildren",   sizeof(s.numchildren));
	s.numchildren = 0; s.numchildren = ~s.numchildren;
	dump("fldunsigned numchildren", s.numchildren > 0);
	dump("fldofs children", offsetof(platcheck_t, children));
	dump("fldsize children",   sizeof(s.children));
	dump("fldofs name", offsetof(platcheck_t, name));
	dump("fldsize name",   sizeof(s.name));
	dump("fldofs type", offsetof(platcheck_t, type));
	dump("fldsize type",   sizeof(s.type));
	s.type = 0; s.type = ~s.type;
	dump("fldunsigned type", s.type > 0);
	dump("fldofs quant", offsetof(platcheck_t, quant));
	dump("fldsize quant",   sizeof(s.quant));
	s.quant = 0; s.quant = ~s.quant;
	dump("fldunsigned quant", s.quant > 0);
}

void dump_section_XML_ERROR_ABORTED(void) {
	if ((XML_ERROR_ABORTED) <= 0) {
	    long long x = (long long)(XML_ERROR_ABORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ABORTED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_ASYNC_ENTITY(void) {
	if ((XML_ERROR_ASYNC_ENTITY) <= 0) {
	    long long x = (long long)(XML_ERROR_ASYNC_ENTITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ASYNC_ENTITY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF(void) {
	if ((XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_BAD_CHAR_REF(void) {
	if ((XML_ERROR_BAD_CHAR_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_BAD_CHAR_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_BAD_CHAR_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_BINARY_ENTITY_REF(void) {
	if ((XML_ERROR_BINARY_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_BINARY_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_BINARY_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING(void) {
	if ((XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING) <= 0) {
	    long long x = (long long)(XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_DUPLICATE_ATTRIBUTE(void) {
	if ((XML_ERROR_DUPLICATE_ATTRIBUTE) <= 0) {
	    long long x = (long long)(XML_ERROR_DUPLICATE_ATTRIBUTE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_DUPLICATE_ATTRIBUTE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_ENTITY_DECLARED_IN_PE(void) {
	if ((XML_ERROR_ENTITY_DECLARED_IN_PE) <= 0) {
	    long long x = (long long)(XML_ERROR_ENTITY_DECLARED_IN_PE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_ENTITY_DECLARED_IN_PE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_EXTERNAL_ENTITY_HANDLING(void) {
	if ((XML_ERROR_EXTERNAL_ENTITY_HANDLING) <= 0) {
	    long long x = (long long)(XML_ERROR_EXTERNAL_ENTITY_HANDLING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_EXTERNAL_ENTITY_HANDLING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_FEATURE_REQUIRES_XML_DTD(void) {
	if ((XML_ERROR_FEATURE_REQUIRES_XML_DTD) <= 0) {
	    long long x = (long long)(XML_ERROR_FEATURE_REQUIRES_XML_DTD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_FEATURE_REQUIRES_XML_DTD);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_FINISHED(void) {
	if ((XML_ERROR_FINISHED) <= 0) {
	    long long x = (long long)(XML_ERROR_FINISHED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_FINISHED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_INCOMPLETE_PE(void) {
	if ((XML_ERROR_INCOMPLETE_PE) <= 0) {
	    long long x = (long long)(XML_ERROR_INCOMPLETE_PE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_INCOMPLETE_PE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_INCORRECT_ENCODING(void) {
	if ((XML_ERROR_INCORRECT_ENCODING) <= 0) {
	    long long x = (long long)(XML_ERROR_INCORRECT_ENCODING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_INCORRECT_ENCODING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_INVALID_TOKEN(void) {
	if ((XML_ERROR_INVALID_TOKEN) <= 0) {
	    long long x = (long long)(XML_ERROR_INVALID_TOKEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_INVALID_TOKEN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_JUNK_AFTER_DOC_ELEMENT(void) {
	if ((XML_ERROR_JUNK_AFTER_DOC_ELEMENT) <= 0) {
	    long long x = (long long)(XML_ERROR_JUNK_AFTER_DOC_ELEMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_JUNK_AFTER_DOC_ELEMENT);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_MISPLACED_XML_PI(void) {
	if ((XML_ERROR_MISPLACED_XML_PI) <= 0) {
	    long long x = (long long)(XML_ERROR_MISPLACED_XML_PI);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_MISPLACED_XML_PI);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_NOT_STANDALONE(void) {
	if ((XML_ERROR_NOT_STANDALONE) <= 0) {
	    long long x = (long long)(XML_ERROR_NOT_STANDALONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NOT_STANDALONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_NOT_SUSPENDED(void) {
	if ((XML_ERROR_NOT_SUSPENDED) <= 0) {
	    long long x = (long long)(XML_ERROR_NOT_SUSPENDED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NOT_SUSPENDED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_NO_ELEMENTS(void) {
	if ((XML_ERROR_NO_ELEMENTS) <= 0) {
	    long long x = (long long)(XML_ERROR_NO_ELEMENTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NO_ELEMENTS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_NO_MEMORY(void) {
	if ((XML_ERROR_NO_MEMORY) <= 0) {
	    long long x = (long long)(XML_ERROR_NO_MEMORY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_NO_MEMORY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_PARAM_ENTITY_REF(void) {
	if ((XML_ERROR_PARAM_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_PARAM_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_PARAM_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_PARTIAL_CHAR(void) {
	if ((XML_ERROR_PARTIAL_CHAR) <= 0) {
	    long long x = (long long)(XML_ERROR_PARTIAL_CHAR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_PARTIAL_CHAR);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_PUBLICID(void) {
	if ((XML_ERROR_PUBLICID) <= 0) {
	    long long x = (long long)(XML_ERROR_PUBLICID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_PUBLICID);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_RECURSIVE_ENTITY_REF(void) {
	if ((XML_ERROR_RECURSIVE_ENTITY_REF) <= 0) {
	    long long x = (long long)(XML_ERROR_RECURSIVE_ENTITY_REF);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_RECURSIVE_ENTITY_REF);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_SUSPENDED(void) {
	if ((XML_ERROR_SUSPENDED) <= 0) {
	    long long x = (long long)(XML_ERROR_SUSPENDED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_SUSPENDED);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_SUSPEND_PE(void) {
	if ((XML_ERROR_SUSPEND_PE) <= 0) {
	    long long x = (long long)(XML_ERROR_SUSPEND_PE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_SUSPEND_PE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_SYNTAX(void) {
	if ((XML_ERROR_SYNTAX) <= 0) {
	    long long x = (long long)(XML_ERROR_SYNTAX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_SYNTAX);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_TAG_MISMATCH(void) {
	if ((XML_ERROR_TAG_MISMATCH) <= 0) {
	    long long x = (long long)(XML_ERROR_TAG_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_TAG_MISMATCH);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_TEXT_DECL(void) {
	if ((XML_ERROR_TEXT_DECL) <= 0) {
	    long long x = (long long)(XML_ERROR_TEXT_DECL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_TEXT_DECL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_UNBOUND_PREFIX(void) {
	if ((XML_ERROR_UNBOUND_PREFIX) <= 0) {
	    long long x = (long long)(XML_ERROR_UNBOUND_PREFIX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNBOUND_PREFIX);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_UNCLOSED_CDATA_SECTION(void) {
	if ((XML_ERROR_UNCLOSED_CDATA_SECTION) <= 0) {
	    long long x = (long long)(XML_ERROR_UNCLOSED_CDATA_SECTION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNCLOSED_CDATA_SECTION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_UNCLOSED_TOKEN(void) {
	if ((XML_ERROR_UNCLOSED_TOKEN) <= 0) {
	    long long x = (long long)(XML_ERROR_UNCLOSED_TOKEN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNCLOSED_TOKEN);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_UNDECLARING_PREFIX(void) {
	if ((XML_ERROR_UNDECLARING_PREFIX) <= 0) {
	    long long x = (long long)(XML_ERROR_UNDECLARING_PREFIX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNDECLARING_PREFIX);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_UNDEFINED_ENTITY(void) {
	if ((XML_ERROR_UNDEFINED_ENTITY) <= 0) {
	    long long x = (long long)(XML_ERROR_UNDEFINED_ENTITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNDEFINED_ENTITY);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_UNEXPECTED_STATE(void) {
	if ((XML_ERROR_UNEXPECTED_STATE) <= 0) {
	    long long x = (long long)(XML_ERROR_UNEXPECTED_STATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNEXPECTED_STATE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_UNKNOWN_ENCODING(void) {
	if ((XML_ERROR_UNKNOWN_ENCODING) <= 0) {
	    long long x = (long long)(XML_ERROR_UNKNOWN_ENCODING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_UNKNOWN_ENCODING);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_ERROR_XML_DECL(void) {
	if ((XML_ERROR_XML_DECL) <= 0) {
	    long long x = (long long)(XML_ERROR_XML_DECL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_ERROR_XML_DECL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_Encoding(void) {
	typedef XML_Encoding platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs map", offsetof(platcheck_t, map));
	dump("fldsize map",   sizeof(s.map));
	dump("fldofs data", offsetof(platcheck_t, data));
	dump("fldsize data",   sizeof(s.data));
	dump("fldofs convert", offsetof(platcheck_t, convert));
	dump("fldsize convert",   sizeof(s.convert));
	dump("fldofs release", offsetof(platcheck_t, release));
	dump("fldsize release",   sizeof(s.release));
}

void dump_section_XML_FALSE(void) {
	if ((XML_FALSE) <= 0) {
	    long long x = (long long)(XML_FALSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_FALSE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_MAJOR_VERSION(void) {
	if ((XML_MAJOR_VERSION) <= 0) {
	    long long x = (long long)(XML_MAJOR_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_MAJOR_VERSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_MICRO_VERSION(void) {
	if ((XML_MICRO_VERSION) <= 0) {
	    long long x = (long long)(XML_MICRO_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_MICRO_VERSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_MINOR_VERSION(void) {
	if ((XML_MINOR_VERSION) <= 0) {
	    long long x = (long long)(XML_MINOR_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_MINOR_VERSION);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_PARAM_ENTITY_PARSING_ALWAYS(void) {
	if ((XML_PARAM_ENTITY_PARSING_ALWAYS) <= 0) {
	    long long x = (long long)(XML_PARAM_ENTITY_PARSING_ALWAYS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_PARAM_ENTITY_PARSING_ALWAYS);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_PARAM_ENTITY_PARSING_NEVER(void) {
	if ((XML_PARAM_ENTITY_PARSING_NEVER) <= 0) {
	    long long x = (long long)(XML_PARAM_ENTITY_PARSING_NEVER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_PARAM_ENTITY_PARSING_NEVER);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE(void) {
	if ((XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE) <= 0) {
	    long long x = (long long)(XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE);
	    printf("value: %llu\n", x);
	}
}

void dump_section_XML_Parser_SIZE(void) {
	dump("size",  sizeof(XML_Parser));
}

void dump_section_XML_TRUE(void) {
	if ((XML_TRUE) <= 0) {
	    long long x = (long long)(XML_TRUE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(XML_TRUE);
	    printf("value: %llu\n", x);
	}
}

int main(int argc, char *argv[]) {
	printf("-+- XML_CQUANT_NONE\n");
	dump_section_XML_CQUANT_NONE();
	printf("---\n");
	printf("-+- XML_CQUANT_OPT\n");
	dump_section_XML_CQUANT_OPT();
	printf("---\n");
	printf("-+- XML_CQUANT_PLUS\n");
	dump_section_XML_CQUANT_PLUS();
	printf("---\n");
	printf("-+- XML_CQUANT_REP\n");
	dump_section_XML_CQUANT_REP();
	printf("---\n");
	printf("-+- XML_CTYPE_ANY\n");
	dump_section_XML_CTYPE_ANY();
	printf("---\n");
	printf("-+- XML_CTYPE_CHOICE\n");
	dump_section_XML_CTYPE_CHOICE();
	printf("---\n");
	printf("-+- XML_CTYPE_EMPTY\n");
	dump_section_XML_CTYPE_EMPTY();
	printf("---\n");
	printf("-+- XML_CTYPE_MIXED\n");
	dump_section_XML_CTYPE_MIXED();
	printf("---\n");
	printf("-+- XML_CTYPE_NAME\n");
	dump_section_XML_CTYPE_NAME();
	printf("---\n");
	printf("-+- XML_CTYPE_SEQ\n");
	dump_section_XML_CTYPE_SEQ();
	printf("---\n");
	printf("-+- XML_Content\n");
	dump_section_XML_Content();
	printf("---\n");
	printf("-+- XML_ERROR_ABORTED\n");
	dump_section_XML_ERROR_ABORTED();
	printf("---\n");
	printf("-+- XML_ERROR_ASYNC_ENTITY\n");
	dump_section_XML_ERROR_ASYNC_ENTITY();
	printf("---\n");
	printf("-+- XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF\n");
	dump_section_XML_ERROR_ATTRIBUTE_EXTERNAL_ENTITY_REF();
	printf("---\n");
	printf("-+- XML_ERROR_BAD_CHAR_REF\n");
	dump_section_XML_ERROR_BAD_CHAR_REF();
	printf("---\n");
	printf("-+- XML_ERROR_BINARY_ENTITY_REF\n");
	dump_section_XML_ERROR_BINARY_ENTITY_REF();
	printf("---\n");
	printf("-+- XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING\n");
	dump_section_XML_ERROR_CANT_CHANGE_FEATURE_ONCE_PARSING();
	printf("---\n");
	printf("-+- XML_ERROR_DUPLICATE_ATTRIBUTE\n");
	dump_section_XML_ERROR_DUPLICATE_ATTRIBUTE();
	printf("---\n");
	printf("-+- XML_ERROR_ENTITY_DECLARED_IN_PE\n");
	dump_section_XML_ERROR_ENTITY_DECLARED_IN_PE();
	printf("---\n");
	printf("-+- XML_ERROR_EXTERNAL_ENTITY_HANDLING\n");
	dump_section_XML_ERROR_EXTERNAL_ENTITY_HANDLING();
	printf("---\n");
	printf("-+- XML_ERROR_FEATURE_REQUIRES_XML_DTD\n");
	dump_section_XML_ERROR_FEATURE_REQUIRES_XML_DTD();
	printf("---\n");
	printf("-+- XML_ERROR_FINISHED\n");
	dump_section_XML_ERROR_FINISHED();
	printf("---\n");
	printf("-+- XML_ERROR_INCOMPLETE_PE\n");
	dump_section_XML_ERROR_INCOMPLETE_PE();
	printf("---\n");
	printf("-+- XML_ERROR_INCORRECT_ENCODING\n");
	dump_section_XML_ERROR_INCORRECT_ENCODING();
	printf("---\n");
	printf("-+- XML_ERROR_INVALID_TOKEN\n");
	dump_section_XML_ERROR_INVALID_TOKEN();
	printf("---\n");
	printf("-+- XML_ERROR_JUNK_AFTER_DOC_ELEMENT\n");
	dump_section_XML_ERROR_JUNK_AFTER_DOC_ELEMENT();
	printf("---\n");
	printf("-+- XML_ERROR_MISPLACED_XML_PI\n");
	dump_section_XML_ERROR_MISPLACED_XML_PI();
	printf("---\n");
	printf("-+- XML_ERROR_NOT_STANDALONE\n");
	dump_section_XML_ERROR_NOT_STANDALONE();
	printf("---\n");
	printf("-+- XML_ERROR_NOT_SUSPENDED\n");
	dump_section_XML_ERROR_NOT_SUSPENDED();
	printf("---\n");
	printf("-+- XML_ERROR_NO_ELEMENTS\n");
	dump_section_XML_ERROR_NO_ELEMENTS();
	printf("---\n");
	printf("-+- XML_ERROR_NO_MEMORY\n");
	dump_section_XML_ERROR_NO_MEMORY();
	printf("---\n");
	printf("-+- XML_ERROR_PARAM_ENTITY_REF\n");
	dump_section_XML_ERROR_PARAM_ENTITY_REF();
	printf("---\n");
	printf("-+- XML_ERROR_PARTIAL_CHAR\n");
	dump_section_XML_ERROR_PARTIAL_CHAR();
	printf("---\n");
	printf("-+- XML_ERROR_PUBLICID\n");
	dump_section_XML_ERROR_PUBLICID();
	printf("---\n");
	printf("-+- XML_ERROR_RECURSIVE_ENTITY_REF\n");
	dump_section_XML_ERROR_RECURSIVE_ENTITY_REF();
	printf("---\n");
	printf("-+- XML_ERROR_SUSPENDED\n");
	dump_section_XML_ERROR_SUSPENDED();
	printf("---\n");
	printf("-+- XML_ERROR_SUSPEND_PE\n");
	dump_section_XML_ERROR_SUSPEND_PE();
	printf("---\n");
	printf("-+- XML_ERROR_SYNTAX\n");
	dump_section_XML_ERROR_SYNTAX();
	printf("---\n");
	printf("-+- XML_ERROR_TAG_MISMATCH\n");
	dump_section_XML_ERROR_TAG_MISMATCH();
	printf("---\n");
	printf("-+- XML_ERROR_TEXT_DECL\n");
	dump_section_XML_ERROR_TEXT_DECL();
	printf("---\n");
	printf("-+- XML_ERROR_UNBOUND_PREFIX\n");
	dump_section_XML_ERROR_UNBOUND_PREFIX();
	printf("---\n");
	printf("-+- XML_ERROR_UNCLOSED_CDATA_SECTION\n");
	dump_section_XML_ERROR_UNCLOSED_CDATA_SECTION();
	printf("---\n");
	printf("-+- XML_ERROR_UNCLOSED_TOKEN\n");
	dump_section_XML_ERROR_UNCLOSED_TOKEN();
	printf("---\n");
	printf("-+- XML_ERROR_UNDECLARING_PREFIX\n");
	dump_section_XML_ERROR_UNDECLARING_PREFIX();
	printf("---\n");
	printf("-+- XML_ERROR_UNDEFINED_ENTITY\n");
	dump_section_XML_ERROR_UNDEFINED_ENTITY();
	printf("---\n");
	printf("-+- XML_ERROR_UNEXPECTED_STATE\n");
	dump_section_XML_ERROR_UNEXPECTED_STATE();
	printf("---\n");
	printf("-+- XML_ERROR_UNKNOWN_ENCODING\n");
	dump_section_XML_ERROR_UNKNOWN_ENCODING();
	printf("---\n");
	printf("-+- XML_ERROR_XML_DECL\n");
	dump_section_XML_ERROR_XML_DECL();
	printf("---\n");
	printf("-+- XML_Encoding\n");
	dump_section_XML_Encoding();
	printf("---\n");
	printf("-+- XML_FALSE\n");
	dump_section_XML_FALSE();
	printf("---\n");
	printf("-+- XML_MAJOR_VERSION\n");
	dump_section_XML_MAJOR_VERSION();
	printf("---\n");
	printf("-+- XML_MICRO_VERSION\n");
	dump_section_XML_MICRO_VERSION();
	printf("---\n");
	printf("-+- XML_MINOR_VERSION\n");
	dump_section_XML_MINOR_VERSION();
	printf("---\n");
	printf("-+- XML_PARAM_ENTITY_PARSING_ALWAYS\n");
	dump_section_XML_PARAM_ENTITY_PARSING_ALWAYS();
	printf("---\n");
	printf("-+- XML_PARAM_ENTITY_PARSING_NEVER\n");
	dump_section_XML_PARAM_ENTITY_PARSING_NEVER();
	printf("---\n");
	printf("-+- XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE\n");
	dump_section_XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE();
	printf("---\n");
	printf("-+- XML_Parser_SIZE\n");
	dump_section_XML_Parser_SIZE();
	printf("---\n");
	printf("-+- XML_TRUE\n");
	dump_section_XML_TRUE();
	printf("---\n");
	return 0;
}
