/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <unistd.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <utime.h>
#include <sys/time.h>
#include <sys/times.h>
#include <grp.h>
#include <dirent.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <signal.h>
#include <sys/utsname.h>
#include <pty.h>

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_CLOCK_T(void) {
	typedef clock_t platcheck_t;

	platcheck_t x;
	dump("size",  sizeof(platcheck_t));
	x = 0; x = ~x;
	dump("unsigned", x > 0);
}

void dump_section_OFF_T_SIZE(void) {
	dump("size",  sizeof(off_t));
}

void dump_section_SEEK_CUR(void) {
#ifdef SEEK_CUR
	dump("defined", 1);
	if ((SEEK_CUR) <= 0) {
	    long long x = (long long)(SEEK_CUR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SEEK_CUR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SEEK_END(void) {
#ifdef SEEK_END
	dump("defined", 1);
	if ((SEEK_END) <= 0) {
	    long long x = (long long)(SEEK_END);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SEEK_END);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SEEK_SET(void) {
#ifdef SEEK_SET
	dump("defined", 1);
	if ((SEEK_SET) <= 0) {
	    long long x = (long long)(SEEK_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SEEK_SET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TMS(void) {
	typedef struct tms platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs tms_utime", offsetof(platcheck_t, tms_utime));
	dump("fldsize tms_utime",   sizeof(s.tms_utime));
	s.tms_utime = 0; s.tms_utime = ~s.tms_utime;
	dump("fldunsigned tms_utime", s.tms_utime > 0);
	dump("fldofs tms_stime", offsetof(platcheck_t, tms_stime));
	dump("fldsize tms_stime",   sizeof(s.tms_stime));
	s.tms_stime = 0; s.tms_stime = ~s.tms_stime;
	dump("fldunsigned tms_stime", s.tms_stime > 0);
	dump("fldofs tms_cutime", offsetof(platcheck_t, tms_cutime));
	dump("fldsize tms_cutime",   sizeof(s.tms_cutime));
	s.tms_cutime = 0; s.tms_cutime = ~s.tms_cutime;
	dump("fldunsigned tms_cutime", s.tms_cutime > 0);
	dump("fldofs tms_cstime", offsetof(platcheck_t, tms_cstime));
	dump("fldsize tms_cstime",   sizeof(s.tms_cstime));
	s.tms_cstime = 0; s.tms_cstime = ~s.tms_cstime;
	dump("fldunsigned tms_cstime", s.tms_cstime > 0);
}

void dump_section_UTIMBUF(void) {
	typedef struct utimbuf platcheck_t;
	typedef struct {
	    char c;
	    platcheck_t s;
	} platcheck2_t;

	platcheck_t s;
	dump("align", offsetof(platcheck2_t, s));
	dump("size",  sizeof(platcheck_t));
	dump("fldofs actime", offsetof(platcheck_t, actime));
	dump("fldsize actime",   sizeof(s.actime));
	s.actime = 0; s.actime = ~s.actime;
	dump("fldunsigned actime", s.actime > 0);
	dump("fldofs modtime", offsetof(platcheck_t, modtime));
	dump("fldsize modtime",   sizeof(s.modtime));
	s.modtime = 0; s.modtime = ~s.modtime;
	dump("fldunsigned modtime", s.modtime > 0);
}

int main(int argc, char *argv[]) {
	printf("-+- CLOCK_T\n");
	dump_section_CLOCK_T();
	printf("---\n");
	printf("-+- OFF_T_SIZE\n");
	dump_section_OFF_T_SIZE();
	printf("---\n");
	printf("-+- SEEK_CUR\n");
	dump_section_SEEK_CUR();
	printf("---\n");
	printf("-+- SEEK_END\n");
	dump_section_SEEK_END();
	printf("---\n");
	printf("-+- SEEK_SET\n");
	dump_section_SEEK_SET();
	printf("---\n");
	printf("-+- TMS\n");
	dump_section_TMS();
	printf("---\n");
	printf("-+- UTIMBUF\n");
	dump_section_UTIMBUF();
	printf("---\n");
	return 0;
}
