/***** Start of precommondefs.h *****/

/* This is extracted from pyconfig.h from CPython.  It sets the macros
   that affect the features we get from system include files.
   It must not #include anything. */

#ifndef __PYPY_PRECOMMONDEFS_H
#define __PYPY_PRECOMMONDEFS_H


/* Define on Darwin to activate all library features */
#define _DARWIN_C_SOURCE 1
/* This must be set to 64 on some systems to enable large file support. */
#define _FILE_OFFSET_BITS 64
/* Define on Linux to activate all library features */
#define _GNU_SOURCE 1
/* This must be defined on some systems to enable large file support. */
#define _LARGEFILE_SOURCE 1
/* Define on NetBSD to activate all library features */
#define _NETBSD_SOURCE 1
/* Define to activate features from IEEE Stds 1003.1-2001 */
#ifndef _POSIX_C_SOURCE
#  define _POSIX_C_SOURCE 200112L
#endif
/* Define on FreeBSD to activate all library features */
#define __BSD_VISIBLE 1
#define __XSI_VISIBLE 700
/* Windows: winsock/winsock2 mess */
#define WIN32_LEAN_AND_MEAN
#ifdef _WIN64
   typedef          __int64 Signed;
   typedef unsigned __int64 Unsigned;
#  define SIGNED_MIN LLONG_MIN
#else
   typedef          long Signed;
   typedef unsigned long Unsigned;
#  define SIGNED_MIN LONG_MIN
#endif

#if !defined(RPY_ASSERT) && !defined(RPY_LL_ASSERT)
#  define NDEBUG
#endif


/* All functions and global variables declared anywhere should use
   one of the following attributes:

   RPY_EXPORTED:  the symbol is exported out of libpypy-c.so.

   RPY_EXTERN:    the symbol is not exported out of libpypy-c.so, but
                  otherwise works like 'extern' by being available to
                  other C sources.

   static:        as usual, this means the symbol is local to this C file.

   Don't use _RPY_HIDDEN directly.  For tests involving building a custom
   .so, translator/tool/cbuild.py overrides RPY_EXTERN so that it becomes
   equal to RPY_EXPORTED.

   Any function or global variable declared with no attribute at all is
   a bug; please report or fix it.
*/
#ifdef __GNUC__
#  define RPY_EXPORTED extern __attribute__((visibility("default")))
#  define _RPY_HIDDEN  __attribute__((visibility("hidden")))
#else
#  define RPY_EXPORTED extern __declspec(dllexport)
#  define _RPY_HIDDEN  /* nothing */
#endif
#ifndef RPY_EXTERN
#  define RPY_EXTERN   extern _RPY_HIDDEN
#endif


#endif /* __PYPY_PRECOMMONDEFS_H */

/***** End of precommondefs.h *****/

#include <openssl/ssl.h>
#include <openssl/err.h>
#include <openssl/rand.h>
#include <openssl/evp.h>
#include <openssl/ossl_typ.h>
#include <openssl/x509v3.h>
#include <openssl/comp.h>
#define pypy_GENERAL_NAME_dirn(name) (name->d.dirn)
#define pypy_GENERAL_NAME_uri(name) (name->d.uniformResourceIdentifier)
#define pypy_GENERAL_NAME_pop_free(names) (sk_GENERAL_NAME_pop_free(names, GENERAL_NAME_free))
#define pypy_X509_OBJECT_data_x509(obj) (obj->data.x509)
#define pypy_DIST_POINT_fullname(obj) (obj->distpoint->name.fullname)

#include <stdio.h>
#include <stddef.h>   /* for offsetof() */

void dump(char* key, int value) {
    printf("%s: %d\n", key, value);
}


void dump_section_ACCESS_DENIED(void) {
#ifdef SSL_AD_ACCESS_DENIED
	dump("defined", 1);
	if ((SSL_AD_ACCESS_DENIED) <= 0) {
	    long long x = (long long)(SSL_AD_ACCESS_DENIED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_ACCESS_DENIED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_APP_DATA_IN_HANDSHAKE(void) {
#ifdef SSL_R_APP_DATA_IN_HANDSHAKE
	dump("defined", 1);
	if ((SSL_R_APP_DATA_IN_HANDSHAKE) <= 0) {
	    long long x = (long long)(SSL_R_APP_DATA_IN_HANDSHAKE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_APP_DATA_IN_HANDSHAKE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT(void) {
#ifdef SSL_R_ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT
	dump("defined", 1);
	if ((SSL_R_ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT) <= 0) {
	    long long x = (long long)(SSL_R_ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_ALERT_RECORD(void) {
#ifdef SSL_R_BAD_ALERT_RECORD
	dump("defined", 1);
	if ((SSL_R_BAD_ALERT_RECORD) <= 0) {
	    long long x = (long long)(SSL_R_BAD_ALERT_RECORD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_ALERT_RECORD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_AUTHENTICATION_TYPE(void) {
#ifdef SSL_R_BAD_AUTHENTICATION_TYPE
	dump("defined", 1);
	if ((SSL_R_BAD_AUTHENTICATION_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_AUTHENTICATION_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_AUTHENTICATION_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_BASE64_DECODE(void) {
#ifdef PEM_R_BAD_BASE64_DECODE
	dump("defined", 1);
	if ((PEM_R_BAD_BASE64_DECODE) <= 0) {
	    long long x = (long long)(PEM_R_BAD_BASE64_DECODE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BAD_BASE64_DECODE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_CERTIFICATE(void) {
#ifdef SSL_AD_BAD_CERTIFICATE
	dump("defined", 1);
	if ((SSL_AD_BAD_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_AD_BAD_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_BAD_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_CERTIFICATE_HASH_VALUE(void) {
#ifdef SSL_AD_BAD_CERTIFICATE_HASH_VALUE
	dump("defined", 1);
	if ((SSL_AD_BAD_CERTIFICATE_HASH_VALUE) <= 0) {
	    long long x = (long long)(SSL_AD_BAD_CERTIFICATE_HASH_VALUE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_BAD_CERTIFICATE_HASH_VALUE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_CERTIFICATE_STATUS_RESPONSE(void) {
#ifdef SSL_AD_BAD_CERTIFICATE_STATUS_RESPONSE
	dump("defined", 1);
	if ((SSL_AD_BAD_CERTIFICATE_STATUS_RESPONSE) <= 0) {
	    long long x = (long long)(SSL_AD_BAD_CERTIFICATE_STATUS_RESPONSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_BAD_CERTIFICATE_STATUS_RESPONSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_CHANGE_CIPHER_SPEC(void) {
#ifdef SSL_R_BAD_CHANGE_CIPHER_SPEC
	dump("defined", 1);
	if ((SSL_R_BAD_CHANGE_CIPHER_SPEC) <= 0) {
	    long long x = (long long)(SSL_R_BAD_CHANGE_CIPHER_SPEC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_CHANGE_CIPHER_SPEC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_CHECKSUM(void) {
#ifdef SSL_R_BAD_CHECKSUM
	dump("defined", 1);
	if ((SSL_R_BAD_CHECKSUM) <= 0) {
	    long long x = (long long)(SSL_R_BAD_CHECKSUM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_CHECKSUM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DATA_RETURNED_BY_CALLBACK(void) {
#ifdef SSL_R_BAD_DATA_RETURNED_BY_CALLBACK
	dump("defined", 1);
	if ((SSL_R_BAD_DATA_RETURNED_BY_CALLBACK) <= 0) {
	    long long x = (long long)(SSL_R_BAD_DATA_RETURNED_BY_CALLBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_DATA_RETURNED_BY_CALLBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DECOMPRESSION(void) {
#ifdef SSL_R_BAD_DECOMPRESSION
	dump("defined", 1);
	if ((SSL_R_BAD_DECOMPRESSION) <= 0) {
	    long long x = (long long)(SSL_R_BAD_DECOMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_DECOMPRESSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DECRYPT(void) {
#ifdef PEM_R_BAD_DECRYPT
	dump("defined", 1);
	if ((PEM_R_BAD_DECRYPT) <= 0) {
	    long long x = (long long)(PEM_R_BAD_DECRYPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BAD_DECRYPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DH_G_LENGTH(void) {
#ifdef SSL_R_BAD_DH_G_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_DH_G_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_DH_G_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_DH_G_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DH_PUB_KEY_LENGTH(void) {
#ifdef SSL_R_BAD_DH_PUB_KEY_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_DH_PUB_KEY_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_DH_PUB_KEY_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_DH_PUB_KEY_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DH_P_LENGTH(void) {
#ifdef SSL_R_BAD_DH_P_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_DH_P_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_DH_P_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_DH_P_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DIGEST_LENGTH(void) {
#ifdef SSL_R_BAD_DIGEST_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_DIGEST_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_DIGEST_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_DIGEST_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_DSA_SIGNATURE(void) {
#ifdef SSL_R_BAD_DSA_SIGNATURE
	dump("defined", 1);
	if ((SSL_R_BAD_DSA_SIGNATURE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_DSA_SIGNATURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_DSA_SIGNATURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_ECC_CERT(void) {
#ifdef SSL_R_BAD_ECC_CERT
	dump("defined", 1);
	if ((SSL_R_BAD_ECC_CERT) <= 0) {
	    long long x = (long long)(SSL_R_BAD_ECC_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_ECC_CERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_ECDSA_SIGNATURE(void) {
#ifdef SSL_R_BAD_ECDSA_SIGNATURE
	dump("defined", 1);
	if ((SSL_R_BAD_ECDSA_SIGNATURE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_ECDSA_SIGNATURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_ECDSA_SIGNATURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_ECPOINT(void) {
#ifdef SSL_R_BAD_ECPOINT
	dump("defined", 1);
	if ((SSL_R_BAD_ECPOINT) <= 0) {
	    long long x = (long long)(SSL_R_BAD_ECPOINT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_ECPOINT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_END_LINE(void) {
#ifdef PEM_R_BAD_END_LINE
	dump("defined", 1);
	if ((PEM_R_BAD_END_LINE) <= 0) {
	    long long x = (long long)(PEM_R_BAD_END_LINE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BAD_END_LINE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_HANDSHAKE_LENGTH(void) {
#ifdef SSL_R_BAD_HANDSHAKE_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_HANDSHAKE_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_HANDSHAKE_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_HANDSHAKE_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_HELLO_REQUEST(void) {
#ifdef SSL_R_BAD_HELLO_REQUEST
	dump("defined", 1);
	if ((SSL_R_BAD_HELLO_REQUEST) <= 0) {
	    long long x = (long long)(SSL_R_BAD_HELLO_REQUEST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_HELLO_REQUEST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_IV_CHARS(void) {
#ifdef PEM_R_BAD_IV_CHARS
	dump("defined", 1);
	if ((PEM_R_BAD_IV_CHARS) <= 0) {
	    long long x = (long long)(PEM_R_BAD_IV_CHARS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BAD_IV_CHARS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_LENGTH(void) {
#ifdef SSL_R_BAD_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_MAC_DECODE(void) {
#ifdef SSL_R_BAD_MAC_DECODE
	dump("defined", 1);
	if ((SSL_R_BAD_MAC_DECODE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_MAC_DECODE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_MAC_DECODE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_MAC_LENGTH(void) {
#ifdef SSL_R_BAD_MAC_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_MAC_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_MAC_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_MAC_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_MAGIC_NUMBER(void) {
#ifdef PEM_R_BAD_MAGIC_NUMBER
	dump("defined", 1);
	if ((PEM_R_BAD_MAGIC_NUMBER) <= 0) {
	    long long x = (long long)(PEM_R_BAD_MAGIC_NUMBER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BAD_MAGIC_NUMBER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_MESSAGE_TYPE(void) {
#ifdef SSL_R_BAD_MESSAGE_TYPE
	dump("defined", 1);
	if ((SSL_R_BAD_MESSAGE_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_MESSAGE_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_MESSAGE_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_PACKET_LENGTH(void) {
#ifdef SSL_R_BAD_PACKET_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_PACKET_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_PACKET_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_PACKET_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_PASSWORD_READ(void) {
#ifdef PEM_R_BAD_PASSWORD_READ
	dump("defined", 1);
	if ((PEM_R_BAD_PASSWORD_READ) <= 0) {
	    long long x = (long long)(PEM_R_BAD_PASSWORD_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BAD_PASSWORD_READ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_PROTOCOL_VERSION_NUMBER(void) {
#ifdef SSL_R_BAD_PROTOCOL_VERSION_NUMBER
	dump("defined", 1);
	if ((SSL_R_BAD_PROTOCOL_VERSION_NUMBER) <= 0) {
	    long long x = (long long)(SSL_R_BAD_PROTOCOL_VERSION_NUMBER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_PROTOCOL_VERSION_NUMBER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_PSK_IDENTITY_HINT_LENGTH(void) {
#ifdef SSL_R_BAD_PSK_IDENTITY_HINT_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_PSK_IDENTITY_HINT_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_PSK_IDENTITY_HINT_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_PSK_IDENTITY_HINT_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_RECORD_MAC(void) {
#ifdef SSL_AD_BAD_RECORD_MAC
	dump("defined", 1);
	if ((SSL_AD_BAD_RECORD_MAC) <= 0) {
	    long long x = (long long)(SSL_AD_BAD_RECORD_MAC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_BAD_RECORD_MAC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_RESPONSE_ARGUMENT(void) {
#ifdef SSL_R_BAD_RESPONSE_ARGUMENT
	dump("defined", 1);
	if ((SSL_R_BAD_RESPONSE_ARGUMENT) <= 0) {
	    long long x = (long long)(SSL_R_BAD_RESPONSE_ARGUMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_RESPONSE_ARGUMENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_RSA_DECRYPT(void) {
#ifdef SSL_R_BAD_RSA_DECRYPT
	dump("defined", 1);
	if ((SSL_R_BAD_RSA_DECRYPT) <= 0) {
	    long long x = (long long)(SSL_R_BAD_RSA_DECRYPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_RSA_DECRYPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_RSA_ENCRYPT(void) {
#ifdef SSL_R_BAD_RSA_ENCRYPT
	dump("defined", 1);
	if ((SSL_R_BAD_RSA_ENCRYPT) <= 0) {
	    long long x = (long long)(SSL_R_BAD_RSA_ENCRYPT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_RSA_ENCRYPT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_RSA_E_LENGTH(void) {
#ifdef SSL_R_BAD_RSA_E_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_RSA_E_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_RSA_E_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_RSA_E_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_RSA_MODULUS_LENGTH(void) {
#ifdef SSL_R_BAD_RSA_MODULUS_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_RSA_MODULUS_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_RSA_MODULUS_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_RSA_MODULUS_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_RSA_SIGNATURE(void) {
#ifdef SSL_R_BAD_RSA_SIGNATURE
	dump("defined", 1);
	if ((SSL_R_BAD_RSA_SIGNATURE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_RSA_SIGNATURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_RSA_SIGNATURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_SIGNATURE(void) {
#ifdef SSL_R_BAD_SIGNATURE
	dump("defined", 1);
	if ((SSL_R_BAD_SIGNATURE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_SIGNATURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_SIGNATURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_SSL_FILETYPE(void) {
#ifdef SSL_R_BAD_SSL_FILETYPE
	dump("defined", 1);
	if ((SSL_R_BAD_SSL_FILETYPE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_SSL_FILETYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_SSL_FILETYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_SSL_SESSION_ID_LENGTH(void) {
#ifdef SSL_R_BAD_SSL_SESSION_ID_LENGTH
	dump("defined", 1);
	if ((SSL_R_BAD_SSL_SESSION_ID_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_BAD_SSL_SESSION_ID_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_SSL_SESSION_ID_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_STATE(void) {
#ifdef SSL_R_BAD_STATE
	dump("defined", 1);
	if ((SSL_R_BAD_STATE) <= 0) {
	    long long x = (long long)(SSL_R_BAD_STATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_STATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_VERSION_NUMBER(void) {
#ifdef PEM_R_BAD_VERSION_NUMBER
	dump("defined", 1);
	if ((PEM_R_BAD_VERSION_NUMBER) <= 0) {
	    long long x = (long long)(PEM_R_BAD_VERSION_NUMBER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BAD_VERSION_NUMBER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_WRITE_RETRY(void) {
#ifdef SSL_R_BAD_WRITE_RETRY
	dump("defined", 1);
	if ((SSL_R_BAD_WRITE_RETRY) <= 0) {
	    long long x = (long long)(SSL_R_BAD_WRITE_RETRY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BAD_WRITE_RETRY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BAD_X509_FILETYPE(void) {
#ifdef X509_R_BAD_X509_FILETYPE
	dump("defined", 1);
	if ((X509_R_BAD_X509_FILETYPE) <= 0) {
	    long long x = (long long)(X509_R_BAD_X509_FILETYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_BAD_X509_FILETYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BASE64_DECODE_ERROR(void) {
#ifdef X509_R_BASE64_DECODE_ERROR
	dump("defined", 1);
	if ((X509_R_BASE64_DECODE_ERROR) <= 0) {
	    long long x = (long long)(X509_R_BASE64_DECODE_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_BASE64_DECODE_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BIO_NOT_SET(void) {
#ifdef SSL_R_BIO_NOT_SET
	dump("defined", 1);
	if ((SSL_R_BIO_NOT_SET) <= 0) {
	    long long x = (long long)(SSL_R_BIO_NOT_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BIO_NOT_SET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BIO_WRITE_FAILURE(void) {
#ifdef PEM_R_BIO_WRITE_FAILURE
	dump("defined", 1);
	if ((PEM_R_BIO_WRITE_FAILURE) <= 0) {
	    long long x = (long long)(PEM_R_BIO_WRITE_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_BIO_WRITE_FAILURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BLOCK_CIPHER_PAD_IS_WRONG(void) {
#ifdef SSL_R_BLOCK_CIPHER_PAD_IS_WRONG
	dump("defined", 1);
	if ((SSL_R_BLOCK_CIPHER_PAD_IS_WRONG) <= 0) {
	    long long x = (long long)(SSL_R_BLOCK_CIPHER_PAD_IS_WRONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BLOCK_CIPHER_PAD_IS_WRONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_BN_LIB(void) {
#ifdef SSL_R_BN_LIB
	dump("defined", 1);
	if ((SSL_R_BN_LIB) <= 0) {
	    long long x = (long long)(SSL_R_BN_LIB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_BN_LIB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CANT_CHECK_DH_KEY(void) {
#ifdef X509_R_CANT_CHECK_DH_KEY
	dump("defined", 1);
	if ((X509_R_CANT_CHECK_DH_KEY) <= 0) {
	    long long x = (long long)(X509_R_CANT_CHECK_DH_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_CANT_CHECK_DH_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CA_DN_LENGTH_MISMATCH(void) {
#ifdef SSL_R_CA_DN_LENGTH_MISMATCH
	dump("defined", 1);
	if ((SSL_R_CA_DN_LENGTH_MISMATCH) <= 0) {
	    long long x = (long long)(SSL_R_CA_DN_LENGTH_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CA_DN_LENGTH_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CA_DN_TOO_LONG(void) {
#ifdef SSL_R_CA_DN_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_CA_DN_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_CA_DN_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CA_DN_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CCS_RECEIVED_EARLY(void) {
#ifdef SSL_R_CCS_RECEIVED_EARLY
	dump("defined", 1);
	if ((SSL_R_CCS_RECEIVED_EARLY) <= 0) {
	    long long x = (long long)(SSL_R_CCS_RECEIVED_EARLY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CCS_RECEIVED_EARLY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERTIFICATE_EXPIRED(void) {
#ifdef SSL_AD_CERTIFICATE_EXPIRED
	dump("defined", 1);
	if ((SSL_AD_CERTIFICATE_EXPIRED) <= 0) {
	    long long x = (long long)(SSL_AD_CERTIFICATE_EXPIRED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_CERTIFICATE_EXPIRED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERTIFICATE_REVOKED(void) {
#ifdef SSL_AD_CERTIFICATE_REVOKED
	dump("defined", 1);
	if ((SSL_AD_CERTIFICATE_REVOKED) <= 0) {
	    long long x = (long long)(SSL_AD_CERTIFICATE_REVOKED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_CERTIFICATE_REVOKED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERTIFICATE_UNKNOWN(void) {
#ifdef SSL_AD_CERTIFICATE_UNKNOWN
	dump("defined", 1);
	if ((SSL_AD_CERTIFICATE_UNKNOWN) <= 0) {
	    long long x = (long long)(SSL_AD_CERTIFICATE_UNKNOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_CERTIFICATE_UNKNOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERTIFICATE_UNOBTAINABLE(void) {
#ifdef SSL_AD_CERTIFICATE_UNOBTAINABLE
	dump("defined", 1);
	if ((SSL_AD_CERTIFICATE_UNOBTAINABLE) <= 0) {
	    long long x = (long long)(SSL_AD_CERTIFICATE_UNOBTAINABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_CERTIFICATE_UNOBTAINABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERTIFICATE_VERIFY_FAILED(void) {
#ifdef SSL_R_CERTIFICATE_VERIFY_FAILED
	dump("defined", 1);
	if ((SSL_R_CERTIFICATE_VERIFY_FAILED) <= 0) {
	    long long x = (long long)(SSL_R_CERTIFICATE_VERIFY_FAILED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CERTIFICATE_VERIFY_FAILED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERT_ALREADY_IN_HASH_TABLE(void) {
#ifdef X509_R_CERT_ALREADY_IN_HASH_TABLE
	dump("defined", 1);
	if ((X509_R_CERT_ALREADY_IN_HASH_TABLE) <= 0) {
	    long long x = (long long)(X509_R_CERT_ALREADY_IN_HASH_TABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_CERT_ALREADY_IN_HASH_TABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CERT_LENGTH_MISMATCH(void) {
#ifdef SSL_R_CERT_LENGTH_MISMATCH
	dump("defined", 1);
	if ((SSL_R_CERT_LENGTH_MISMATCH) <= 0) {
	    long long x = (long long)(SSL_R_CERT_LENGTH_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CERT_LENGTH_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CHALLENGE_IS_DIFFERENT(void) {
#ifdef SSL_R_CHALLENGE_IS_DIFFERENT
	dump("defined", 1);
	if ((SSL_R_CHALLENGE_IS_DIFFERENT) <= 0) {
	    long long x = (long long)(SSL_R_CHALLENGE_IS_DIFFERENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CHALLENGE_IS_DIFFERENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CIPHER_CODE_WRONG_LENGTH(void) {
#ifdef SSL_R_CIPHER_CODE_WRONG_LENGTH
	dump("defined", 1);
	if ((SSL_R_CIPHER_CODE_WRONG_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_CIPHER_CODE_WRONG_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CIPHER_CODE_WRONG_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CIPHER_IS_NULL(void) {
#ifdef PEM_R_CIPHER_IS_NULL
	dump("defined", 1);
	if ((PEM_R_CIPHER_IS_NULL) <= 0) {
	    long long x = (long long)(PEM_R_CIPHER_IS_NULL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_CIPHER_IS_NULL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CIPHER_OR_HASH_UNAVAILABLE(void) {
#ifdef SSL_R_CIPHER_OR_HASH_UNAVAILABLE
	dump("defined", 1);
	if ((SSL_R_CIPHER_OR_HASH_UNAVAILABLE) <= 0) {
	    long long x = (long long)(SSL_R_CIPHER_OR_HASH_UNAVAILABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CIPHER_OR_HASH_UNAVAILABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CIPHER_TABLE_SRC_ERROR(void) {
#ifdef SSL_R_CIPHER_TABLE_SRC_ERROR
	dump("defined", 1);
	if ((SSL_R_CIPHER_TABLE_SRC_ERROR) <= 0) {
	    long long x = (long long)(SSL_R_CIPHER_TABLE_SRC_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CIPHER_TABLE_SRC_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CLIENTHELLO_TLSEXT(void) {
#ifdef SSL_R_CLIENTHELLO_TLSEXT
	dump("defined", 1);
	if ((SSL_R_CLIENTHELLO_TLSEXT) <= 0) {
	    long long x = (long long)(SSL_R_CLIENTHELLO_TLSEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CLIENTHELLO_TLSEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CLOSE_NOTIFY(void) {
#ifdef SSL_AD_CLOSE_NOTIFY
	dump("defined", 1);
	if ((SSL_AD_CLOSE_NOTIFY) <= 0) {
	    long long x = (long long)(SSL_AD_CLOSE_NOTIFY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_CLOSE_NOTIFY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_COMPRESSED_LENGTH_TOO_LONG(void) {
#ifdef SSL_R_COMPRESSED_LENGTH_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_COMPRESSED_LENGTH_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_COMPRESSED_LENGTH_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_COMPRESSED_LENGTH_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_COMPRESSION_DISABLED(void) {
#ifdef SSL_R_COMPRESSION_DISABLED
	dump("defined", 1);
	if ((SSL_R_COMPRESSION_DISABLED) <= 0) {
	    long long x = (long long)(SSL_R_COMPRESSION_DISABLED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_COMPRESSION_DISABLED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_COMPRESSION_FAILURE(void) {
#ifdef SSL_R_COMPRESSION_FAILURE
	dump("defined", 1);
	if ((SSL_R_COMPRESSION_FAILURE) <= 0) {
	    long long x = (long long)(SSL_R_COMPRESSION_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_COMPRESSION_FAILURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE(void) {
#ifdef SSL_R_COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE
	dump("defined", 1);
	if ((SSL_R_COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE) <= 0) {
	    long long x = (long long)(SSL_R_COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_COMPRESSION_LIBRARY_ERROR(void) {
#ifdef SSL_R_COMPRESSION_LIBRARY_ERROR
	dump("defined", 1);
	if ((SSL_R_COMPRESSION_LIBRARY_ERROR) <= 0) {
	    long long x = (long long)(SSL_R_COMPRESSION_LIBRARY_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_COMPRESSION_LIBRARY_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CONNECTION_ID_IS_DIFFERENT(void) {
#ifdef SSL_R_CONNECTION_ID_IS_DIFFERENT
	dump("defined", 1);
	if ((SSL_R_CONNECTION_ID_IS_DIFFERENT) <= 0) {
	    long long x = (long long)(SSL_R_CONNECTION_ID_IS_DIFFERENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CONNECTION_ID_IS_DIFFERENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_CONNECTION_TYPE_NOT_SET(void) {
#ifdef SSL_R_CONNECTION_TYPE_NOT_SET
	dump("defined", 1);
	if ((SSL_R_CONNECTION_TYPE_NOT_SET) <= 0) {
	    long long x = (long long)(SSL_R_CONNECTION_TYPE_NOT_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_CONNECTION_TYPE_NOT_SET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_COOKIE_MISMATCH(void) {
#ifdef SSL_R_COOKIE_MISMATCH
	dump("defined", 1);
	if ((SSL_R_COOKIE_MISMATCH) <= 0) {
	    long long x = (long long)(SSL_R_COOKIE_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_COOKIE_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DATA_BETWEEN_CCS_AND_FINISHED(void) {
#ifdef SSL_R_DATA_BETWEEN_CCS_AND_FINISHED
	dump("defined", 1);
	if ((SSL_R_DATA_BETWEEN_CCS_AND_FINISHED) <= 0) {
	    long long x = (long long)(SSL_R_DATA_BETWEEN_CCS_AND_FINISHED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DATA_BETWEEN_CCS_AND_FINISHED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DATA_LENGTH_TOO_LONG(void) {
#ifdef SSL_R_DATA_LENGTH_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_DATA_LENGTH_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_DATA_LENGTH_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DATA_LENGTH_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DECODE_ERROR(void) {
#ifdef SSL_AD_DECODE_ERROR
	dump("defined", 1);
	if ((SSL_AD_DECODE_ERROR) <= 0) {
	    long long x = (long long)(SSL_AD_DECODE_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_DECODE_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DECOMPRESSION_FAILURE(void) {
#ifdef SSL_AD_DECOMPRESSION_FAILURE
	dump("defined", 1);
	if ((SSL_AD_DECOMPRESSION_FAILURE) <= 0) {
	    long long x = (long long)(SSL_AD_DECOMPRESSION_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_DECOMPRESSION_FAILURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DECRYPTION_FAILED(void) {
#ifdef SSL_R_DECRYPTION_FAILED
	dump("defined", 1);
	if ((SSL_R_DECRYPTION_FAILED) <= 0) {
	    long long x = (long long)(SSL_R_DECRYPTION_FAILED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DECRYPTION_FAILED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DECRYPTION_FAILED_OR_BAD_RECORD_MAC(void) {
#ifdef SSL_R_DECRYPTION_FAILED_OR_BAD_RECORD_MAC
	dump("defined", 1);
	if ((SSL_R_DECRYPTION_FAILED_OR_BAD_RECORD_MAC) <= 0) {
	    long long x = (long long)(SSL_R_DECRYPTION_FAILED_OR_BAD_RECORD_MAC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DECRYPTION_FAILED_OR_BAD_RECORD_MAC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DECRYPT_ERROR(void) {
#ifdef SSL_AD_DECRYPT_ERROR
	dump("defined", 1);
	if ((SSL_AD_DECRYPT_ERROR) <= 0) {
	    long long x = (long long)(SSL_AD_DECRYPT_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_DECRYPT_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DH_PUBLIC_VALUE_LENGTH_IS_WRONG(void) {
#ifdef SSL_R_DH_PUBLIC_VALUE_LENGTH_IS_WRONG
	dump("defined", 1);
	if ((SSL_R_DH_PUBLIC_VALUE_LENGTH_IS_WRONG) <= 0) {
	    long long x = (long long)(SSL_R_DH_PUBLIC_VALUE_LENGTH_IS_WRONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DH_PUBLIC_VALUE_LENGTH_IS_WRONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DIGEST_CHECK_FAILED(void) {
#ifdef SSL_R_DIGEST_CHECK_FAILED
	dump("defined", 1);
	if ((SSL_R_DIGEST_CHECK_FAILED) <= 0) {
	    long long x = (long long)(SSL_R_DIGEST_CHECK_FAILED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DIGEST_CHECK_FAILED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DTLS_MESSAGE_TOO_BIG(void) {
#ifdef SSL_R_DTLS_MESSAGE_TOO_BIG
	dump("defined", 1);
	if ((SSL_R_DTLS_MESSAGE_TOO_BIG) <= 0) {
	    long long x = (long long)(SSL_R_DTLS_MESSAGE_TOO_BIG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DTLS_MESSAGE_TOO_BIG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_DUPLICATE_COMPRESSION_ID(void) {
#ifdef SSL_R_DUPLICATE_COMPRESSION_ID
	dump("defined", 1);
	if ((SSL_R_DUPLICATE_COMPRESSION_ID) <= 0) {
	    long long x = (long long)(SSL_R_DUPLICATE_COMPRESSION_ID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_DUPLICATE_COMPRESSION_ID);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECC_CERT_NOT_FOR_KEY_AGREEMENT(void) {
#ifdef SSL_R_ECC_CERT_NOT_FOR_KEY_AGREEMENT
	dump("defined", 1);
	if ((SSL_R_ECC_CERT_NOT_FOR_KEY_AGREEMENT) <= 0) {
	    long long x = (long long)(SSL_R_ECC_CERT_NOT_FOR_KEY_AGREEMENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ECC_CERT_NOT_FOR_KEY_AGREEMENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECC_CERT_NOT_FOR_SIGNING(void) {
#ifdef SSL_R_ECC_CERT_NOT_FOR_SIGNING
	dump("defined", 1);
	if ((SSL_R_ECC_CERT_NOT_FOR_SIGNING) <= 0) {
	    long long x = (long long)(SSL_R_ECC_CERT_NOT_FOR_SIGNING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ECC_CERT_NOT_FOR_SIGNING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECC_CERT_SHOULD_HAVE_RSA_SIGNATURE(void) {
#ifdef SSL_R_ECC_CERT_SHOULD_HAVE_RSA_SIGNATURE
	dump("defined", 1);
	if ((SSL_R_ECC_CERT_SHOULD_HAVE_RSA_SIGNATURE) <= 0) {
	    long long x = (long long)(SSL_R_ECC_CERT_SHOULD_HAVE_RSA_SIGNATURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ECC_CERT_SHOULD_HAVE_RSA_SIGNATURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECC_CERT_SHOULD_HAVE_SHA1_SIGNATURE(void) {
#ifdef SSL_R_ECC_CERT_SHOULD_HAVE_SHA1_SIGNATURE
	dump("defined", 1);
	if ((SSL_R_ECC_CERT_SHOULD_HAVE_SHA1_SIGNATURE) <= 0) {
	    long long x = (long long)(SSL_R_ECC_CERT_SHOULD_HAVE_SHA1_SIGNATURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ECC_CERT_SHOULD_HAVE_SHA1_SIGNATURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ECGROUP_TOO_LARGE_FOR_CIPHER(void) {
#ifdef SSL_R_ECGROUP_TOO_LARGE_FOR_CIPHER
	dump("defined", 1);
	if ((SSL_R_ECGROUP_TOO_LARGE_FOR_CIPHER) <= 0) {
	    long long x = (long long)(SSL_R_ECGROUP_TOO_LARGE_FOR_CIPHER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ECGROUP_TOO_LARGE_FOR_CIPHER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ENCRYPTED_LENGTH_TOO_LONG(void) {
#ifdef SSL_R_ENCRYPTED_LENGTH_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_ENCRYPTED_LENGTH_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_ENCRYPTED_LENGTH_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ENCRYPTED_LENGTH_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERROR_CONVERTING_PRIVATE_KEY(void) {
#ifdef PEM_R_ERROR_CONVERTING_PRIVATE_KEY
	dump("defined", 1);
	if ((PEM_R_ERROR_CONVERTING_PRIVATE_KEY) <= 0) {
	    long long x = (long long)(PEM_R_ERROR_CONVERTING_PRIVATE_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_ERROR_CONVERTING_PRIVATE_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERROR_GENERATING_TMP_RSA_KEY(void) {
#ifdef SSL_R_ERROR_GENERATING_TMP_RSA_KEY
	dump("defined", 1);
	if ((SSL_R_ERROR_GENERATING_TMP_RSA_KEY) <= 0) {
	    long long x = (long long)(SSL_R_ERROR_GENERATING_TMP_RSA_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ERROR_GENERATING_TMP_RSA_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERROR_IN_RECEIVED_CIPHER_LIST(void) {
#ifdef SSL_R_ERROR_IN_RECEIVED_CIPHER_LIST
	dump("defined", 1);
	if ((SSL_R_ERROR_IN_RECEIVED_CIPHER_LIST) <= 0) {
	    long long x = (long long)(SSL_R_ERROR_IN_RECEIVED_CIPHER_LIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ERROR_IN_RECEIVED_CIPHER_LIST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ERR_ASN1_LIB(void) {
#ifdef X509_R_ERR_ASN1_LIB
	dump("defined", 1);
	if ((X509_R_ERR_ASN1_LIB) <= 0) {
	    long long x = (long long)(X509_R_ERR_ASN1_LIB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_ERR_ASN1_LIB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EXCESSIVE_MESSAGE_SIZE(void) {
#ifdef SSL_R_EXCESSIVE_MESSAGE_SIZE
	dump("defined", 1);
	if ((SSL_R_EXCESSIVE_MESSAGE_SIZE) <= 0) {
	    long long x = (long long)(SSL_R_EXCESSIVE_MESSAGE_SIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_EXCESSIVE_MESSAGE_SIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EXPECTING_PRIVATE_KEY_BLOB(void) {
#ifdef PEM_R_EXPECTING_PRIVATE_KEY_BLOB
	dump("defined", 1);
	if ((PEM_R_EXPECTING_PRIVATE_KEY_BLOB) <= 0) {
	    long long x = (long long)(PEM_R_EXPECTING_PRIVATE_KEY_BLOB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_EXPECTING_PRIVATE_KEY_BLOB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EXPECTING_PUBLIC_KEY_BLOB(void) {
#ifdef PEM_R_EXPECTING_PUBLIC_KEY_BLOB
	dump("defined", 1);
	if ((PEM_R_EXPECTING_PUBLIC_KEY_BLOB) <= 0) {
	    long long x = (long long)(PEM_R_EXPECTING_PUBLIC_KEY_BLOB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_EXPECTING_PUBLIC_KEY_BLOB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_EXTRA_DATA_IN_MESSAGE(void) {
#ifdef SSL_R_EXTRA_DATA_IN_MESSAGE
	dump("defined", 1);
	if ((SSL_R_EXTRA_DATA_IN_MESSAGE) <= 0) {
	    long long x = (long long)(SSL_R_EXTRA_DATA_IN_MESSAGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_EXTRA_DATA_IN_MESSAGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_GOT_A_FIN_BEFORE_A_CCS(void) {
#ifdef SSL_R_GOT_A_FIN_BEFORE_A_CCS
	dump("defined", 1);
	if ((SSL_R_GOT_A_FIN_BEFORE_A_CCS) <= 0) {
	    long long x = (long long)(SSL_R_GOT_A_FIN_BEFORE_A_CCS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_GOT_A_FIN_BEFORE_A_CCS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_HANDSHAKE_FAILURE(void) {
#ifdef SSL_AD_HANDSHAKE_FAILURE
	dump("defined", 1);
	if ((SSL_AD_HANDSHAKE_FAILURE) <= 0) {
	    long long x = (long long)(SSL_AD_HANDSHAKE_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_HANDSHAKE_FAILURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_HTTPS_PROXY_REQUEST(void) {
#ifdef SSL_R_HTTPS_PROXY_REQUEST
	dump("defined", 1);
	if ((SSL_R_HTTPS_PROXY_REQUEST) <= 0) {
	    long long x = (long long)(SSL_R_HTTPS_PROXY_REQUEST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_HTTPS_PROXY_REQUEST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_HTTP_REQUEST(void) {
#ifdef SSL_R_HTTP_REQUEST
	dump("defined", 1);
	if ((SSL_R_HTTP_REQUEST) <= 0) {
	    long long x = (long long)(SSL_R_HTTP_REQUEST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_HTTP_REQUEST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ILLEGAL_PADDING(void) {
#ifdef SSL_R_ILLEGAL_PADDING
	dump("defined", 1);
	if ((SSL_R_ILLEGAL_PADDING) <= 0) {
	    long long x = (long long)(SSL_R_ILLEGAL_PADDING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ILLEGAL_PADDING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ILLEGAL_PARAMETER(void) {
#ifdef SSL_AD_ILLEGAL_PARAMETER
	dump("defined", 1);
	if ((SSL_AD_ILLEGAL_PARAMETER) <= 0) {
	    long long x = (long long)(SSL_AD_ILLEGAL_PARAMETER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_ILLEGAL_PARAMETER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INCONSISTENT_COMPRESSION(void) {
#ifdef SSL_R_INCONSISTENT_COMPRESSION
	dump("defined", 1);
	if ((SSL_R_INCONSISTENT_COMPRESSION) <= 0) {
	    long long x = (long long)(SSL_R_INCONSISTENT_COMPRESSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_INCONSISTENT_COMPRESSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INCONSISTENT_HEADER(void) {
#ifdef PEM_R_INCONSISTENT_HEADER
	dump("defined", 1);
	if ((PEM_R_INCONSISTENT_HEADER) <= 0) {
	    long long x = (long long)(PEM_R_INCONSISTENT_HEADER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_INCONSISTENT_HEADER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INSUFFICIENT_SECURITY(void) {
#ifdef SSL_AD_INSUFFICIENT_SECURITY
	dump("defined", 1);
	if ((SSL_AD_INSUFFICIENT_SECURITY) <= 0) {
	    long long x = (long long)(SSL_AD_INSUFFICIENT_SECURITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_INSUFFICIENT_SECURITY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INTERNAL_ERROR(void) {
#ifdef SSL_AD_INTERNAL_ERROR
	dump("defined", 1);
	if ((SSL_AD_INTERNAL_ERROR) <= 0) {
	    long long x = (long long)(SSL_AD_INTERNAL_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_INTERNAL_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_CHALLENGE_LENGTH(void) {
#ifdef SSL_R_INVALID_CHALLENGE_LENGTH
	dump("defined", 1);
	if ((SSL_R_INVALID_CHALLENGE_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_INVALID_CHALLENGE_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_INVALID_CHALLENGE_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_COMMAND(void) {
#ifdef SSL_R_INVALID_COMMAND
	dump("defined", 1);
	if ((SSL_R_INVALID_COMMAND) <= 0) {
	    long long x = (long long)(SSL_R_INVALID_COMMAND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_INVALID_COMMAND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_COMPRESSION_ALGORITHM(void) {
#ifdef SSL_R_INVALID_COMPRESSION_ALGORITHM
	dump("defined", 1);
	if ((SSL_R_INVALID_COMPRESSION_ALGORITHM) <= 0) {
	    long long x = (long long)(SSL_R_INVALID_COMPRESSION_ALGORITHM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_INVALID_COMPRESSION_ALGORITHM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_DIRECTORY(void) {
#ifdef X509_R_INVALID_DIRECTORY
	dump("defined", 1);
	if ((X509_R_INVALID_DIRECTORY) <= 0) {
	    long long x = (long long)(X509_R_INVALID_DIRECTORY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_INVALID_DIRECTORY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_FIELD_NAME(void) {
#ifdef X509_R_INVALID_FIELD_NAME
	dump("defined", 1);
	if ((X509_R_INVALID_FIELD_NAME) <= 0) {
	    long long x = (long long)(X509_R_INVALID_FIELD_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_INVALID_FIELD_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_PURPOSE(void) {
#ifdef SSL_R_INVALID_PURPOSE
	dump("defined", 1);
	if ((SSL_R_INVALID_PURPOSE) <= 0) {
	    long long x = (long long)(SSL_R_INVALID_PURPOSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_INVALID_PURPOSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_STATUS_RESPONSE(void) {
#ifdef SSL_R_INVALID_STATUS_RESPONSE
	dump("defined", 1);
	if ((SSL_R_INVALID_STATUS_RESPONSE) <= 0) {
	    long long x = (long long)(SSL_R_INVALID_STATUS_RESPONSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_INVALID_STATUS_RESPONSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_TICKET_KEYS_LENGTH(void) {
#ifdef SSL_R_INVALID_TICKET_KEYS_LENGTH
	dump("defined", 1);
	if ((SSL_R_INVALID_TICKET_KEYS_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_INVALID_TICKET_KEYS_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_INVALID_TICKET_KEYS_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_INVALID_TRUST(void) {
#ifdef X509_R_INVALID_TRUST
	dump("defined", 1);
	if ((X509_R_INVALID_TRUST) <= 0) {
	    long long x = (long long)(X509_R_INVALID_TRUST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_INVALID_TRUST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KEYBLOB_HEADER_PARSE_ERROR(void) {
#ifdef PEM_R_KEYBLOB_HEADER_PARSE_ERROR
	dump("defined", 1);
	if ((PEM_R_KEYBLOB_HEADER_PARSE_ERROR) <= 0) {
	    long long x = (long long)(PEM_R_KEYBLOB_HEADER_PARSE_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_KEYBLOB_HEADER_PARSE_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KEYBLOB_TOO_SHORT(void) {
#ifdef PEM_R_KEYBLOB_TOO_SHORT
	dump("defined", 1);
	if ((PEM_R_KEYBLOB_TOO_SHORT) <= 0) {
	    long long x = (long long)(PEM_R_KEYBLOB_TOO_SHORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_KEYBLOB_TOO_SHORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KEY_ARG_TOO_LONG(void) {
#ifdef SSL_R_KEY_ARG_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_KEY_ARG_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_KEY_ARG_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KEY_ARG_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KEY_TYPE_MISMATCH(void) {
#ifdef X509_R_KEY_TYPE_MISMATCH
	dump("defined", 1);
	if ((X509_R_KEY_TYPE_MISMATCH) <= 0) {
	    long long x = (long long)(X509_R_KEY_TYPE_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_KEY_TYPE_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KEY_VALUES_MISMATCH(void) {
#ifdef X509_R_KEY_VALUES_MISMATCH
	dump("defined", 1);
	if ((X509_R_KEY_VALUES_MISMATCH) <= 0) {
	    long long x = (long long)(X509_R_KEY_VALUES_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_KEY_VALUES_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5(void) {
#ifdef SSL_R_KRB5
	dump("defined", 1);
	if ((SSL_R_KRB5) <= 0) {
	    long long x = (long long)(SSL_R_KRB5);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_C_CC_PRINC(void) {
#ifdef SSL_R_KRB5_C_CC_PRINC
	dump("defined", 1);
	if ((SSL_R_KRB5_C_CC_PRINC) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_C_CC_PRINC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_C_CC_PRINC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_C_GET_CRED(void) {
#ifdef SSL_R_KRB5_C_GET_CRED
	dump("defined", 1);
	if ((SSL_R_KRB5_C_GET_CRED) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_C_GET_CRED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_C_GET_CRED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_C_INIT(void) {
#ifdef SSL_R_KRB5_C_INIT
	dump("defined", 1);
	if ((SSL_R_KRB5_C_INIT) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_C_INIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_C_INIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_C_MK_REQ(void) {
#ifdef SSL_R_KRB5_C_MK_REQ
	dump("defined", 1);
	if ((SSL_R_KRB5_C_MK_REQ) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_C_MK_REQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_C_MK_REQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_S_BAD_TICKET(void) {
#ifdef SSL_R_KRB5_S_BAD_TICKET
	dump("defined", 1);
	if ((SSL_R_KRB5_S_BAD_TICKET) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_S_BAD_TICKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_S_BAD_TICKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_S_INIT(void) {
#ifdef SSL_R_KRB5_S_INIT
	dump("defined", 1);
	if ((SSL_R_KRB5_S_INIT) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_S_INIT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_S_INIT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_S_RD_REQ(void) {
#ifdef SSL_R_KRB5_S_RD_REQ
	dump("defined", 1);
	if ((SSL_R_KRB5_S_RD_REQ) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_S_RD_REQ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_S_RD_REQ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_S_TKT_EXPIRED(void) {
#ifdef SSL_R_KRB5_S_TKT_EXPIRED
	dump("defined", 1);
	if ((SSL_R_KRB5_S_TKT_EXPIRED) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_S_TKT_EXPIRED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_S_TKT_EXPIRED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_S_TKT_NYV(void) {
#ifdef SSL_R_KRB5_S_TKT_NYV
	dump("defined", 1);
	if ((SSL_R_KRB5_S_TKT_NYV) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_S_TKT_NYV);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_S_TKT_NYV);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_KRB5_S_TKT_SKEW(void) {
#ifdef SSL_R_KRB5_S_TKT_SKEW
	dump("defined", 1);
	if ((SSL_R_KRB5_S_TKT_SKEW) <= 0) {
	    long long x = (long long)(SSL_R_KRB5_S_TKT_SKEW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_KRB5_S_TKT_SKEW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LENGTH_MISMATCH(void) {
#ifdef SSL_R_LENGTH_MISMATCH
	dump("defined", 1);
	if ((SSL_R_LENGTH_MISMATCH) <= 0) {
	    long long x = (long long)(SSL_R_LENGTH_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_LENGTH_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LENGTH_TOO_SHORT(void) {
#ifdef SSL_R_LENGTH_TOO_SHORT
	dump("defined", 1);
	if ((SSL_R_LENGTH_TOO_SHORT) <= 0) {
	    long long x = (long long)(SSL_R_LENGTH_TOO_SHORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_LENGTH_TOO_SHORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LIBRARY_BUG(void) {
#ifdef SSL_R_LIBRARY_BUG
	dump("defined", 1);
	if ((SSL_R_LIBRARY_BUG) <= 0) {
	    long long x = (long long)(SSL_R_LIBRARY_BUG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_LIBRARY_BUG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LIBRARY_HAS_NO_CIPHERS(void) {
#ifdef SSL_R_LIBRARY_HAS_NO_CIPHERS
	dump("defined", 1);
	if ((SSL_R_LIBRARY_HAS_NO_CIPHERS) <= 0) {
	    long long x = (long long)(SSL_R_LIBRARY_HAS_NO_CIPHERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_LIBRARY_HAS_NO_CIPHERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOADING_CERT_DIR(void) {
#ifdef X509_R_LOADING_CERT_DIR
	dump("defined", 1);
	if ((X509_R_LOADING_CERT_DIR) <= 0) {
	    long long x = (long long)(X509_R_LOADING_CERT_DIR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_LOADING_CERT_DIR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_LOADING_DEFAULTS(void) {
#ifdef X509_R_LOADING_DEFAULTS
	dump("defined", 1);
	if ((X509_R_LOADING_DEFAULTS) <= 0) {
	    long long x = (long long)(X509_R_LOADING_DEFAULTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_LOADING_DEFAULTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MESSAGE_TOO_LONG(void) {
#ifdef SSL_R_MESSAGE_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_MESSAGE_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_MESSAGE_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MESSAGE_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_METHOD_NOT_SUPPORTED(void) {
#ifdef X509_R_METHOD_NOT_SUPPORTED
	dump("defined", 1);
	if ((X509_R_METHOD_NOT_SUPPORTED) <= 0) {
	    long long x = (long long)(X509_R_METHOD_NOT_SUPPORTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_METHOD_NOT_SUPPORTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_DH_DSA_CERT(void) {
#ifdef SSL_R_MISSING_DH_DSA_CERT
	dump("defined", 1);
	if ((SSL_R_MISSING_DH_DSA_CERT) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_DH_DSA_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_DH_DSA_CERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_DH_KEY(void) {
#ifdef SSL_R_MISSING_DH_KEY
	dump("defined", 1);
	if ((SSL_R_MISSING_DH_KEY) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_DH_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_DH_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_DH_RSA_CERT(void) {
#ifdef SSL_R_MISSING_DH_RSA_CERT
	dump("defined", 1);
	if ((SSL_R_MISSING_DH_RSA_CERT) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_DH_RSA_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_DH_RSA_CERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_DSA_SIGNING_CERT(void) {
#ifdef SSL_R_MISSING_DSA_SIGNING_CERT
	dump("defined", 1);
	if ((SSL_R_MISSING_DSA_SIGNING_CERT) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_DSA_SIGNING_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_DSA_SIGNING_CERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_EXPORT_TMP_DH_KEY(void) {
#ifdef SSL_R_MISSING_EXPORT_TMP_DH_KEY
	dump("defined", 1);
	if ((SSL_R_MISSING_EXPORT_TMP_DH_KEY) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_EXPORT_TMP_DH_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_EXPORT_TMP_DH_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_EXPORT_TMP_RSA_KEY(void) {
#ifdef SSL_R_MISSING_EXPORT_TMP_RSA_KEY
	dump("defined", 1);
	if ((SSL_R_MISSING_EXPORT_TMP_RSA_KEY) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_EXPORT_TMP_RSA_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_EXPORT_TMP_RSA_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_RSA_CERTIFICATE(void) {
#ifdef SSL_R_MISSING_RSA_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_MISSING_RSA_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_RSA_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_RSA_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_RSA_ENCRYPTING_CERT(void) {
#ifdef SSL_R_MISSING_RSA_ENCRYPTING_CERT
	dump("defined", 1);
	if ((SSL_R_MISSING_RSA_ENCRYPTING_CERT) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_RSA_ENCRYPTING_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_RSA_ENCRYPTING_CERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_RSA_SIGNING_CERT(void) {
#ifdef SSL_R_MISSING_RSA_SIGNING_CERT
	dump("defined", 1);
	if ((SSL_R_MISSING_RSA_SIGNING_CERT) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_RSA_SIGNING_CERT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_RSA_SIGNING_CERT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_TMP_DH_KEY(void) {
#ifdef SSL_R_MISSING_TMP_DH_KEY
	dump("defined", 1);
	if ((SSL_R_MISSING_TMP_DH_KEY) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_TMP_DH_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_TMP_DH_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_TMP_ECDH_KEY(void) {
#ifdef SSL_R_MISSING_TMP_ECDH_KEY
	dump("defined", 1);
	if ((SSL_R_MISSING_TMP_ECDH_KEY) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_TMP_ECDH_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_TMP_ECDH_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_TMP_RSA_KEY(void) {
#ifdef SSL_R_MISSING_TMP_RSA_KEY
	dump("defined", 1);
	if ((SSL_R_MISSING_TMP_RSA_KEY) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_TMP_RSA_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_TMP_RSA_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_TMP_RSA_PKEY(void) {
#ifdef SSL_R_MISSING_TMP_RSA_PKEY
	dump("defined", 1);
	if ((SSL_R_MISSING_TMP_RSA_PKEY) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_TMP_RSA_PKEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_TMP_RSA_PKEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_MISSING_VERIFY_MESSAGE(void) {
#ifdef SSL_R_MISSING_VERIFY_MESSAGE
	dump("defined", 1);
	if ((SSL_R_MISSING_VERIFY_MESSAGE) <= 0) {
	    long long x = (long long)(SSL_R_MISSING_VERIFY_MESSAGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_MISSING_VERIFY_MESSAGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NON_SSLV2_INITIAL_PACKET(void) {
#ifdef SSL_R_NON_SSLV2_INITIAL_PACKET
	dump("defined", 1);
	if ((SSL_R_NON_SSLV2_INITIAL_PACKET) <= 0) {
	    long long x = (long long)(SSL_R_NON_SSLV2_INITIAL_PACKET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NON_SSLV2_INITIAL_PACKET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NOT_DEK_INFO(void) {
#ifdef PEM_R_NOT_DEK_INFO
	dump("defined", 1);
	if ((PEM_R_NOT_DEK_INFO) <= 0) {
	    long long x = (long long)(PEM_R_NOT_DEK_INFO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_NOT_DEK_INFO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NOT_ENCRYPTED(void) {
#ifdef PEM_R_NOT_ENCRYPTED
	dump("defined", 1);
	if ((PEM_R_NOT_ENCRYPTED) <= 0) {
	    long long x = (long long)(PEM_R_NOT_ENCRYPTED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_NOT_ENCRYPTED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NOT_PROC_TYPE(void) {
#ifdef PEM_R_NOT_PROC_TYPE
	dump("defined", 1);
	if ((PEM_R_NOT_PROC_TYPE) <= 0) {
	    long long x = (long long)(PEM_R_NOT_PROC_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_NOT_PROC_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CERTIFICATES_RETURNED(void) {
#ifdef SSL_R_NO_CERTIFICATES_RETURNED
	dump("defined", 1);
	if ((SSL_R_NO_CERTIFICATES_RETURNED) <= 0) {
	    long long x = (long long)(SSL_R_NO_CERTIFICATES_RETURNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CERTIFICATES_RETURNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CERTIFICATE_ASSIGNED(void) {
#ifdef SSL_R_NO_CERTIFICATE_ASSIGNED
	dump("defined", 1);
	if ((SSL_R_NO_CERTIFICATE_ASSIGNED) <= 0) {
	    long long x = (long long)(SSL_R_NO_CERTIFICATE_ASSIGNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CERTIFICATE_ASSIGNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CERTIFICATE_RETURNED(void) {
#ifdef SSL_R_NO_CERTIFICATE_RETURNED
	dump("defined", 1);
	if ((SSL_R_NO_CERTIFICATE_RETURNED) <= 0) {
	    long long x = (long long)(SSL_R_NO_CERTIFICATE_RETURNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CERTIFICATE_RETURNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CERTIFICATE_SET(void) {
#ifdef SSL_R_NO_CERTIFICATE_SET
	dump("defined", 1);
	if ((SSL_R_NO_CERTIFICATE_SET) <= 0) {
	    long long x = (long long)(SSL_R_NO_CERTIFICATE_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CERTIFICATE_SET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CERTIFICATE_SPECIFIED(void) {
#ifdef SSL_R_NO_CERTIFICATE_SPECIFIED
	dump("defined", 1);
	if ((SSL_R_NO_CERTIFICATE_SPECIFIED) <= 0) {
	    long long x = (long long)(SSL_R_NO_CERTIFICATE_SPECIFIED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CERTIFICATE_SPECIFIED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CERT_SET_FOR_US_TO_VERIFY(void) {
#ifdef X509_R_NO_CERT_SET_FOR_US_TO_VERIFY
	dump("defined", 1);
	if ((X509_R_NO_CERT_SET_FOR_US_TO_VERIFY) <= 0) {
	    long long x = (long long)(X509_R_NO_CERT_SET_FOR_US_TO_VERIFY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_NO_CERT_SET_FOR_US_TO_VERIFY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CIPHERS_AVAILABLE(void) {
#ifdef SSL_R_NO_CIPHERS_AVAILABLE
	dump("defined", 1);
	if ((SSL_R_NO_CIPHERS_AVAILABLE) <= 0) {
	    long long x = (long long)(SSL_R_NO_CIPHERS_AVAILABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CIPHERS_AVAILABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CIPHERS_PASSED(void) {
#ifdef SSL_R_NO_CIPHERS_PASSED
	dump("defined", 1);
	if ((SSL_R_NO_CIPHERS_PASSED) <= 0) {
	    long long x = (long long)(SSL_R_NO_CIPHERS_PASSED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CIPHERS_PASSED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CIPHERS_SPECIFIED(void) {
#ifdef SSL_R_NO_CIPHERS_SPECIFIED
	dump("defined", 1);
	if ((SSL_R_NO_CIPHERS_SPECIFIED) <= 0) {
	    long long x = (long long)(SSL_R_NO_CIPHERS_SPECIFIED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CIPHERS_SPECIFIED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CIPHER_LIST(void) {
#ifdef SSL_R_NO_CIPHER_LIST
	dump("defined", 1);
	if ((SSL_R_NO_CIPHER_LIST) <= 0) {
	    long long x = (long long)(SSL_R_NO_CIPHER_LIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CIPHER_LIST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CIPHER_MATCH(void) {
#ifdef SSL_R_NO_CIPHER_MATCH
	dump("defined", 1);
	if ((SSL_R_NO_CIPHER_MATCH) <= 0) {
	    long long x = (long long)(SSL_R_NO_CIPHER_MATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CIPHER_MATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CLIENT_CERT_METHOD(void) {
#ifdef SSL_R_NO_CLIENT_CERT_METHOD
	dump("defined", 1);
	if ((SSL_R_NO_CLIENT_CERT_METHOD) <= 0) {
	    long long x = (long long)(SSL_R_NO_CLIENT_CERT_METHOD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CLIENT_CERT_METHOD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_CLIENT_CERT_RECEIVED(void) {
#ifdef SSL_R_NO_CLIENT_CERT_RECEIVED
	dump("defined", 1);
	if ((SSL_R_NO_CLIENT_CERT_RECEIVED) <= 0) {
	    long long x = (long long)(SSL_R_NO_CLIENT_CERT_RECEIVED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_CLIENT_CERT_RECEIVED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_COMPRESSION_SPECIFIED(void) {
#ifdef SSL_R_NO_COMPRESSION_SPECIFIED
	dump("defined", 1);
	if ((SSL_R_NO_COMPRESSION_SPECIFIED) <= 0) {
	    long long x = (long long)(SSL_R_NO_COMPRESSION_SPECIFIED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_COMPRESSION_SPECIFIED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_GOST_CERTIFICATE_SENT_BY_PEER(void) {
#ifdef SSL_R_NO_GOST_CERTIFICATE_SENT_BY_PEER
	dump("defined", 1);
	if ((SSL_R_NO_GOST_CERTIFICATE_SENT_BY_PEER) <= 0) {
	    long long x = (long long)(SSL_R_NO_GOST_CERTIFICATE_SENT_BY_PEER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_GOST_CERTIFICATE_SENT_BY_PEER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_METHOD_SPECIFIED(void) {
#ifdef SSL_R_NO_METHOD_SPECIFIED
	dump("defined", 1);
	if ((SSL_R_NO_METHOD_SPECIFIED) <= 0) {
	    long long x = (long long)(SSL_R_NO_METHOD_SPECIFIED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_METHOD_SPECIFIED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_PRIVATEKEY(void) {
#ifdef SSL_R_NO_PRIVATEKEY
	dump("defined", 1);
	if ((SSL_R_NO_PRIVATEKEY) <= 0) {
	    long long x = (long long)(SSL_R_NO_PRIVATEKEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_PRIVATEKEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_PRIVATE_KEY_ASSIGNED(void) {
#ifdef SSL_R_NO_PRIVATE_KEY_ASSIGNED
	dump("defined", 1);
	if ((SSL_R_NO_PRIVATE_KEY_ASSIGNED) <= 0) {
	    long long x = (long long)(SSL_R_NO_PRIVATE_KEY_ASSIGNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_PRIVATE_KEY_ASSIGNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_PROTOCOLS_AVAILABLE(void) {
#ifdef SSL_R_NO_PROTOCOLS_AVAILABLE
	dump("defined", 1);
	if ((SSL_R_NO_PROTOCOLS_AVAILABLE) <= 0) {
	    long long x = (long long)(SSL_R_NO_PROTOCOLS_AVAILABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_PROTOCOLS_AVAILABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_PUBLICKEY(void) {
#ifdef SSL_R_NO_PUBLICKEY
	dump("defined", 1);
	if ((SSL_R_NO_PUBLICKEY) <= 0) {
	    long long x = (long long)(SSL_R_NO_PUBLICKEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_PUBLICKEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_RENEGOTIATION(void) {
#ifdef SSL_AD_NO_RENEGOTIATION
	dump("defined", 1);
	if ((SSL_AD_NO_RENEGOTIATION) <= 0) {
	    long long x = (long long)(SSL_AD_NO_RENEGOTIATION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_NO_RENEGOTIATION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_REQUIRED_DIGEST(void) {
#ifdef SSL_R_NO_REQUIRED_DIGEST
	dump("defined", 1);
	if ((SSL_R_NO_REQUIRED_DIGEST) <= 0) {
	    long long x = (long long)(SSL_R_NO_REQUIRED_DIGEST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_REQUIRED_DIGEST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_SHARED_CIPHER(void) {
#ifdef SSL_R_NO_SHARED_CIPHER
	dump("defined", 1);
	if ((SSL_R_NO_SHARED_CIPHER) <= 0) {
	    long long x = (long long)(SSL_R_NO_SHARED_CIPHER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_SHARED_CIPHER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_START_LINE(void) {
#ifdef PEM_R_NO_START_LINE
	dump("defined", 1);
	if ((PEM_R_NO_START_LINE) <= 0) {
	    long long x = (long long)(PEM_R_NO_START_LINE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_NO_START_LINE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NO_VERIFY_CALLBACK(void) {
#ifdef SSL_R_NO_VERIFY_CALLBACK
	dump("defined", 1);
	if ((SSL_R_NO_VERIFY_CALLBACK) <= 0) {
	    long long x = (long long)(SSL_R_NO_VERIFY_CALLBACK);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NO_VERIFY_CALLBACK);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NULL_SSL_CTX(void) {
#ifdef SSL_R_NULL_SSL_CTX
	dump("defined", 1);
	if ((SSL_R_NULL_SSL_CTX) <= 0) {
	    long long x = (long long)(SSL_R_NULL_SSL_CTX);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NULL_SSL_CTX);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_NULL_SSL_METHOD_PASSED(void) {
#ifdef SSL_R_NULL_SSL_METHOD_PASSED
	dump("defined", 1);
	if ((SSL_R_NULL_SSL_METHOD_PASSED) <= 0) {
	    long long x = (long long)(SSL_R_NULL_SSL_METHOD_PASSED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_NULL_SSL_METHOD_PASSED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OLD_SESSION_CIPHER_NOT_RETURNED(void) {
#ifdef SSL_R_OLD_SESSION_CIPHER_NOT_RETURNED
	dump("defined", 1);
	if ((SSL_R_OLD_SESSION_CIPHER_NOT_RETURNED) <= 0) {
	    long long x = (long long)(SSL_R_OLD_SESSION_CIPHER_NOT_RETURNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_OLD_SESSION_CIPHER_NOT_RETURNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED(void) {
#ifdef SSL_R_OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED
	dump("defined", 1);
	if ((SSL_R_OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED) <= 0) {
	    long long x = (long long)(SSL_R_OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_ONLY_TLS_ALLOWED_IN_FIPS_MODE(void) {
#ifdef SSL_R_ONLY_TLS_ALLOWED_IN_FIPS_MODE
	dump("defined", 1);
	if ((SSL_R_ONLY_TLS_ALLOWED_IN_FIPS_MODE) <= 0) {
	    long long x = (long long)(SSL_R_ONLY_TLS_ALLOWED_IN_FIPS_MODE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_ONLY_TLS_ALLOWED_IN_FIPS_MODE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_OPAQUE_PRF_INPUT_TOO_LONG(void) {
#ifdef SSL_R_OPAQUE_PRF_INPUT_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_OPAQUE_PRF_INPUT_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_OPAQUE_PRF_INPUT_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_OPAQUE_PRF_INPUT_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PACKET_LENGTH_TOO_LONG(void) {
#ifdef SSL_R_PACKET_LENGTH_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_PACKET_LENGTH_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_PACKET_LENGTH_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PACKET_LENGTH_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PARSE_TLSEXT(void) {
#ifdef SSL_R_PARSE_TLSEXT
	dump("defined", 1);
	if ((SSL_R_PARSE_TLSEXT) <= 0) {
	    long long x = (long long)(SSL_R_PARSE_TLSEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PARSE_TLSEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PATH_TOO_LONG(void) {
#ifdef SSL_R_PATH_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_PATH_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_PATH_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PATH_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PEER_DID_NOT_RETURN_A_CERTIFICATE(void) {
#ifdef SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PEER_DID_NOT_RETURN_A_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PEER_ERROR(void) {
#ifdef SSL_R_PEER_ERROR
	dump("defined", 1);
	if ((SSL_R_PEER_ERROR) <= 0) {
	    long long x = (long long)(SSL_R_PEER_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PEER_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PEER_ERROR_CERTIFICATE(void) {
#ifdef SSL_R_PEER_ERROR_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_PEER_ERROR_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_PEER_ERROR_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PEER_ERROR_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PEER_ERROR_NO_CERTIFICATE(void) {
#ifdef SSL_R_PEER_ERROR_NO_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_PEER_ERROR_NO_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_PEER_ERROR_NO_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PEER_ERROR_NO_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PEER_ERROR_NO_CIPHER(void) {
#ifdef SSL_R_PEER_ERROR_NO_CIPHER
	dump("defined", 1);
	if ((SSL_R_PEER_ERROR_NO_CIPHER) <= 0) {
	    long long x = (long long)(SSL_R_PEER_ERROR_NO_CIPHER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PEER_ERROR_NO_CIPHER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE(void) {
#ifdef SSL_R_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE
	dump("defined", 1);
	if ((SSL_R_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PEM(void) {
	if ((ERR_LIB_PEM) <= 0) {
	    long long x = (long long)(ERR_LIB_PEM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_PEM);
	    printf("value: %llu\n", x);
	}
}

void dump_section_PRE_MAC_LENGTH_TOO_LONG(void) {
#ifdef SSL_R_PRE_MAC_LENGTH_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_PRE_MAC_LENGTH_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_PRE_MAC_LENGTH_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PRE_MAC_LENGTH_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PROBLEMS_GETTING_PASSWORD(void) {
#ifdef PEM_R_PROBLEMS_GETTING_PASSWORD
	dump("defined", 1);
	if ((PEM_R_PROBLEMS_GETTING_PASSWORD) <= 0) {
	    long long x = (long long)(PEM_R_PROBLEMS_GETTING_PASSWORD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_PROBLEMS_GETTING_PASSWORD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PROBLEMS_MAPPING_CIPHER_FUNCTIONS(void) {
#ifdef SSL_R_PROBLEMS_MAPPING_CIPHER_FUNCTIONS
	dump("defined", 1);
	if ((SSL_R_PROBLEMS_MAPPING_CIPHER_FUNCTIONS) <= 0) {
	    long long x = (long long)(SSL_R_PROBLEMS_MAPPING_CIPHER_FUNCTIONS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PROBLEMS_MAPPING_CIPHER_FUNCTIONS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PROTOCOL_IS_SHUTDOWN(void) {
#ifdef SSL_R_PROTOCOL_IS_SHUTDOWN
	dump("defined", 1);
	if ((SSL_R_PROTOCOL_IS_SHUTDOWN) <= 0) {
	    long long x = (long long)(SSL_R_PROTOCOL_IS_SHUTDOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PROTOCOL_IS_SHUTDOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PROTOCOL_VERSION(void) {
#ifdef SSL_AD_PROTOCOL_VERSION
	dump("defined", 1);
	if ((SSL_AD_PROTOCOL_VERSION) <= 0) {
	    long long x = (long long)(SSL_AD_PROTOCOL_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_PROTOCOL_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PSK_IDENTITY_NOT_FOUND(void) {
#ifdef SSL_R_PSK_IDENTITY_NOT_FOUND
	dump("defined", 1);
	if ((SSL_R_PSK_IDENTITY_NOT_FOUND) <= 0) {
	    long long x = (long long)(SSL_R_PSK_IDENTITY_NOT_FOUND);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PSK_IDENTITY_NOT_FOUND);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PSK_NO_CLIENT_CB(void) {
#ifdef SSL_R_PSK_NO_CLIENT_CB
	dump("defined", 1);
	if ((SSL_R_PSK_NO_CLIENT_CB) <= 0) {
	    long long x = (long long)(SSL_R_PSK_NO_CLIENT_CB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PSK_NO_CLIENT_CB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PSK_NO_SERVER_CB(void) {
#ifdef SSL_R_PSK_NO_SERVER_CB
	dump("defined", 1);
	if ((SSL_R_PSK_NO_SERVER_CB) <= 0) {
	    long long x = (long long)(SSL_R_PSK_NO_SERVER_CB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PSK_NO_SERVER_CB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PUBLIC_KEY_DECODE_ERROR(void) {
#ifdef X509_R_PUBLIC_KEY_DECODE_ERROR
	dump("defined", 1);
	if ((X509_R_PUBLIC_KEY_DECODE_ERROR) <= 0) {
	    long long x = (long long)(X509_R_PUBLIC_KEY_DECODE_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_PUBLIC_KEY_DECODE_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PUBLIC_KEY_ENCODE_ERROR(void) {
#ifdef X509_R_PUBLIC_KEY_ENCODE_ERROR
	dump("defined", 1);
	if ((X509_R_PUBLIC_KEY_ENCODE_ERROR) <= 0) {
	    long long x = (long long)(X509_R_PUBLIC_KEY_ENCODE_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_PUBLIC_KEY_ENCODE_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PUBLIC_KEY_ENCRYPT_ERROR(void) {
#ifdef SSL_R_PUBLIC_KEY_ENCRYPT_ERROR
	dump("defined", 1);
	if ((SSL_R_PUBLIC_KEY_ENCRYPT_ERROR) <= 0) {
	    long long x = (long long)(SSL_R_PUBLIC_KEY_ENCRYPT_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PUBLIC_KEY_ENCRYPT_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PUBLIC_KEY_IS_NOT_RSA(void) {
#ifdef SSL_R_PUBLIC_KEY_IS_NOT_RSA
	dump("defined", 1);
	if ((SSL_R_PUBLIC_KEY_IS_NOT_RSA) <= 0) {
	    long long x = (long long)(SSL_R_PUBLIC_KEY_IS_NOT_RSA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PUBLIC_KEY_IS_NOT_RSA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PUBLIC_KEY_NOT_RSA(void) {
#ifdef SSL_R_PUBLIC_KEY_NOT_RSA
	dump("defined", 1);
	if ((SSL_R_PUBLIC_KEY_NOT_RSA) <= 0) {
	    long long x = (long long)(SSL_R_PUBLIC_KEY_NOT_RSA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_PUBLIC_KEY_NOT_RSA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PUBLIC_KEY_NO_RSA(void) {
#ifdef PEM_R_PUBLIC_KEY_NO_RSA
	dump("defined", 1);
	if ((PEM_R_PUBLIC_KEY_NO_RSA) <= 0) {
	    long long x = (long long)(PEM_R_PUBLIC_KEY_NO_RSA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_PUBLIC_KEY_NO_RSA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PVK_DATA_TOO_SHORT(void) {
#ifdef PEM_R_PVK_DATA_TOO_SHORT
	dump("defined", 1);
	if ((PEM_R_PVK_DATA_TOO_SHORT) <= 0) {
	    long long x = (long long)(PEM_R_PVK_DATA_TOO_SHORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_PVK_DATA_TOO_SHORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_PVK_TOO_SHORT(void) {
#ifdef PEM_R_PVK_TOO_SHORT
	dump("defined", 1);
	if ((PEM_R_PVK_TOO_SHORT) <= 0) {
	    long long x = (long long)(PEM_R_PVK_TOO_SHORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_PVK_TOO_SHORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_READ_BIO_NOT_SET(void) {
#ifdef SSL_R_READ_BIO_NOT_SET
	dump("defined", 1);
	if ((SSL_R_READ_BIO_NOT_SET) <= 0) {
	    long long x = (long long)(SSL_R_READ_BIO_NOT_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_READ_BIO_NOT_SET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_READ_KEY(void) {
#ifdef PEM_R_READ_KEY
	dump("defined", 1);
	if ((PEM_R_READ_KEY) <= 0) {
	    long long x = (long long)(PEM_R_READ_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_READ_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_READ_TIMEOUT_EXPIRED(void) {
#ifdef SSL_R_READ_TIMEOUT_EXPIRED
	dump("defined", 1);
	if ((SSL_R_READ_TIMEOUT_EXPIRED) <= 0) {
	    long long x = (long long)(SSL_R_READ_TIMEOUT_EXPIRED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_READ_TIMEOUT_EXPIRED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_READ_WRONG_PACKET_TYPE(void) {
#ifdef SSL_R_READ_WRONG_PACKET_TYPE
	dump("defined", 1);
	if ((SSL_R_READ_WRONG_PACKET_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_READ_WRONG_PACKET_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_READ_WRONG_PACKET_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RECORD_LENGTH_MISMATCH(void) {
#ifdef SSL_R_RECORD_LENGTH_MISMATCH
	dump("defined", 1);
	if ((SSL_R_RECORD_LENGTH_MISMATCH) <= 0) {
	    long long x = (long long)(SSL_R_RECORD_LENGTH_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_RECORD_LENGTH_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RECORD_OVERFLOW(void) {
#ifdef SSL_AD_RECORD_OVERFLOW
	dump("defined", 1);
	if ((SSL_AD_RECORD_OVERFLOW) <= 0) {
	    long long x = (long long)(SSL_AD_RECORD_OVERFLOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_RECORD_OVERFLOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RECORD_TOO_LARGE(void) {
#ifdef SSL_R_RECORD_TOO_LARGE
	dump("defined", 1);
	if ((SSL_R_RECORD_TOO_LARGE) <= 0) {
	    long long x = (long long)(SSL_R_RECORD_TOO_LARGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_RECORD_TOO_LARGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RECORD_TOO_SMALL(void) {
#ifdef SSL_R_RECORD_TOO_SMALL
	dump("defined", 1);
	if ((SSL_R_RECORD_TOO_SMALL) <= 0) {
	    long long x = (long long)(SSL_R_RECORD_TOO_SMALL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_RECORD_TOO_SMALL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RENEGOTIATE_EXT_TOO_LONG(void) {
#ifdef SSL_R_RENEGOTIATE_EXT_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_RENEGOTIATE_EXT_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_RENEGOTIATE_EXT_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_RENEGOTIATE_EXT_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RENEGOTIATION_ENCODING_ERR(void) {
#ifdef SSL_R_RENEGOTIATION_ENCODING_ERR
	dump("defined", 1);
	if ((SSL_R_RENEGOTIATION_ENCODING_ERR) <= 0) {
	    long long x = (long long)(SSL_R_RENEGOTIATION_ENCODING_ERR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_RENEGOTIATION_ENCODING_ERR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_RENEGOTIATION_MISMATCH(void) {
#ifdef SSL_R_RENEGOTIATION_MISMATCH
	dump("defined", 1);
	if ((SSL_R_RENEGOTIATION_MISMATCH) <= 0) {
	    long long x = (long long)(SSL_R_RENEGOTIATION_MISMATCH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_RENEGOTIATION_MISMATCH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_REQUIRED_CIPHER_MISSING(void) {
#ifdef SSL_R_REQUIRED_CIPHER_MISSING
	dump("defined", 1);
	if ((SSL_R_REQUIRED_CIPHER_MISSING) <= 0) {
	    long long x = (long long)(SSL_R_REQUIRED_CIPHER_MISSING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_REQUIRED_CIPHER_MISSING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_REQUIRED_COMPRESSSION_ALGORITHM_MISSING(void) {
#ifdef SSL_R_REQUIRED_COMPRESSSION_ALGORITHM_MISSING
	dump("defined", 1);
	if ((SSL_R_REQUIRED_COMPRESSSION_ALGORITHM_MISSING) <= 0) {
	    long long x = (long long)(SSL_R_REQUIRED_COMPRESSSION_ALGORITHM_MISSING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_REQUIRED_COMPRESSSION_ALGORITHM_MISSING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_REUSE_CERT_LENGTH_NOT_ZERO(void) {
#ifdef SSL_R_REUSE_CERT_LENGTH_NOT_ZERO
	dump("defined", 1);
	if ((SSL_R_REUSE_CERT_LENGTH_NOT_ZERO) <= 0) {
	    long long x = (long long)(SSL_R_REUSE_CERT_LENGTH_NOT_ZERO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_REUSE_CERT_LENGTH_NOT_ZERO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_REUSE_CERT_TYPE_NOT_ZERO(void) {
#ifdef SSL_R_REUSE_CERT_TYPE_NOT_ZERO
	dump("defined", 1);
	if ((SSL_R_REUSE_CERT_TYPE_NOT_ZERO) <= 0) {
	    long long x = (long long)(SSL_R_REUSE_CERT_TYPE_NOT_ZERO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_REUSE_CERT_TYPE_NOT_ZERO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_REUSE_CIPHER_LIST_NOT_ZERO(void) {
#ifdef SSL_R_REUSE_CIPHER_LIST_NOT_ZERO
	dump("defined", 1);
	if ((SSL_R_REUSE_CIPHER_LIST_NOT_ZERO) <= 0) {
	    long long x = (long long)(SSL_R_REUSE_CIPHER_LIST_NOT_ZERO);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_REUSE_CIPHER_LIST_NOT_ZERO);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SCSV_RECEIVED_WHEN_RENEGOTIATING(void) {
#ifdef SSL_R_SCSV_RECEIVED_WHEN_RENEGOTIATING
	dump("defined", 1);
	if ((SSL_R_SCSV_RECEIVED_WHEN_RENEGOTIATING) <= 0) {
	    long long x = (long long)(SSL_R_SCSV_RECEIVED_WHEN_RENEGOTIATING);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SCSV_RECEIVED_WHEN_RENEGOTIATING);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SERVERHELLO_TLSEXT(void) {
#ifdef SSL_R_SERVERHELLO_TLSEXT
	dump("defined", 1);
	if ((SSL_R_SERVERHELLO_TLSEXT) <= 0) {
	    long long x = (long long)(SSL_R_SERVERHELLO_TLSEXT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SERVERHELLO_TLSEXT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SESSION_ID_CONTEXT_UNINITIALIZED(void) {
#ifdef SSL_R_SESSION_ID_CONTEXT_UNINITIALIZED
	dump("defined", 1);
	if ((SSL_R_SESSION_ID_CONTEXT_UNINITIALIZED) <= 0) {
	    long long x = (long long)(SSL_R_SESSION_ID_CONTEXT_UNINITIALIZED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SESSION_ID_CONTEXT_UNINITIALIZED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SHORT_HEADER(void) {
#ifdef PEM_R_SHORT_HEADER
	dump("defined", 1);
	if ((PEM_R_SHORT_HEADER) <= 0) {
	    long long x = (long long)(PEM_R_SHORT_HEADER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_SHORT_HEADER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SHORT_READ(void) {
#ifdef SSL_R_SHORT_READ
	dump("defined", 1);
	if ((SSL_R_SHORT_READ) <= 0) {
	    long long x = (long long)(SSL_R_SHORT_READ);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SHORT_READ);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SHOULD_RETRY(void) {
#ifdef X509_R_SHOULD_RETRY
	dump("defined", 1);
	if ((X509_R_SHOULD_RETRY) <= 0) {
	    long long x = (long long)(X509_R_SHOULD_RETRY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_SHOULD_RETRY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SIGNATURE_FOR_NON_SIGNING_CERTIFICATE(void) {
#ifdef SSL_R_SIGNATURE_FOR_NON_SIGNING_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_SIGNATURE_FOR_NON_SIGNING_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_SIGNATURE_FOR_NON_SIGNING_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SIGNATURE_FOR_NON_SIGNING_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL(void) {
	if ((ERR_LIB_SSL) <= 0) {
	    long long x = (long long)(ERR_LIB_SSL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_SSL);
	    printf("value: %llu\n", x);
	}
}

void dump_section_SSL23_DOING_SESSION_ID_REUSE(void) {
#ifdef SSL_R_SSL23_DOING_SESSION_ID_REUSE
	dump("defined", 1);
	if ((SSL_R_SSL23_DOING_SESSION_ID_REUSE) <= 0) {
	    long long x = (long long)(SSL_R_SSL23_DOING_SESSION_ID_REUSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL23_DOING_SESSION_ID_REUSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL2_CONNECTION_ID_TOO_LONG(void) {
#ifdef SSL_R_SSL2_CONNECTION_ID_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_SSL2_CONNECTION_ID_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_SSL2_CONNECTION_ID_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL2_CONNECTION_ID_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL3_EXT_INVALID_ECPOINTFORMAT(void) {
#ifdef SSL_R_SSL3_EXT_INVALID_ECPOINTFORMAT
	dump("defined", 1);
	if ((SSL_R_SSL3_EXT_INVALID_ECPOINTFORMAT) <= 0) {
	    long long x = (long long)(SSL_R_SSL3_EXT_INVALID_ECPOINTFORMAT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL3_EXT_INVALID_ECPOINTFORMAT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL3_EXT_INVALID_SERVERNAME(void) {
#ifdef SSL_R_SSL3_EXT_INVALID_SERVERNAME
	dump("defined", 1);
	if ((SSL_R_SSL3_EXT_INVALID_SERVERNAME) <= 0) {
	    long long x = (long long)(SSL_R_SSL3_EXT_INVALID_SERVERNAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL3_EXT_INVALID_SERVERNAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL3_EXT_INVALID_SERVERNAME_TYPE(void) {
#ifdef SSL_R_SSL3_EXT_INVALID_SERVERNAME_TYPE
	dump("defined", 1);
	if ((SSL_R_SSL3_EXT_INVALID_SERVERNAME_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_SSL3_EXT_INVALID_SERVERNAME_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL3_EXT_INVALID_SERVERNAME_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL3_SESSION_ID_TOO_LONG(void) {
#ifdef SSL_R_SSL3_SESSION_ID_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_SSL3_SESSION_ID_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_SSL3_SESSION_ID_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL3_SESSION_ID_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL3_SESSION_ID_TOO_SHORT(void) {
#ifdef SSL_R_SSL3_SESSION_ID_TOO_SHORT
	dump("defined", 1);
	if ((SSL_R_SSL3_SESSION_ID_TOO_SHORT) <= 0) {
	    long long x = (long long)(SSL_R_SSL3_SESSION_ID_TOO_SHORT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL3_SESSION_ID_TOO_SHORT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_BAD_CERTIFICATE(void) {
#ifdef SSL_R_SSLV3_ALERT_BAD_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_BAD_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_BAD_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_BAD_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_BAD_RECORD_MAC(void) {
#ifdef SSL_R_SSLV3_ALERT_BAD_RECORD_MAC
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_BAD_RECORD_MAC) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_BAD_RECORD_MAC);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_BAD_RECORD_MAC);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_CERTIFICATE_EXPIRED(void) {
#ifdef SSL_R_SSLV3_ALERT_CERTIFICATE_EXPIRED
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_CERTIFICATE_EXPIRED) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_CERTIFICATE_EXPIRED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_CERTIFICATE_EXPIRED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_CERTIFICATE_REVOKED(void) {
#ifdef SSL_R_SSLV3_ALERT_CERTIFICATE_REVOKED
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_CERTIFICATE_REVOKED) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_CERTIFICATE_REVOKED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_CERTIFICATE_REVOKED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_CERTIFICATE_UNKNOWN(void) {
#ifdef SSL_R_SSLV3_ALERT_CERTIFICATE_UNKNOWN
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_CERTIFICATE_UNKNOWN) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_CERTIFICATE_UNKNOWN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_CERTIFICATE_UNKNOWN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_DECOMPRESSION_FAILURE(void) {
#ifdef SSL_R_SSLV3_ALERT_DECOMPRESSION_FAILURE
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_DECOMPRESSION_FAILURE) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_DECOMPRESSION_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_DECOMPRESSION_FAILURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_HANDSHAKE_FAILURE(void) {
#ifdef SSL_R_SSLV3_ALERT_HANDSHAKE_FAILURE
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_HANDSHAKE_FAILURE) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_HANDSHAKE_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_HANDSHAKE_FAILURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_ILLEGAL_PARAMETER(void) {
#ifdef SSL_R_SSLV3_ALERT_ILLEGAL_PARAMETER
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_ILLEGAL_PARAMETER) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_ILLEGAL_PARAMETER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_ILLEGAL_PARAMETER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_NO_CERTIFICATE(void) {
#ifdef SSL_R_SSLV3_ALERT_NO_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_NO_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_NO_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_NO_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_UNEXPECTED_MESSAGE(void) {
#ifdef SSL_R_SSLV3_ALERT_UNEXPECTED_MESSAGE
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_UNEXPECTED_MESSAGE) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_UNEXPECTED_MESSAGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_UNEXPECTED_MESSAGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSLV3_ALERT_UNSUPPORTED_CERTIFICATE(void) {
#ifdef SSL_R_SSLV3_ALERT_UNSUPPORTED_CERTIFICATE
	dump("defined", 1);
	if ((SSL_R_SSLV3_ALERT_UNSUPPORTED_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_R_SSLV3_ALERT_UNSUPPORTED_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSLV3_ALERT_UNSUPPORTED_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION(void) {
#ifdef SSL_R_SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION
	dump("defined", 1);
	if ((SSL_R_SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION) <= 0) {
	    long long x = (long long)(SSL_R_SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_HANDSHAKE_FAILURE(void) {
#ifdef SSL_R_SSL_HANDSHAKE_FAILURE
	dump("defined", 1);
	if ((SSL_R_SSL_HANDSHAKE_FAILURE) <= 0) {
	    long long x = (long long)(SSL_R_SSL_HANDSHAKE_FAILURE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_HANDSHAKE_FAILURE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_LIBRARY_HAS_NO_CIPHERS(void) {
#ifdef SSL_R_SSL_LIBRARY_HAS_NO_CIPHERS
	dump("defined", 1);
	if ((SSL_R_SSL_LIBRARY_HAS_NO_CIPHERS) <= 0) {
	    long long x = (long long)(SSL_R_SSL_LIBRARY_HAS_NO_CIPHERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_LIBRARY_HAS_NO_CIPHERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_SESSION_ID_CALLBACK_FAILED(void) {
#ifdef SSL_R_SSL_SESSION_ID_CALLBACK_FAILED
	dump("defined", 1);
	if ((SSL_R_SSL_SESSION_ID_CALLBACK_FAILED) <= 0) {
	    long long x = (long long)(SSL_R_SSL_SESSION_ID_CALLBACK_FAILED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_SESSION_ID_CALLBACK_FAILED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_SESSION_ID_CONFLICT(void) {
#ifdef SSL_R_SSL_SESSION_ID_CONFLICT
	dump("defined", 1);
	if ((SSL_R_SSL_SESSION_ID_CONFLICT) <= 0) {
	    long long x = (long long)(SSL_R_SSL_SESSION_ID_CONFLICT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_SESSION_ID_CONFLICT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_SESSION_ID_CONTEXT_TOO_LONG(void) {
#ifdef SSL_R_SSL_SESSION_ID_CONTEXT_TOO_LONG
	dump("defined", 1);
	if ((SSL_R_SSL_SESSION_ID_CONTEXT_TOO_LONG) <= 0) {
	    long long x = (long long)(SSL_R_SSL_SESSION_ID_CONTEXT_TOO_LONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_SESSION_ID_CONTEXT_TOO_LONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_SESSION_ID_HAS_BAD_LENGTH(void) {
#ifdef SSL_R_SSL_SESSION_ID_HAS_BAD_LENGTH
	dump("defined", 1);
	if ((SSL_R_SSL_SESSION_ID_HAS_BAD_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_SSL_SESSION_ID_HAS_BAD_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_SESSION_ID_HAS_BAD_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_SSL_SESSION_ID_IS_DIFFERENT(void) {
#ifdef SSL_R_SSL_SESSION_ID_IS_DIFFERENT
	dump("defined", 1);
	if ((SSL_R_SSL_SESSION_ID_IS_DIFFERENT) <= 0) {
	    long long x = (long long)(SSL_R_SSL_SESSION_ID_IS_DIFFERENT);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_SSL_SESSION_ID_IS_DIFFERENT);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_ACCESS_DENIED(void) {
#ifdef SSL_R_TLSV1_ALERT_ACCESS_DENIED
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_ACCESS_DENIED) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_ACCESS_DENIED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_ACCESS_DENIED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_DECODE_ERROR(void) {
#ifdef SSL_R_TLSV1_ALERT_DECODE_ERROR
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_DECODE_ERROR) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_DECODE_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_DECODE_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_DECRYPTION_FAILED(void) {
#ifdef SSL_R_TLSV1_ALERT_DECRYPTION_FAILED
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_DECRYPTION_FAILED) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_DECRYPTION_FAILED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_DECRYPTION_FAILED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_DECRYPT_ERROR(void) {
#ifdef SSL_R_TLSV1_ALERT_DECRYPT_ERROR
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_DECRYPT_ERROR) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_DECRYPT_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_DECRYPT_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_EXPORT_RESTRICTION(void) {
#ifdef SSL_R_TLSV1_ALERT_EXPORT_RESTRICTION
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_EXPORT_RESTRICTION) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_EXPORT_RESTRICTION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_EXPORT_RESTRICTION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_INSUFFICIENT_SECURITY(void) {
#ifdef SSL_R_TLSV1_ALERT_INSUFFICIENT_SECURITY
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_INSUFFICIENT_SECURITY) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_INSUFFICIENT_SECURITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_INSUFFICIENT_SECURITY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_INTERNAL_ERROR(void) {
#ifdef SSL_R_TLSV1_ALERT_INTERNAL_ERROR
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_INTERNAL_ERROR) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_INTERNAL_ERROR);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_INTERNAL_ERROR);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_NO_RENEGOTIATION(void) {
#ifdef SSL_R_TLSV1_ALERT_NO_RENEGOTIATION
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_NO_RENEGOTIATION) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_NO_RENEGOTIATION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_NO_RENEGOTIATION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_PROTOCOL_VERSION(void) {
#ifdef SSL_R_TLSV1_ALERT_PROTOCOL_VERSION
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_PROTOCOL_VERSION) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_PROTOCOL_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_PROTOCOL_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_RECORD_OVERFLOW(void) {
#ifdef SSL_R_TLSV1_ALERT_RECORD_OVERFLOW
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_RECORD_OVERFLOW) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_RECORD_OVERFLOW);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_RECORD_OVERFLOW);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_UNKNOWN_CA(void) {
#ifdef SSL_R_TLSV1_ALERT_UNKNOWN_CA
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_UNKNOWN_CA) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_UNKNOWN_CA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_UNKNOWN_CA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_ALERT_USER_CANCELLED(void) {
#ifdef SSL_R_TLSV1_ALERT_USER_CANCELLED
	dump("defined", 1);
	if ((SSL_R_TLSV1_ALERT_USER_CANCELLED) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_ALERT_USER_CANCELLED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_ALERT_USER_CANCELLED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_BAD_CERTIFICATE_HASH_VALUE(void) {
#ifdef SSL_R_TLSV1_BAD_CERTIFICATE_HASH_VALUE
	dump("defined", 1);
	if ((SSL_R_TLSV1_BAD_CERTIFICATE_HASH_VALUE) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_BAD_CERTIFICATE_HASH_VALUE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_BAD_CERTIFICATE_HASH_VALUE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE(void) {
#ifdef SSL_R_TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE
	dump("defined", 1);
	if ((SSL_R_TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_CERTIFICATE_UNOBTAINABLE(void) {
#ifdef SSL_R_TLSV1_CERTIFICATE_UNOBTAINABLE
	dump("defined", 1);
	if ((SSL_R_TLSV1_CERTIFICATE_UNOBTAINABLE) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_CERTIFICATE_UNOBTAINABLE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_CERTIFICATE_UNOBTAINABLE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_UNRECOGNIZED_NAME(void) {
#ifdef SSL_R_TLSV1_UNRECOGNIZED_NAME
	dump("defined", 1);
	if ((SSL_R_TLSV1_UNRECOGNIZED_NAME) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_UNRECOGNIZED_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_UNRECOGNIZED_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLSV1_UNSUPPORTED_EXTENSION(void) {
#ifdef SSL_R_TLSV1_UNSUPPORTED_EXTENSION
	dump("defined", 1);
	if ((SSL_R_TLSV1_UNSUPPORTED_EXTENSION) <= 0) {
	    long long x = (long long)(SSL_R_TLSV1_UNSUPPORTED_EXTENSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLSV1_UNSUPPORTED_EXTENSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLS_CLIENT_CERT_REQ_WITH_ANON_CIPHER(void) {
#ifdef SSL_R_TLS_CLIENT_CERT_REQ_WITH_ANON_CIPHER
	dump("defined", 1);
	if ((SSL_R_TLS_CLIENT_CERT_REQ_WITH_ANON_CIPHER) <= 0) {
	    long long x = (long long)(SSL_R_TLS_CLIENT_CERT_REQ_WITH_ANON_CIPHER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLS_CLIENT_CERT_REQ_WITH_ANON_CIPHER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLS_INVALID_ECPOINTFORMAT_LIST(void) {
#ifdef SSL_R_TLS_INVALID_ECPOINTFORMAT_LIST
	dump("defined", 1);
	if ((SSL_R_TLS_INVALID_ECPOINTFORMAT_LIST) <= 0) {
	    long long x = (long long)(SSL_R_TLS_INVALID_ECPOINTFORMAT_LIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLS_INVALID_ECPOINTFORMAT_LIST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLS_PEER_DID_NOT_RESPOND_WITH_CERTIFICATE_LIST(void) {
#ifdef SSL_R_TLS_PEER_DID_NOT_RESPOND_WITH_CERTIFICATE_LIST
	dump("defined", 1);
	if ((SSL_R_TLS_PEER_DID_NOT_RESPOND_WITH_CERTIFICATE_LIST) <= 0) {
	    long long x = (long long)(SSL_R_TLS_PEER_DID_NOT_RESPOND_WITH_CERTIFICATE_LIST);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLS_PEER_DID_NOT_RESPOND_WITH_CERTIFICATE_LIST);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TLS_RSA_ENCRYPTED_VALUE_LENGTH_IS_WRONG(void) {
#ifdef SSL_R_TLS_RSA_ENCRYPTED_VALUE_LENGTH_IS_WRONG
	dump("defined", 1);
	if ((SSL_R_TLS_RSA_ENCRYPTED_VALUE_LENGTH_IS_WRONG) <= 0) {
	    long long x = (long long)(SSL_R_TLS_RSA_ENCRYPTED_VALUE_LENGTH_IS_WRONG);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TLS_RSA_ENCRYPTED_VALUE_LENGTH_IS_WRONG);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_TRIED_TO_USE_UNSUPPORTED_CIPHER(void) {
#ifdef SSL_R_TRIED_TO_USE_UNSUPPORTED_CIPHER
	dump("defined", 1);
	if ((SSL_R_TRIED_TO_USE_UNSUPPORTED_CIPHER) <= 0) {
	    long long x = (long long)(SSL_R_TRIED_TO_USE_UNSUPPORTED_CIPHER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_TRIED_TO_USE_UNSUPPORTED_CIPHER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_DECODE_DH_CERTS(void) {
#ifdef SSL_R_UNABLE_TO_DECODE_DH_CERTS
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_DECODE_DH_CERTS) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_DECODE_DH_CERTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_DECODE_DH_CERTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_DECODE_ECDH_CERTS(void) {
#ifdef SSL_R_UNABLE_TO_DECODE_ECDH_CERTS
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_DECODE_ECDH_CERTS) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_DECODE_ECDH_CERTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_DECODE_ECDH_CERTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_EXTRACT_PUBLIC_KEY(void) {
#ifdef SSL_R_UNABLE_TO_EXTRACT_PUBLIC_KEY
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_EXTRACT_PUBLIC_KEY) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_EXTRACT_PUBLIC_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_EXTRACT_PUBLIC_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_FIND_DH_PARAMETERS(void) {
#ifdef SSL_R_UNABLE_TO_FIND_DH_PARAMETERS
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_FIND_DH_PARAMETERS) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_FIND_DH_PARAMETERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_FIND_DH_PARAMETERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_FIND_ECDH_PARAMETERS(void) {
#ifdef SSL_R_UNABLE_TO_FIND_ECDH_PARAMETERS
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_FIND_ECDH_PARAMETERS) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_FIND_ECDH_PARAMETERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_FIND_ECDH_PARAMETERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_FIND_PARAMETERS_IN_CHAIN(void) {
#ifdef X509_R_UNABLE_TO_FIND_PARAMETERS_IN_CHAIN
	dump("defined", 1);
	if ((X509_R_UNABLE_TO_FIND_PARAMETERS_IN_CHAIN) <= 0) {
	    long long x = (long long)(X509_R_UNABLE_TO_FIND_PARAMETERS_IN_CHAIN);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_UNABLE_TO_FIND_PARAMETERS_IN_CHAIN);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS(void) {
#ifdef SSL_R_UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_FIND_SSL_METHOD(void) {
#ifdef SSL_R_UNABLE_TO_FIND_SSL_METHOD
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_FIND_SSL_METHOD) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_FIND_SSL_METHOD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_FIND_SSL_METHOD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_GET_CERTS_PUBLIC_KEY(void) {
#ifdef X509_R_UNABLE_TO_GET_CERTS_PUBLIC_KEY
	dump("defined", 1);
	if ((X509_R_UNABLE_TO_GET_CERTS_PUBLIC_KEY) <= 0) {
	    long long x = (long long)(X509_R_UNABLE_TO_GET_CERTS_PUBLIC_KEY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_UNABLE_TO_GET_CERTS_PUBLIC_KEY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_LOAD_SSL2_MD5_ROUTINES(void) {
#ifdef SSL_R_UNABLE_TO_LOAD_SSL2_MD5_ROUTINES
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_LOAD_SSL2_MD5_ROUTINES) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_LOAD_SSL2_MD5_ROUTINES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_LOAD_SSL2_MD5_ROUTINES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_LOAD_SSL3_MD5_ROUTINES(void) {
#ifdef SSL_R_UNABLE_TO_LOAD_SSL3_MD5_ROUTINES
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_LOAD_SSL3_MD5_ROUTINES) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_LOAD_SSL3_MD5_ROUTINES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_LOAD_SSL3_MD5_ROUTINES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES(void) {
#ifdef SSL_R_UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES
	dump("defined", 1);
	if ((SSL_R_UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES) <= 0) {
	    long long x = (long long)(SSL_R_UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNEXPECTED_MESSAGE(void) {
#ifdef SSL_AD_UNEXPECTED_MESSAGE
	dump("defined", 1);
	if ((SSL_AD_UNEXPECTED_MESSAGE) <= 0) {
	    long long x = (long long)(SSL_AD_UNEXPECTED_MESSAGE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_UNEXPECTED_MESSAGE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNEXPECTED_RECORD(void) {
#ifdef SSL_R_UNEXPECTED_RECORD
	dump("defined", 1);
	if ((SSL_R_UNEXPECTED_RECORD) <= 0) {
	    long long x = (long long)(SSL_R_UNEXPECTED_RECORD);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNEXPECTED_RECORD);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNINITIALIZED(void) {
#ifdef SSL_R_UNINITIALIZED
	dump("defined", 1);
	if ((SSL_R_UNINITIALIZED) <= 0) {
	    long long x = (long long)(SSL_R_UNINITIALIZED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNINITIALIZED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_ALERT_TYPE(void) {
#ifdef SSL_R_UNKNOWN_ALERT_TYPE
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_ALERT_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_ALERT_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_ALERT_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_CA(void) {
#ifdef SSL_AD_UNKNOWN_CA
	dump("defined", 1);
	if ((SSL_AD_UNKNOWN_CA) <= 0) {
	    long long x = (long long)(SSL_AD_UNKNOWN_CA);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_UNKNOWN_CA);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_CERTIFICATE_TYPE(void) {
#ifdef SSL_R_UNKNOWN_CERTIFICATE_TYPE
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_CERTIFICATE_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_CERTIFICATE_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_CERTIFICATE_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_CIPHER_RETURNED(void) {
#ifdef SSL_R_UNKNOWN_CIPHER_RETURNED
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_CIPHER_RETURNED) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_CIPHER_RETURNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_CIPHER_RETURNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_CIPHER_TYPE(void) {
#ifdef SSL_R_UNKNOWN_CIPHER_TYPE
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_CIPHER_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_CIPHER_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_CIPHER_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_KEY_EXCHANGE_TYPE(void) {
#ifdef SSL_R_UNKNOWN_KEY_EXCHANGE_TYPE
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_KEY_EXCHANGE_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_KEY_EXCHANGE_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_KEY_EXCHANGE_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_KEY_TYPE(void) {
#ifdef X509_R_UNKNOWN_KEY_TYPE
	dump("defined", 1);
	if ((X509_R_UNKNOWN_KEY_TYPE) <= 0) {
	    long long x = (long long)(X509_R_UNKNOWN_KEY_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_UNKNOWN_KEY_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_NID(void) {
#ifdef X509_R_UNKNOWN_NID
	dump("defined", 1);
	if ((X509_R_UNKNOWN_NID) <= 0) {
	    long long x = (long long)(X509_R_UNKNOWN_NID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_UNKNOWN_NID);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_PKEY_TYPE(void) {
#ifdef SSL_R_UNKNOWN_PKEY_TYPE
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_PKEY_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_PKEY_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_PKEY_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_PROTOCOL(void) {
#ifdef SSL_R_UNKNOWN_PROTOCOL
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_PROTOCOL) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_PROTOCOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_PROTOCOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_PSK_IDENTITY(void) {
#ifdef SSL_AD_UNKNOWN_PSK_IDENTITY
	dump("defined", 1);
	if ((SSL_AD_UNKNOWN_PSK_IDENTITY) <= 0) {
	    long long x = (long long)(SSL_AD_UNKNOWN_PSK_IDENTITY);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_UNKNOWN_PSK_IDENTITY);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_PURPOSE_ID(void) {
#ifdef X509_R_UNKNOWN_PURPOSE_ID
	dump("defined", 1);
	if ((X509_R_UNKNOWN_PURPOSE_ID) <= 0) {
	    long long x = (long long)(X509_R_UNKNOWN_PURPOSE_ID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_UNKNOWN_PURPOSE_ID);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_REMOTE_ERROR_TYPE(void) {
#ifdef SSL_R_UNKNOWN_REMOTE_ERROR_TYPE
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_REMOTE_ERROR_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_REMOTE_ERROR_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_REMOTE_ERROR_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_SSL_VERSION(void) {
#ifdef SSL_R_UNKNOWN_SSL_VERSION
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_SSL_VERSION) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_SSL_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_SSL_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_STATE(void) {
#ifdef SSL_R_UNKNOWN_STATE
	dump("defined", 1);
	if ((SSL_R_UNKNOWN_STATE) <= 0) {
	    long long x = (long long)(SSL_R_UNKNOWN_STATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNKNOWN_STATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNKNOWN_TRUST_ID(void) {
#ifdef X509_R_UNKNOWN_TRUST_ID
	dump("defined", 1);
	if ((X509_R_UNKNOWN_TRUST_ID) <= 0) {
	    long long x = (long long)(X509_R_UNKNOWN_TRUST_ID);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_UNKNOWN_TRUST_ID);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNRECOGNIZED_NAME(void) {
#ifdef SSL_AD_UNRECOGNIZED_NAME
	dump("defined", 1);
	if ((SSL_AD_UNRECOGNIZED_NAME) <= 0) {
	    long long x = (long long)(SSL_AD_UNRECOGNIZED_NAME);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_UNRECOGNIZED_NAME);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSAFE_LEGACY_RENEGOTIATION_DISABLED(void) {
#ifdef SSL_R_UNSAFE_LEGACY_RENEGOTIATION_DISABLED
	dump("defined", 1);
	if ((SSL_R_UNSAFE_LEGACY_RENEGOTIATION_DISABLED) <= 0) {
	    long long x = (long long)(SSL_R_UNSAFE_LEGACY_RENEGOTIATION_DISABLED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSAFE_LEGACY_RENEGOTIATION_DISABLED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_ALGORITHM(void) {
#ifdef X509_R_UNSUPPORTED_ALGORITHM
	dump("defined", 1);
	if ((X509_R_UNSUPPORTED_ALGORITHM) <= 0) {
	    long long x = (long long)(X509_R_UNSUPPORTED_ALGORITHM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_UNSUPPORTED_ALGORITHM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_CERTIFICATE(void) {
#ifdef SSL_AD_UNSUPPORTED_CERTIFICATE
	dump("defined", 1);
	if ((SSL_AD_UNSUPPORTED_CERTIFICATE) <= 0) {
	    long long x = (long long)(SSL_AD_UNSUPPORTED_CERTIFICATE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_UNSUPPORTED_CERTIFICATE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_CIPHER(void) {
#ifdef SSL_R_UNSUPPORTED_CIPHER
	dump("defined", 1);
	if ((SSL_R_UNSUPPORTED_CIPHER) <= 0) {
	    long long x = (long long)(SSL_R_UNSUPPORTED_CIPHER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSUPPORTED_CIPHER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_COMPRESSION_ALGORITHM(void) {
#ifdef SSL_R_UNSUPPORTED_COMPRESSION_ALGORITHM
	dump("defined", 1);
	if ((SSL_R_UNSUPPORTED_COMPRESSION_ALGORITHM) <= 0) {
	    long long x = (long long)(SSL_R_UNSUPPORTED_COMPRESSION_ALGORITHM);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSUPPORTED_COMPRESSION_ALGORITHM);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_DIGEST_TYPE(void) {
#ifdef SSL_R_UNSUPPORTED_DIGEST_TYPE
	dump("defined", 1);
	if ((SSL_R_UNSUPPORTED_DIGEST_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNSUPPORTED_DIGEST_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSUPPORTED_DIGEST_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_ELLIPTIC_CURVE(void) {
#ifdef SSL_R_UNSUPPORTED_ELLIPTIC_CURVE
	dump("defined", 1);
	if ((SSL_R_UNSUPPORTED_ELLIPTIC_CURVE) <= 0) {
	    long long x = (long long)(SSL_R_UNSUPPORTED_ELLIPTIC_CURVE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSUPPORTED_ELLIPTIC_CURVE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_ENCRYPTION(void) {
#ifdef PEM_R_UNSUPPORTED_ENCRYPTION
	dump("defined", 1);
	if ((PEM_R_UNSUPPORTED_ENCRYPTION) <= 0) {
	    long long x = (long long)(PEM_R_UNSUPPORTED_ENCRYPTION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_UNSUPPORTED_ENCRYPTION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_EXTENSION(void) {
#ifdef SSL_AD_UNSUPPORTED_EXTENSION
	dump("defined", 1);
	if ((SSL_AD_UNSUPPORTED_EXTENSION) <= 0) {
	    long long x = (long long)(SSL_AD_UNSUPPORTED_EXTENSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_UNSUPPORTED_EXTENSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_KEY_COMPONENTS(void) {
#ifdef PEM_R_UNSUPPORTED_KEY_COMPONENTS
	dump("defined", 1);
	if ((PEM_R_UNSUPPORTED_KEY_COMPONENTS) <= 0) {
	    long long x = (long long)(PEM_R_UNSUPPORTED_KEY_COMPONENTS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(PEM_R_UNSUPPORTED_KEY_COMPONENTS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_PROTOCOL(void) {
#ifdef SSL_R_UNSUPPORTED_PROTOCOL
	dump("defined", 1);
	if ((SSL_R_UNSUPPORTED_PROTOCOL) <= 0) {
	    long long x = (long long)(SSL_R_UNSUPPORTED_PROTOCOL);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSUPPORTED_PROTOCOL);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_SSL_VERSION(void) {
#ifdef SSL_R_UNSUPPORTED_SSL_VERSION
	dump("defined", 1);
	if ((SSL_R_UNSUPPORTED_SSL_VERSION) <= 0) {
	    long long x = (long long)(SSL_R_UNSUPPORTED_SSL_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSUPPORTED_SSL_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_UNSUPPORTED_STATUS_TYPE(void) {
#ifdef SSL_R_UNSUPPORTED_STATUS_TYPE
	dump("defined", 1);
	if ((SSL_R_UNSUPPORTED_STATUS_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_UNSUPPORTED_STATUS_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_UNSUPPORTED_STATUS_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_USER_CANCELLED(void) {
#ifdef SSL_AD_USER_CANCELLED
	dump("defined", 1);
	if ((SSL_AD_USER_CANCELLED) <= 0) {
	    long long x = (long long)(SSL_AD_USER_CANCELLED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_AD_USER_CANCELLED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRITE_BIO_NOT_SET(void) {
#ifdef SSL_R_WRITE_BIO_NOT_SET
	dump("defined", 1);
	if ((SSL_R_WRITE_BIO_NOT_SET) <= 0) {
	    long long x = (long long)(SSL_R_WRITE_BIO_NOT_SET);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRITE_BIO_NOT_SET);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_CIPHER_RETURNED(void) {
#ifdef SSL_R_WRONG_CIPHER_RETURNED
	dump("defined", 1);
	if ((SSL_R_WRONG_CIPHER_RETURNED) <= 0) {
	    long long x = (long long)(SSL_R_WRONG_CIPHER_RETURNED);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRONG_CIPHER_RETURNED);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_LOOKUP_TYPE(void) {
#ifdef X509_R_WRONG_LOOKUP_TYPE
	dump("defined", 1);
	if ((X509_R_WRONG_LOOKUP_TYPE) <= 0) {
	    long long x = (long long)(X509_R_WRONG_LOOKUP_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_WRONG_LOOKUP_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_MESSAGE_TYPE(void) {
#ifdef SSL_R_WRONG_MESSAGE_TYPE
	dump("defined", 1);
	if ((SSL_R_WRONG_MESSAGE_TYPE) <= 0) {
	    long long x = (long long)(SSL_R_WRONG_MESSAGE_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRONG_MESSAGE_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_NUMBER_OF_KEY_BITS(void) {
#ifdef SSL_R_WRONG_NUMBER_OF_KEY_BITS
	dump("defined", 1);
	if ((SSL_R_WRONG_NUMBER_OF_KEY_BITS) <= 0) {
	    long long x = (long long)(SSL_R_WRONG_NUMBER_OF_KEY_BITS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRONG_NUMBER_OF_KEY_BITS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_SIGNATURE_LENGTH(void) {
#ifdef SSL_R_WRONG_SIGNATURE_LENGTH
	dump("defined", 1);
	if ((SSL_R_WRONG_SIGNATURE_LENGTH) <= 0) {
	    long long x = (long long)(SSL_R_WRONG_SIGNATURE_LENGTH);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRONG_SIGNATURE_LENGTH);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_SIGNATURE_SIZE(void) {
#ifdef SSL_R_WRONG_SIGNATURE_SIZE
	dump("defined", 1);
	if ((SSL_R_WRONG_SIGNATURE_SIZE) <= 0) {
	    long long x = (long long)(SSL_R_WRONG_SIGNATURE_SIZE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRONG_SIGNATURE_SIZE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_SSL_VERSION(void) {
#ifdef SSL_R_WRONG_SSL_VERSION
	dump("defined", 1);
	if ((SSL_R_WRONG_SSL_VERSION) <= 0) {
	    long long x = (long long)(SSL_R_WRONG_SSL_VERSION);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRONG_SSL_VERSION);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_TYPE(void) {
#ifdef X509_R_WRONG_TYPE
	dump("defined", 1);
	if ((X509_R_WRONG_TYPE) <= 0) {
	    long long x = (long long)(X509_R_WRONG_TYPE);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(X509_R_WRONG_TYPE);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_WRONG_VERSION_NUMBER(void) {
#ifdef SSL_R_WRONG_VERSION_NUMBER
	dump("defined", 1);
	if ((SSL_R_WRONG_VERSION_NUMBER) <= 0) {
	    long long x = (long long)(SSL_R_WRONG_VERSION_NUMBER);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_WRONG_VERSION_NUMBER);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_X509(void) {
	if ((ERR_LIB_X509) <= 0) {
	    long long x = (long long)(ERR_LIB_X509);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(ERR_LIB_X509);
	    printf("value: %llu\n", x);
	}
}

void dump_section_X509_LIB(void) {
#ifdef SSL_R_X509_LIB
	dump("defined", 1);
	if ((SSL_R_X509_LIB) <= 0) {
	    long long x = (long long)(SSL_R_X509_LIB);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_X509_LIB);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

void dump_section_X509_VERIFICATION_SETUP_PROBLEMS(void) {
#ifdef SSL_R_X509_VERIFICATION_SETUP_PROBLEMS
	dump("defined", 1);
	if ((SSL_R_X509_VERIFICATION_SETUP_PROBLEMS) <= 0) {
	    long long x = (long long)(SSL_R_X509_VERIFICATION_SETUP_PROBLEMS);
	    printf("value: %lld\n", x);
	} else {
	    unsigned long long x = (unsigned long long)(SSL_R_X509_VERIFICATION_SETUP_PROBLEMS);
	    printf("value: %llu\n", x);
	}
#else
	dump("defined", 0);
#endif
}

int main(int argc, char *argv[]) {
	printf("-+- ACCESS_DENIED\n");
	dump_section_ACCESS_DENIED();
	printf("---\n");
	printf("-+- APP_DATA_IN_HANDSHAKE\n");
	dump_section_APP_DATA_IN_HANDSHAKE();
	printf("---\n");
	printf("-+- ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT\n");
	dump_section_ATTEMPT_TO_REUSE_SESSION_IN_DIFFERENT_CONTEXT();
	printf("---\n");
	printf("-+- BAD_ALERT_RECORD\n");
	dump_section_BAD_ALERT_RECORD();
	printf("---\n");
	printf("-+- BAD_AUTHENTICATION_TYPE\n");
	dump_section_BAD_AUTHENTICATION_TYPE();
	printf("---\n");
	printf("-+- BAD_BASE64_DECODE\n");
	dump_section_BAD_BASE64_DECODE();
	printf("---\n");
	printf("-+- BAD_CERTIFICATE\n");
	dump_section_BAD_CERTIFICATE();
	printf("---\n");
	printf("-+- BAD_CERTIFICATE_HASH_VALUE\n");
	dump_section_BAD_CERTIFICATE_HASH_VALUE();
	printf("---\n");
	printf("-+- BAD_CERTIFICATE_STATUS_RESPONSE\n");
	dump_section_BAD_CERTIFICATE_STATUS_RESPONSE();
	printf("---\n");
	printf("-+- BAD_CHANGE_CIPHER_SPEC\n");
	dump_section_BAD_CHANGE_CIPHER_SPEC();
	printf("---\n");
	printf("-+- BAD_CHECKSUM\n");
	dump_section_BAD_CHECKSUM();
	printf("---\n");
	printf("-+- BAD_DATA_RETURNED_BY_CALLBACK\n");
	dump_section_BAD_DATA_RETURNED_BY_CALLBACK();
	printf("---\n");
	printf("-+- BAD_DECOMPRESSION\n");
	dump_section_BAD_DECOMPRESSION();
	printf("---\n");
	printf("-+- BAD_DECRYPT\n");
	dump_section_BAD_DECRYPT();
	printf("---\n");
	printf("-+- BAD_DH_G_LENGTH\n");
	dump_section_BAD_DH_G_LENGTH();
	printf("---\n");
	printf("-+- BAD_DH_PUB_KEY_LENGTH\n");
	dump_section_BAD_DH_PUB_KEY_LENGTH();
	printf("---\n");
	printf("-+- BAD_DH_P_LENGTH\n");
	dump_section_BAD_DH_P_LENGTH();
	printf("---\n");
	printf("-+- BAD_DIGEST_LENGTH\n");
	dump_section_BAD_DIGEST_LENGTH();
	printf("---\n");
	printf("-+- BAD_DSA_SIGNATURE\n");
	dump_section_BAD_DSA_SIGNATURE();
	printf("---\n");
	printf("-+- BAD_ECC_CERT\n");
	dump_section_BAD_ECC_CERT();
	printf("---\n");
	printf("-+- BAD_ECDSA_SIGNATURE\n");
	dump_section_BAD_ECDSA_SIGNATURE();
	printf("---\n");
	printf("-+- BAD_ECPOINT\n");
	dump_section_BAD_ECPOINT();
	printf("---\n");
	printf("-+- BAD_END_LINE\n");
	dump_section_BAD_END_LINE();
	printf("---\n");
	printf("-+- BAD_HANDSHAKE_LENGTH\n");
	dump_section_BAD_HANDSHAKE_LENGTH();
	printf("---\n");
	printf("-+- BAD_HELLO_REQUEST\n");
	dump_section_BAD_HELLO_REQUEST();
	printf("---\n");
	printf("-+- BAD_IV_CHARS\n");
	dump_section_BAD_IV_CHARS();
	printf("---\n");
	printf("-+- BAD_LENGTH\n");
	dump_section_BAD_LENGTH();
	printf("---\n");
	printf("-+- BAD_MAC_DECODE\n");
	dump_section_BAD_MAC_DECODE();
	printf("---\n");
	printf("-+- BAD_MAC_LENGTH\n");
	dump_section_BAD_MAC_LENGTH();
	printf("---\n");
	printf("-+- BAD_MAGIC_NUMBER\n");
	dump_section_BAD_MAGIC_NUMBER();
	printf("---\n");
	printf("-+- BAD_MESSAGE_TYPE\n");
	dump_section_BAD_MESSAGE_TYPE();
	printf("---\n");
	printf("-+- BAD_PACKET_LENGTH\n");
	dump_section_BAD_PACKET_LENGTH();
	printf("---\n");
	printf("-+- BAD_PASSWORD_READ\n");
	dump_section_BAD_PASSWORD_READ();
	printf("---\n");
	printf("-+- BAD_PROTOCOL_VERSION_NUMBER\n");
	dump_section_BAD_PROTOCOL_VERSION_NUMBER();
	printf("---\n");
	printf("-+- BAD_PSK_IDENTITY_HINT_LENGTH\n");
	dump_section_BAD_PSK_IDENTITY_HINT_LENGTH();
	printf("---\n");
	printf("-+- BAD_RECORD_MAC\n");
	dump_section_BAD_RECORD_MAC();
	printf("---\n");
	printf("-+- BAD_RESPONSE_ARGUMENT\n");
	dump_section_BAD_RESPONSE_ARGUMENT();
	printf("---\n");
	printf("-+- BAD_RSA_DECRYPT\n");
	dump_section_BAD_RSA_DECRYPT();
	printf("---\n");
	printf("-+- BAD_RSA_ENCRYPT\n");
	dump_section_BAD_RSA_ENCRYPT();
	printf("---\n");
	printf("-+- BAD_RSA_E_LENGTH\n");
	dump_section_BAD_RSA_E_LENGTH();
	printf("---\n");
	printf("-+- BAD_RSA_MODULUS_LENGTH\n");
	dump_section_BAD_RSA_MODULUS_LENGTH();
	printf("---\n");
	printf("-+- BAD_RSA_SIGNATURE\n");
	dump_section_BAD_RSA_SIGNATURE();
	printf("---\n");
	printf("-+- BAD_SIGNATURE\n");
	dump_section_BAD_SIGNATURE();
	printf("---\n");
	printf("-+- BAD_SSL_FILETYPE\n");
	dump_section_BAD_SSL_FILETYPE();
	printf("---\n");
	printf("-+- BAD_SSL_SESSION_ID_LENGTH\n");
	dump_section_BAD_SSL_SESSION_ID_LENGTH();
	printf("---\n");
	printf("-+- BAD_STATE\n");
	dump_section_BAD_STATE();
	printf("---\n");
	printf("-+- BAD_VERSION_NUMBER\n");
	dump_section_BAD_VERSION_NUMBER();
	printf("---\n");
	printf("-+- BAD_WRITE_RETRY\n");
	dump_section_BAD_WRITE_RETRY();
	printf("---\n");
	printf("-+- BAD_X509_FILETYPE\n");
	dump_section_BAD_X509_FILETYPE();
	printf("---\n");
	printf("-+- BASE64_DECODE_ERROR\n");
	dump_section_BASE64_DECODE_ERROR();
	printf("---\n");
	printf("-+- BIO_NOT_SET\n");
	dump_section_BIO_NOT_SET();
	printf("---\n");
	printf("-+- BIO_WRITE_FAILURE\n");
	dump_section_BIO_WRITE_FAILURE();
	printf("---\n");
	printf("-+- BLOCK_CIPHER_PAD_IS_WRONG\n");
	dump_section_BLOCK_CIPHER_PAD_IS_WRONG();
	printf("---\n");
	printf("-+- BN_LIB\n");
	dump_section_BN_LIB();
	printf("---\n");
	printf("-+- CANT_CHECK_DH_KEY\n");
	dump_section_CANT_CHECK_DH_KEY();
	printf("---\n");
	printf("-+- CA_DN_LENGTH_MISMATCH\n");
	dump_section_CA_DN_LENGTH_MISMATCH();
	printf("---\n");
	printf("-+- CA_DN_TOO_LONG\n");
	dump_section_CA_DN_TOO_LONG();
	printf("---\n");
	printf("-+- CCS_RECEIVED_EARLY\n");
	dump_section_CCS_RECEIVED_EARLY();
	printf("---\n");
	printf("-+- CERTIFICATE_EXPIRED\n");
	dump_section_CERTIFICATE_EXPIRED();
	printf("---\n");
	printf("-+- CERTIFICATE_REVOKED\n");
	dump_section_CERTIFICATE_REVOKED();
	printf("---\n");
	printf("-+- CERTIFICATE_UNKNOWN\n");
	dump_section_CERTIFICATE_UNKNOWN();
	printf("---\n");
	printf("-+- CERTIFICATE_UNOBTAINABLE\n");
	dump_section_CERTIFICATE_UNOBTAINABLE();
	printf("---\n");
	printf("-+- CERTIFICATE_VERIFY_FAILED\n");
	dump_section_CERTIFICATE_VERIFY_FAILED();
	printf("---\n");
	printf("-+- CERT_ALREADY_IN_HASH_TABLE\n");
	dump_section_CERT_ALREADY_IN_HASH_TABLE();
	printf("---\n");
	printf("-+- CERT_LENGTH_MISMATCH\n");
	dump_section_CERT_LENGTH_MISMATCH();
	printf("---\n");
	printf("-+- CHALLENGE_IS_DIFFERENT\n");
	dump_section_CHALLENGE_IS_DIFFERENT();
	printf("---\n");
	printf("-+- CIPHER_CODE_WRONG_LENGTH\n");
	dump_section_CIPHER_CODE_WRONG_LENGTH();
	printf("---\n");
	printf("-+- CIPHER_IS_NULL\n");
	dump_section_CIPHER_IS_NULL();
	printf("---\n");
	printf("-+- CIPHER_OR_HASH_UNAVAILABLE\n");
	dump_section_CIPHER_OR_HASH_UNAVAILABLE();
	printf("---\n");
	printf("-+- CIPHER_TABLE_SRC_ERROR\n");
	dump_section_CIPHER_TABLE_SRC_ERROR();
	printf("---\n");
	printf("-+- CLIENTHELLO_TLSEXT\n");
	dump_section_CLIENTHELLO_TLSEXT();
	printf("---\n");
	printf("-+- CLOSE_NOTIFY\n");
	dump_section_CLOSE_NOTIFY();
	printf("---\n");
	printf("-+- COMPRESSED_LENGTH_TOO_LONG\n");
	dump_section_COMPRESSED_LENGTH_TOO_LONG();
	printf("---\n");
	printf("-+- COMPRESSION_DISABLED\n");
	dump_section_COMPRESSION_DISABLED();
	printf("---\n");
	printf("-+- COMPRESSION_FAILURE\n");
	dump_section_COMPRESSION_FAILURE();
	printf("---\n");
	printf("-+- COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE\n");
	dump_section_COMPRESSION_ID_NOT_WITHIN_PRIVATE_RANGE();
	printf("---\n");
	printf("-+- COMPRESSION_LIBRARY_ERROR\n");
	dump_section_COMPRESSION_LIBRARY_ERROR();
	printf("---\n");
	printf("-+- CONNECTION_ID_IS_DIFFERENT\n");
	dump_section_CONNECTION_ID_IS_DIFFERENT();
	printf("---\n");
	printf("-+- CONNECTION_TYPE_NOT_SET\n");
	dump_section_CONNECTION_TYPE_NOT_SET();
	printf("---\n");
	printf("-+- COOKIE_MISMATCH\n");
	dump_section_COOKIE_MISMATCH();
	printf("---\n");
	printf("-+- DATA_BETWEEN_CCS_AND_FINISHED\n");
	dump_section_DATA_BETWEEN_CCS_AND_FINISHED();
	printf("---\n");
	printf("-+- DATA_LENGTH_TOO_LONG\n");
	dump_section_DATA_LENGTH_TOO_LONG();
	printf("---\n");
	printf("-+- DECODE_ERROR\n");
	dump_section_DECODE_ERROR();
	printf("---\n");
	printf("-+- DECOMPRESSION_FAILURE\n");
	dump_section_DECOMPRESSION_FAILURE();
	printf("---\n");
	printf("-+- DECRYPTION_FAILED\n");
	dump_section_DECRYPTION_FAILED();
	printf("---\n");
	printf("-+- DECRYPTION_FAILED_OR_BAD_RECORD_MAC\n");
	dump_section_DECRYPTION_FAILED_OR_BAD_RECORD_MAC();
	printf("---\n");
	printf("-+- DECRYPT_ERROR\n");
	dump_section_DECRYPT_ERROR();
	printf("---\n");
	printf("-+- DH_PUBLIC_VALUE_LENGTH_IS_WRONG\n");
	dump_section_DH_PUBLIC_VALUE_LENGTH_IS_WRONG();
	printf("---\n");
	printf("-+- DIGEST_CHECK_FAILED\n");
	dump_section_DIGEST_CHECK_FAILED();
	printf("---\n");
	printf("-+- DTLS_MESSAGE_TOO_BIG\n");
	dump_section_DTLS_MESSAGE_TOO_BIG();
	printf("---\n");
	printf("-+- DUPLICATE_COMPRESSION_ID\n");
	dump_section_DUPLICATE_COMPRESSION_ID();
	printf("---\n");
	printf("-+- ECC_CERT_NOT_FOR_KEY_AGREEMENT\n");
	dump_section_ECC_CERT_NOT_FOR_KEY_AGREEMENT();
	printf("---\n");
	printf("-+- ECC_CERT_NOT_FOR_SIGNING\n");
	dump_section_ECC_CERT_NOT_FOR_SIGNING();
	printf("---\n");
	printf("-+- ECC_CERT_SHOULD_HAVE_RSA_SIGNATURE\n");
	dump_section_ECC_CERT_SHOULD_HAVE_RSA_SIGNATURE();
	printf("---\n");
	printf("-+- ECC_CERT_SHOULD_HAVE_SHA1_SIGNATURE\n");
	dump_section_ECC_CERT_SHOULD_HAVE_SHA1_SIGNATURE();
	printf("---\n");
	printf("-+- ECGROUP_TOO_LARGE_FOR_CIPHER\n");
	dump_section_ECGROUP_TOO_LARGE_FOR_CIPHER();
	printf("---\n");
	printf("-+- ENCRYPTED_LENGTH_TOO_LONG\n");
	dump_section_ENCRYPTED_LENGTH_TOO_LONG();
	printf("---\n");
	printf("-+- ERROR_CONVERTING_PRIVATE_KEY\n");
	dump_section_ERROR_CONVERTING_PRIVATE_KEY();
	printf("---\n");
	printf("-+- ERROR_GENERATING_TMP_RSA_KEY\n");
	dump_section_ERROR_GENERATING_TMP_RSA_KEY();
	printf("---\n");
	printf("-+- ERROR_IN_RECEIVED_CIPHER_LIST\n");
	dump_section_ERROR_IN_RECEIVED_CIPHER_LIST();
	printf("---\n");
	printf("-+- ERR_ASN1_LIB\n");
	dump_section_ERR_ASN1_LIB();
	printf("---\n");
	printf("-+- EXCESSIVE_MESSAGE_SIZE\n");
	dump_section_EXCESSIVE_MESSAGE_SIZE();
	printf("---\n");
	printf("-+- EXPECTING_PRIVATE_KEY_BLOB\n");
	dump_section_EXPECTING_PRIVATE_KEY_BLOB();
	printf("---\n");
	printf("-+- EXPECTING_PUBLIC_KEY_BLOB\n");
	dump_section_EXPECTING_PUBLIC_KEY_BLOB();
	printf("---\n");
	printf("-+- EXTRA_DATA_IN_MESSAGE\n");
	dump_section_EXTRA_DATA_IN_MESSAGE();
	printf("---\n");
	printf("-+- GOT_A_FIN_BEFORE_A_CCS\n");
	dump_section_GOT_A_FIN_BEFORE_A_CCS();
	printf("---\n");
	printf("-+- HANDSHAKE_FAILURE\n");
	dump_section_HANDSHAKE_FAILURE();
	printf("---\n");
	printf("-+- HTTPS_PROXY_REQUEST\n");
	dump_section_HTTPS_PROXY_REQUEST();
	printf("---\n");
	printf("-+- HTTP_REQUEST\n");
	dump_section_HTTP_REQUEST();
	printf("---\n");
	printf("-+- ILLEGAL_PADDING\n");
	dump_section_ILLEGAL_PADDING();
	printf("---\n");
	printf("-+- ILLEGAL_PARAMETER\n");
	dump_section_ILLEGAL_PARAMETER();
	printf("---\n");
	printf("-+- INCONSISTENT_COMPRESSION\n");
	dump_section_INCONSISTENT_COMPRESSION();
	printf("---\n");
	printf("-+- INCONSISTENT_HEADER\n");
	dump_section_INCONSISTENT_HEADER();
	printf("---\n");
	printf("-+- INSUFFICIENT_SECURITY\n");
	dump_section_INSUFFICIENT_SECURITY();
	printf("---\n");
	printf("-+- INTERNAL_ERROR\n");
	dump_section_INTERNAL_ERROR();
	printf("---\n");
	printf("-+- INVALID_CHALLENGE_LENGTH\n");
	dump_section_INVALID_CHALLENGE_LENGTH();
	printf("---\n");
	printf("-+- INVALID_COMMAND\n");
	dump_section_INVALID_COMMAND();
	printf("---\n");
	printf("-+- INVALID_COMPRESSION_ALGORITHM\n");
	dump_section_INVALID_COMPRESSION_ALGORITHM();
	printf("---\n");
	printf("-+- INVALID_DIRECTORY\n");
	dump_section_INVALID_DIRECTORY();
	printf("---\n");
	printf("-+- INVALID_FIELD_NAME\n");
	dump_section_INVALID_FIELD_NAME();
	printf("---\n");
	printf("-+- INVALID_PURPOSE\n");
	dump_section_INVALID_PURPOSE();
	printf("---\n");
	printf("-+- INVALID_STATUS_RESPONSE\n");
	dump_section_INVALID_STATUS_RESPONSE();
	printf("---\n");
	printf("-+- INVALID_TICKET_KEYS_LENGTH\n");
	dump_section_INVALID_TICKET_KEYS_LENGTH();
	printf("---\n");
	printf("-+- INVALID_TRUST\n");
	dump_section_INVALID_TRUST();
	printf("---\n");
	printf("-+- KEYBLOB_HEADER_PARSE_ERROR\n");
	dump_section_KEYBLOB_HEADER_PARSE_ERROR();
	printf("---\n");
	printf("-+- KEYBLOB_TOO_SHORT\n");
	dump_section_KEYBLOB_TOO_SHORT();
	printf("---\n");
	printf("-+- KEY_ARG_TOO_LONG\n");
	dump_section_KEY_ARG_TOO_LONG();
	printf("---\n");
	printf("-+- KEY_TYPE_MISMATCH\n");
	dump_section_KEY_TYPE_MISMATCH();
	printf("---\n");
	printf("-+- KEY_VALUES_MISMATCH\n");
	dump_section_KEY_VALUES_MISMATCH();
	printf("---\n");
	printf("-+- KRB5\n");
	dump_section_KRB5();
	printf("---\n");
	printf("-+- KRB5_C_CC_PRINC\n");
	dump_section_KRB5_C_CC_PRINC();
	printf("---\n");
	printf("-+- KRB5_C_GET_CRED\n");
	dump_section_KRB5_C_GET_CRED();
	printf("---\n");
	printf("-+- KRB5_C_INIT\n");
	dump_section_KRB5_C_INIT();
	printf("---\n");
	printf("-+- KRB5_C_MK_REQ\n");
	dump_section_KRB5_C_MK_REQ();
	printf("---\n");
	printf("-+- KRB5_S_BAD_TICKET\n");
	dump_section_KRB5_S_BAD_TICKET();
	printf("---\n");
	printf("-+- KRB5_S_INIT\n");
	dump_section_KRB5_S_INIT();
	printf("---\n");
	printf("-+- KRB5_S_RD_REQ\n");
	dump_section_KRB5_S_RD_REQ();
	printf("---\n");
	printf("-+- KRB5_S_TKT_EXPIRED\n");
	dump_section_KRB5_S_TKT_EXPIRED();
	printf("---\n");
	printf("-+- KRB5_S_TKT_NYV\n");
	dump_section_KRB5_S_TKT_NYV();
	printf("---\n");
	printf("-+- KRB5_S_TKT_SKEW\n");
	dump_section_KRB5_S_TKT_SKEW();
	printf("---\n");
	printf("-+- LENGTH_MISMATCH\n");
	dump_section_LENGTH_MISMATCH();
	printf("---\n");
	printf("-+- LENGTH_TOO_SHORT\n");
	dump_section_LENGTH_TOO_SHORT();
	printf("---\n");
	printf("-+- LIBRARY_BUG\n");
	dump_section_LIBRARY_BUG();
	printf("---\n");
	printf("-+- LIBRARY_HAS_NO_CIPHERS\n");
	dump_section_LIBRARY_HAS_NO_CIPHERS();
	printf("---\n");
	printf("-+- LOADING_CERT_DIR\n");
	dump_section_LOADING_CERT_DIR();
	printf("---\n");
	printf("-+- LOADING_DEFAULTS\n");
	dump_section_LOADING_DEFAULTS();
	printf("---\n");
	printf("-+- MESSAGE_TOO_LONG\n");
	dump_section_MESSAGE_TOO_LONG();
	printf("---\n");
	printf("-+- METHOD_NOT_SUPPORTED\n");
	dump_section_METHOD_NOT_SUPPORTED();
	printf("---\n");
	printf("-+- MISSING_DH_DSA_CERT\n");
	dump_section_MISSING_DH_DSA_CERT();
	printf("---\n");
	printf("-+- MISSING_DH_KEY\n");
	dump_section_MISSING_DH_KEY();
	printf("---\n");
	printf("-+- MISSING_DH_RSA_CERT\n");
	dump_section_MISSING_DH_RSA_CERT();
	printf("---\n");
	printf("-+- MISSING_DSA_SIGNING_CERT\n");
	dump_section_MISSING_DSA_SIGNING_CERT();
	printf("---\n");
	printf("-+- MISSING_EXPORT_TMP_DH_KEY\n");
	dump_section_MISSING_EXPORT_TMP_DH_KEY();
	printf("---\n");
	printf("-+- MISSING_EXPORT_TMP_RSA_KEY\n");
	dump_section_MISSING_EXPORT_TMP_RSA_KEY();
	printf("---\n");
	printf("-+- MISSING_RSA_CERTIFICATE\n");
	dump_section_MISSING_RSA_CERTIFICATE();
	printf("---\n");
	printf("-+- MISSING_RSA_ENCRYPTING_CERT\n");
	dump_section_MISSING_RSA_ENCRYPTING_CERT();
	printf("---\n");
	printf("-+- MISSING_RSA_SIGNING_CERT\n");
	dump_section_MISSING_RSA_SIGNING_CERT();
	printf("---\n");
	printf("-+- MISSING_TMP_DH_KEY\n");
	dump_section_MISSING_TMP_DH_KEY();
	printf("---\n");
	printf("-+- MISSING_TMP_ECDH_KEY\n");
	dump_section_MISSING_TMP_ECDH_KEY();
	printf("---\n");
	printf("-+- MISSING_TMP_RSA_KEY\n");
	dump_section_MISSING_TMP_RSA_KEY();
	printf("---\n");
	printf("-+- MISSING_TMP_RSA_PKEY\n");
	dump_section_MISSING_TMP_RSA_PKEY();
	printf("---\n");
	printf("-+- MISSING_VERIFY_MESSAGE\n");
	dump_section_MISSING_VERIFY_MESSAGE();
	printf("---\n");
	printf("-+- NON_SSLV2_INITIAL_PACKET\n");
	dump_section_NON_SSLV2_INITIAL_PACKET();
	printf("---\n");
	printf("-+- NOT_DEK_INFO\n");
	dump_section_NOT_DEK_INFO();
	printf("---\n");
	printf("-+- NOT_ENCRYPTED\n");
	dump_section_NOT_ENCRYPTED();
	printf("---\n");
	printf("-+- NOT_PROC_TYPE\n");
	dump_section_NOT_PROC_TYPE();
	printf("---\n");
	printf("-+- NO_CERTIFICATES_RETURNED\n");
	dump_section_NO_CERTIFICATES_RETURNED();
	printf("---\n");
	printf("-+- NO_CERTIFICATE_ASSIGNED\n");
	dump_section_NO_CERTIFICATE_ASSIGNED();
	printf("---\n");
	printf("-+- NO_CERTIFICATE_RETURNED\n");
	dump_section_NO_CERTIFICATE_RETURNED();
	printf("---\n");
	printf("-+- NO_CERTIFICATE_SET\n");
	dump_section_NO_CERTIFICATE_SET();
	printf("---\n");
	printf("-+- NO_CERTIFICATE_SPECIFIED\n");
	dump_section_NO_CERTIFICATE_SPECIFIED();
	printf("---\n");
	printf("-+- NO_CERT_SET_FOR_US_TO_VERIFY\n");
	dump_section_NO_CERT_SET_FOR_US_TO_VERIFY();
	printf("---\n");
	printf("-+- NO_CIPHERS_AVAILABLE\n");
	dump_section_NO_CIPHERS_AVAILABLE();
	printf("---\n");
	printf("-+- NO_CIPHERS_PASSED\n");
	dump_section_NO_CIPHERS_PASSED();
	printf("---\n");
	printf("-+- NO_CIPHERS_SPECIFIED\n");
	dump_section_NO_CIPHERS_SPECIFIED();
	printf("---\n");
	printf("-+- NO_CIPHER_LIST\n");
	dump_section_NO_CIPHER_LIST();
	printf("---\n");
	printf("-+- NO_CIPHER_MATCH\n");
	dump_section_NO_CIPHER_MATCH();
	printf("---\n");
	printf("-+- NO_CLIENT_CERT_METHOD\n");
	dump_section_NO_CLIENT_CERT_METHOD();
	printf("---\n");
	printf("-+- NO_CLIENT_CERT_RECEIVED\n");
	dump_section_NO_CLIENT_CERT_RECEIVED();
	printf("---\n");
	printf("-+- NO_COMPRESSION_SPECIFIED\n");
	dump_section_NO_COMPRESSION_SPECIFIED();
	printf("---\n");
	printf("-+- NO_GOST_CERTIFICATE_SENT_BY_PEER\n");
	dump_section_NO_GOST_CERTIFICATE_SENT_BY_PEER();
	printf("---\n");
	printf("-+- NO_METHOD_SPECIFIED\n");
	dump_section_NO_METHOD_SPECIFIED();
	printf("---\n");
	printf("-+- NO_PRIVATEKEY\n");
	dump_section_NO_PRIVATEKEY();
	printf("---\n");
	printf("-+- NO_PRIVATE_KEY_ASSIGNED\n");
	dump_section_NO_PRIVATE_KEY_ASSIGNED();
	printf("---\n");
	printf("-+- NO_PROTOCOLS_AVAILABLE\n");
	dump_section_NO_PROTOCOLS_AVAILABLE();
	printf("---\n");
	printf("-+- NO_PUBLICKEY\n");
	dump_section_NO_PUBLICKEY();
	printf("---\n");
	printf("-+- NO_RENEGOTIATION\n");
	dump_section_NO_RENEGOTIATION();
	printf("---\n");
	printf("-+- NO_REQUIRED_DIGEST\n");
	dump_section_NO_REQUIRED_DIGEST();
	printf("---\n");
	printf("-+- NO_SHARED_CIPHER\n");
	dump_section_NO_SHARED_CIPHER();
	printf("---\n");
	printf("-+- NO_START_LINE\n");
	dump_section_NO_START_LINE();
	printf("---\n");
	printf("-+- NO_VERIFY_CALLBACK\n");
	dump_section_NO_VERIFY_CALLBACK();
	printf("---\n");
	printf("-+- NULL_SSL_CTX\n");
	dump_section_NULL_SSL_CTX();
	printf("---\n");
	printf("-+- NULL_SSL_METHOD_PASSED\n");
	dump_section_NULL_SSL_METHOD_PASSED();
	printf("---\n");
	printf("-+- OLD_SESSION_CIPHER_NOT_RETURNED\n");
	dump_section_OLD_SESSION_CIPHER_NOT_RETURNED();
	printf("---\n");
	printf("-+- OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED\n");
	dump_section_OLD_SESSION_COMPRESSION_ALGORITHM_NOT_RETURNED();
	printf("---\n");
	printf("-+- ONLY_TLS_ALLOWED_IN_FIPS_MODE\n");
	dump_section_ONLY_TLS_ALLOWED_IN_FIPS_MODE();
	printf("---\n");
	printf("-+- OPAQUE_PRF_INPUT_TOO_LONG\n");
	dump_section_OPAQUE_PRF_INPUT_TOO_LONG();
	printf("---\n");
	printf("-+- PACKET_LENGTH_TOO_LONG\n");
	dump_section_PACKET_LENGTH_TOO_LONG();
	printf("---\n");
	printf("-+- PARSE_TLSEXT\n");
	dump_section_PARSE_TLSEXT();
	printf("---\n");
	printf("-+- PATH_TOO_LONG\n");
	dump_section_PATH_TOO_LONG();
	printf("---\n");
	printf("-+- PEER_DID_NOT_RETURN_A_CERTIFICATE\n");
	dump_section_PEER_DID_NOT_RETURN_A_CERTIFICATE();
	printf("---\n");
	printf("-+- PEER_ERROR\n");
	dump_section_PEER_ERROR();
	printf("---\n");
	printf("-+- PEER_ERROR_CERTIFICATE\n");
	dump_section_PEER_ERROR_CERTIFICATE();
	printf("---\n");
	printf("-+- PEER_ERROR_NO_CERTIFICATE\n");
	dump_section_PEER_ERROR_NO_CERTIFICATE();
	printf("---\n");
	printf("-+- PEER_ERROR_NO_CIPHER\n");
	dump_section_PEER_ERROR_NO_CIPHER();
	printf("---\n");
	printf("-+- PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE\n");
	dump_section_PEER_ERROR_UNSUPPORTED_CERTIFICATE_TYPE();
	printf("---\n");
	printf("-+- PEM\n");
	dump_section_PEM();
	printf("---\n");
	printf("-+- PRE_MAC_LENGTH_TOO_LONG\n");
	dump_section_PRE_MAC_LENGTH_TOO_LONG();
	printf("---\n");
	printf("-+- PROBLEMS_GETTING_PASSWORD\n");
	dump_section_PROBLEMS_GETTING_PASSWORD();
	printf("---\n");
	printf("-+- PROBLEMS_MAPPING_CIPHER_FUNCTIONS\n");
	dump_section_PROBLEMS_MAPPING_CIPHER_FUNCTIONS();
	printf("---\n");
	printf("-+- PROTOCOL_IS_SHUTDOWN\n");
	dump_section_PROTOCOL_IS_SHUTDOWN();
	printf("---\n");
	printf("-+- PROTOCOL_VERSION\n");
	dump_section_PROTOCOL_VERSION();
	printf("---\n");
	printf("-+- PSK_IDENTITY_NOT_FOUND\n");
	dump_section_PSK_IDENTITY_NOT_FOUND();
	printf("---\n");
	printf("-+- PSK_NO_CLIENT_CB\n");
	dump_section_PSK_NO_CLIENT_CB();
	printf("---\n");
	printf("-+- PSK_NO_SERVER_CB\n");
	dump_section_PSK_NO_SERVER_CB();
	printf("---\n");
	printf("-+- PUBLIC_KEY_DECODE_ERROR\n");
	dump_section_PUBLIC_KEY_DECODE_ERROR();
	printf("---\n");
	printf("-+- PUBLIC_KEY_ENCODE_ERROR\n");
	dump_section_PUBLIC_KEY_ENCODE_ERROR();
	printf("---\n");
	printf("-+- PUBLIC_KEY_ENCRYPT_ERROR\n");
	dump_section_PUBLIC_KEY_ENCRYPT_ERROR();
	printf("---\n");
	printf("-+- PUBLIC_KEY_IS_NOT_RSA\n");
	dump_section_PUBLIC_KEY_IS_NOT_RSA();
	printf("---\n");
	printf("-+- PUBLIC_KEY_NOT_RSA\n");
	dump_section_PUBLIC_KEY_NOT_RSA();
	printf("---\n");
	printf("-+- PUBLIC_KEY_NO_RSA\n");
	dump_section_PUBLIC_KEY_NO_RSA();
	printf("---\n");
	printf("-+- PVK_DATA_TOO_SHORT\n");
	dump_section_PVK_DATA_TOO_SHORT();
	printf("---\n");
	printf("-+- PVK_TOO_SHORT\n");
	dump_section_PVK_TOO_SHORT();
	printf("---\n");
	printf("-+- READ_BIO_NOT_SET\n");
	dump_section_READ_BIO_NOT_SET();
	printf("---\n");
	printf("-+- READ_KEY\n");
	dump_section_READ_KEY();
	printf("---\n");
	printf("-+- READ_TIMEOUT_EXPIRED\n");
	dump_section_READ_TIMEOUT_EXPIRED();
	printf("---\n");
	printf("-+- READ_WRONG_PACKET_TYPE\n");
	dump_section_READ_WRONG_PACKET_TYPE();
	printf("---\n");
	printf("-+- RECORD_LENGTH_MISMATCH\n");
	dump_section_RECORD_LENGTH_MISMATCH();
	printf("---\n");
	printf("-+- RECORD_OVERFLOW\n");
	dump_section_RECORD_OVERFLOW();
	printf("---\n");
	printf("-+- RECORD_TOO_LARGE\n");
	dump_section_RECORD_TOO_LARGE();
	printf("---\n");
	printf("-+- RECORD_TOO_SMALL\n");
	dump_section_RECORD_TOO_SMALL();
	printf("---\n");
	printf("-+- RENEGOTIATE_EXT_TOO_LONG\n");
	dump_section_RENEGOTIATE_EXT_TOO_LONG();
	printf("---\n");
	printf("-+- RENEGOTIATION_ENCODING_ERR\n");
	dump_section_RENEGOTIATION_ENCODING_ERR();
	printf("---\n");
	printf("-+- RENEGOTIATION_MISMATCH\n");
	dump_section_RENEGOTIATION_MISMATCH();
	printf("---\n");
	printf("-+- REQUIRED_CIPHER_MISSING\n");
	dump_section_REQUIRED_CIPHER_MISSING();
	printf("---\n");
	printf("-+- REQUIRED_COMPRESSSION_ALGORITHM_MISSING\n");
	dump_section_REQUIRED_COMPRESSSION_ALGORITHM_MISSING();
	printf("---\n");
	printf("-+- REUSE_CERT_LENGTH_NOT_ZERO\n");
	dump_section_REUSE_CERT_LENGTH_NOT_ZERO();
	printf("---\n");
	printf("-+- REUSE_CERT_TYPE_NOT_ZERO\n");
	dump_section_REUSE_CERT_TYPE_NOT_ZERO();
	printf("---\n");
	printf("-+- REUSE_CIPHER_LIST_NOT_ZERO\n");
	dump_section_REUSE_CIPHER_LIST_NOT_ZERO();
	printf("---\n");
	printf("-+- SCSV_RECEIVED_WHEN_RENEGOTIATING\n");
	dump_section_SCSV_RECEIVED_WHEN_RENEGOTIATING();
	printf("---\n");
	printf("-+- SERVERHELLO_TLSEXT\n");
	dump_section_SERVERHELLO_TLSEXT();
	printf("---\n");
	printf("-+- SESSION_ID_CONTEXT_UNINITIALIZED\n");
	dump_section_SESSION_ID_CONTEXT_UNINITIALIZED();
	printf("---\n");
	printf("-+- SHORT_HEADER\n");
	dump_section_SHORT_HEADER();
	printf("---\n");
	printf("-+- SHORT_READ\n");
	dump_section_SHORT_READ();
	printf("---\n");
	printf("-+- SHOULD_RETRY\n");
	dump_section_SHOULD_RETRY();
	printf("---\n");
	printf("-+- SIGNATURE_FOR_NON_SIGNING_CERTIFICATE\n");
	dump_section_SIGNATURE_FOR_NON_SIGNING_CERTIFICATE();
	printf("---\n");
	printf("-+- SSL\n");
	dump_section_SSL();
	printf("---\n");
	printf("-+- SSL23_DOING_SESSION_ID_REUSE\n");
	dump_section_SSL23_DOING_SESSION_ID_REUSE();
	printf("---\n");
	printf("-+- SSL2_CONNECTION_ID_TOO_LONG\n");
	dump_section_SSL2_CONNECTION_ID_TOO_LONG();
	printf("---\n");
	printf("-+- SSL3_EXT_INVALID_ECPOINTFORMAT\n");
	dump_section_SSL3_EXT_INVALID_ECPOINTFORMAT();
	printf("---\n");
	printf("-+- SSL3_EXT_INVALID_SERVERNAME\n");
	dump_section_SSL3_EXT_INVALID_SERVERNAME();
	printf("---\n");
	printf("-+- SSL3_EXT_INVALID_SERVERNAME_TYPE\n");
	dump_section_SSL3_EXT_INVALID_SERVERNAME_TYPE();
	printf("---\n");
	printf("-+- SSL3_SESSION_ID_TOO_LONG\n");
	dump_section_SSL3_SESSION_ID_TOO_LONG();
	printf("---\n");
	printf("-+- SSL3_SESSION_ID_TOO_SHORT\n");
	dump_section_SSL3_SESSION_ID_TOO_SHORT();
	printf("---\n");
	printf("-+- SSLV3_ALERT_BAD_CERTIFICATE\n");
	dump_section_SSLV3_ALERT_BAD_CERTIFICATE();
	printf("---\n");
	printf("-+- SSLV3_ALERT_BAD_RECORD_MAC\n");
	dump_section_SSLV3_ALERT_BAD_RECORD_MAC();
	printf("---\n");
	printf("-+- SSLV3_ALERT_CERTIFICATE_EXPIRED\n");
	dump_section_SSLV3_ALERT_CERTIFICATE_EXPIRED();
	printf("---\n");
	printf("-+- SSLV3_ALERT_CERTIFICATE_REVOKED\n");
	dump_section_SSLV3_ALERT_CERTIFICATE_REVOKED();
	printf("---\n");
	printf("-+- SSLV3_ALERT_CERTIFICATE_UNKNOWN\n");
	dump_section_SSLV3_ALERT_CERTIFICATE_UNKNOWN();
	printf("---\n");
	printf("-+- SSLV3_ALERT_DECOMPRESSION_FAILURE\n");
	dump_section_SSLV3_ALERT_DECOMPRESSION_FAILURE();
	printf("---\n");
	printf("-+- SSLV3_ALERT_HANDSHAKE_FAILURE\n");
	dump_section_SSLV3_ALERT_HANDSHAKE_FAILURE();
	printf("---\n");
	printf("-+- SSLV3_ALERT_ILLEGAL_PARAMETER\n");
	dump_section_SSLV3_ALERT_ILLEGAL_PARAMETER();
	printf("---\n");
	printf("-+- SSLV3_ALERT_NO_CERTIFICATE\n");
	dump_section_SSLV3_ALERT_NO_CERTIFICATE();
	printf("---\n");
	printf("-+- SSLV3_ALERT_UNEXPECTED_MESSAGE\n");
	dump_section_SSLV3_ALERT_UNEXPECTED_MESSAGE();
	printf("---\n");
	printf("-+- SSLV3_ALERT_UNSUPPORTED_CERTIFICATE\n");
	dump_section_SSLV3_ALERT_UNSUPPORTED_CERTIFICATE();
	printf("---\n");
	printf("-+- SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION\n");
	dump_section_SSL_CTX_HAS_NO_DEFAULT_SSL_VERSION();
	printf("---\n");
	printf("-+- SSL_HANDSHAKE_FAILURE\n");
	dump_section_SSL_HANDSHAKE_FAILURE();
	printf("---\n");
	printf("-+- SSL_LIBRARY_HAS_NO_CIPHERS\n");
	dump_section_SSL_LIBRARY_HAS_NO_CIPHERS();
	printf("---\n");
	printf("-+- SSL_SESSION_ID_CALLBACK_FAILED\n");
	dump_section_SSL_SESSION_ID_CALLBACK_FAILED();
	printf("---\n");
	printf("-+- SSL_SESSION_ID_CONFLICT\n");
	dump_section_SSL_SESSION_ID_CONFLICT();
	printf("---\n");
	printf("-+- SSL_SESSION_ID_CONTEXT_TOO_LONG\n");
	dump_section_SSL_SESSION_ID_CONTEXT_TOO_LONG();
	printf("---\n");
	printf("-+- SSL_SESSION_ID_HAS_BAD_LENGTH\n");
	dump_section_SSL_SESSION_ID_HAS_BAD_LENGTH();
	printf("---\n");
	printf("-+- SSL_SESSION_ID_IS_DIFFERENT\n");
	dump_section_SSL_SESSION_ID_IS_DIFFERENT();
	printf("---\n");
	printf("-+- TLSV1_ALERT_ACCESS_DENIED\n");
	dump_section_TLSV1_ALERT_ACCESS_DENIED();
	printf("---\n");
	printf("-+- TLSV1_ALERT_DECODE_ERROR\n");
	dump_section_TLSV1_ALERT_DECODE_ERROR();
	printf("---\n");
	printf("-+- TLSV1_ALERT_DECRYPTION_FAILED\n");
	dump_section_TLSV1_ALERT_DECRYPTION_FAILED();
	printf("---\n");
	printf("-+- TLSV1_ALERT_DECRYPT_ERROR\n");
	dump_section_TLSV1_ALERT_DECRYPT_ERROR();
	printf("---\n");
	printf("-+- TLSV1_ALERT_EXPORT_RESTRICTION\n");
	dump_section_TLSV1_ALERT_EXPORT_RESTRICTION();
	printf("---\n");
	printf("-+- TLSV1_ALERT_INSUFFICIENT_SECURITY\n");
	dump_section_TLSV1_ALERT_INSUFFICIENT_SECURITY();
	printf("---\n");
	printf("-+- TLSV1_ALERT_INTERNAL_ERROR\n");
	dump_section_TLSV1_ALERT_INTERNAL_ERROR();
	printf("---\n");
	printf("-+- TLSV1_ALERT_NO_RENEGOTIATION\n");
	dump_section_TLSV1_ALERT_NO_RENEGOTIATION();
	printf("---\n");
	printf("-+- TLSV1_ALERT_PROTOCOL_VERSION\n");
	dump_section_TLSV1_ALERT_PROTOCOL_VERSION();
	printf("---\n");
	printf("-+- TLSV1_ALERT_RECORD_OVERFLOW\n");
	dump_section_TLSV1_ALERT_RECORD_OVERFLOW();
	printf("---\n");
	printf("-+- TLSV1_ALERT_UNKNOWN_CA\n");
	dump_section_TLSV1_ALERT_UNKNOWN_CA();
	printf("---\n");
	printf("-+- TLSV1_ALERT_USER_CANCELLED\n");
	dump_section_TLSV1_ALERT_USER_CANCELLED();
	printf("---\n");
	printf("-+- TLSV1_BAD_CERTIFICATE_HASH_VALUE\n");
	dump_section_TLSV1_BAD_CERTIFICATE_HASH_VALUE();
	printf("---\n");
	printf("-+- TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE\n");
	dump_section_TLSV1_BAD_CERTIFICATE_STATUS_RESPONSE();
	printf("---\n");
	printf("-+- TLSV1_CERTIFICATE_UNOBTAINABLE\n");
	dump_section_TLSV1_CERTIFICATE_UNOBTAINABLE();
	printf("---\n");
	printf("-+- TLSV1_UNRECOGNIZED_NAME\n");
	dump_section_TLSV1_UNRECOGNIZED_NAME();
	printf("---\n");
	printf("-+- TLSV1_UNSUPPORTED_EXTENSION\n");
	dump_section_TLSV1_UNSUPPORTED_EXTENSION();
	printf("---\n");
	printf("-+- TLS_CLIENT_CERT_REQ_WITH_ANON_CIPHER\n");
	dump_section_TLS_CLIENT_CERT_REQ_WITH_ANON_CIPHER();
	printf("---\n");
	printf("-+- TLS_INVALID_ECPOINTFORMAT_LIST\n");
	dump_section_TLS_INVALID_ECPOINTFORMAT_LIST();
	printf("---\n");
	printf("-+- TLS_PEER_DID_NOT_RESPOND_WITH_CERTIFICATE_LIST\n");
	dump_section_TLS_PEER_DID_NOT_RESPOND_WITH_CERTIFICATE_LIST();
	printf("---\n");
	printf("-+- TLS_RSA_ENCRYPTED_VALUE_LENGTH_IS_WRONG\n");
	dump_section_TLS_RSA_ENCRYPTED_VALUE_LENGTH_IS_WRONG();
	printf("---\n");
	printf("-+- TRIED_TO_USE_UNSUPPORTED_CIPHER\n");
	dump_section_TRIED_TO_USE_UNSUPPORTED_CIPHER();
	printf("---\n");
	printf("-+- UNABLE_TO_DECODE_DH_CERTS\n");
	dump_section_UNABLE_TO_DECODE_DH_CERTS();
	printf("---\n");
	printf("-+- UNABLE_TO_DECODE_ECDH_CERTS\n");
	dump_section_UNABLE_TO_DECODE_ECDH_CERTS();
	printf("---\n");
	printf("-+- UNABLE_TO_EXTRACT_PUBLIC_KEY\n");
	dump_section_UNABLE_TO_EXTRACT_PUBLIC_KEY();
	printf("---\n");
	printf("-+- UNABLE_TO_FIND_DH_PARAMETERS\n");
	dump_section_UNABLE_TO_FIND_DH_PARAMETERS();
	printf("---\n");
	printf("-+- UNABLE_TO_FIND_ECDH_PARAMETERS\n");
	dump_section_UNABLE_TO_FIND_ECDH_PARAMETERS();
	printf("---\n");
	printf("-+- UNABLE_TO_FIND_PARAMETERS_IN_CHAIN\n");
	dump_section_UNABLE_TO_FIND_PARAMETERS_IN_CHAIN();
	printf("---\n");
	printf("-+- UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS\n");
	dump_section_UNABLE_TO_FIND_PUBLIC_KEY_PARAMETERS();
	printf("---\n");
	printf("-+- UNABLE_TO_FIND_SSL_METHOD\n");
	dump_section_UNABLE_TO_FIND_SSL_METHOD();
	printf("---\n");
	printf("-+- UNABLE_TO_GET_CERTS_PUBLIC_KEY\n");
	dump_section_UNABLE_TO_GET_CERTS_PUBLIC_KEY();
	printf("---\n");
	printf("-+- UNABLE_TO_LOAD_SSL2_MD5_ROUTINES\n");
	dump_section_UNABLE_TO_LOAD_SSL2_MD5_ROUTINES();
	printf("---\n");
	printf("-+- UNABLE_TO_LOAD_SSL3_MD5_ROUTINES\n");
	dump_section_UNABLE_TO_LOAD_SSL3_MD5_ROUTINES();
	printf("---\n");
	printf("-+- UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES\n");
	dump_section_UNABLE_TO_LOAD_SSL3_SHA1_ROUTINES();
	printf("---\n");
	printf("-+- UNEXPECTED_MESSAGE\n");
	dump_section_UNEXPECTED_MESSAGE();
	printf("---\n");
	printf("-+- UNEXPECTED_RECORD\n");
	dump_section_UNEXPECTED_RECORD();
	printf("---\n");
	printf("-+- UNINITIALIZED\n");
	dump_section_UNINITIALIZED();
	printf("---\n");
	printf("-+- UNKNOWN_ALERT_TYPE\n");
	dump_section_UNKNOWN_ALERT_TYPE();
	printf("---\n");
	printf("-+- UNKNOWN_CA\n");
	dump_section_UNKNOWN_CA();
	printf("---\n");
	printf("-+- UNKNOWN_CERTIFICATE_TYPE\n");
	dump_section_UNKNOWN_CERTIFICATE_TYPE();
	printf("---\n");
	printf("-+- UNKNOWN_CIPHER_RETURNED\n");
	dump_section_UNKNOWN_CIPHER_RETURNED();
	printf("---\n");
	printf("-+- UNKNOWN_CIPHER_TYPE\n");
	dump_section_UNKNOWN_CIPHER_TYPE();
	printf("---\n");
	printf("-+- UNKNOWN_KEY_EXCHANGE_TYPE\n");
	dump_section_UNKNOWN_KEY_EXCHANGE_TYPE();
	printf("---\n");
	printf("-+- UNKNOWN_KEY_TYPE\n");
	dump_section_UNKNOWN_KEY_TYPE();
	printf("---\n");
	printf("-+- UNKNOWN_NID\n");
	dump_section_UNKNOWN_NID();
	printf("---\n");
	printf("-+- UNKNOWN_PKEY_TYPE\n");
	dump_section_UNKNOWN_PKEY_TYPE();
	printf("---\n");
	printf("-+- UNKNOWN_PROTOCOL\n");
	dump_section_UNKNOWN_PROTOCOL();
	printf("---\n");
	printf("-+- UNKNOWN_PSK_IDENTITY\n");
	dump_section_UNKNOWN_PSK_IDENTITY();
	printf("---\n");
	printf("-+- UNKNOWN_PURPOSE_ID\n");
	dump_section_UNKNOWN_PURPOSE_ID();
	printf("---\n");
	printf("-+- UNKNOWN_REMOTE_ERROR_TYPE\n");
	dump_section_UNKNOWN_REMOTE_ERROR_TYPE();
	printf("---\n");
	printf("-+- UNKNOWN_SSL_VERSION\n");
	dump_section_UNKNOWN_SSL_VERSION();
	printf("---\n");
	printf("-+- UNKNOWN_STATE\n");
	dump_section_UNKNOWN_STATE();
	printf("---\n");
	printf("-+- UNKNOWN_TRUST_ID\n");
	dump_section_UNKNOWN_TRUST_ID();
	printf("---\n");
	printf("-+- UNRECOGNIZED_NAME\n");
	dump_section_UNRECOGNIZED_NAME();
	printf("---\n");
	printf("-+- UNSAFE_LEGACY_RENEGOTIATION_DISABLED\n");
	dump_section_UNSAFE_LEGACY_RENEGOTIATION_DISABLED();
	printf("---\n");
	printf("-+- UNSUPPORTED_ALGORITHM\n");
	dump_section_UNSUPPORTED_ALGORITHM();
	printf("---\n");
	printf("-+- UNSUPPORTED_CERTIFICATE\n");
	dump_section_UNSUPPORTED_CERTIFICATE();
	printf("---\n");
	printf("-+- UNSUPPORTED_CIPHER\n");
	dump_section_UNSUPPORTED_CIPHER();
	printf("---\n");
	printf("-+- UNSUPPORTED_COMPRESSION_ALGORITHM\n");
	dump_section_UNSUPPORTED_COMPRESSION_ALGORITHM();
	printf("---\n");
	printf("-+- UNSUPPORTED_DIGEST_TYPE\n");
	dump_section_UNSUPPORTED_DIGEST_TYPE();
	printf("---\n");
	printf("-+- UNSUPPORTED_ELLIPTIC_CURVE\n");
	dump_section_UNSUPPORTED_ELLIPTIC_CURVE();
	printf("---\n");
	printf("-+- UNSUPPORTED_ENCRYPTION\n");
	dump_section_UNSUPPORTED_ENCRYPTION();
	printf("---\n");
	printf("-+- UNSUPPORTED_EXTENSION\n");
	dump_section_UNSUPPORTED_EXTENSION();
	printf("---\n");
	printf("-+- UNSUPPORTED_KEY_COMPONENTS\n");
	dump_section_UNSUPPORTED_KEY_COMPONENTS();
	printf("---\n");
	printf("-+- UNSUPPORTED_PROTOCOL\n");
	dump_section_UNSUPPORTED_PROTOCOL();
	printf("---\n");
	printf("-+- UNSUPPORTED_SSL_VERSION\n");
	dump_section_UNSUPPORTED_SSL_VERSION();
	printf("---\n");
	printf("-+- UNSUPPORTED_STATUS_TYPE\n");
	dump_section_UNSUPPORTED_STATUS_TYPE();
	printf("---\n");
	printf("-+- USER_CANCELLED\n");
	dump_section_USER_CANCELLED();
	printf("---\n");
	printf("-+- WRITE_BIO_NOT_SET\n");
	dump_section_WRITE_BIO_NOT_SET();
	printf("---\n");
	printf("-+- WRONG_CIPHER_RETURNED\n");
	dump_section_WRONG_CIPHER_RETURNED();
	printf("---\n");
	printf("-+- WRONG_LOOKUP_TYPE\n");
	dump_section_WRONG_LOOKUP_TYPE();
	printf("---\n");
	printf("-+- WRONG_MESSAGE_TYPE\n");
	dump_section_WRONG_MESSAGE_TYPE();
	printf("---\n");
	printf("-+- WRONG_NUMBER_OF_KEY_BITS\n");
	dump_section_WRONG_NUMBER_OF_KEY_BITS();
	printf("---\n");
	printf("-+- WRONG_SIGNATURE_LENGTH\n");
	dump_section_WRONG_SIGNATURE_LENGTH();
	printf("---\n");
	printf("-+- WRONG_SIGNATURE_SIZE\n");
	dump_section_WRONG_SIGNATURE_SIZE();
	printf("---\n");
	printf("-+- WRONG_SSL_VERSION\n");
	dump_section_WRONG_SSL_VERSION();
	printf("---\n");
	printf("-+- WRONG_TYPE\n");
	dump_section_WRONG_TYPE();
	printf("---\n");
	printf("-+- WRONG_VERSION_NUMBER\n");
	dump_section_WRONG_VERSION_NUMBER();
	printf("---\n");
	printf("-+- X509\n");
	dump_section_X509();
	printf("---\n");
	printf("-+- X509_LIB\n");
	dump_section_X509_LIB();
	printf("---\n");
	printf("-+- X509_VERIFICATION_SETUP_PROBLEMS\n");
	dump_section_X509_VERIFICATION_SETUP_PROBLEMS();
	printf("---\n");
	return 0;
}
